(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    356242,      13282]*)
(*NotebookOutlinePosition[    357343,      13316]*)
(*  CellTagsIndexPosition[    357299,      13312]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\

Signal Propagation in a Cell Layer 
modeled by a 2L-system
\
\>", "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Christian Jacob, jacob@cpsc.ucalgary.ca \[Dash] April 1997 / \
February 2001 \[Copyright]\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Preparations \[Ellipsis]", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \($basicDirectory = \
\[IndentingNewLine]SetDirectory[\[IndentingNewLine]ToFileName[{\
EvolvicaDirectory, "\<Chapters\>", \
\[IndentingNewLine]"\<09-DevelopmentalPrograms\>", "\<L-Systems\>", \
"\<Packages\>"}]]\)], "Input",
  InitializationCell->True],

Cell["Get[\"kLSystems.m\"]", "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["2L-System for Simulated Signal Propagation", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"\naxiom1 = \nAXIOM[T,a,a,a,a,a,a,a,a,b,a,a,a,a,a,a,b,a,a,a,a,a,b,a,a,a,T];\n\
\nlrules1 =\n  LRULES[ \n    LRule[LEFT[ c ], PRED[ a ], RIGHT[   ], SUCC[ c \
] ],\n    LRule[LEFT[   ], PRED[ c ], RIGHT[ a ], SUCC[ a ] ],\n    \
LRule[LEFT[   ], PRED[ a ], RIGHT[ d ], SUCC[ d ] ],\n    LRule[LEFT[ a ], \
PRED[ d ], RIGHT[   ], SUCC[ a ] ],\n    LRule[LEFT[ c ], PRED[ a ], RIGHT[ d \
], SUCC[ b ] ],\n    LRule[LEFT[   ], PRED[ a ], RIGHT[ b ], SUCC[ d ] ],\n   \
 LRule[LEFT[ b ], PRED[ a ], RIGHT[   ], SUCC[ c ] ],\n    LRule[LEFT[ a ], \
PRED[ b ], RIGHT[ a ], SUCC[ a ] ],\n    LRule[LEFT[   ], PRED[ c ], RIGHT[ d \
], SUCC[ d ] ],\n    LRule[LEFT[ c ], PRED[ d ], RIGHT[   ], SUCC[ c ] ],\n   \
 LRule[LEFT[ T ], PRED[ d ], RIGHT[   ], SUCC[ c ] ],\n    LRule[LEFT[   ], \
PRED[ c ], RIGHT[ T ], SUCC[ d ] ],\n    LRule[LEFT[ c ], PRED[ T ], RIGHT[ c \
], SUCC[ a ] ],\n    LRule[LEFT[ d ], PRED[ T ], RIGHT[ d ], SUCC[ a ] ]\n  \
];\n  \nFormat[AXIOM[x___]] := {x};\n"], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"runKLSystem[LSystem[axiom1, lrules1], 1] // TableForm"], "Input",
  AspectRatioFixed->True],

Cell[OutputFormData[
"\<\
TableForm[{AXIOM[T, a, a, a, a, a, a, a, a, b, a, a, a, a, a, a, 
 
    b, a, a, a, a, a, b, a, a, a, T], 
 
   {AXIOM[T, a, a, a, a, a, a, a, d, a, c, a, a, a, a, d, a, c, 
 
     a, a, a, d, a, c, a, a, T]}, 
 
   {AXIOM[T, a, a, a, a, a, a, d, a, a, a, c, a, a, d, a, a, a, 
 
     c, a, d, a, a, a, c, a, T]}, 
 
   {AXIOM[T, a, a, a, a, a, d, a, a, a, a, a, c, d, a, a, a, a, 
 
     a, c, a, a, a, a, a, c, T]}, 
 
   {AXIOM[T, a, a, a, a, d, a, a, a, a, a, a, d, c, a, a, a, a, 
 
     a, a, c, a, a, a, a, d, T]}, 
 
   {AXIOM[T, a, a, a, d, a, a, a, a, a, a, d, a, a, c, a, a, a, 
 
     a, a, a, c, a, a, d, a, T]}, 
 
   {AXIOM[T, a, a, d, a, a, a, a, a, a, d, a, a, a, a, c, a, a, 
 
     a, a, a, a, c, d, a, a, T]}}]\
\>", 
"\<\
{T, a, a, a, a, a, a, a, a, b, a, a, a, a, a, a, b, a, a, a, a, 
 
  a, b, a, a, a, T}

{T, a, a, a, a, a, a, a, d, a, c, a, a, a, a, d, a, c, a, a, a, 
 
   d, a, c, a, a, T}

{T, a, a, a, a, a, a, d, a, a, a, c, a, a, d, a, a, a, c, a, d, 
 
   a, a, a, c, a, T}

{T, a, a, a, a, a, d, a, a, a, a, a, c, d, a, a, a, a, a, c, a, 
 
   a, a, a, a, c, T}

{T, a, a, a, a, d, a, a, a, a, a, a, d, c, a, a, a, a, a, a, c, 
 
   a, a, a, a, d, T}

{T, a, a, a, d, a, a, a, a, a, a, d, a, a, c, a, a, a, a, a, a, 
 
   c, a, a, d, a, T}

{T, a, a, d, a, a, a, a, a, a, d, a, a, a, a, c, a, a, a, a, a, 
 
   a, c, d, a, a, T}\
\>"], "Output",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Animation"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .05 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0302343 0.025 0.047619 [
[ 0 0 0 0 ]
[ 1 .05 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .05 L
0 .05 L
closepath
clip
newpath
p
p
.9 g
.001 w
.05404 .025 m
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.08428 .025 m
matrix currentmatrix
.01512 .02381 scale
5.57512 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
5.57512 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.12963 .025 m
matrix currentmatrix
.03023 .02381 scale
4.28751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
4.28751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.17498 .025 m
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.20522 .025 m
matrix currentmatrix
.01512 .02381 scale
13.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
13.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.23545 .025 m
matrix currentmatrix
.01512 .02381 scale
15.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
15.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.26568 .025 m
matrix currentmatrix
.01512 .02381 scale
17.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
17.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.29592 .025 m
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.32615 .025 m
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.3715 .025 m
matrix currentmatrix
.03023 .02381 scale
12.2874 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
12.2874 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.41686 .025 m
matrix currentmatrix
.01512 .02381 scale
27.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
27.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.44709 .025 m
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.47732 .025 m
matrix currentmatrix
.01512 .02381 scale
31.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
31.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.50756 .025 m
matrix currentmatrix
.01512 .02381 scale
33.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
33.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.55291 .025 m
matrix currentmatrix
.03023 .02381 scale
18.2875 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
18.2875 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.61338 .025 m
matrix currentmatrix
.03023 .02381 scale
20.2875 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
20.2875 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.65873 .025 m
matrix currentmatrix
.01512 .02381 scale
43.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
43.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.68896 .025 m
matrix currentmatrix
.01512 .02381 scale
45.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
45.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.7192 .025 m
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.74943 .025 m
matrix currentmatrix
.01512 .02381 scale
49.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
49.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.77967 .025 m
matrix currentmatrix
.01512 .02381 scale
51.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
51.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.82502 .025 m
matrix currentmatrix
.03023 .02381 scale
27.2875 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
27.2875 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.88549 .025 m
matrix currentmatrix
.03023 .02381 scale
29.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
29.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.93084 .025 m
matrix currentmatrix
.01512 .02381 scale
61.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
61.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.96107 .025 m
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{458, 32},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007:000080P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5H/1JX00=d81_l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000e5D0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0b`000?l0b`000?l0b`000?l0b`000?l0
b`0001P000==CTd02`000de>C@0?0006CDi=CTe>4@0014i=CTd:0003CTe>00/000=>CDh02P0014e>
CDh:0004CDi=CPX000A=CTe>3`001Ti=CTe>CA4000==CTd02P0014i=CTd:0004CTe>C@X000A>CDi=
3P001di=CTe>CDh05@001di=CTe>CDh0400014e>CDh:0004CDi=CPX000==CTd02`000de>C@0:0004
CTe>C@l000I=CTe>CDhE0007CTe>CDi=CP0@0004CDi=CPX000A=CTe>400001H00Th3aP03CP0000D0
0dh3aP03CP0000T00dh6P`E>2P02CPC600=>00001@02CP?600=>00001P02CP?600=>00001@02CPC6
00=>00001@02CPC600=>00001@02CPC600=>00002@03CPJ31Dh900=>0lH00dh00005009>1<H00dh0
0005009>1<H00dh00005009>1<H00dh00009009>1iD5CPd00dh7P`A>2P02CPC600=>00001@02CPC6
00=>00001@02CP?600=>00001@03CP?600=>00001@02CPC600=>00002@03CPJE1Dh>009>1h<5CPT0
0Th4aP03CP0000D00Th4aP03CP0000d0000E0007C]K6e/KFCP060008CLKFa]K6eTh9000ACTf3Th>C
Pi>3Th>CPi>3Tdh0200024g6e/KFa]I>1P0024g6e/KFa]I>1P001dg6e/KFaTd01P0024kFa]K6e/I=
1P0024kFa]K6e/I=1P0024kFa]K6e/I=20004Ti=CY>3Th>CPi>3Th>CPi>3C@L000Q=a]K6e/KFCPH0
00Q=a]K6e/KFCPH000Q=a]K6e/KFCPH000Q=a]K6e/KFCPP000==CTd03YD00dh00008000ACDjCPi>3
Th>CPi>3Th>CPdd0200024kFa]K6e/I=1P0024kFa]K6e/I=1P0024kFa]K6e/I=1@0024g6e/KFa]I>
1P0024g6e/KFa]I>2@000di=U@0=U@03CP0000P0019=CTf3Th>CPi>3Th>CPi>3Tdh70008C]K6e/KF
aTd60008C]K6e/KFaTd?000050000dk6aP05aP03CP00008000=>a/H01/H00dh00004009>4H<00dh0
00040003C/K600K600=>00000P000dk6aP06aP03CP00008000=>a/H01LH00dh000020003C/K600K6
00=>00000P000dk6aP06aP03CP00008000=>a/H01/H00dh00003009>4X<00dh000030003C/K600K6
00=>00000P000dk6aP06aP03CP00008000=>a/H01/H00dh000020003C/K600K600=>00000`02CQ:E
00=>00001@02CQ6300=>000010000dk6aP06aP03CP00008000=>a/H01/H00dh000020003C/K600K6
00E>0000CP08aP03CP00008000=>a/H01/H00dh0000300=>4ID00dh00005009>4X<00dh000030003
C/K600K600=>00000P000dk6aP06aP03CP0000`0000C000;C]K6e/KFa]K6eTh00`002dkFa]K6e/KF
a]I>00@001I=Pi>3Th>CPi>3Th>CPi>3Th>CPi=>100034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6
eTh2000;CLKFa]K6e/KFaTd00P0034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd2000<C]K6e/KF
a]K6e/I=0`005df3Th>CPi>3Th>CPi>3Th>CPi>3Th==00@000]>e/KFa]K6e/KFCP02000<CLKFa]K6
e/KFa]I>0P0034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6eTh30003CYFE01>E00=>00000`005TjC
Pi>3Th>CPi>3Th>CPi>3Th>CPdd4000<C]K6e/KFa]K6e/I=0P0034kFa]K6e/KFa]K6C@8000a>e/KF
a]K6e/KFaTd2000;C]K6e/KFa]K6eTh00P0034g6e/KFa]K6e/KFCP<000=>UID04iD00dh00003000G
CY>3Th>CPi>3Th>CPi>3Th>CPi>3Tdh00`0034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd=0000
4`000dk6aP07aP05CP0004h02LH01Dh0001>01J300E>0000CP0:aP04CP00CP[600A>001>2LH014h0
04h:aP04CP00CP[600A>001>2/H01Dh0001>01F300=>00000P000dk6aP07aP04CP00CP[600A>001>
2/H014h004h:aP05CP0004h05ID00dh000020003CX>301B300E>0000CP0:aP04CP00CP[600A>001>
2/H014h004h9aP04CP00CP[600E>0000CP0FU@03CP00008000=>Ph<04h<01Dh0001>00[600A>001>
2/H00dh0000;00004P00Y4g6e/KFa]K6e/KFaTd0CLKFa]K6e/KFa]K6C@1=Pi>3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CCP1>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFCP1>e/KFa]K6
e/KFa]I>04kFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCP1>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>
0P00>Dg6e/KFa]K6e/KFaTd0CLKFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTd0
C@0GU@1UC@00CY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdd0CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6
e/I=04g6e/KFa]K6e/KFaTd0CLKFa]K6e/KFa]K6C@1=a]K6e/KFa]K6e/I=04d069D074h004f3Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CPdd2000KC]K6e/KFa]K6e/KFCP1>e/KFa]K6e/KFa]I>00`0000B0003
C/K600W600=>04h02lH00dh0CP0HP`03CP1>00c60Th;aP03CP1>00_600=>04h02lH00dh0CP0;aP9>
3<H00dh0CP0GP`04CP00CP_600=>04h02lH2CPc60Th<aP03CP1>01NE00A>001>68<00dh0CP0<aP9>
2lH00dh0CP0;aP03CP1>00_600=>04h02lH00dh0CP0HU@04CP00CQN300A>001>2lH00dh0CP0;aP03
CP0000X0000B003NCLKFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCY>3Th>CPi>3Th>CPi>3Th>CPi>3
Th>CPi>3CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6
e/I=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==C]K6
e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>6ID0Hdi=
Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6e/KF
a]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=CP0JU@0hCDjCPi>3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CCTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6eTh<00004P000dk6aP0:aP03C/K600_6
00=>Ph<068<2CPc60Th<aP03C/K600_600=>a/H02lH00dk6aP0:aP9>3<H2CQV30Th=aP03C/K600[6
0Th<aP9>3<H2CQVE0ThJP`9>3<H2CPc60Th<aP03C/K600_600=>a/H02/H2CQZE0ThIP`9>3LH00dk6
aP0:aP03CP0000X0000A003NC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CPde>e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KF
a]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFCY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>C
Pi>3TdkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=
6iD0HTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>
e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>6YD0>Df3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CPi>3Th==a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6C@0;00004@000dk6aP0;aP03
C/K600_600=>Ph<068<2CPc600=>a/H02lH00dk6aP0;aP03C/K600_600=>a/H02lH00dk6aP0:aP03
CX>301V300=>a/H02lH00dk6aP0;aP03C/K600_600=>a/H02/H00djEU@0IU@03CX>301V300=>a/H0
2/H2CPc600=>a/H02lH00dk6aP0;aP03C/K600_600=>UID069D00dj3P`0IP`03C/K600_600=>a/H0
2lH00dh0000900004@00gTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>C
Pi>3Th>CPi>3Th==C]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KF
a]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6eTi=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>C
Pi=>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CA^E
069=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFC]K6
e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCQZE03U=Pi>3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTd02`00014000=>a/H02lH00dk6
aP0;aP03CX>301R30Th<aP03C/K600_600=>a/H02lH00dk6aP0;aP03C/K600_600=>a/H02/H2CQZ3
00=>a/H02lH00dk6aP0;aP03C/K600[60Th<aP03CYFE01VE00=>Ph<068<2CPc60Th<aP03C/K600_6
00=>a/H02lH00dk6aP0;aP03CYFE01RE00=>Ph<06H<00dk6aP0;aP03C/K600_600=>00002@000140
0=i>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CDkF
a]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KF
a]K6e/KFaTg6e/KFa]K6e/KFa]I>CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CC]K6e/KFa]K6e/KF
a]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTdKU@1RCH>CPi>3Th>CPi>3
Th>CPi>3Th>CPi>3Th>CCTg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6
e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eThJU@0iCH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdg6
e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=00/0000B0003C/K600[60Th;aP03CP1>01R300=>04h0
3<H2CPc60Th;aP9>3<H2CPc60Th<aP9>6H<00dh0CP0;aP9>3<H2CPc60Th<aP9>6ID00dh0CP0IP`9>
3<H2CPc60Th<aP9>2lH2CPc60ThIU@03CP1>01V30Th<aP9>3<H00dh0000:00004P00gTg6e/KFa]K6
e/KFa]I>CLKFa]K6e/KFa]K6C@1=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP1>e/KFa]K6e/KFa]K6
CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=a]K6
e/KFa]K6e/KFCTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3C@1=a]K6e/KFa]K6e/I=C]K6e/KFa]K6
e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=CQVE06A>04jCPi>3Th>CPi>3Th>CPi>3Th>C
Pi>3Th==04g6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KF
aTe>e/KFa]K6e/KFa]K6C@1=69D0>Dh0CY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>CLKFa]K6e/KF
a]K6eTi=a]K6e/KFa]K6e/KFCP0<00004P000dk6aP09aP03CP1>00_600=>00000ThEP`05CP0004h0
2/H00dh0CP0;aP03CP1>00_600=>04h02lH00dh0CP0:aP04CP00CP[600=>00000ThFP`04CP00CP_6
00=>04h02lH00dh0CP0:aP04CP00CP[600=>00000ThFU@04CP00009>5H<01Dh0001>00[600A>001>
2/H00dh0CP0;aP03CP1>00_600=>04h02lH014h004hFU@04CP00009>5X<014h004h;aP03CP1>00_6
00=>00002P0001<000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=10005DjCPi>3Th>CPi>3Th>C
Pi>3Th>CCP04000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6eTh2000<
CLKFa]K6e/KFa]I>0P002dg6e/KFa]K6e/I=00<000]=a]K6e/KFa]K6C@04000FCY>3Th>CPi>3Th>C
Pi>3Th>CPi>3C@@000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=0P002dkFa]K6e/KFa]I>0080
00a=a]K6e/KFa]K6eTh40003CIFE01:E00=>000010005Df3Th>CPi>3Th>CPi>3Th>CPi>3C@05000;
CLKFa]K6e/KFaTd00P0034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=
0P0034kFa]K6e/KFa]K6C@<000==UID04YD00dh00004000FCH>CPi>3Th>CPi>3Th>CPi>3Th>CCP@0
00a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>300001<000=>a/H01lH01Dh0001>00W600=>0000
10000dj3P`0>P`9>1P000dk6aP06aP05CP0004h02LH01Dh0001>00W600E>0000CP08aP9>0`000dk6
aP06aP9>0`000dk6aP06aP03CP0000@000=>Ph<03h<2CPD000=>a/H01lH01Dh0001>00S60Th30003
C/K600K60Th30003C/K600K600=>000010000djEU@0?U@9>20000dj3P`0>P`9>1P000dk6aP06aP03
CP00008000=>a/H01/H01Dh0001>00W600E>0000CP09aP05CP0004h02<H2CPD000=>UID03iD2CPP0
00=>Ph<03h<2CPD000=>a/H01/H2CP<000=>a/H01/H2CPd0000D0009CLKFa]K6e/I=00D000U=a]K6
e/KFaTd0200044i=Pi>3Th>CPi>3Th>CCTd90008CLKFa]K6eTh50009C]K6e/KFa]I>00D000U>e/KF
a]K6eTh01@0024kFa]K6e/I=1P0024kFa]K6e/I=1P0024kFa]K6e/I=20004Di=CY>3Th>CPi>3Th>C
Pde>00P000U=a]K6e/KFaTd01@0024g6e/KFa]I>1P0024g6e/KFa]I>1P0024g6e/KFa]I>20000de>
U@0<U@03CTd000X0011=CY>3Th>CPi>3Th>CPde>2@0024kFa]K6e/I=1P0024kFa]K6e/I=1@002Dg6
e/KFa]K6C@050009CLKFa]K6e/I=00D000Q=a]K6e/KFCPP000==CTd039D00di=000:000ACDjCPi>3
Th>CPi>3Th>CCTd0200024kFa]K6e/I=1P0024kFa]K6e/I=3`0001D00dh2aP9>1`03CP;60Th;00=>
1h<2CP`00Th2aP9>1`03CP;60Th700=>0/H2CPL00dh00lI>CP0800=>00?6CTh02002CP;60Th<009>
1h<3CP/00dh2aP9>1`03CP03aTi>00P00dh00lI>CP08009>0/H2CP/00dh7U@=>3`03CPN30Th<009>
0/H2CPP00Th2aP9>1`03CP;60Th700=>0/H2CPL00dh00lI>CP0<009>29D2CPl00dh7P`=>2`03CP03
aTi>00P00dh00lI>CP0@000060000de>000;0003CDh000l000M=CTe>CDi=010000=>C@002`000di=
000;0003CTd000/000=>00002`000dh0000:0003CDh000l000M=CTe>CDi=014000==CP002`000dd0
000;0003C@0000X000=>C@003`001di=CTe>CDh05@001di=CTe>CDh040000de>000;0003CDh000/0
00==CP002`000de>000;0003C@0000h000Q>CDi=CTe>CA@000M>CDi=CTe>014000=>00002`000dh0
000@0000o`3;0000o`3;0000o`3;0000o`3;0000\
\>"],
  ImageRangeCache->{{{0, 457}, {31, 0}} -> {-0.787665, -0.712262, 0.0723749, 
  0.0459524}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .05 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0302343 0.025 0.047619 [
[ 0 0 0 0 ]
[ 1 .05 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .05 L
0 .05 L
closepath
clip
newpath
p
p
.9 g
.001 w
.05404 .025 m
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.08428 .025 m
matrix currentmatrix
.01512 .02381 scale
5.57512 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
5.57512 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.11451 .025 m
matrix currentmatrix
.01512 .02381 scale
7.57484 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
7.57484 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.14475 .025 m
matrix currentmatrix
.01512 .02381 scale
9.57521 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
9.57521 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.17498 .025 m
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.20522 .025 m
matrix currentmatrix
.01512 .02381 scale
13.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
13.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.23545 .025 m
matrix currentmatrix
.01512 .02381 scale
15.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
15.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.2808 .025 m
matrix currentmatrix
.03023 .02381 scale
9.28746 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
9.28746 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.32615 .025 m
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.3715 .025 m
matrix currentmatrix
.03023 .02381 scale
12.2874 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
12.2874 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.41686 .025 m
matrix currentmatrix
.01512 .02381 scale
27.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
27.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.44709 .025 m
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.47732 .025 m
matrix currentmatrix
.01512 .02381 scale
31.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
31.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.50756 .025 m
matrix currentmatrix
.01512 .02381 scale
33.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
33.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.55291 .025 m
matrix currentmatrix
.03023 .02381 scale
18.2875 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
18.2875 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.59826 .025 m
matrix currentmatrix
.01512 .02381 scale
39.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
39.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.64361 .025 m
matrix currentmatrix
.03023 .02381 scale
21.2874 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
21.2874 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.68896 .025 m
matrix currentmatrix
.01512 .02381 scale
45.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
45.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.7192 .025 m
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.74943 .025 m
matrix currentmatrix
.01512 .02381 scale
49.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
49.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.79478 .025 m
matrix currentmatrix
.03023 .02381 scale
26.2873 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
26.2873 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.84014 .025 m
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.88549 .025 m
matrix currentmatrix
.03023 .02381 scale
29.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
29.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.93084 .025 m
matrix currentmatrix
.01512 .02381 scale
61.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
61.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.96107 .025 m
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{458, 32},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007:000080P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5H/1JX00=d81_l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000e5D0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0b`000?l0b`000?l0b`000?l0b`000?l0
b`0001P000==CTd02`000de>C@0:0004CTe>C@X000A>CDi=2P0014i=CTd:0003CTe>00/000=>CDh0
3`001di=CTe>CDh0400014e>CDh?0006CTe>CDi=4@000de>C@0:0004CTe>C@X000A>CDi=2P0014i=
CTd>0007CTe>CDi=CP0@0004CDi=CPl000I>CDi=CTdA0004CDi=CPX000==CTd02`000de>C@0?0006
CDi=CTe>4@0014i=CTd>0007CTe>CDi=CP0@0004CDi=CPX000A=CTe>400001H00Th3aP03CP0000D0
0dh3aP03CP0000D00Th4aP03CP0000D00Th4aP03CP0000D00Th4aP03CP0000D00Th3aP03CP0000H0
0Th3aP03CP0000T00dh7P`A>2P02CPC600=>00002@03CPJE1Dh900=>0lH00dh00005009>1<H00dh0
0005009>1<H00dh00005009>1<H00dh00009009>1h<5CPT00Th4aP03CP0000T00dh6U@E>2P02CPC6
00=>00001@02CP?600=>00001@03CP?600=>00002@03CPJ31Dh:009>1<H00dh00009009>1iD5CPT0
0Th4aP03CP0000D00Th4aP03CP0000d0000E0007C]K6e/KFCP060008CLKFa]K6eTh60008CLKFa]K6
eTh60008CLKFa]K6eTh60008CLKFa]K6eTh60008CLKFa]K6eTh60007CLKFa]K6C@09000ACDjCPi>3
Th>CPi>3Th>CPdd0200024kFa]K6e/I=20000di=CP0>U@03C@0000D000Q=a]K6e/KFCPH000Q=a]K6
e/KFCPH000Q=a]K6e/KFCPH000Q=a]K6e/KFCPP0019=CTf3Th>CPi>3Th>CPi>3Tdh70008C]K6e/KF
aTd90003CDjE00fE00==00001P0024kFa]K6e/I=1P0024kFa]K6e/I=1@0024g6e/KFa]I>2@004Di=
Pi>3Th>CPi>3Th>CPi=>00P000Q=a]K6e/KFCPP000==CTd03YD00dh000050008C]K6e/KFaTd60008
C]K6e/KFaTd?000050000dk6aP05aP03CP00008000=>a/H01/H00dh000020003C/K600K600=>0000
0P000dk6aP06aP03CP00008000=>a/H01/H00dh000020003C/K600K600=>00000P000dk6aP05aP03
CP0000@00ThAP`03CP0000@000=>a/H01/H00dh00003009>4YD00dh000030003C/K600K600=>0000
0P000dk6aP06aP03CP00008000=>a/H01/H00dh000020003C/K600K600=>00000`02CQ:300=>0000
0`000dk6aP06aP03CP0000@00ThAU@03CP0000@000=>a/H01/H00dh000020003C/K600K600E>0000
CP08aP03CP0000@00ThAP`03CP0000@000=>a/H01/H00dh00003009>4YD00dh000030003C/K600K6
00=>00000P000dk6aP06aP03CP0000`0000C000;C]K6e/KFa]K6eTh00`002dkFa]K6e/KFa]I>0080
00a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6
eTh2000;CLKFa]K6e/KFaTd010005TjCPi>3Th>CPi>3Th>CPi>3Th>CPdd4000<C]K6e/KFa]K6e/I=
0`000dfEU@0CU@03C@00008000]>e/KFa]K6e/KFCP02000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6
e/KFCP8000a=a]K6e/KFa]K6eTh3000GCY>3Th>CPi>3Th>CPi>3Th>CPi>3Tdh00`0034kFa]K6e/KF
a]K6C@@000=>UID04YD00dd00002000<C]K6e/KFa]K6e/I=0P0034kFa]K6e/KFa]K6C@8000]>e/KF
a]K6e/KFCP04000FCH>CPi>3Th>CPi>3Th>CPi>3Th>CCP@000a=a]K6e/KFa]K6eTh30003CYFE01>E
011>0000C]K6e/KFa]K6e/I=0P0034kFa]K6e/KFa]K6C@d0000C0003C/K600O600E>0000CP09aP04
CP00CP[600A>001>2/H014h004h:aP04CP00CP[600A>001>2LH01Dh0001>01J300E>0000CP0:aP05
CP0004h05ID00dh000020003C/K600O600A>001>2/H014h004h:aP04CP00CP[600E>0000CP0EP`05
CP0004h02/H01Dh0001>01JE00E>0000CP0:aP04CP00CP[600A>001>2LH01Dh0001>01J300E>0000
CP0:aP05CP0004h05ID01Dh0001>00[600A>001>2/H00dh0000;00004P00S4g6e/KFa]K6e/KFaTd0
CLKFa]K6e/KFa]K6C@1=a]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6
e/KFa]K6eTh0C]K6e/KFa]K6e/KFCP1>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3C@1=a]K6e/KFa]K6
e/KFCP1>5iD0E4h004g6e/KFa]K6e/KFaTd0CLKFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KF
a]K6e/KFaTd0CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3C@8000m>e/KFa]K6e/KFa]I>04h069D0Edd0
CLKFa]K6e/KFa]K6C@1=a]K6e/KFa]K6e/I=04g6e/KFa]K6e/KFaTd0CH>CPi>3Th>CPi>3Th>CPi>3
Th>CPi>3Tdh0C]K6e/KFa]K6e/KFaTd0C@0GU@0NC@00C]K6e/KFa]K6e/KFCP1>e/KFa]K6e/KFa]I>
3000018000=>a/H02LH00dh0CP0;aP03CP1>00_60Th<aP9>3<H2CP_600=>04h02lH00dh0CP0HP`03
CP1>00c600=>04h05iD014h004h;aP03CP1>00_60Th<aP9>3<H00dh0CP0GP`04CP00CP_600=>04h0
69D00dh0CP0;aP03CP1>00_600=>04h02lH00dh0CP0HP`03CP1>00c600=>04h05iD014h004h;aP03
CP1>00_600=>00002P00018008]=a]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6
CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=Pi>3
Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>CLKFa]K6e/KFa]K6eTi=01VE06==C]K6e/KFa]K6e/KFa]I>
e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>Th>CPi>3Th>CPi>3Th>CPi>3
Th>CPi>3Tdi=a]K6e/KFa]K6e/KFaTd06YD0EDi=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>e/KF
a]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPde>e/KFa]K6e/KFa]K6CDh06ID07Di=
a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]I>00`0000B0003C/K600[600=>a/H02lH00dk6aP0:aP9>
3<H2CPc60Th<aP03C/K600_600=>Ph<068<2CPc60ThIU@9>3LH00dk6aP0:aP9>3<H2CPc60ThIP`9>
3LH00djEU@0HU@9>3<H2CPc600=>a/H02lH00dj3P`0HP`9>3<H2CQVE0Th=aP03C/K600[600=>0000
2P00014008]>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KF
a]K6eTkFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CH>CPi>3Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CPdg6e/KFa]K6e/KFa]I>01^E069>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KF
C]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdg6e/KF
a]K6e/KFa]K6CAZE05A>CLKFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==C]K6e/KFa]K6e/KFaTdKU@0MCLKFa]K6e/KFa]K6e/I=a]K6
e/KFa]K6e/KFaTd02`00014000=>a/H02lH00dk6aP0;aP03C/K600_600=>a/H02lH00dk6aP0:aP03
C/K600_600=>a/H02lH00dj3P`0IP`03C/K600[600=>UID06ID00dk6aP0;aP03C/K600_600=>a/H0
2lH00dk6aP0:aP03CX>301V300=>a/H02lH00djEU@0HU@9>3<H00dk6aP0;aP03C/K600_600=>Ph<0
68<2CPc600=>UID06ID00dk6aP0;aP03C/K600_600=>00002@00014008a>e/KFa]K6e/KFa]K6eTkF
a]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=a]K6e/KF
a]K6e/KFaTg6e/KFa]K6e/KFa]K6CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdg6e/KFa]K6e/KF
a]I>CAZE069>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KF
a]K6CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdg6e/KFa]K6e/KFa]K6CAZE05A>CLKFa]K6e/KF
a]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==
C]K6e/KFa]K6e/KFaTdKU@0MCLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTd02`00014000=>a/H0
2lH00dk6aP0;aP03C/K600_600=>a/H02/H2CPc600=>a/H02lH00dk6aP0;aP03CX>301R30Th<aP9>
6YD00dk6aP0;aP03C/K600_600=>a/H02/H2CPc600=>Ph<06H<00dk6aP0;aP03CYFE01RE0Th<aP03
C/K600_600=>a/H02lH00dj3P`0HP`9>3<H00djEU@0IU@03C/K600_600=>a/H02lH00dh000090000
4@00S4kFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=
C]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=Pi>3Th>CPi>3Th>CPi>3Th>C
Pi>3Th>CPi=>CLKFa]K6e/KFa]K6eTi=6YD0HTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KF
a]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CLKFa]K6e/KF
a]K6e/I=6YD0E4i=a]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTjCPi>3Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CPde>e/KFa]K6e/KFa]K6CA^E01e=a]K6e/KFa]K6e/KFaTg6e/KFa]K6
e/KFa]K6C@0;00004P000dk6aP0:aP9>2lH2CPc60Th<aP9>3<H2CPc60Th;aP03CP1>01V30Th<aP9>
6ID00dh0CP0;aP9>3<H2CPc60Th<aP9>6H<2CPc600=>04h069D00dh0CP0<aP9>3<H2CP_600=>04h0
68<00dh0CP0<aP9>6ID2CPc60Th<aP03CP0000X0000B002;CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6
e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>
e/KFa]K6e/KFa]I>04jCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==04g6e/KFa]K6e/KFa]I>C@0IU@1T
C@1=a]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=CY>3
Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>CLKFa]K6e/KFa]K6eTh0CQRE05I=04g6e/KFa]K6e/KFa]I>
CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/I=04f3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>04kFa]K6
e/KFa]K6e/I=CQVE01e>CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCP0<00004P000dk6aP09aP03
CP1>00_600=>04h02lH00dh0CP0:aP04CP00CP[600=>04h02lH00dh0CP0;aP03CP00009>5H<01Dh0
001>00[600=>00000ThFU@04CP00CP_600=>04h02lH00dh0CP0:aP04CP00CP[600=>00000ThFP`04
CP00CP_600A>001>5YD01Dh0001>00[600=>04h02lH00dh0CP0;aP03CP00009>5H<01Dh0001>00[6
00=>00000ThFU@04CP00CP_600=>04h02lH00dh0000:00004`0034kFa]K6e/KFa]K6C@8000a>e/KF
a]K6e/KFaTd2000<C]K6e/KFa]K6e/I=0P002dkFa]K6e/KFa]I>008000a=a]K6e/KFa]K6eTh2000<
CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP@001E=Pi>3Th>CPi>3Th>CPi>3Th>CPdd01@002dg6
e/KFa]K6e/I=00@000=>UID04YD00dd00002000<C]K6e/KFa]K6e/I=0P0034kFa]K6e/KFa]K6C@80
00]>e/KFa]K6e/KFCP02000<CLKFa]K6e/KFa]I>10005Tf3Th>CPi>3Th>CPi>3Th>CPi>3Tdh4000<
CLKFa]K6e/KFa]I>0`000di=U@0BU@03C@00008000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=
0P0034kFa]K6e/KFa]K6C@@001E>Th>CPi>3Th>CPi>3Th>CPi>3Tdh0100034g6e/KFa]K6e/KFCP@0
00==UID04YD00dh00002000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP`0000C0003C/K600O6
00E>0000CP09aP05CP0004h02<H2CP<000=>a/H01/H00dh000020003C/K600K600E>0000CP09aP05
CP0004h02LH00dh000040003CX>300j30Th60003C/K600K600=>000010000djEU@0?U@9>1@000dk6
aP07aP05CP0004h02<H2CP<000=>a/H01/H2CP<000=>a/H01/H00dh000040003CX>300n30Th50003
C/K600K60Th60003CYFE00jE0Th60003C/K600K600E>0000CP09aP05CP0004h02LH00dh000040003
CX>300j30Th60003C/K600K600=>000010000djEU@0?U@9>1@000dk6aP06aP9>0`000dk6aP06aP9>
3@0001@000U=a]K6e/KFaTd01@002Dg6e/KFa]K6C@050008CLKFa]K6eTh60008CLKFa]K6eTh60008
CLKFa]K6eTh50009C]K6e/KFa]I>00D000U>e/KFa]K6eTh0200044e>Th>CPi>3Th>CPi>3CDh90008
C]K6e/KFaTd80003CTe>00bE00==CP001`002Dg6e/KFa]K6C@050008CLKFa]K6eTh60008CLKFa]K6
eTh60008CLKFa]K6eTh8000ACDjCPi>3Th>CPi>3Th>CCTd0200024kFa]K6e/I=2@000de>U@0;U@03
CDh000P000Q>e/KFa]K6C@D000U=a]K6e/KFaTd01@002Dg6e/KFa]K6C@08000@CTf3Th>CPi>3Th>C
Pi=>C@T000Q=a]K6e/KFCPP000==CYD039D00di=00070008C]K6e/KFaTd60008C]K6e/KFaTd?0000
5@03CP;60Th700=>0/H2CPL00dh00lI>CP08009>0/H2CPP00Th2aP9>1`03CP;60Th700=>0/H2CP/0
0dh7P`9>3002CP;60Th<009>1iD3CP/00dh2aP9>1`03CP03aTi>00P00dh00lI>CP08009>0/H2CP/0
0dh7P`=>2`03CP03aTi>00`00dh7U@9>3002CP;60Th700=>0/H2CPL00dh2aP9>2`03CPN30Th<009>
0/H2CP/00dh7U@=>2`03CP03aTi>00P00dh00lI>CP0@000060000de>000;0003CDh000/000==0000
2P000di=000;0003CTd000/000=>C@002`000di=000?0007CTe>CDi=CP0@0003CDh000l000M=CTe>
CDi=014000==CP002`000dd0000;0003C@0000X000=>C@003`001di=CTe>CDh04@000dh0000?0007
CTe>CDi=CP0@0003CDh000/000==CP002`000de>000?0007CDi=CTe>C@0@0003CTd000l000M>CDi=
CTe>014000=>00002`000dh0000@0000o`3;0000o`3;0000o`3;0000o`3;0000\
\>"],
  ImageRangeCache->{{{0, 457}, {31, 0}} -> {-0.787665, -0.712262, 0.0723749, 
  0.0459524}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .05 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0302343 0.025 0.047619 [
[ 0 0 0 0 ]
[ 1 .05 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .05 L
0 .05 L
closepath
clip
newpath
p
p
.9 g
.001 w
.05404 .025 m
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.08428 .025 m
matrix currentmatrix
.01512 .02381 scale
5.57512 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
5.57512 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.11451 .025 m
matrix currentmatrix
.01512 .02381 scale
7.57484 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
7.57484 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.14475 .025 m
matrix currentmatrix
.01512 .02381 scale
9.57521 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
9.57521 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.17498 .025 m
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.20522 .025 m
matrix currentmatrix
.01512 .02381 scale
13.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
13.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.25057 .025 m
matrix currentmatrix
.03023 .02381 scale
8.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
8.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.29592 .025 m
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.32615 .025 m
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.35639 .025 m
matrix currentmatrix
.01512 .02381 scale
23.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
23.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.40174 .025 m
matrix currentmatrix
.03023 .02381 scale
13.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
13.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.44709 .025 m
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.47732 .025 m
matrix currentmatrix
.01512 .02381 scale
31.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
31.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.52268 .025 m
matrix currentmatrix
.03023 .02381 scale
17.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
17.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.56803 .025 m
matrix currentmatrix
.01512 .02381 scale
37.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
37.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.59826 .025 m
matrix currentmatrix
.01512 .02381 scale
39.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
39.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.6285 .025 m
matrix currentmatrix
.01512 .02381 scale
41.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
41.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.67385 .025 m
matrix currentmatrix
.03023 .02381 scale
22.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
22.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.7192 .025 m
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.76455 .025 m
matrix currentmatrix
.03023 .02381 scale
25.2875 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
25.2875 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.8099 .025 m
matrix currentmatrix
.01512 .02381 scale
53.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
53.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.84014 .025 m
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.87037 .025 m
matrix currentmatrix
.01512 .02381 scale
57.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
57.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.91572 .025 m
matrix currentmatrix
.03023 .02381 scale
30.2874 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
30.2874 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.96107 .025 m
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{458, 32},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007:000080P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5H/1JX00=d81_l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000e5D0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0b`000?l0b`000?l0b`000?l0b`000?l0
b`0001P000==CTd02`000de>C@0:0004CTe>C@X000A>CDi=2P0014i=CTd:0003CTe>00l000M>CDi=
CTe>010000A=CTe>2P0014e>CDh:0004CDi=CPh000M=CTe>CDi=010000A>CDi=2P0014i=CTd?0006
CDi=CTe>4@000di=CP0:0004CDi=CPX000A=CTe>3`001Ti=CTe>CA4000==CTd03`001de>CDi=CTd0
400014i=CTd:0004CTe>C@X000=>CDh03`001di=CTe>CDh0400014e>CDh@00005P02CP?600=>0000
1@03CP?600=>00001@02CPC600=>00001@02CPC600=>00001@02CPC600=>00001@02CP?600=>0000
2P02CPN31Dh9009>1<H00dh00005009>1<H00dh00005009>1<H00dh00009009>1iD5CPT00Th4aP03
CP0000D00Th4aP03CP0000T00dh6P`E>2P02CP?600=>00001@02CPC600=>00001@02CPC600=>0000
2@03CPJE1Dh:009>0lH00dh0000900=>1h<4CPX00Th4aP03CP0000D00Th4aP03CP0000D00Th3aP03
CP0000X00Th7U@E>2@02CPC600=>00003@0001D000M>e/KFa]I>00H000Q=a]K6e/KFCPH000Q=a]K6
e/KFCPH000Q=a]K6e/KFCPH000Q=a]K6e/KFCPH000Q=a]K6e/KFCPP0019=CTf3Th>CPi>3Th>CPi>3
Tdh70008C]K6e/KFaTd60008C]K6e/KFaTd60008C]K6e/KFaTd80003CTe>00jE00==00001@0024g6
e/KFa]I>1P0024g6e/KFa]I>20004Te>CH>CPi>3Th>CPi>3Th>CCPP000M=a]K6e/I=00H000Q>e/KF
a]K6C@H000Q>e/KFa]K6C@T000==CYD03ID00dd000060008C]K6e/KFaTd8000ACTf3Th>CPi>3Th>C
Pi>3Tdh0200024g6e/KFa]I>1P0024g6e/KFa]I>1P0024g6e/KFa]I>20000de>C@0>U@03CP0000D0
00Q>e/KFa]K6C@l0000D0003C/K600G600=>00000P000dk6aP06aP03CP00008000=>a/H01/H00dh0
00020003C/K600K600=>00000P000dk6aP06aP03CP00008000=>a/H01/H00dh00003009>4X<00dh0
00030003C/K600K600=>00000P000dk6aP06aP03CP00008000=>a/H01/H00dh00003009>4YD00dh0
00030003C/K600K600=>00000P000dk6aP06aP03CP0000<00ThBP`03CP0000@000=>a/H01LH00dh0
00020003C/K600K600=>00000P000dk6aP06aP03CP0000<00dhAU@03CP0000@000=>a/H01/H00dh0
0003009>4H<00dh000040003C/K600K600=>00000P000dk6aP06aP03CP00008000=>a/H01/H00dh0
0003009>4YD00dh000030003C/K600K600=>0000300001<000]>e/KFa]K6e/KFCP03000;C]K6e/KF
a]K6eTh00P0034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>0P0034g6
e/KFa]K6e/KFCP<001M>Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP03000<C]K6e/KFa]K6e/I=0P0034kF
a]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd30003CIFE01>E011=0000CLKFa]K6e/KFa]I>0P0034g6
e/KFa]K6e/KFCP<001M>Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP04000;CLKFa]K6e/KFaTd00P0034kF
a]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd30003CIFE01>E00==00000P0034kFa]K6e/KFa]K6C@<0
01I=Pi>3Th>CPi>3Th>CPi>3Th>CPi=>100034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6eTh2000<
CLKFa]K6e/KFa]I>0`000djEU@0CU@0@CP0004kFa]K6e/KFa]K6C@d0000C0003C/K600O600E>0000
CP09aP04CP00CP[600A>001>2/H014h004h:aP04CP00CP[600E>0000CP0EP`05CP0004h02/H014h0
04h:aP04CP00CP[600E>0000CP0EU@05CP0004h02/H014h004h:aP05CP0004h05H<00dh000020003
C/K600O600A>001>2/H014h004h:aP05CP0004h05YD01Dh0001>00[600A>001>5X<01Dh0001>00[6
00A>001>2/H014h004h:aP04CP00CQJE00E>0000CP0:aP03CP0000/0000B001BCLKFa]K6e/KFa]K6
C@1=a]K6e/KFa]K6e/I=04g6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6
e/KFa]K6e/KFCP8001U=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==008002Q>e/KFa]K6e/KFa]I>CLKF
a]K6e/KFa]K6eTi=a]K6e/KFa]K6e/I=0P000djEU@0EU@0hCP00CLKFa]K6e/KFa]K6CDkFa]K6e/KF
a]K6e/I=04f3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdd2000[C]K6e/KFa]K6e/KFCP1>e/KFa]K6e/KF
a]I>04kFa]K6e/KFa]K6eTh0CP0HU@1FC@1=a]K6e/KFa]K6e/I=04f3Th>CPi>3Th>CPi>3Th>CPi>3
Th>CPi=>04kFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]I>04hHU@0@C@00C]K6
e/KFa]K6e/KFCP`0000B0003C/K600W600=>04h02lH00dh0CP0;aP9>3<H2CPc60Th;aP04CP00CQN3
00A>001>2lH2CPc60Th;aP04CP00CQNE00A>001>2lH2CPc600=>04h068<00dh0CP0;aP03CP1>00_6
00=>04h02lH00dh0CP0HU@03CP1>00_600=>04h068<00dh0CP0<aP9>3<H2CP_600=>04h069D014h0
04h;aP03CP0000X0000B002ICLKFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFaTe>
e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>Th>CPi>3Th>CPi>3Th>CPi>3
Th>CPi>3Tdi=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=01VE06==C]K6
e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdg6e/KFa]K6
e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFCTd06YD0EDi=a]K6e/KFa]K6e/KFCY>3Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CPi>3CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KF
a]K6CDh06ID03di=a]K6e/KFa]K6e/KFCP0<00004P000dk6aP0:aP03C/K600_600=>a/H02/H2CPc6
0Th<aP9>3<H2CQV30Th<aP9>3<H2CPc60ThIU@9>3<H2CPc60ThJP`03C/K600_600=>a/H02lH00dk6
aP0:aP9>6YD2CPc600=>Ph<068<2CPc60Th<aP9>3<H2CQVE0Th<aP03CP0000X0000A002IC]K6e/KF
a]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KF
a]K6CLKFa]K6e/KFa]K6e/I=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6e/I=
a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>01^E069>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KF
CY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KF
a]K6e/KFa]K6CAZE05A>e/KFa]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>e/KF
a]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTdKU@0?CLKFa]K6e/KFa]K6e/I=00/0
000A0003C/K600_600=>a/H02lH00dk6aP0;aP03C/K600_600=>a/H02/H00dk6aP0;aP03CX>301V3
00=>a/H02lH00dk6aP0:aP9>3<H00djEU@0IU@03C/K600_600=>a/H02lH00dj3P`0HP`03C/K600_6
00=>a/H02lH00dk6aP0;aP03CYFE01RE00=>a/H02lH00dj3P`0IP`03C/K600_600=>a/H02/H00dk6
aP0;aP03CYFE01VE00=>a/H02lH00dh0000900004@00VDkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KF
a]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CH>C
Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6eTi=a]K6e/KF
a]K6e/KFCP0KU@1RC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>C
Pi>3Th>CPdg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTdJU@1DC]K6e/KF
a]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KF
a]K6CDkFa]K6e/KFa]K6e/I=6iD03dg6e/KFa]K6e/KFa]K6C@0;00004@000dk6aP0;aP03C/K600_6
00=>a/H02lH00dk6aP0:aP9>3<H00dk6aP0;aP03CX>301V300=>a/H02lH00dk6aP0:aP9>3<H00djE
U@0IU@03C/K600_600=>a/H02/H2CQZ300=>a/H02lH00dk6aP0;aP03C/K600_600=>UID069D00dk6
aP0;aP03CX>301R30Th<aP9>3<H2CPc600=>UID069D2CPg600=>00002@00014009U>e/KFa]K6e/KF
a]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=
a]K6e/KFa]K6e/KFaTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==a]K6e/KFa]K6e/KFaTg6e/KF
a]K6e/KFa]I>CLKFa]K6e/KFa]K6eTh06iD0HTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFaTe>Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KF
a]K6e/I=6YD0E4kFa]K6e/KFa]K6e/KFCY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CDkFa]K6e/KF
a]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CAZE011>CLKFa]K6e/KFa]K6e/I=2`000180
00=>a/H02/H2CP_60Th<aP9>3<H2CPc60Th<aP9>6H<2CPc60Th<aP9>3<H2CQVE0Th<aP9>3<H2CQV3
00=>04h03<H00dk6aP0:aP9>3<H2CQVE00=>04h03<H2CQV30Th<aP9>3<H2CPc60ThIU@9>3<H00dh0
000:00004P00VDg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6
e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=CY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdd0
CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>C@0HU@1UCP1>e/KFa]K6e/KF
a]K6CDkFa]K6e/KFa]K6e/I=04f3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>04kFa]K6e/KFa]K6e/I=
a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>04h069D0ETd0CLKFa]K6e/KFa]K6eTi=Pi>3Th>CPi>3
Th>CPi>3Th>CPi>3Th>CCP1>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>
69D044d0CLKFa]K6e/KFa]K6eTh<00004P000dk6aP09aP03CP1>00_600=>04h02lH00dh0CP0:aP04
CP00CP[600=>04h02lH00dh00002CQF300E>0000CP0:aP04CP00CP[600A>001>2/H00dh00002CQFE
00E>0000CP0;aP03CP1>00[600E>0000CP0FP`04CP00CP_600=>04h02lH00dh0CP0:aP05CP0004h0
5YD014h004h;aP03CP00009>5H<01Dh0001>00[600A>001>2/H00dh0CP0;aP03CP00009>5ID01Dh0
001>00_600=>00002P0001<000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=0P0034kFa]K6e/KF
a]K6C@8000]>e/KFa]K6e/KFCP02000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP@001I=Pi>3
Th>CPi>3Th>CPi>3Th>CPi=>10002dg6e/KFa]K6e/I=00<000]=a]K6e/KFa]K6C@02000<C]K6e/KF
a]K6e/I=10000djEU@0BU@03C@00008000a>e/KFa]K6e/KFaTd2000;C]K6e/KFa]K6eTh010005Tf3
Th>CPi>3Th>CPi>3Th>CPi>3Tdh4000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP8000]=a]K6
e/KFa]K6C@040003CYFE01:E00==00000P0034kFa]K6e/KFa]K6C@@001E>Th>CPi>3Th>CPi>3Th>C
Pi>3Tdh01@002dkFa]K6e/KFa]I>008000a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>10000dfE
U@0BU@03CP00008000a=a]K6e/KFa]K6eTh<00004`000dk6aP07aP05CP0004h02LH01Dh0001>00S6
0Th30003C/K600K600=>00000P000dk6aP06aP05CP0004h02LH00dh000040003CX>300n30Th50003
C/K600K60Th30003C/K600K600=>00000P000dk6aP06aP03CP0000@000=>UID03iD2CPD000=>a/H0
1/H2CP<000=>a/H01/H2CPD000=>Ph<03h<2CPD000=>a/H01lH01Dh0001>00S60Th30003C/K600K6
0Th50003CYFE00nE0Th50003C/K600O600=>000010000dj3P`0>P`9>1P000dk6aP06aP9>0`000dk6
aP06aP05CP0004h02LH00dh000040003CYFE00nE0Th50003C/K600K60Th=000050002Dg6e/KFa]K6
C@050009CLKFa]K6e/I=00D000Q=a]K6e/KFCPH000Q=a]K6e/KFCPH000Q=a]K6e/KFCPD000U>e/KF
a]K6eTh020004De>Th>CPi>3Th>CPi>3CDi=00P000Q>e/KFa]K6C@H000Q>e/KFa]K6C@H000Q>e/KF
a]K6C@P000=>CID039D00de>00070008CLKFa]K6eTh60008CLKFa]K6eTh8000ACDi=Pi>3Th>CPi>3
Th>CCTd020002DkFa]K6e/KFCP050008C]K6e/KFaTd60008C]K6e/KFaTd80003CTe>00bE00==CP00
1`002Dg6e/KFa]K6C@08000@CTf3Th>CPi>3Th>CPi=>C@T000Q=a]K6e/KFCPH000Q=a]K6e/KFCPD0
00U>e/KFa]K6eTh020000de>U@0;U@03CDi=00P000Q>e/KFa]K6C@l0000E00=>0/H2CPL00dh2aP9>
1`03CP03aTi>00P00Th2aP9>2002CP;60Th700=>0/H2CP/00dh7P`9>3003CP03aTi>00P00Th2aP9>
2002CP;60Th;00=>1iD3CP/00dh00lI>CP0800=>00?6CTh03002CPN30dh;00=>0/H2CPL00dh00lI>
CP0800=>00?6CTh03002CPNE0dh;00=>0/H2CP/00dh7P`9>3003CP03aTi>00P00Th2aP9>1`03CP;6
0Th;00=>1iD2CP`00dh00lI>CP0@000060000de>000;0003CDh000/000==00002P000di=000;0003
CTd000/000=>C@003`001di=CTe>CDh04@000dh0000:0003CDh000/000==CP003`001de>CDi=CTd0
4@000dd0000;0003C@0000h000M>CDi=CTe>014000=>C@002`000dh0000;0003CP0000h000M=CTe>
CDi=014000==CP003`001de>CDi=CTd04@000dd0000:0003CTd000/000=>C@003`001di=CTe>CDh0
4@000dh0000@0000o`3;0000o`3;0000o`3;0000o`3;0000\
\>"],
  ImageRangeCache->{{{0, 457}, {31, 0}} -> {-0.787665, -0.712262, 0.0723749, 
  0.0459524}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .05 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0322841 0.025 0.047619 [
[ 0 0 0 0 ]
[ 1 .05 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .05 L
0 .05 L
closepath
clip
newpath
p
p
.9 g
.001 w
.05609 .025 m
matrix currentmatrix
.01614 .02381 scale
3.47478 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
3.47478 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.08838 .025 m
matrix currentmatrix
.01614 .02381 scale
5.47514 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
5.47514 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.12066 .025 m
matrix currentmatrix
.01614 .02381 scale
7.47489 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
7.47489 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.15295 .025 m
matrix currentmatrix
.01614 .02381 scale
9.47525 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
9.47525 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.18523 .025 m
matrix currentmatrix
.01614 .02381 scale
11.475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
11.475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.23366 .025 m
matrix currentmatrix
.03228 .02381 scale
7.23762 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03228 .02381 scale
7.23762 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.28208 .025 m
matrix currentmatrix
.01614 .02381 scale
17.4749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
17.4749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.31437 .025 m
matrix currentmatrix
.01614 .02381 scale
19.4752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
19.4752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.34665 .025 m
matrix currentmatrix
.01614 .02381 scale
21.475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
21.475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.37893 .025 m
matrix currentmatrix
.01614 .02381 scale
23.4747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
23.4747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.41122 .025 m
matrix currentmatrix
.01614 .02381 scale
25.4751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
25.4751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.45964 .025 m
matrix currentmatrix
.03228 .02381 scale
14.2374 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03228 .02381 scale
14.2374 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.52421 .025 m
matrix currentmatrix
.03228 .02381 scale
16.2374 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03228 .02381 scale
16.2374 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.57264 .025 m
matrix currentmatrix
.01614 .02381 scale
35.4751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
35.4751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.60492 .025 m
matrix currentmatrix
.01614 .02381 scale
37.4748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
37.4748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.63721 .025 m
matrix currentmatrix
.01614 .02381 scale
39.4752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
39.4752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.66949 .025 m
matrix currentmatrix
.01614 .02381 scale
41.4749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
41.4749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.70178 .025 m
matrix currentmatrix
.01614 .02381 scale
43.4753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
43.4753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.4 g
.001 w
.73406 .025 m
matrix currentmatrix
.01614 .02381 scale
45.475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
45.475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.76634 .025 m
matrix currentmatrix
.01614 .02381 scale
47.4748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
47.4748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.79863 .025 m
matrix currentmatrix
.01614 .02381 scale
49.4751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
49.4751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.83091 .025 m
matrix currentmatrix
.01614 .02381 scale
51.4749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
51.4749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.8632 .025 m
matrix currentmatrix
.01614 .02381 scale
53.4752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
53.4752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.89548 .025 m
matrix currentmatrix
.01614 .02381 scale
55.475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
55.475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.94391 .025 m
matrix currentmatrix
.03228 .02381 scale
29.2376 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03228 .02381 scale
29.2376 1.05 1 0 365.73 arc
setmatrix
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{458, 32},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007:000080P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5H/1JX00=d81_l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000e5D0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0b`000?l0b`000?l0b`000?l0b`000?l0
b`0001T000A>CDi=2P0014i=CTd;0004CDi=CP/000A>CDi=2`0014e>CDh?0007CTe>CDi=CP0B0004
CDi=CP/000A>CDi=2P0014i=CTd;0004CDi=CP/000A>CDi=40001di=CTe>CDh05P001de>CDi=CTd0
4P0014i=CTd:0004CTe>C@/000A=CTe>2`0014i=CTd;0004CDi=CPX000A=CTe>2`0014i=CTd;0004
CDi=CP/000A>CDi=2P0014i=CTd;0004CDi=CQ0000M=CTe>CDi=01L0000F00=>1<H00dh00005009>
1<H00dh00006009>1<H00dh00006009>1<H00dh0000500=>1<H00dh0000:009>1h<5CP/00Th4aP03
CP0000D00dh4aP03CP0000D00Th4aP03CP0000H00Th4aP03CP0000H00Th4aP03CP0000X00dh7U@E>
3P03CPN31Dh:00=>1<H00dh00005009>1<H00dh00006009>1<H00dh00006009>1<H00dh0000500=>
1<H00dh00005009>18400dh00006009>1<H00dh00006009>1<H00dh0000500=>1<H00dh00005009>
1<H00dh00006009>1<H00dh0000:00=>1iD5CQ80000E0009C]K6e/KFa]I>00H000U=a]K6e/KFaTd0
1P0024kFa]K6e/I=1`0024g6e/KFa]I>1P002Dg6e/KFa]K6C@09000CCDi=Pi>3Th>CPi>3Th>CPi=>
C@080008C]K6e/KFaTd60009C]K6e/KFa]I>00H000U=a]K6e/KFaTd01P0024kFa]K6e/I=1`0024g6
e/KFa]I>2@000di=CP0?U@03CP0000T0019>CH>CPi>3Th>CPi>3Th>CPdd80009C]K6e/KFa]I>00H0
00U=a]K6e/KFaTd01P0024kFa]K6e/I=1`0024g6e/KFa]I>1P002Dg6e/KFa]K6C@060003CX6100F1
00=>0000100024g6e/KFa]I>1`0024kFa]K6e/I=1P002DkFa]K6e/KFCP060009CLKFa]K6e/I=00H0
00Q>e/KFa]K6C@T000==CTd03iD00dd0000?000050000dk6aP07aP03CP00008000=>a/H01lH00dh0
00020003C/K600K600=>00000`000dk6aP06aP03CP00008000=>a/H01lH00dh00004009>4h<00dh0
00040003C/K600K600=>00000P000dk6aP07aP03CP00008000=>a/H01lH00dh000020003C/K600K6
00=>00000`000dk6aP06aP03CP0000@00ThCU@03CP0000D00dhBP`03CP0000@000=>a/H01lH00dh0
00020003C/K600O600=>00000P000dk6aP06aP03CP0000<000=>a/H01/H00dh000020003C/K600O6
00=>00000P000dj1P@07P@03CP00008000=>a/H01/H00dh000030003C/K600K600=>00000P000dk6
aP07aP03CP00008000=>a/H01lH00dh000020003C/K600K600=>00001002CQ>E00=>00003P0001<0
00e>e/KFa]K6e/KFa]I>008000e=a]K6e/KFa]K6e/I=008000a>e/KFa]K6e/KFaTd3000<CLKFa]K6
e/KFa]I>0P003Dg6e/KFa]K6e/KFaTd0100064jCPi>3Th>CPi>3Th>CPi>3Th>CPi>3C@@000a>e/KF
a]K6e/KFaTd2000=C]K6e/KFa]K6e/KFCP02000=CLKFa]K6e/KFa]K6C@02000<C]K6e/KFa]K6e/I=
0`0034g6e/KFa]K6e/KFCP@000==UID059D00dh00003000HCY>3Th>CPi>3Th>CPi>3Th>CPi>3Th==
10003DkFa]K6e/KFa]K6eTh00P003Dg6e/KFa]K6e/KFaTd00P0034kFa]K6e/KFa]K6C@<000a=a]K6
e/KFa]K6eTh2000=CLKFa]K6e/KFa]K6C@020003CX6100V100m>001=a]K6e/KFa]K6eTh00`0034kF
a]K6e/KFa]K6C@8000e>e/KFa]K6e/KFa]I>008000e=a]K6e/KFa]K6e/I=008000a>e/KFa]K6e/KF
aTd40003CYFE01BE00==00003@0001<000=>a/H02LH014h004h;aP04CP00CP[600E>0000CP0:aP04
CP00CP_600E>0000CP0GP`03CP00008000=>a/H02<H014h004h;aP04CP00CP_600A>001>2/H01Dh0
001>00[600E>0000CP0GU@03CP0000<000=>Ph<05H<01Dh0001>00_600A>001>2lH014h004h:aP05
CP0004h02/H014h004h;aP04CP00CP^100A>001>2/H01Dh0001>00[600A>001>2lH014h004h;aP04
CP00CP[600=>00000P000djEU@0EU@03CP0000`0000B001VCLKFa]K6e/KFa]K6e/I=C]K6e/KFa]K6
e/KFaTd0CLKFa]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6eTh0CY>3Th>CPi>3
Th>CPi>3Th>CPi>3Th>CPi=>0P00Bdg6e/KFa]K6e/KFa]I>04kFa]K6e/KFa]K6e/I=C]K6e/KFa]K6
e/KFaTd0CLKFa]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFaTd0C@0IU@0OC@0004f3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CPi>3C@02001:C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6C@1=a]K6e/KFa]K6e/KF
CP1>e/KFa]K6e/KFa]K6C@1=a]K6e/KFa]K6e/KFCTd<P@1;CP1>e/KFa]K6e/KFa]K6C@1=a]K6e/KF
a]K6e/KFCP1>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=04g6e/KFa]K6e/KFa]I>008000==UID0
5iD00dd0000;00004P000dk6aP0;aP9>3<H00dh0CP0<aP03CP1>00c60Th=aP03CP1>01V300A>001>
3<H00dh0CP0<aP9>3<H00dh0CP0<aP03CP1>00c600=>04h06YD014h004hIP`04CP00CPc60Th<aP03
CP1>00c600=>04h03<H00dh0CP0<aP9>38400dh0CP0<aP03CP1>00c600=>04h03<H2CPc600=>04h0
3<H014h004hIU@03CP0000/0000B002bCLKFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFa]I>e/KFa]K6
e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6eTi=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3
Th>CPi>3CDkFa]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/KFCTg6e/KFa]K6
e/KFa]K6CLKFa]K6e/KFa]K6e/I=CQbE06U=CY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Tdi=a]K6
e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CDkFa]K6
e/KFa]K6e/KFCTd03H40C4e>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]K6
CDkFa]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]K6CDhKU@03CP0000X0000B0003C/K600_60Th=aP03
C/K600c600=>a/H02lH2CPg60ThKP`9>3LH2CPg60Th=aP9>3LH00dk6aP0;aP9>79D2CQ^30Th=aP9>
3LH2CPg600=>a/H02lH2CPg60Th=P@9>3LH00dk6aP0;aP9>3LH2CPg60Th=aP9>6iD00dh0000:0000
4P00/Tg6e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6
e/KFC]K6e/KFa]K6e/KFa]I>CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>e/KFa]K6e/KFa]K6
e/I=a]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6
eThLU@1YCH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6e/KFC]K6e/KFa]K6
e/KFa]I>e/KFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6e/I=00f104]=a]K6
e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6
e/KFa]K6e/KFaTd079D00dh0000:00004P000dk6aP0;aP9>3LH00dk6aP0<aP03C/K600c600=>a/H0
2lH2CQb300=>a/H03<H00dk6aP0;aP9>3LH00dk6aP0<aP03C/K600c600=>UID06YD00dj3P`0KP`03
C/K600c600=>a/H02lH00dk6aP0<aP03C/K600c600=>a/H03<H00dj1P@0;P@03C/K600c600=>a/H0
3<H00dk6aP0<aP03C/K600_600=>a/H03<H00djEU@0JU@9>2`0001800;9=a]K6e/KFa]K6e/KFaTe>
e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCTf3
Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CC]K6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=C]K6
e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFa]I>79D0JDf3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CPi>3Th>CPdg6e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]K6
CLKFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]K6C@0=P@1;CLKFa]K6e/KFa]K6e/KFC]K6e/KFa]K6
e/KFa]K6CLKFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6e/I=01bE00=>C@00
2P00018000=>a/H02lH2CPg600=>a/H03<H00dk6aP0<aP03C/K600_60ThLP`03C/K600c600=>a/H0
2lH2CPg600=>a/H03<H00dk6aP0<aP03CYFE01ZE00=>Ph<06X<2CPg60Th=aP03C/K600c600=>a/H0
3<H00dk6aP0;aP9>3H400dk6aP0<aP03C/K600c600=>a/H02lH2CPg600=>a/H03<H00djEU@0JU@03
CP0000X0000B002bCLKFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6e/I=a]K6
e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTi=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3TdkFa]K6
e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]K6CLKFa]K6
e/KFa]K6e/KFCQbE06U=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Tdi=a]K6e/KFa]K6e/KFaTe>
e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCTd0
3H40Bdg6e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6
e/KFC]K6e/KFa]K6e/KFa]K6C@0LU@03CP0000X0000B0003C/K600_60Th=aP9>3<H2CPg60Th=aP9>
6h<2CPg60Th=aP9>3LH2CPc60Th=aP03CP1>01ZE00=>04h06h<2CPg60Th=aP9>3<H2CPg60Th=aP9>
3H42CPc60Th=aP9>3LH2CPg60Th<aP03CP1>01ZE00=>00002`0001800;==a]K6e/KFa]K6e/KFaTe>
e/KFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/KFCP1>
Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Tdh0C]K6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6e/I=C]K6
e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFaTd0C@0JU@1ZCP1>Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CPi>3Th==04g6e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KF
a]I>CLKFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFa]I>C@f104a=C]K6e/KFa]K6e/KFaTe>e/KFa]K6
e/KFa]K6eTi=a]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCP1>6YD00dd0
000;00004`000dk6aP09aP04CP00CP_600=>04h03<H00dh0CP0;aP04CP00CP_600E>0000CP0GP`05
CP0004h02lH014h004h;aP04CP00CP_600=>04h03<H00dh0CP0<aP03CP00009>5iD014h00002CQN3
00E>0000CP0;aP04CP00CP_600=>04h03<H00dh0CP0<aP03CP1>00_600A>001>2h400dh0CP0<aP03
CP1>00c600=>04h02lH014h004h;aP03CP1>00c600=>00000ThGU@03CP0000`0000D000<CLKFa]K6
e/KFa]I>0P003Dg6e/KFa]K6e/KFaTd00P003DkFa]K6e/KFa]K6eTh00P0034g6e/KFa]K6e/KFCP<0
00a>e/KFa]K6e/KFaTd4000HCTf3Th>CPi>3Th>CPi>3Th>CPi>3Th==100034kFa]K6e/KFa]K6C@<0
00a=a]K6e/KFa]K6eTh2000=CLKFa]K6e/KFa]K6C@02000=C]K6e/KFa]K6e/KFCP02000=CLKFa]K6
e/KFa]K6C@040003CYFE01>E00=>000010005df3Th>CPi>3Th>CPi>3Th>CPi>3Th==00D000a=a]K6
e/KFa]K6eTh3000<C]K6e/KFa]K6e/I=0P003DkFa]K6e/KFa]K6eTh00P003Dg6e/KFa]K6e/KFaTd0
0P0034kFa]K6e/KFa]K6C@<000==PH40284044h004g6e/KFa]K6e/KFaTd2000=C]K6e/KFa]K6e/KF
CP02000<CLKFa]K6e/KFa]I>0`0034kFa]K6e/KFa]K6C@8000e>e/KFa]K6e/KFa]I>00@000==UID0
4iD00dd0000=000050000dk6aP07aP03CP00008000=>a/H01lH00dh000020003C/K600K60Th30003
C/K600O60Th30003C/K600O600=>00001@000dj3P`0@P`9>1@000dk6aP07aP9>0`000dk6aP07aP03
CP00008000=>a/H01lH00dh000020003C/K600K60Th30003C/K600O60Th60003CYFE012E0Th80003
CX>301230Th60003C/K600O600=>00000P000dk6aP07aP03CP00008000=>a/H01/H2CP<000=>a/H0
1lH2CP<000=>a/H01lH00dh000020003CX6100N100=>00000P000dk6aP06aP9>0`000dk6aP07aP9>
0`000dk6aP07aP03CP00008000=>a/H01lH00dh000020003C/K600K60Th60003CYFE012E0Th@0000
5@002DkFa]K6e/KFCP060009CLKFa]K6e/I=00H000Q>e/KFa]K6C@H000U>e/KFa]K6eTh01P002Dg6
e/KFa]K6C@09000BCDjCPi>3Th>CPi>3Th>CCTe>20002Dg6e/KFa]K6C@060009C]K6e/KFa]I>00H0
00U=a]K6e/KFaTd01P0024kFa]K6e/I=1P002DkFa]K6e/KFCP090003CTfE00fE00=>C@002P004Te>
CH>CPi>3Th>CPi>3Th==CPT000U>e/KFa]K6eTh01P002Dg6e/KFa]K6C@060008C]K6e/KFaTd60009
C]K6e/KFa]I>00H000U=a]K6e/KFaTd01P000dj1P@05P@03CP0000@000Q=a]K6e/KFCPH000U=a]K6
e/KFaTd01P002DkFa]K6e/KFCP060009CLKFa]K6e/I=00H000Q>e/KFa]K6C@T000==CTd03ID00de>
000A00005P03CP;60Th800=>0/H2CPP00Th2aP9>2003CP;60Th800=>0/H2CP`00dh8P`9>3003CP;6
0Th800=>0/H2CPP00dh2aP9>2002CP;60Th800=>0/H2CP`00dh8U@=>4003CPN30dh<00=>0/H2CPP0
0dh2aP9>2002CP;60Th800=>0/H2CPP00dh2aP9>2003CP:10Th8009>0/H2CPP00dh2aP9>2003CP;6
0Th800=>0/H2CPP00Th2aP9>3@03CPNE0dhD00006@000di=000<0003CDh000/000==CP0030000di=
000<0003CDh0010000Q>CDi=CTe>CA4000==CP0030000di=000<0003CDh000/000==CP0030000di=
000@0008CDi=CTe>CDhF0007CDi=CTe>C@0B0003CTd000`000==CP002`000de>000<0003CTd000`0
00==CP0030000di=000;0003CTd000`000==CP0030000di=000<0003CDh000/000==CP004@001de>
CDi=CTd05`000?l0b`000?l0b`000?l0b`000?l0b`000001\
\>"],
  ImageRangeCache->{{{0, 457}, {31, 0}} -> {-0.737654, -0.712262, 0.0677797, 
  0.0459524}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .05 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0302343 0.025 0.047619 [
[ 0 0 0 0 ]
[ 1 .05 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .05 L
0 .05 L
closepath
clip
newpath
p
p
.9 g
.001 w
.05404 .025 m
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.08428 .025 m
matrix currentmatrix
.01512 .02381 scale
5.57512 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
5.57512 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.11451 .025 m
matrix currentmatrix
.01512 .02381 scale
7.57484 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
7.57484 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.14475 .025 m
matrix currentmatrix
.01512 .02381 scale
9.57521 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
9.57521 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.1901 .025 m
matrix currentmatrix
.03023 .02381 scale
6.28756 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
6.28756 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.23545 .025 m
matrix currentmatrix
.01512 .02381 scale
15.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
15.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.26568 .025 m
matrix currentmatrix
.01512 .02381 scale
17.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
17.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.29592 .025 m
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.32615 .025 m
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.35639 .025 m
matrix currentmatrix
.01512 .02381 scale
23.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
23.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.38662 .025 m
matrix currentmatrix
.01512 .02381 scale
25.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
25.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.43197 .025 m
matrix currentmatrix
.03023 .02381 scale
14.2874 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
14.2874 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.49244 .025 m
matrix currentmatrix
.03023 .02381 scale
16.2875 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
16.2875 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.53779 .025 m
matrix currentmatrix
.01512 .02381 scale
35.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
35.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.56803 .025 m
matrix currentmatrix
.01512 .02381 scale
37.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
37.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.59826 .025 m
matrix currentmatrix
.01512 .02381 scale
39.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
39.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.6285 .025 m
matrix currentmatrix
.01512 .02381 scale
41.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
41.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.67385 .025 m
matrix currentmatrix
.03023 .02381 scale
22.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
22.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.7192 .025 m
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.76455 .025 m
matrix currentmatrix
.03023 .02381 scale
25.2875 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
25.2875 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.8099 .025 m
matrix currentmatrix
.01512 .02381 scale
53.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
53.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.84014 .025 m
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.87037 .025 m
matrix currentmatrix
.01512 .02381 scale
57.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
57.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.9006 .025 m
matrix currentmatrix
.01512 .02381 scale
59.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
59.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.94596 .025 m
matrix currentmatrix
.03023 .02381 scale
31.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
31.2876 1.05 1 0 365.73 arc
setmatrix
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{458, 32},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007:000080P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5H/1JX00=d81_l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000e5D0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0b`000?l0b`000?l0b`000?l0b`000?l0
b`0001P000==CTd02`000de>C@0:0004CTe>C@X000A>CDi=3`001Te>CDi=CQ4000=>CDh02P0014e>
CDh:0004CDi=CPX000A=CTe>2P0014e>CDh:0003CDi=00l000M=CTe>CDi=01D000I=CTe>CDhA0003
CTe>00/000=>CDh02P0014e>CDh:0004CDi=CPl000I>CDi=CTdA0003CDi=00l000M=CTe>CDi=0100
00A>CDi=2P0014i=CTd:0003CTe>00/000=>CDh03`001Ti=CTe>CAL0000F009>0lH00dh0000500=>
0lH00dh00005009>1<H00dh00005009>1<H00dh0000900=>1X<5CPX00Th3aP03CP0000D00Th4aP03
CP0000D00Th4aP03CP0000D00Th4aP03CP0000D00Th4aP03CP0000D00Th3aP03CP0000T00dh7P`E>
3@03CPJE1Dh:009>0lH00dh00006009>0lH00dh00005009>1<H00dh00005009>1<H00dh0000900=>
1X<5CPX00Th3aP03CP0000T00dh7U@A>2P02CPC600=>00001@02CPC600=>00001@02CP?600=>0000
1P02CP?600=>00002@03CPJ31DhB00005@001dkFa]K6eTh01P0024g6e/KFa]I>1P0024g6e/KFa]I>
1P0024g6e/KFa]I>20004Te>CH>CPi>3Th>CPi>3Th>CCPP000M=a]K6e/I=00H000Q>e/KFa]K6C@H0
00Q>e/KFa]K6C@H000Q>e/KFa]K6C@H000Q>e/KFa]K6C@H000Q>e/KFa]K6C@P0019>CH>CPi>3Th>C
Pi>3Th>CPdd:0003CTfE00fE00=>00001P0024g6e/KFa]I>1P001dg6e/KFaTd01P0024kFa]K6e/I=
1P0024kFa]K6e/I=2@004De>Th>CPi>3Th>CPi>3Th==00P000Q>e/KFa]K6C@P000=>CID03ID00dh0
00060008CLKFa]K6eTh60008CLKFa]K6eTh60008CLKFa]K6eTh60007CLKFa]K6C@09000ACDjCPi>3
Th>CPi>3Th>CPdd04@0001@000=>a/H01LH00dh000020003C/K600K600=>00000P000dk6aP06aP03
CP00008000=>a/H01/H00dh00003009>4X<00dh000040003C/K600G600=>00000P000dk6aP06aP03
CP00008000=>a/H01/H00dh000020003C/K600K600=>00000P000dk6aP06aP03CP00008000=>a/H0
1/H00dh00003009>4H<00dh00006009>4ID00dh000040003C/K600K600=>00000P000dk6aP05aP03
CP00008000=>a/H01/H00dh000020003C/K600K600=>00000`03CQ6300=>000010000dk6aP06aP03
CP0000<00ThAU@03CP0000@000=>a/H01/H00dh000020003C/K600K600=>00000P000dk6aP06aP03
CP00008000=>a/H01LH00dh00004009>4H<00dh0000>00004`002dkFa]K6e/KFa]I>00<000]>e/KF
a]K6e/KFCP02000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP<001M>Th>CPi>3Th>CPi>3Th>C
Pi>3Th>CCP04000;CLKFa]K6e/KFaTd00P0034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd2000<
C]K6e/KFa]K6e/I=0P0034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd3000FCH>CPi>3Th>CPi>3
Th>CPi>3Th>CCPH000==UID04YD00dh00002000<CLKFa]K6e/KFa]I>0P002dg6e/KFa]K6e/I=0080
00a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=0`005df3Th>CPi>3Th>CPi>3Th>CPi>3Th==00@0
00a>e/KFa]K6e/KFaTd30003CIFE01:E00=>00000P0034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6
eTh2000<CLKFa]K6e/KFa]I>0P002dg6e/KFa]K6e/I=00@001I>Th>CPi>3Th>CPi>3Th>CPi>3Th==
3`0001<000=>a/H01lH01Dh0001>00W600A>001>2/H014h004h:aP05CP0004h05X<01Dh0001>00W6
00A>001>2/H014h004h:aP04CP00CP[600A>001>2/H014h004h:aP04CP00CQJ300=>00000P000djE
U@0DU@05CP0004h02/H014h004h9aP04CP00CP[600A>001>2/H01Dh0001>01J300E>0000CP0:aP04
CP00CQJE00E>0000CP0:aP04CP00CP[600A>001>2/H014h004h9aP05CP0004h05X<00dh0000<0000
4P00`4g6e/KFa]K6e/KFaTd0CLKFa]K6e/KFa]K6C@1=a]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTd0
CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Tdh0C]K6e/KFa]K6e/KFCP1>e/KFa]K6e/KFa]I>04kFa]K6
e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFaTd0CLKFa]K6e/KFa]K6C@1=Pi>3Th>CPi>3
Th>CPi>3Th>CPi>3Th>CCP8000==UID05YD0I4h0C]K6e/KFa]K6e/KFCP1>e/KFa]K6e/KFa]I>04kF
a]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFCP1>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3C@1=a]K6e/KF
a]K6e/I=04dHU@1DCP1>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFCP1>e/KF
a]K6e/KFa]I>04jCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==3@00018000=>a/H02LH00dh0CP0;aP03
CP1>00_60Th<aP03CP1>01R300=>04h02lH00dh0CP0;aP03CP1>00_60Th<aP9>2lH00dh0CP0;aP03
CP1>01R300A>001>69D00dh0CP0;aP03CP1>00_600=>04h02lH00dh0CP0;aP03CP1>01R300=>04h0
2lH00dh0CP0HU@03CP1>00c60Th<aP9>2lH00dh0CP0;aP03CP1>01R300=>00002`0001800<9=a]K6
e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=CY>3Th>CPi>3
Th>CPi>3Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]I>
CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>CPi>3
Th>CPi>3Th==CQZE069=C]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6
e/KFa]K6e/KFCTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Tdi=a]K6e/KFa]K6e/KFCQZE05A=C]K6
e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTf3Th>CPi>3
Th>CPi>3Th>CPi>3Th>CPi>3Tdh<00004P000dk6aP0:aP03C/K600_600=>a/H02/H2CPc60ThJP`03
C/K600_600=>a/H02lH00dk6aP0:aP9>3<H2CPc60Th<aP03CX>301R30ThJU@9>3<H00dk6aP0;aP03
C/K600_600=>a/H02/H2CQZ30Th<aP03CYFE01RE0Th<aP9>3<H2CPc600=>a/H02lH00dj3P`0HP`03
CP0000X0000A0033C]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KF
a]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KF
a]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTjC
Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>01ZE069=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6
CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3TdkFa]K6
e/KFa]K6e/KFCQ^E05=>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KF
a]K6e/KFa]K6CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP0<00004@000dk6aP0;aP03C/K600_6
00=>a/H02lH00dk6aP0;aP03CX>301R300=>a/H02lH00dk6aP0;aP03C/K600_600=>a/H02/H2CPc6
00=>a/H02lH00dj3P`0IP`03CYFE01RE00=>a/H02lH00dk6aP0;aP03C/K600_600=>a/H02lH00dj3
P`0HP`03C/K600_600=>UID06ID00dk6aP0;aP03C/K600[600=>a/H02lH00dk6aP0;aP03CX>301R3
0Th;00004@00`dkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KF
a]K6e/KFCY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KF
aTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP0JU@1RCLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6
e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>e/KFa]K6
e/KFa]K6eThKU@1DC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=a]K6e/KF
a]K6e/KFaTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Tdi=2`00014000=>a/H02lH00dk6aP0;aP03
C/K600_600=>a/H02/H2CQZ300=>a/H02lH00dk6aP0;aP03C/K600_600=>a/H02/H2CPc600=>a/H0
2lH00dj3P`0HP`9>6YD00dk6aP0;aP03C/K600_600=>a/H02lH00dk6aP0;aP03CX>301R300=>a/H0
2lH00djEU@0HU@9>3<H2CPc60Th<aP03C/K600_600=>Ph<068<00dh0000:00004@00`dkFa]K6e/KF
a]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=CY>3Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKF
a]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>CPi>3Th>C
Pi>3Th==CP0JU@1RCLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6
e/KFa]K6e/I=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>e/KFa]K6e/KFa]K6eThJU@1DCDkFa]K6
e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=Pi>3Th>CPi>3
Th>CPi>3Th>CPi>3Th>CPi=>3000018000=>a/H02/H2CP_60Th<aP9>3<H2CQV300=>04h02lH2CPc6
0Th<aP9>3<H2CPc60Th<aP9>6H<00dh0CP0HU@03CP1>00c60Th<aP03C/K600[60Th<aP9>6H<00dh0
CP0<aP9>6ID2CPc60Th<aP9>3<H2CPc60ThHP`03CP0000/0000B0030CLKFa]K6e/KFa]K6eTi=a]K6
e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6C@1=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3
Th>CCP1>e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>
CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>0P000dfE
U@0FU@1TCP1>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KF
a]I>04jCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==04g6e/KFa]K6e/KFa]I>CARE05A>04kFa]K6e/KF
a]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=CY>3Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CPdd=00004P000dk6aP09aP03CP1>00_600=>04h02lH00dh0CP0:aP05CP0004h0
5X<014h004h;aP03CP1>00_600=>04h02/H014h004h:aP04CP00CP[600=>04h02lH00dh00002CQF3
00=>00000P000djEU@0DU@04CP00CP_600=>04h02lH00dh0CP0;aP03CP1>00[600E>0000CP0FP`04
CP00CP_600=>00000ThEU@05CP0004h02/H014h004h:aP03CP1>00_600=>04h02lH00dh00002CQF3
00=>0000300001<000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=0P0034kFa]K6e/KFa]K6C@80
00]>e/KFa]K6e/KFCP04000FCH>CPi>3Th>CPi>3Th>CPi>3Th>CCP@000a=a]K6e/KFa]K6eTh2000<
CLKFa]K6e/KFa]I>0P002dg6e/KFa]K6e/I=00<000]=a]K6e/KFa]K6C@02000<C]K6e/KFa]K6e/I=
0P0034kFa]K6e/KFa]K6C@@001I>Th>CPi>3Th>CPi>3Th>CPi>3Th==1@000dfEU@0BU@03CP000080
00a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP8000]=a]K6e/KFa]K6
C@04000FCY>3Th>CPi>3Th>CPi>3Th>CPi>3C@@000a>e/KFa]K6e/KFaTd40003CYFE016E00=>0000
0`002dkFa]K6e/KFa]I>008000a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6
e/KFCP@001E=Pi>3Th>CPi>3Th>CPi>3Th>CPdd03`0001<000=>a/H01lH01Dh0001>00W600E>0000
CP08aP9>0`000dk6aP06aP03CP0000@000=>Ph<03h<2CPD000=>a/H01lH01Dh0001>00S60Th30003
C/K600K60Th30003C/K600K600=>00000P000dk6aP06aP05CP0004h02LH00dh000040003CX>300n3
0Th70003CYFE00nE0Th50003C/K600O600E>0000CP09aP05CP0004h02<H2CP<000=>a/H01/H2CPD0
00=>Ph<03h<2CPD000=>a/H01lH00dh000040003CYFE00jE0Th60003C/K600K60Th30003C/K600K6
00E>0000CP09aP05CP0004h02LH00dh000040003CX>300j30Th@000050002Dg6e/KFa]K6C@050009
CLKFa]K6e/I=00D000Q=a]K6e/KFCPH000Q=a]K6e/KFCPP0015=CTf3Th>CPi>3Th>CPi=>C@080009
C]K6e/KFa]I>00D000Q>e/KFa]K6C@H000Q>e/KFa]K6C@H000Q>e/KFa]K6C@H000Q>e/KFa]K6C@D0
00U=a]K6e/KFaTd020004Di=Pi>3Th>CPi>3Th>CCTe>00X000==CTd039D00di=00070009C]K6e/KF
a]I>00D000U>e/KFa]K6eTh01@0024kFa]K6e/I=1P0024kFa]K6e/I=20004Di=CY>3Th>CPi>3Th>C
Pde>00P000U=a]K6e/KFaTd020000di=U@0;U@03CTd000P000Q=a]K6e/KFCPH000Q=a]K6e/KFCPD0
00U>e/KFa]K6eTh01@002DkFa]K6e/KFCP08000@CDjCPi>3Th>CPi>3Th==CQ80000E00=>0/H2CPL0
0dh2aP9>1`03CP03aTi>00P00Th2aP9>3002CPN30dh;00=>0/H2CPL00dh00lI>CP0800=>00?6CTh0
2002CP;60Th8009>0/H2CPL00dh2aP9>2`03CPN30Th@009>29D2CP/00dh2aP9>1`03CP;60Th700=>
00?6CTh02003CP03aTi>00`00Th7P`=>2`03CP;60Th;00=>1iD2CP`00dh00lI>CP08009>0/H2CPL0
0dh2aP9>1`03CP;60Th;00=>1h<2CQ@0000H0003CDh000/000==CP002`000dd0000:0003CTd000l0
00M>CDi=CTe>014000=>C@002`000dh0000;0003CP0000X000==CP002`000de>000;0003CDh000l0
00M=CTe>CDi=01@000Q>CDi=CTe>CA0000=>C@002`000di=000;0003CP0000/000=>00003P001de>
CDi=CTd04@000de>000?0007CDi=CTe>C@0A0003C@0000X000=>C@002`000di=000;0003CTd000l0
00M>CDi=CTe>01H0003o0</0003o0</0003o0</0003o0</00000\
\>"],
  ImageRangeCache->{{{0, 457}, {31, 0}} -> {-0.787665, -0.712262, 0.0723749, 
  0.0459524}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .05 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0302343 0.025 0.047619 [
[ 0 0 0 0 ]
[ 1 .05 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .05 L
0 .05 L
closepath
clip
newpath
p
p
.9 g
.001 w
.05404 .025 m
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.08428 .025 m
matrix currentmatrix
.01512 .02381 scale
5.57512 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
5.57512 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.11451 .025 m
matrix currentmatrix
.01512 .02381 scale
7.57484 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
7.57484 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.15986 .025 m
matrix currentmatrix
.03023 .02381 scale
5.28737 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
5.28737 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.20522 .025 m
matrix currentmatrix
.01512 .02381 scale
13.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
13.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.23545 .025 m
matrix currentmatrix
.01512 .02381 scale
15.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
15.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.26568 .025 m
matrix currentmatrix
.01512 .02381 scale
17.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
17.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.29592 .025 m
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.32615 .025 m
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.35639 .025 m
matrix currentmatrix
.01512 .02381 scale
23.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
23.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.40174 .025 m
matrix currentmatrix
.03023 .02381 scale
13.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
13.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.44709 .025 m
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.47732 .025 m
matrix currentmatrix
.01512 .02381 scale
31.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
31.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.52268 .025 m
matrix currentmatrix
.03023 .02381 scale
17.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
17.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.56803 .025 m
matrix currentmatrix
.01512 .02381 scale
37.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
37.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.59826 .025 m
matrix currentmatrix
.01512 .02381 scale
39.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
39.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.64361 .025 m
matrix currentmatrix
.03023 .02381 scale
21.2874 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
21.2874 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.68896 .025 m
matrix currentmatrix
.01512 .02381 scale
45.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
45.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.7192 .025 m
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.74943 .025 m
matrix currentmatrix
.01512 .02381 scale
49.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
49.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.79478 .025 m
matrix currentmatrix
.03023 .02381 scale
26.2873 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
26.2873 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.84014 .025 m
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.87037 .025 m
matrix currentmatrix
.01512 .02381 scale
57.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
57.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.91572 .025 m
matrix currentmatrix
.03023 .02381 scale
30.2874 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
30.2874 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.96107 .025 m
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{458, 32},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007:000080P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5H/1JX00=d81_l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000e5D0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0b`000?l0b`000?l0b`000?l0b`000?l0
b`0001P000==CTd02`000de>C@0:0004CTe>C@l000I=CTe>CDhA0003CTe>00/000=>CDh02P0014e>
CDh:0004CDi=CPX000A=CTe>2P0014e>CDh>0007CDi=CTe>C@0@0004CTe>C@X000A>CDi=3`001Te>
CDi=CQ4000=>CDh02P0014e>CDh?0006CTe>CDi=4@0014e>CDh:0003CDi=00/000==CTd03`001Te>
CDi=CQ4000A>CDi=2P000di=CP0?0007CTe>CDi=CP0@0004CDi=CQ00000F009>0lH00dh0000500=>
0lH00dh00005009>1<H00dh0000900=>1X<5CPX00Th3aP03CP0000H00Th3aP03CP0000D00Th4aP03
CP0000D00Th4aP03CP0000D00Th4aP03CP0000D00Th4aP03CP0000T00Th7P`E>2@02CPC600=>0000
1@02CPC600=>00002@03CPJE1Dh:009>0lH00dh00005009>1<H00dh0000900=>1X<5CPX00Th4aP03
CP0000D00Th3aP03CP0000D00dh3aP03CP0000T00dh6U@E>2P02CPC600=>00001@02CP?600=>0000
2P02CPN31Dh9009>1<H00dh0000=00005@001dkFa]K6eTh01P0024g6e/KFa]I>1P0024g6e/KFa]I>
2@004Di=Pi>3Th>CPi>3Th>CPi=>00P000Q=a]K6e/KFCPH000M=a]K6e/I=00H000Q>e/KFa]K6C@H0
00Q>e/KFa]K6C@H000Q>e/KFa]K6C@H000Q>e/KFa]K6C@P0019>CDjCPi>3Th>CPi>3Th>CPdd70008
CLKFa]K6eTh60008CLKFa]K6eTh80003CDi=00jE00=>00001P001dg6e/KFaTd01P0024kFa]K6e/I=
2@004De>Th>CPi>3Th>CPi>3Th==00P000Q>e/KFa]K6C@H000Q>e/KFa]K6C@D000Q=a]K6e/KFCPT0
00=>CID03ID00dh000060008CLKFa]K6eTh60008CLKFa]K6eTh8000BCDi=Pi>3Th>CPi>3Th>CPi=>
1`0024kFa]K6e/I=3`0001@000=>a/H01LH00dh000020003C/K600K600=>00000P000dk6aP06aP03
CP0000@00ThAP`03CP0000@000=>a/H01/H00dh000020003C/K600G600=>00000P000dk6aP06aP03
CP00008000=>a/H01/H00dh000020003C/K600K600=>00000P000dk6aP06aP03CP0000<00ThBP`03
CP0000<000=>a/H01/H00dh000020003C/K600K600=>00000`02CQ:E00=>000010000dk6aP05aP03
CP00008000=>a/H01/H00dh00004009>4H<00dh000040003C/K600K600=>00000P000dk6aP06aP05
CP0004h02<H00dh00004009>4ID00dh000040003C/K600K600=>00000P000dk6aP06aP03CP0000<0
0ThBP`03CP0000<000=>a/H01/H00dh0000<00004`002dkFa]K6e/KFa]I>00<000]>e/KFa]K6e/KF
CP02000<CLKFa]K6e/KFa]I>10005Tf3Th>CPi>3Th>CPi>3Th>CPi>3Tdh4000<CLKFa]K6e/KFa]I>
0P002dg6e/KFa]K6e/I=008000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=0P0034kFa]K6e/KF
a]K6C@8000a>e/KFa]K6e/KFaTd3000GCH>CPi>3Th>CPi>3Th>CPi>3Th>CPdd00`0034g6e/KFa]K6
e/KFCP8000a=a]K6e/KFa]K6eTh30003CYFE01>E00=>00000P002dg6e/KFa]K6e/I=008000a>e/KF
a]K6e/KFaTd4000FCY>3Th>CPi>3Th>CPi>3Th>CPi>3C@@000a>e/KFa]K6e/KFaTd2000<C]K6e/KF
a]K6e/I=0P002dkFa]K6e/KFa]I>00@000==UID04YD00dh00002000<CLKFa]K6e/KFa]I>0P0034g6
e/KFa]K6e/KFCP<001M>Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP03000<C]K6e/KFa]K6e/I=3@0001<0
00=>a/H01lH01Dh0001>00W600A>001>2/H01Dh0001>01J300E>0000CP0:aP04CP00CPW600A>001>
2/H014h004h:aP04CP00CP[600A>001>2/H01Dh0001>01F300E>0000CP0:aP04CP00CP[600E>0000
CP0EU@03CP00008000=>a/H01lH014h004h:aP05CP0004h05X<01Dh0001>00[600A>001>2/H014h0
04h9aP05CP0004h05YD01Dh0001>00[600A>001>2/H014h004hFP`05CP0004h02/H00dh0000;0000
4P00Udg6e/KFa]K6e/KFaTd0CLKFa]K6e/KFa]K6C@1=a]K6e/KFa]K6e/I=04f3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CPi=>04kFa]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFCP1>e/KFa]K6e/KFa]I>04kFa]K6
e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFaTd00P006DjCPi>3Th>CPi>3Th>CPi>3Th>C
Pi>3Tdh00P007Dg6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6C@1=01NE06E=001>e/KFa]K6e/KFa]I>
04kFa]K6e/KFa]K6eTh0CY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdd0CLKFa]K6e/KFa]K6C@1=a]K6
e/KFa]K6e/I=04g6e/KFa]K6e/KFaTd0C@0HU@0hCP1>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6eTh0
CY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdd2000=C]K6e/KFa]K6e/KFCP0<00004P000dk6aP09aP03
CP1>00_600=>04h02lH00dh0CP0HP`03CP1>00_600=>04h02lH00dh0CP0;aP03CP1>00_60Th<aP9>
2lH014h004hGP`04CP00CP_60Th<aP03CP1>01RE00=>04h02lH00dh0CP0;aP03CP1>01R300=>04h0
2lH00dh0CP0;aP03CP1>00_600=>04h069D00dh0CP0<aP9>2lH00dh0CP0HP`04CP00CP_600=>0000
2P0001800=1=a]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CDjCPi>3Th>CPi>3
Th>CPi>3Th>CPi>3Th>CPde>e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6
e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTf3Th>CPi>3Th>CPi>3Th>CPi>3
Th>CPi>3CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>6YD0HTg6e/KFa]K6e/KFa]K6CLKFa]K6
e/KFa]K6e/I=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6
e/KFC]K6e/KFa]K6e/KFa]I>6YD0ATe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=CY>3Th>CPi>3
Th>CPi>3Th>CPi>3Th>CPi=>CLKFa]K6e/KFa]K6eTh<00004P000dk6aP0:aP03C/K600_600=>a/H0
2/H2CQZ30Th<aP03C/K600_600=>a/H02lH00dk6aP0:aP9>3<H2CPc60ThIP`9>3<H2CPc60ThJU@03
C/K600_600=>a/H02lH00dj3P`0HP`9>3<H2CPc600=>a/H02lH00djEU@0HU@9>3<H2CPc60ThIP`9>
3<H00dh0000:00004@00dDkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTjC
Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KF
a]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCY>3Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CPi>3TdkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>01ZE069=a]K6e/KFa]K6
e/KFaTg6e/KFa]K6e/KFa]K6CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCTg6e/KFa]K6e/KFa]I>
e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCQZE04M=C]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6
CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdg6e/KFa]K6e/KFa]K6C@0;00004@000dk6aP0;aP03
C/K600_600=>a/H02lH00dj3P`0HP`03C/K600_600=>a/H02lH00dk6aP0;aP03C/K600_600=>a/H0
2/H2CPc600=>Ph<06H<00dk6aP0;aP03C/K600_600=>UID069D00dk6aP0;aP03C/K600_600=>Ph<0
68<2CPc600=>a/H02lH00dk6aP0;aP03CYFE01RE0Th<aP03C/K600_600=>Ph<06H<00dk6aP0;aP03
CP0000T0000A003AC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCY>3Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KF
a]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTh06YD0HTg6e/KFa]K6e/KFa]K6
CLKFa]K6e/KFa]K6e/I=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>CLKFa]K6e/KFa]K6eTkFa]K6
e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>6YD0Ade>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=Pi>3
Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6e/I=00/0000A0003C/K600_600=>a/H0
2lH00dk6aP0;aP03CX>301R300=>a/H02lH00dk6aP0;aP03C/K600_600=>a/H02lH00dk6aP0:aP9>
3<H00dj3P`0IP`03C/K600_600=>a/H02/H2CQZE00=>a/H02lH00dk6aP0;aP03CX>301R30Th<aP03
C/K600_600=>a/H02lH00djEU@0HU@9>3<H2CPc600=>Ph<068<2CPg600=>00002@0001400=5>e/KF
a]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>CPi>3Th>C
Pi>3Th==a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KF
aTg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>e/KF
a]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=CP0JU@1RCLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTf3
Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Tdi=a]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6
e/KFa]K6eThJU@17CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTf3Th>CPi>3Th>CPi>3Th>CPi>3
Th>CPi>3Tdi=a]K6e/KFa]K6e/KFaTd02`00018000=>a/H02/H2CP_60Th<aP03CP1>01R300=>04h0
3<H2CP_60Th<aP9>3<H2CPc60Th<aP9>6H<2CPc60Th<aP9>6ID00dh0CP0<aP03C/K600[600=>04h0
68<00dh0CP0<aP9>3<H2CP_600=>04h069D00dh0CP0<aP9>3<H2CQV30Th<aP03CP0000X0000B003A
CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTd0CH>CPi>3Th>CPi>3Th>CPi>3
Th>CPi>3Tdh0C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6
e/KFCTg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP1>
e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=04d069D0I4h0C]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KF
a]I>04jCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==04g6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=
a]K6e/KFa]K6e/I=04dHU@17CP1>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=CY>3Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CPdd0CLKFa]K6e/KFa]K6eTh03000018000=>a/H02LH00dh0CP0;aP03CP1>00_6
00A>001>5X<014h004h;aP03CP1>00_600=>04h02lH00dh0CP0:aP04CP00CP[600A>001>2/H00dh0
0002CQF300E>0000CP0;aP03CP1>00[600E>0000CP0FU@04CP00CP_600=>04h02lH014h004hFP`05
CP0004h02/H00dh0CP0;aP03CP1>00_600=>00000ThEU@05CP0004h02/H00dh0CP0;aP03CP00009>
5H<01Dh0001>00_600=>00002P0001<000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=0P0034kF
a]K6e/KFa]K6C@<001I=Pi>3Th>CPi>3Th>CPi>3Th>CPi=>100034g6e/KFa]K6e/KFCP8000a=a]K6
e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>0P002dg6e/KFa]K6e/I=00<000]=a]K6e/KFa]K6C@02000<
C]K6e/KFa]K6e/I=10005TjCPi>3Th>CPi>3Th>CPi>3Th>CPdd4000<C]K6e/KFa]K6e/I=0P002dkF
a]K6e/KFa]I>00@000==UID04YD00dh00002000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP<0
01I>CH>CPi>3Th>CPi>3Th>CPi>3Th==100034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd2000<
C]K6e/KFa]K6e/I=10000djEU@0AU@03CP00008000a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>
10005Tf3Th>CPi>3Th>CPi>3Th>CPi>3Tdh4000<CLKFa]K6e/KFa]I>300001<000=>a/H01lH01Dh0
001>00W600E>0000CP08aP9>1@000dj3P`0?P`9>1@000dk6aP07aP05CP0004h02LH01Dh0001>00S6
0Th30003C/K600K60Th30003C/K600K600=>00000P000dk6aP06aP03CP0000@000=>Ph<03h<2CPD0
00=>a/H01/H2CP<000=>a/H01/H2CPD000=>UID03iD2CPD000=>a/H01lH01Dh0001>00S60Th60003
CX>300j30Th60003C/K600K600E>0000CP09aP05CP0004h02LH00dh000040003CYFE00jE0Th60003
C/K600K600E>0000CP09aP03CP0000@000=>Ph<03h<2CPD000=>a/H01/H2CPd0000D0009CLKFa]K6
e/I=00D000U=a]K6e/KFaTd01@0024g6e/KFa]I>20004De>CH>CPi>3Th>CPi>3Tdi=00P000U>e/KF
a]K6eTh01@002DkFa]K6e/KFCP050008C]K6e/KFaTd60008C]K6e/KFaTd60008C]K6e/KFaTd60008
C]K6e/KFaTd8000ACTf3Th>CPi>3Th>CPi>3CDh0200024g6e/KFa]I>1P0024g6e/KFa]I>20000de>
C@0<U@03CTd000L000U>e/KFa]K6eTh01@0024kFa]K6e/I=2@0044e>Th>CPi>3Th>CPi>3CDh90008
C]K6e/KFaTd50009CLKFa]K6e/I=00D000U=a]K6e/KFaTd020000di=U@0;U@03CTd000P000Q=a]K6
e/KFCPD000U>e/KFa]K6eTh020004De>Th>CPi>3Th>CPi>3CDi=00P000Q>e/KFa]K6C@l0000E00=>
0/H2CPL00dh2aP9>1`03CP03aTi>00`00Th8P`9>2`03CP;60Th700=>0/H2CPL00dh00lI>CP0800=>
00?6CTh02002CP;60Th8009>0/H2CP/00dh7P`=>2`03CP03aTi>00P00dh00lI>CP0<009>1iD3CP/0
0dh2aP9>1`03CP03aTi>00`00dh7P`9>3002CP;60Th700=>0/H2CPL00dh2aP9>2`03CPNE0Th<009>
0/H2CPL00dh2aP9>2`03CPN30Th<00=>00?6CTh0400001P000==CP002`000de>000;0003C@0000h0
00Q>CDi=CTe>CA0000=>C@002`000di=000;0003CP0000/000=>00002P000de>000;0003CDh000l0
00M=CTe>CDi=014000==00002`000dd0000>0007CTe>CDi=CP0A0003CTd000/000=>00003`001di=
CTe>CDh040000de>000;0003CDh000/000==CP003`001de>CDi=CTd040000di=000;0003CTd000l0
00M>CDi=CTe>014000=>000040000?l0b`000?l0b`000?l0b`000?l0b`000001\
\>"],
  ImageRangeCache->{{{0, 457}, {31, 0}} -> {-0.787665, -0.712262, 0.0723749, 
  0.0459524}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .05 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0302343 0.025 0.047619 [
[ 0 0 0 0 ]
[ 1 .05 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .05 L
0 .05 L
closepath
clip
newpath
p
p
.9 g
.001 w
.05404 .025 m
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.08428 .025 m
matrix currentmatrix
.01512 .02381 scale
5.57512 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
5.57512 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.12963 .025 m
matrix currentmatrix
.03023 .02381 scale
4.28751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
4.28751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.17498 .025 m
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.20522 .025 m
matrix currentmatrix
.01512 .02381 scale
13.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
13.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.23545 .025 m
matrix currentmatrix
.01512 .02381 scale
15.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
15.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.26568 .025 m
matrix currentmatrix
.01512 .02381 scale
17.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
17.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.29592 .025 m
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.32615 .025 m
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.3715 .025 m
matrix currentmatrix
.03023 .02381 scale
12.2874 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
12.2874 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.41686 .025 m
matrix currentmatrix
.01512 .02381 scale
27.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
27.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.44709 .025 m
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.47732 .025 m
matrix currentmatrix
.01512 .02381 scale
31.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
31.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.50756 .025 m
matrix currentmatrix
.01512 .02381 scale
33.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
33.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.55291 .025 m
matrix currentmatrix
.03023 .02381 scale
18.2875 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
18.2875 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.61338 .025 m
matrix currentmatrix
.03023 .02381 scale
20.2875 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
20.2875 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.65873 .025 m
matrix currentmatrix
.01512 .02381 scale
43.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
43.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.68896 .025 m
matrix currentmatrix
.01512 .02381 scale
45.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
45.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.7192 .025 m
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.74943 .025 m
matrix currentmatrix
.01512 .02381 scale
49.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
49.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.77967 .025 m
matrix currentmatrix
.01512 .02381 scale
51.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
51.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.82502 .025 m
matrix currentmatrix
.03023 .02381 scale
27.2875 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
27.2875 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.88549 .025 m
matrix currentmatrix
.03023 .02381 scale
29.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
29.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.93084 .025 m
matrix currentmatrix
.01512 .02381 scale
61.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
61.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.96107 .025 m
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{458, 32},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007:000080P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5H/1JX00=d81_l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000e5D0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0b`000?l0b`000?l0b`000?l0b`000?l0
b`0001P000==CTd02`000de>C@0?0006CDi=CTe>4@0014i=CTd:0003CTe>00/000=>CDh02P0014e>
CDh:0004CDi=CPX000A=CTe>3`001Ti=CTe>CA4000==CTd02P0014i=CTd:0004CTe>C@X000A>CDi=
3P001di=CTe>CDh05@001di=CTe>CDh0400014e>CDh:0004CDi=CPX000==CTd02`000de>C@0:0004
CTe>C@l000I=CTe>CDhE0007CTe>CDi=CP0@0004CDi=CPX000A=CTe>400001H00Th3aP03CP0000D0
0dh3aP03CP0000T00dh6P`E>2P02CPC600=>00001@02CP?600=>00001P02CP?600=>00001@02CPC6
00=>00001@02CPC600=>00001@02CPC600=>00002@03CPJ31Dh900=>0lH00dh00005009>1<H00dh0
0005009>1<H00dh00005009>1<H00dh00009009>1iD5CPd00dh7P`A>2P02CPC600=>00001@02CPC6
00=>00001@02CP?600=>00001@03CP?600=>00001@02CPC600=>00002@03CPJE1Dh>009>1h<5CPT0
0Th4aP03CP0000D00Th4aP03CP0000d0000E0007C]K6e/KFCP060008CLKFa]K6eTh9000ACTf3Th>C
Pi>3Th>CPi>3Tdh0200024g6e/KFa]I>1P0024g6e/KFa]I>1P001dg6e/KFaTd01P0024kFa]K6e/I=
1P0024kFa]K6e/I=1P0024kFa]K6e/I=20004Ti=CY>3Th>CPi>3Th>CPi>3C@L000Q=a]K6e/KFCPH0
00Q=a]K6e/KFCPH000Q=a]K6e/KFCPH000Q=a]K6e/KFCPP000==CTd03YD00dh00008000ACDjCPi>3
Th>CPi>3Th>CPdd0200024kFa]K6e/I=1P0024kFa]K6e/I=1P0024kFa]K6e/I=1@0024g6e/KFa]I>
1P0024g6e/KFa]I>2@000di=U@0=U@03CP0000P0019=CTf3Th>CPi>3Th>CPi>3Tdh70008C]K6e/KF
aTd60008C]K6e/KFaTd?000050000dk6aP05aP03CP00008000=>a/H01/H00dh00004009>4H<00dh0
00040003C/K600K600=>00000P000dk6aP06aP03CP00008000=>a/H01LH00dh000020003C/K600K6
00=>00000P000dk6aP06aP03CP00008000=>a/H01/H00dh00003009>4X<00dh000030003C/K600K6
00=>00000P000dk6aP06aP03CP00008000=>a/H01/H00dh000020003C/K600K600=>00000`02CQ:E
00=>00001@02CQ6300=>000010000dk6aP06aP03CP00008000=>a/H01/H00dh000020003C/K600K6
00E>0000CP08aP03CP00008000=>a/H01/H00dh0000300=>4ID00dh00005009>4X<00dh000030003
C/K600K600=>00000P000dk6aP06aP03CP0000`0000C000;C]K6e/KFa]K6eTh00`002dkFa]K6e/KF
a]I>00@001I=Pi>3Th>CPi>3Th>CPi>3Th>CPi=>100034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6
eTh2000;CLKFa]K6e/KFaTd00P0034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd2000<C]K6e/KF
a]K6e/I=0`005df3Th>CPi>3Th>CPi>3Th>CPi>3Th==00@000]>e/KFa]K6e/KFCP02000<CLKFa]K6
e/KFa]I>0P0034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6eTh30003CYFE01>E00=>00000`005TjC
Pi>3Th>CPi>3Th>CPi>3Th>CPdd4000<C]K6e/KFa]K6e/I=0P0034kFa]K6e/KFa]K6C@8000a>e/KF
a]K6e/KFaTd2000;C]K6e/KFa]K6eTh00P0034g6e/KFa]K6e/KFCP<000=>UID04iD00dh00003000G
CY>3Th>CPi>3Th>CPi>3Th>CPi>3Tdh00`0034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd=0000
4`000dk6aP07aP05CP0004h02LH01Dh0001>01J300E>0000CP0:aP04CP00CP[600A>001>2LH014h0
04h:aP04CP00CP[600A>001>2/H01Dh0001>01F300=>00000P000dk6aP07aP04CP00CP[600A>001>
2/H014h004h:aP05CP0004h05ID00dh000020003CX>301B300E>0000CP0:aP04CP00CP[600A>001>
2/H014h004h9aP04CP00CP[600E>0000CP0FU@03CP00008000=>Ph<04h<01Dh0001>00[600A>001>
2/H00dh0000;00004P00Y4g6e/KFa]K6e/KFaTd0CLKFa]K6e/KFa]K6C@1=Pi>3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CCP1>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFCP1>e/KFa]K6
e/KFa]I>04kFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCP1>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>
0P00>Dg6e/KFa]K6e/KFaTd0CLKFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTd0
C@0GU@1UC@00CY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdd0CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6
e/I=04g6e/KFa]K6e/KFaTd0CLKFa]K6e/KFa]K6C@1=a]K6e/KFa]K6e/I=04d069D074h004f3Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CPdd2000KC]K6e/KFa]K6e/KFCP1>e/KFa]K6e/KFa]I>00`0000B0003
C/K600W600=>04h02lH00dh0CP0HP`03CP1>00c60Th;aP03CP1>00_600=>04h02lH00dh0CP0;aP9>
3<H00dh0CP0GP`04CP00CP_600=>04h02lH2CPc60Th<aP03CP1>01NE00A>001>68<00dh0CP0<aP9>
2lH00dh0CP0;aP03CP1>00_600=>04h02lH00dh0CP0HU@04CP00CQN300A>001>2lH00dh0CP0;aP03
CP0000X0000B003NCLKFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCY>3Th>CPi>3Th>CPi>3Th>CPi>3
Th>CPi>3CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6
e/I=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==C]K6
e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>6ID0Hdi=
Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6e/KF
a]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=CP0JU@0hCDjCPi>3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CCTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6eTh<00004P000dk6aP0:aP03C/K600_6
00=>Ph<068<2CPc60Th<aP03C/K600_600=>a/H02lH00dk6aP0:aP9>3<H2CQV30Th=aP03C/K600[6
0Th<aP9>3<H2CQVE0ThJP`9>3<H2CPc60Th<aP03C/K600_600=>a/H02/H2CQZE0ThIP`9>3LH00dk6
aP0:aP03CP0000X0000A003NC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CPde>e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KF
a]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFCY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>C
Pi>3TdkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=
6iD0HTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>
e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>6YD0>Df3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CPi>3Th==a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6C@0;00004@000dk6aP0;aP03
C/K600_600=>Ph<068<2CPc600=>a/H02lH00dk6aP0;aP03C/K600_600=>a/H02lH00dk6aP0:aP03
CX>301V300=>a/H02lH00dk6aP0;aP03C/K600_600=>a/H02/H00djEU@0IU@03CX>301V300=>a/H0
2/H2CPc600=>a/H02lH00dk6aP0;aP03C/K600_600=>UID069D00dj3P`0IP`03C/K600_600=>a/H0
2lH00dh0000900004@00gTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>C
Pi>3Th>CPi>3Th==C]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KF
a]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6eTi=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>C
Pi=>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CA^E
069=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFC]K6
e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCQZE03U=Pi>3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTd02`00014000=>a/H02lH00dk6
aP0;aP03CX>301R30Th<aP03C/K600_600=>a/H02lH00dk6aP0;aP03C/K600_600=>a/H02/H2CQZ3
00=>a/H02lH00dk6aP0;aP03C/K600[60Th<aP03CYFE01VE00=>Ph<068<2CPc60Th<aP03C/K600_6
00=>a/H02lH00dk6aP0;aP03CYFE01RE00=>Ph<06H<00dk6aP0;aP03C/K600_600=>00002@000140
0=i>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CDkF
a]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KF
a]K6e/KFaTg6e/KFa]K6e/KFa]I>CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CC]K6e/KFa]K6e/KF
a]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTdKU@1RCH>CPi>3Th>CPi>3
Th>CPi>3Th>CPi>3Th>CCTg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6
e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eThJU@0iCH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdg6
e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=00/0000B0003C/K600[60Th;aP03CP1>01R300=>04h0
3<H2CPc60Th;aP9>3<H2CPc60Th<aP9>6H<00dh0CP0;aP9>3<H2CPc60Th<aP9>6ID00dh0CP0IP`9>
3<H2CPc60Th<aP9>2lH2CPc60ThIU@03CP1>01V30Th<aP9>3<H00dh0000:00004P00gTg6e/KFa]K6
e/KFa]I>CLKFa]K6e/KFa]K6C@1=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP1>e/KFa]K6e/KFa]K6
CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=a]K6
e/KFa]K6e/KFCTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3C@1=a]K6e/KFa]K6e/I=C]K6e/KFa]K6
e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=CQVE06A>04jCPi>3Th>CPi>3Th>CPi>3Th>C
Pi>3Th==04g6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KF
aTe>e/KFa]K6e/KFa]K6C@1=69D0>Dh0CY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>CLKFa]K6e/KF
a]K6eTi=a]K6e/KFa]K6e/KFCP0<00004P000dk6aP09aP03CP1>00_600=>00000ThEP`05CP0004h0
2/H00dh0CP0;aP03CP1>00_600=>04h02lH00dh0CP0:aP04CP00CP[600=>00000ThFP`04CP00CP_6
00=>04h02lH00dh0CP0:aP04CP00CP[600=>00000ThFU@04CP00009>5H<01Dh0001>00[600A>001>
2/H00dh0CP0;aP03CP1>00_600=>04h02lH014h004hFU@04CP00009>5X<014h004h;aP03CP1>00_6
00=>00002P0001<000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=10005DjCPi>3Th>CPi>3Th>C
Pi>3Th>CCP04000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6eTh2000<
CLKFa]K6e/KFa]I>0P002dg6e/KFa]K6e/I=00<000]=a]K6e/KFa]K6C@04000FCY>3Th>CPi>3Th>C
Pi>3Th>CPi>3C@@000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=0P002dkFa]K6e/KFa]I>0080
00a=a]K6e/KFa]K6eTh40003CIFE01:E00=>000010005Df3Th>CPi>3Th>CPi>3Th>CPi>3C@05000;
CLKFa]K6e/KFaTd00P0034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=
0P0034kFa]K6e/KFa]K6C@<000==UID04YD00dh00004000FCH>CPi>3Th>CPi>3Th>CPi>3Th>CCP@0
00a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>300001<000=>a/H01lH01Dh0001>00W600=>0000
10000dj3P`0>P`9>1P000dk6aP06aP05CP0004h02LH01Dh0001>00W600E>0000CP08aP9>0`000dk6
aP06aP9>0`000dk6aP06aP03CP0000@000=>Ph<03h<2CPD000=>a/H01lH01Dh0001>00S60Th30003
C/K600K60Th30003C/K600K600=>000010000djEU@0?U@9>20000dj3P`0>P`9>1P000dk6aP06aP03
CP00008000=>a/H01/H01Dh0001>00W600E>0000CP09aP05CP0004h02<H2CPD000=>UID03iD2CPP0
00=>Ph<03h<2CPD000=>a/H01/H2CP<000=>a/H01/H2CPd0000D0009CLKFa]K6e/I=00D000U=a]K6
e/KFaTd0200044i=Pi>3Th>CPi>3Th>CCTd90008CLKFa]K6eTh50009C]K6e/KFa]I>00D000U>e/KF
a]K6eTh01@0024kFa]K6e/I=1P0024kFa]K6e/I=1P0024kFa]K6e/I=20004Di=CY>3Th>CPi>3Th>C
Pde>00P000U=a]K6e/KFaTd01@0024g6e/KFa]I>1P0024g6e/KFa]I>1P0024g6e/KFa]I>20000de>
U@0<U@03CTd000X0011=CY>3Th>CPi>3Th>CPde>2@0024kFa]K6e/I=1P0024kFa]K6e/I=1@002Dg6
e/KFa]K6C@050009CLKFa]K6e/I=00D000Q=a]K6e/KFCPP000==CTd039D00di=000:000ACDjCPi>3
Th>CPi>3Th>CCTd0200024kFa]K6e/I=1P0024kFa]K6e/I=3`0001D00dh2aP9>1`03CP;60Th;00=>
1h<2CP`00Th2aP9>1`03CP;60Th700=>0/H2CPL00dh00lI>CP0800=>00?6CTh02002CP;60Th<009>
1h<3CP/00dh2aP9>1`03CP03aTi>00P00dh00lI>CP08009>0/H2CP/00dh7U@=>3`03CPN30Th<009>
0/H2CPP00Th2aP9>1`03CP;60Th700=>0/H2CPL00dh00lI>CP0<009>29D2CPl00dh7P`=>2`03CP03
aTi>00P00dh00lI>CP0@000060000de>000;0003CDh000l000M=CTe>CDi=010000=>C@002`000di=
000;0003CTd000/000=>00002`000dh0000:0003CDh000l000M=CTe>CDi=014000==CP002`000dd0
000;0003C@0000X000=>C@003`001di=CTe>CDh05@001di=CTe>CDh040000de>000;0003CDh000/0
00==CP002`000de>000;0003C@0000h000Q>CDi=CTe>CA@000M>CDi=CTe>014000=>00002`000dh0
000@0000o`3;0000o`3;0000o`3;0000o`3;0000\
\>"],
  ImageRangeCache->{{{0, 457}, {31, 0}} -> {-0.787665, -0.712262, 0.0723749, 
  0.0459524}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .05 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0302343 0.025 0.047619 [
[ 0 0 0 0 ]
[ 1 .05 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .05 L
0 .05 L
closepath
clip
newpath
p
p
.9 g
.001 w
.05404 .025 m
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.0994 .025 m
matrix currentmatrix
.03023 .02381 scale
3.28766 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
3.28766 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.14475 .025 m
matrix currentmatrix
.01512 .02381 scale
9.57521 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
9.57521 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.17498 .025 m
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.20522 .025 m
matrix currentmatrix
.01512 .02381 scale
13.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
13.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.23545 .025 m
matrix currentmatrix
.01512 .02381 scale
15.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
15.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.26568 .025 m
matrix currentmatrix
.01512 .02381 scale
17.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
17.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.29592 .025 m
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.34127 .025 m
matrix currentmatrix
.03023 .02381 scale
11.2875 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
11.2875 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.38662 .025 m
matrix currentmatrix
.01512 .02381 scale
25.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
25.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.41686 .025 m
matrix currentmatrix
.01512 .02381 scale
27.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
27.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.44709 .025 m
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.47732 .025 m
matrix currentmatrix
.01512 .02381 scale
31.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
31.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.50756 .025 m
matrix currentmatrix
.01512 .02381 scale
33.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
33.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.55291 .025 m
matrix currentmatrix
.03023 .02381 scale
18.2875 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
18.2875 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.61338 .025 m
matrix currentmatrix
.03023 .02381 scale
20.2875 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
20.2875 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.65873 .025 m
matrix currentmatrix
.01512 .02381 scale
43.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
43.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.68896 .025 m
matrix currentmatrix
.01512 .02381 scale
45.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
45.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.7192 .025 m
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.74943 .025 m
matrix currentmatrix
.01512 .02381 scale
49.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
49.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.77967 .025 m
matrix currentmatrix
.01512 .02381 scale
51.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
51.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.82502 .025 m
matrix currentmatrix
.03023 .02381 scale
27.2875 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
27.2875 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.88549 .025 m
matrix currentmatrix
.03023 .02381 scale
29.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
29.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.93084 .025 m
matrix currentmatrix
.01512 .02381 scale
61.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
61.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.96107 .025 m
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{458, 32},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007:000080P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5H/1JX00=d81_l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000e5D0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0b`000?l0b`000?l0b`000?l0b`000?l0
b`0001P000==CTd03`001de>CDi=CTd0400014i=CTd:0004CTe>C@X000=>CDh02`000di=CP0:0004
CDi=CPX000A=CTe>3`001Ti=CTe>CA4000==CTd02`000de>C@0:0004CTe>C@X000A>CDi=2P0014i=
CTd>0007CTe>CDi=CP0E0007CTe>CDi=CP0@0004CDi=CPX000A=CTe>2P000de>C@0;0003CDi=00X0
00A>CDi=3`001Te>CDi=CQD000M>CDi=CTe>010000A=CTe>2P0014e>CDh@00005P02CP?600=>0000
2P02CPN31Dh9009>1<H00dh00005009>1<H00dh00005009>0lH00dh00006009>0lH00dh00005009>
1<H00dh00005009>1<H00dh0000900=>1X<5CPX00Th3aP03CP0000D00dh3aP03CP0000D00Th4aP03
CP0000D00Th4aP03CP0000D00Th4aP03CP0000T00Th7P`E>3@03CPNE14h:009>1<H00dh00005009>
1<H00dh00005009>0lH00dh0000500=>0lH00dh00005009>1<H00dh0000900=>1X<5CPh00Th7U@E>
2@02CPC600=>00001@02CPC600=>00003@0001D000M>e/KFa]I>00T0019>CDjCPi>3Th>CPi>3Th>C
Pdd70008CLKFa]K6eTh60008CLKFa]K6eTh60008CLKFa]K6eTh60007CLKFa]K6C@060008C]K6e/KF
aTd60008C]K6e/KFaTd9000ACDjCPi>3Th>CPi>3Th>CPdd0200024kFa]K6e/I=1@0024g6e/KFa]I>
1P0024g6e/KFa]I>1P0024g6e/KFa]I>1P0024g6e/KFa]I>20004Te>CH>CPi>3Th>CPi>3Th>CCPX0
00==CYD03ID00dd000060008C]K6e/KFaTd60008C]K6e/KFaTd60008C]K6e/KFaTd50008CLKFa]K6
eTh60008CLKFa]K6eTh9000ACTf3Th>CPi>3Th>CPi>3Tdh02P000de>C@0>U@03CP0000D000Q>e/KF
a]K6C@H000Q>e/KFa]K6C@l0000D0003C/K600G600=>00001002CQ:300=>00000`000dk6aP06aP03
CP00008000=>a/H01/H00dh000020003C/K600K600=>00000P000dk6aP05aP03CP00008000=>a/H0
1/H00dh000020003C/K600K600=>00000`03CQ6300=>000010000dk6aP06aP05CP0004h02<H00dh0
00020003C/K600K600=>00000P000dk6aP06aP03CP00008000=>a/H01/H00dh00003009>4X<00dh0
0005009>4ID00dh000040003C/K600K600=>00000P000dk6aP06aP03CP00008000=>a/H01/H01Dh0
001>00S600=>00000P000dk6aP06aP03CP0000<00dhAP`03CP0000D00ThBU@03CP0000<000=>a/H0
1/H00dh000020003C/K600K600=>0000300001<000]>e/KFa]K6e/KFCP04000GCH>CPi>3Th>CPi>3
Th>CPi>3Th>CPdd00`0034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>
0P002dg6e/KFa]K6e/I=008000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=0`005df3Th>CPi>3
Th>CPi>3Th>CPi>3Th==00@000a>e/KFa]K6e/KFaTd2000;C]K6e/KFa]K6eTh00P0034g6e/KFa]K6
e/KFCP8000a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>0`005djCPi>3Th>CPi>3Th>CPi>3Th>C
Pi=>00D000=>UID04YD00dd00002000<C]K6e/KFa]K6e/I=0P0034kFa]K6e/KFa]K6C@8000a>e/KF
a]K6e/KFaTd2000;C]K6e/KFa]K6eTh00P0034g6e/KFa]K6e/KFCP<001M>Th>CPi>3Th>CPi>3Th>C
Pi>3Th>CCP050003CYFE01>E011>0000C]K6e/KFa]K6e/I=0P0034kFa]K6e/KFa]K6C@d0000C0003
C/K600O600E>0000CP0FP`05CP0004h02/H014h004h:aP04CP00CP[600A>001>2LH014h004h:aP04
CP00CP[600E>0000CP0FP`05CP0004h02/H014h004h9aP04CP00CP[600A>001>2/H014h004h:aP05
CP0004h05H<00dh000020003CYFE01BE00E>0000CP0:aP04CP00CP[600A>001>2/H014h004h9aP04
CP00CP[600E>0000CP0FP`03CP00008000=>UID04iD01Dh0001>00[600A>001>2/H00dh0000;0000
4P00mdg6e/KFa]K6e/KFaTd0CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Tdh0C]K6e/KFa]K6e/KFaTe>
e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFCP1>e/KFa]K6e/KFa]I>04kFa]K6
e/KFa]K6eTh0CY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdd0CLKFa]K6e/KFa]K6C@1=a]K6e/KFa]K6
e/I=04g6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=04f3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CPdd00P000djEU@0FU@1RC@1=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFaTd0CLKFa]K6
e/KFa]K6C@1=a]K6e/KFa]K6e/I=04g6e/KFa]K6e/KFaTd0CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3
Tdh20003CIFE01FE01i=001>e/KFa]K6e/KFa]I>04kFa]K6e/KFa]K6eTh<00004P000dk6aP09aP03
CP1>01R300=>04h03<H2CPc60Th;aP03CP1>00_600=>04h02lH00dh0CP0;aP03CP1>01R300=>04h0
2lH00dh0CP0;aP03CP1>00_60Th<aP9>3<H00dh0CP0GP`04CP00CQRE00=>04h03<H2CP_600=>04h0
2lH00dh0CP0;aP03CP1>00_600=>04h068<014h004hGU@04CP00CP_600=>04h02lH00dh0000:0000
4P00nDg6e/KFa]K6e/KFa]I>CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==C]K6e/KFa]K6e/KFaTe>
e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6
e/KFa]K6eTi=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>CLKFa]K6e/KFa]K6eTkFa]K6e/KFa]K6
e/KFC]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=CY>3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CPi=>C@0JU@1SCTg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KF
C]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CDjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPde>01VE
01e>CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFCP0<00004P000dk6aP0:aP9>6H<2CPc60Th<aP9>
3<H00dk6aP0;aP03C/K600_600=>a/H02/H2CQZ30Th<aP03C/K600_600=>a/H02/H2CPc60Th<aP9>
6H<2CQZE0Th<aP9>3<H2CPc600=>a/H02lH00dk6aP0:aP9>6X<2CQVE0Th=aP03C/K600[600=>0000
2P0001400?Y>e/KFa]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>e/KFa]K6e/KF
a]K6eTkFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=
a]K6e/KFa]K6e/KFaTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3TdkFa]K6e/KFa]K6e/KFC]K6e/KF
a]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFaTf3Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CPi>3Th==6iD0HDg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTkFa]K6e/KFa]K6
e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdd0
6iD07Dg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=00/0000A0003C/K600_600=>Ph<06H<00dk6
aP0;aP03C/K600[600=>a/H02lH00dk6aP0;aP03C/K600_600=>a/H02lH00dj3P`0HP`03C/K600_6
00=>a/H02lH00dk6aP0;aP03C/K600_600=>a/H02/H00dj3P`0IP`03CYFE01VE00=>a/H02/H2CPc6
00=>a/H02lH00dk6aP0;aP03C/K600_600=>Ph<068<00djEU@0IU@03C/K600_600=>a/H02lH00dh0
000900004@00nTkFa]K6e/KFa]K6e/KFCY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3TdkFa]K6e/KF
a]K6e/KFC]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KF
aTg6e/KFa]K6e/KFa]K6CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CC]K6e/KFa]K6e/KFa]I>e/KF
a]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CH>CPi>3Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CPddKU@1QCLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFC]K6e/KFa]K6
e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3
C@0KU@0MCLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTd02`00014000=>a/H02lH00dj3P`0HP`9>
3<H2CPc600=>a/H02lH00dk6aP0;aP03C/K600_600=>a/H02lH00dj3P`0HP`03C/K600_600=>a/H0
2lH00dk6aP0;aP03C/K600[60Th<aP03CX>301V300=>UID069D2CPc60Th<aP03C/K600_600=>a/H0
2lH00dk6aP0;aP03CX>301R300=>UID06ID00dk6aP0;aP03C/K600_600=>00002@0001400?Y>e/KF
a]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPde>e/KFa]K6e/KFa]K6CDkFa]K6e/KF
a]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KF
aTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3TdkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KF
a]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>C
Pi>3Th==6YD0HTi=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KF
a]K6e/KFC]K6e/KFa]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==6iD07Dg6e/KFa]K6
e/KFa]K6CLKFa]K6e/KFa]K6e/I=00/0000B0003C/K600[60ThIP`9>3<H2CPc60Th<aP9>2lH2CPc6
0Th<aP9>6H<00dh0CP0<aP9>2lH2CPc60Th<aP9>3<H2CQV300=>04h06ID2CPc60Th<aP9>3<H2CP_6
0Th<aP9>6H<00dh0CP0IU@9>3<H2CPc600=>00002P0001800?Y=a]K6e/KFa]K6e/KFCTf3Th>CPi>3
Th>CPi>3Th>CPi>3Th>CPi=>04kFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6
CDkFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>04jCPi>3Th>CPi>3Th>CPi>3
Th>CPi>3Th==04g6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6
e/KFaTe>e/KFa]K6e/KFa]K6CDjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP1>69D0I4d0CLKFa]K6
e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6CDkFa]K6e/KFa]K6
e/I=04f3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>04hIU@0MCTg6e/KFa]K6e/KFa]I>CLKFa]K6e/KF
a]K6eTh03000018000=>a/H02LH00dh00002CQF300E>0000CP0:aP04CP00CP[600=>04h02lH00dh0
CP0;aP03CP1>00_600=>04h02/H01Dh0001>01J300A>001>2lH00dh0CP0;aP03CP1>00_600=>04h0
2/H014h004h:aP03CP00009>5X<014h00002CQFE00E>0000CP0:aP04CP00CP[600=>04h02lH00dh0
CP0;aP03CP1>00_600A>001>5X<014h00002CQJE00A>001>2lH00dh0CP0;aP03CP0000X0000C000<
C]K6e/KFa]K6e/I=10005TjCPi>3Th>CPi>3Th>CPi>3Th>CPdd4000;C]K6e/KFa]K6eTh00P0034g6
e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP80
00]=a]K6e/KFa]K6C@04000FCY>3Th>CPi>3Th>CPi>3Th>CPi>3C@@000a>e/KFa]K6e/KFaTd2000<
C]K6e/KFa]K6e/I=0P0034kFa]K6e/KFa]K6C@8000]>e/KFa]K6e/KFCP02000<CLKFa]K6e/KFa]I>
10005Tf3Th>CPi>3Th>CPi>3Th>CPi>3Tdh60003CIFE016E00==00000`002dg6e/KFa]K6e/I=0080
00a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=0P0034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KF
aTd3000FCH>CPi>3Th>CPi>3Th>CPi>3Th>CCPH000==UID04YD00dh00002000<CLKFa]K6e/KFa]I>
0P0034g6e/KFa]K6e/KFCP`0000C0003C/K600O600=>000010000dj3P`0?P`9>1@000dk6aP06aP03
CP00008000=>a/H01/H01Dh0001>00W600E>0000CP09aP05CP0004h02<H2CP<000=>a/H01/H2CPD0
00=>Ph<03h<2CPD000=>a/H01lH01Dh0001>00W600E>0000CP08aP9>0`000dk6aP06aP9>0`000dk6
aP06aP03CP0000@000=>Ph<03h<2CPP000=>UID03YD2CPH000=>a/H01/H00dh000020003C/K600K6
00E>0000CP09aP05CP0004h02LH01Dh0001>00S60Th50003CX>300n30Th80003CYFE00nE0Th50003
C/K600K60Th30003C/K600K60Th=000050002Dg6e/KFa]K6C@08000ACTf3Th>CPi>3Th>CPi=>CDh0
200024g6e/KFa]I>1P0024g6e/KFa]I>1@002DkFa]K6e/KFCP050009C]K6e/KFa]I>00D000Q>e/KF
a]K6C@H000Q>e/KFa]K6C@P0015>CDjCPi>3Th>CPi>3Th==CP080009CLKFa]K6e/I=00D000U=a]K6
e/KFaTd01@0024g6e/KFa]I>1P0024g6e/KFa]I>1P0024g6e/KFa]I>20004De>Th>CPi>3Th>CPi>3
Tdi=00/000==CYD02iD00de>00080008C]K6e/KFaTd60008C]K6e/KFaTd50009CLKFa]K6e/I=00D0
00U=a]K6e/KFaTd01@0024g6e/KFa]I>20004De>CH>CPi>3Th>CPi>3Tdi=00/000==CYD039D00di=
00070008C]K6e/KFaTd60008C]K6e/KFaTd?00005@03CP;60Th;00=>1h<2CP`00Th2aP9>2002CP;6
0Th700=>0/H2CPL00dh2aP9>1`03CP03aTi>00P00dh00lI>CP0<009>1h<3CP/00dh2aP9>1`03CP;6
0Th700=>00?6CTh02003CP03aTi>00P00Th2aP9>2`03CPN30dh?00=>1iD2CP`00Th2aP9>2002CP;6
0Th700=>0/H2CPL00dh2aP9>1`03CP03aTi>00`00Th8P`9>3`03CPNE0dh;00=>00?6CTh02003CP03
aTi>0100000H0003CDh000l000M=CTe>CDi=010000=>C@002`000di=000;0003CTd000/000=>C@00
2`000dh0000;0003CP0000h000M=CTe>CDi=014000==CP002`000de>000;0003C@0000/000==0000
2P000di=000?0007CTe>CDi=CP0E0007CTe>CDi=CP0@0003CDh000/000==CP002`000de>000;0003
CDh000/000==00003P0024i=CTe>CDi=50001di=CTe>CDh04@000dh0000;0003CP000100003o0</0
003o0</0003o0</0003o0</00000\
\>"],
  ImageRangeCache->{{{0, 457}, {31, 0}} -> {-0.787665, -0.712262, 0.0723749, 
  0.0459524}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .05 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0302343 0.025 0.047619 [
[ 0 0 0 0 ]
[ 1 .05 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .05 L
0 .05 L
closepath
clip
newpath
p
p
.1 g
.001 w
.06916 .025 m
matrix currentmatrix
.03023 .02381 scale
2.28747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
2.28747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.11451 .025 m
matrix currentmatrix
.01512 .02381 scale
7.57484 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
7.57484 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.14475 .025 m
matrix currentmatrix
.01512 .02381 scale
9.57521 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
9.57521 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.17498 .025 m
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.20522 .025 m
matrix currentmatrix
.01512 .02381 scale
13.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
13.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.23545 .025 m
matrix currentmatrix
.01512 .02381 scale
15.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
15.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.26568 .025 m
matrix currentmatrix
.01512 .02381 scale
17.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
17.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.31104 .025 m
matrix currentmatrix
.03023 .02381 scale
10.2877 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
10.2877 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.35639 .025 m
matrix currentmatrix
.01512 .02381 scale
23.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
23.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.38662 .025 m
matrix currentmatrix
.01512 .02381 scale
25.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
25.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.41686 .025 m
matrix currentmatrix
.01512 .02381 scale
27.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
27.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.44709 .025 m
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.47732 .025 m
matrix currentmatrix
.01512 .02381 scale
31.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
31.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.52268 .025 m
matrix currentmatrix
.03023 .02381 scale
17.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
17.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.56803 .025 m
matrix currentmatrix
.01512 .02381 scale
37.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
37.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.59826 .025 m
matrix currentmatrix
.01512 .02381 scale
39.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
39.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.64361 .025 m
matrix currentmatrix
.03023 .02381 scale
21.2874 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
21.2874 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.68896 .025 m
matrix currentmatrix
.01512 .02381 scale
45.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
45.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.7192 .025 m
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.74943 .025 m
matrix currentmatrix
.01512 .02381 scale
49.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
49.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.79478 .025 m
matrix currentmatrix
.03023 .02381 scale
26.2873 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
26.2873 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.84014 .025 m
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.87037 .025 m
matrix currentmatrix
.01512 .02381 scale
57.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
57.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.91572 .025 m
matrix currentmatrix
.03023 .02381 scale
30.2874 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
30.2874 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.96107 .025 m
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{458, 32},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007:000080P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5H/1JX00=d81_l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000e5D0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0b`000?l0b`000?l0b`000?l0b`000?l0
b`0001`000M=CTe>CDi=010000A>CDi=2P0014i=CTd:0004CTe>C@X000=>CDh02`000di=CP0:0004
CDi=CPl000I>CDi=CTdA0004CDi=CPX000==CTd02`000de>C@0:0004CTe>C@X000A>CDi=3`001Te>
CDi=CQ4000=>CDh02P0014e>CDh?0006CTe>CDi=4@0014e>CDh:0003CDi=00/000==CTd03`001Te>
CDi=CQ4000A>CDi=2P000di=CP0?0007CTe>CDi=CP0@0004CDi=CQ00000J009>1h<5CPT00Th4aP03
CP0000D00Th4aP03CP0000D00Th4aP03CP0000D00Th3aP03CP0000H00Th3aP03CP0000D00Th4aP03
CP0000T00dh6P`E>2P02CPC600=>00001@02CP?600=>00001@03CP?600=>00001@02CPC600=>0000
1@02CPC600=>00002@03CPJ31Dh:009>0lH00dh00005009>1<H00dh0000900=>1YD5CPX00Th4aP03
CP0000D00Th3aP03CP0000D00dh3aP03CP0000T00dh6P`E>2P02CPC600=>00001@02CP?600=>0000
2P02CPNE1Dh9009>1<H00dh0000=00005`004Ti=CY>3Th>CPi>3Th>CPi>3C@L000Q=a]K6e/KFCPH0
00Q=a]K6e/KFCPH000Q=a]K6e/KFCPH000Q=a]K6e/KFCPH000M=a]K6e/I=00H000Q>e/KFa]K6C@T0
015=CY>3Th>CPi>3Th>CPi>3C@080008C]K6e/KFaTd60008C]K6e/KFaTd50008CLKFa]K6eTh60008
CLKFa]K6eTh60008CLKFa]K6eTh8000BCDi=Pi>3Th>CPi>3Th>CPi=>20001dg6e/KFaTd01P0024kF
a]K6e/I=2@000de>U@0=U@03C@0000H000Q>e/KFa]K6C@H000Q>e/KFa]K6C@D000Q=a]K6e/KFCPT0
015>CH>CPi>3Th>CPi>3Th>CCP080008CLKFa]K6eTh60008CLKFa]K6eTh80003CDi=00jE00=>0000
1@0024kFa]K6e/I=3`0001D00ThBP`03CP0000<000=>a/H01/H00dh000020003C/K600K600=>0000
0P000dk6aP06aP03CP00008000=>a/H01/H00dh000020003C/K600G600=>00000P000dk6aP06aP03
CP0000@00ThAP`03CP0000@000=>a/H01/H00dh000020003C/K600K600E>0000CP08aP03CP000080
00=>a/H01/H00dh000020003C/K600K600=>00000`02CQ:300=>000010000dk6aP05aP03CP000080
00=>a/H01/H00dh00004009>4ID00dh000040003C/K600K600=>00000P000dk6aP06aP05CP0004h0
2<H00dh00004009>4H<00dh000040003C/K600K600=>00000P000dk6aP06aP03CP0000<00ThBU@03
CP0000<000=>a/H01/H00dh0000<000050005df3Th>CPi>3Th>CPi>3Th>CPi>3Th==00<000a=a]K6
e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6eTh2000;
CLKFa]K6e/KFaTd00P0034kFa]K6e/KFa]K6C@@001I>Th>CPi>3Th>CPi>3Th>CPi>3Th==100034kF
a]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd2000;C]K6e/KFa]K6eTh00P0034g6e/KFa]K6e/KFCP80
00a=a]K6e/KFa]K6eTh3000GCY>3Th>CPi>3Th>CPi>3Th>CPi>3Tdh010002dg6e/KFa]K6e/I=0080
00a>e/KFa]K6e/KFaTd40003CYFE01:E00==00000P0034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KF
aTd2000;C]K6e/KFa]K6eTh010005Tf3Th>CPi>3Th>CPi>3Th>CPi>3Tdh4000<CLKFa]K6e/KFa]I>
0P0034g6e/KFa]K6e/KFCP<000=>UID04iD044h0001>e/KFa]K6e/KFaTd=000050000dj3P`0CP`05
CP0004h02/H014h004h:aP04CP00CP[600A>001>2/H014h004h9aP04CP00CP[600E>0000CP0FP`05
CP0004h02/H014h004h:aP04CP00CPW600A>001>2/H014h004h:aP05CP0004h05H<00dh000020003
C/K600O600A>001>2/H01Dh0001>01JE00E>0000CP0:aP04CP00CP[600A>001>2LH01Dh0001>01J3
00E>0000CP0:aP04CP00CP[600A>001>5YD01Dh0001>00[600=>00002`0001<001U>Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CPi=>00800<e=a]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6
CDkFa]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFCP1>e/KFa]K6e/KFa]I>04jCPi>3Th>CPi>3Th>CPi>3
Th>CPi>3Th==04g6e/KFa]K6e/KFaTd0CLKFa]K6e/KFa]K6C@1=a]K6e/KFa]K6e/I=04g6e/KFa]K6
e/KFaTe>e/KFa]K6e/KFa]K6C@1=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==008001e>e/KFa]K6e/KF
a]I>04kFa]K6e/KFa]K6eTh0CP0HU@1TC@1=a]K6e/KFa]K6e/I=04g6e/KFa]K6e/KFaTd0CLKFa]K6
e/KFa]K6C@1=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP1>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6
eTh0CQRE011=001>e/KFa]K6e/KFa]I>300001<000=>Ph<05H<014h004h;aP9>3<H2CPc60Th;aP03
CP1>00_600=>04h02lH00dh0CP0HP`03CP1>00_600=>04h02lH00dh0CP0;aP03CP1>00_60Th<aP03
CP1>01R300=>04h02lH00dh0CP0;aP03CP1>01RE00=>04h02lH00dh0CP0;aP03CP1>00_600=>04h0
68<00dh0CP0<aP9>2lH00dh0CP0HU@04CP00CP_600=>00002P0001800?m=Pi>3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CPde>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6
e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3
Tdi=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=C]K6
e/KFa]K6e/KFaTe>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==a]K6e/KFa]K6e/KFaTg6e/KFa]H0
00Q=Pi>3Th>CPaZE06=>CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDh06ID03di=
a]K6e/KFa]K6e/KFCP0<00004P000dj3P`0GP`9>3<H2CPc60Th<aP9>3<H00dk6aP0;aP03C/K600_6
00=>Ph<068<2CPc60Th<aP03C/K600_600=>a/H02/H2CPc60ThJP`03C/K600_600=>a/H02lH00djE
U@0HU@9>3<H2CPc600=>a/H02lH00dj3P`0HP`9>3<H2CPc60ThIU@9>3<H00dh0000:00004@00odjC
Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KF
a]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTf3Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CPi>3Tdi=a]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkF
a]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==a]K6e/KF
a]K6e/KFaTg6e/KFaP002DjCPi>3Th>CP`0JU@1RCTg6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkF
a]K6e/KFa]K6e/KFCY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CDkFa]K6e/KFa]K6e/I=a]K6e/KF
a]K6e/KFaTdKU@0?CLKFa]K6e/KFa]K6e/I=00/0000A0003CX>301V300=>a/H02lH00dk6aP0;aP03
C/K600[600=>a/H02lH00dk6aP0;aP03C/K600_600=>Ph<068<2CPc600=>a/H02lH00dk6aP0;aP03
C/K600_600=>a/H02lH00dj3P`0HP`03C/K600_600=>a/H02lH00djEU@0HU@9>3<H00dk6aP0;aP03
C/K600_600=>Ph<068<2CPc600=>a/H02lH00djEU@0IU@03C/K600_600=>00002@0001400?m>Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KF
a]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=Pi>3Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CPi=>CLKFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KF
a]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CLKFa]K6e/KF
a]K6e/I=a]K6e/H000U>Th>CPi>3Th<06YD0HTi=a]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KF
a]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPde>e/KFa]K6e/KFa]K6CDkFa]K6e/KF
a]K6e/I=6iD03dg6e/KFa]K6e/KFa]K6C@0;00004@000dj3P`0IP`03C/K600_600=>a/H02/H2CPc6
00=>a/H02lH00dk6aP0;aP03C/K600_600=>Ph<068<2CPc600=>a/H02lH00dk6aP0;aP03C/K600_6
00=>a/H02/H2CQZ300=>a/H02lH00dk6aP0;aP03CYFE01RE0Th<aP03C/K600_600=>a/H02lH00dj3
P`0HP`9>3<H2CPc600=>UID069D2CPg600=>00002@0001400?m>Th>CPi>3Th>CPi>3Th>CPi>3Th>C
Pi>3Th>CC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KF
aTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>CLKF
a]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KF
a]K6e/I=CY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6e/I=a]K6e/H000U>Th>C
Pi>3Th<06YD0HTi=a]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTjCPi>3Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CPde>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=6YD044i=a]K6e/KF
a]K6e/KFaTd;00004P000dj3P`0GP`9>3<H2CPc60Th<aP9>3<H2CP_60Th<aP03CP1>01R300=>04h0
3<H2CPc60Th;aP9>3<H2CPc60ThIP`03CP1>00c600=>a/H02/H00dh0CP0HU@03CP1>00c60Th<aP9>
2lH00dh0CP0HP`03CP1>00c60Th<aP9>6ID2CPc600=>00002P0001800?m=Pi>3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CPde>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6
e/KFa]K6CDkFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCP1>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3
C@1=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6
e/KFa]K6e/KFaTd0CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Tdh0C]K6e/KFa]K6e/KFaTg6e/KFa]H0
00U=Pi>3Th>CPi<069D0I4d0CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFaTd0
CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Tdh0C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDhHU@0@
C@1=a]K6e/KFa]K6e/KFCP`0000C009>5X<014h004h;aP03CP1>00[600A>001>2/H00dh0CP0;aP03
CP1>00_600=>04h02lH00dh00002CQF300E>0000CP0:aP03CP1>00_600=>04h02lH00dh0CP0;aP03
CP1>00[600E>0000CP0FP`04CP00CP_600=>04h02lH014h004hFU@05CP0004h02/H00dh0CP0;aP03
CP1>00_600=>00000ThEP`05CP0004h02/H00dh0CP0;aP03CP00009>5ID01Dh0001>00_600=>0000
2P0001D001I>Th>CPi>3Th>CPi>3Th>CPi>3Th==100034kFa]K6e/KFa]K6C@8000]>e/KFa]K6e/KF
CP02000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6eTh2000<CLKFa]K6
e/KFa]I>10005Df3Th>CPi>3Th>CPi>3Th>CPi>3C@04000<C]K6e/KFa]K6e/I=0P0034kFa]K6e/KF
a]K6C@8000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=0P002dkFa]K6e/KFa]I>00@001I=Pi>3
Th>CPi>3Th>CPi>3Th>CPi=>100034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6eTh30003CTfE01:E
00==00000P0034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=10005DjC
Pi>3Th>CPi>3Th>CPi>3Th>CCP04000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP@000==UID0
4YD00dh00002000<CLKFa]K6e/KFa]I>300001H000=>Ph<03h<2CPD000=>a/H01/H2CP<000=>a/H0
1/H00dh000020003C/K600K600E>0000CP09aP05CP0004h02LH01Dh0001>00S60Th60003CX>300j3
0Th60003C/K600K600E>0000CP09aP05CP0004h02LH01Dh0001>00S60Th30003C/K600K60Th50003
CX>300n30Th50003C/K600O600E>0000CP08aP9>1P000djEU@0>U@9>1P000dk6aP06aP05CP0004h0
2LH01Dh0001>00W600=>000010000dj3P`0>P`9>1P000dk6aP06aP05CP0004h02LH00dh000040003
CYFE00nE0Th50003C/K600K60Th=00005`004Di=Pi>3Th>CPi>3Th>CPde>00P000Q=a]K6e/KFCPH0
00Q=a]K6e/KFCPH000Q=a]K6e/KFCPD000U>e/KFa]K6eTh01@002DkFa]K6e/KFCP050008C]K6e/KF
aTd9000@CDjCPi>3Th>CPi>3Th==CPT000Q>e/KFa]K6C@D000U=a]K6e/KFaTd01@002Dg6e/KFa]K6
C@050008CLKFa]K6eTh60008CLKFa]K6eTh8000ACDi=Pi>3Th>CPi>3Th>CCTd020002DkFa]K6e/KF
CP050008C]K6e/KFaTd90003CDjE00^E00==CP00200024kFa]K6e/I=1@002Dg6e/KFa]K6C@050009
CLKFa]K6e/I=00P0011>CH>CPi>3Th>CPi>3Tdi=2@0024g6e/KFa]I>1@002DkFa]K6e/KFCP080003
CDjE00^E00==CTd0200024kFa]K6e/I=3`0001T00dh7P`=>2`03CP03aTi>00P00Th2aP9>2002CP;6
0Th700=>0/H2CPL00dh2aP9>1`03CP03aTi>00`00dh7P`9>3002CP;60Th700=>0/H2CPL00dh2aP9>
1`03CP03aTi>00P00dh00lI>CP0<009>1h<3CP/00dh2aP9>1`03CP03aTi>00`00dh7U@9>3002CP;6
0Th700=>0/H2CPL00dh2aP9>2`03CPN30Th<009>0/H2CPL00dh2aP9>2`03CPNE0Th<00=>00?6CTh0
400001`000M=CTe>CDi=014000==00002P000di=000;0003CTd000/000=>C@002`000di=000;0003
CP0000l000M>CDi=CTe>010000==CP002`000de>000;0003CDh000/000==00002`000dd0000>0007
CTe>CDi=CP0A0003CTd000/000=>00003`001di=CTe>CDh040000de>000;0003CDh000/000==CP00
3`001de>CDi=CTd040000di=000;0003CTd000l000M>CDi=CTe>014000=>000040000?l0b`000?l0
b`000?l0b`000?l0b`000001\
\>"],
  ImageRangeCache->{{{0, 457}, {31, 0}} -> {-0.787665, -0.712262, 0.0723749, 
  0.0459524}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .05 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0302343 0.025 0.047619 [
[ 0 0 0 0 ]
[ 1 .05 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .05 L
0 .05 L
closepath
clip
newpath
p
p
.6 g
.001 w
.06916 .025 m
matrix currentmatrix
.03023 .02381 scale
2.28747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
2.28747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.11451 .025 m
matrix currentmatrix
.01512 .02381 scale
7.57484 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
7.57484 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.14475 .025 m
matrix currentmatrix
.01512 .02381 scale
9.57521 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
9.57521 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.17498 .025 m
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.20522 .025 m
matrix currentmatrix
.01512 .02381 scale
13.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
13.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.23545 .025 m
matrix currentmatrix
.01512 .02381 scale
15.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
15.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.2808 .025 m
matrix currentmatrix
.03023 .02381 scale
9.28746 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
9.28746 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.32615 .025 m
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.35639 .025 m
matrix currentmatrix
.01512 .02381 scale
23.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
23.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.38662 .025 m
matrix currentmatrix
.01512 .02381 scale
25.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
25.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.41686 .025 m
matrix currentmatrix
.01512 .02381 scale
27.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
27.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.44709 .025 m
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.49244 .025 m
matrix currentmatrix
.03023 .02381 scale
16.2875 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
16.2875 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.53779 .025 m
matrix currentmatrix
.01512 .02381 scale
35.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
35.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.56803 .025 m
matrix currentmatrix
.01512 .02381 scale
37.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
37.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.59826 .025 m
matrix currentmatrix
.01512 .02381 scale
39.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
39.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.6285 .025 m
matrix currentmatrix
.01512 .02381 scale
41.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
41.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.67385 .025 m
matrix currentmatrix
.03023 .02381 scale
22.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
22.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.7192 .025 m
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.76455 .025 m
matrix currentmatrix
.03023 .02381 scale
25.2875 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
25.2875 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.8099 .025 m
matrix currentmatrix
.01512 .02381 scale
53.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
53.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.84014 .025 m
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.87037 .025 m
matrix currentmatrix
.01512 .02381 scale
57.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
57.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.9006 .025 m
matrix currentmatrix
.01512 .02381 scale
59.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
59.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.94596 .025 m
matrix currentmatrix
.03023 .02381 scale
31.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
31.2876 1.05 1 0 365.73 arc
setmatrix
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{458, 32},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007:000080P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5H/1JX00=d81_l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000e5D0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0b`000?l0b`000?l0b`000?l0b`000?l0
b`0001`000M=CTe>CDi=010000A>CDi=2P0014i=CTd:0004CTe>C@X000=>CDh02`000di=CP0?0007
CTe>CDi=CP0@0004CDi=CPX000A=CTe>2P000de>C@0;0003CDi=00X000A>CDi=3`001Te>CDi=CQ40
00=>CDh02`000di=CP0:0004CDi=CPX000A=CTe>3`001Ti=CTe>CA4000==CTd03`001de>CDi=CTd0
400014i=CTd:0004CTe>C@X000=>CDh02`000di=CP0?0006CTe>CDi=5`0001X00Th7U@E>2@02CPC6
00=>00001@02CPC600=>00001@02CPC600=>00001@02CP?600=>00001P02CP?600=>00002@03CPN3
14h:009>1<H00dh00005009>1<H00dh00005009>0lH00dh0000500=>0lH00dh00005009>1<H00dh0
000900=>1X<5CPX00Th3aP03CP0000H00Th3aP03CP0000D00Th4aP03CP0000D00Th4aP03CP0000T0
0dh6U@E>2P02CP?600=>00002@03CPN314h:009>1<H00dh00005009>1<H00dh00005009>0lH00dh0
0006009>0lH00dh0000900=>1YD5CQ80000G0003CTe>00jE00==00001@0024g6e/KFa]I>1P0024g6
e/KFa]I>1P0024g6e/KFa]I>1P0024g6e/KFa]I>1P001dg6e/KFaTd02@004De>Th>CPi>3Th>CPi>3
Th==00P000Q>e/KFa]K6C@H000Q>e/KFa]K6C@H000Q>e/KFa]K6C@D000Q=a]K6e/KFCPH000Q=a]K6
e/KFCPT0015>CH>CPi>3Th>CPi>3Th>CCP080008CLKFa]K6eTh60007CLKFa]K6C@060008C]K6e/KF
aTd60008C]K6e/KFaTd90003CDjE00fE00==00001P0024kFa]K6e/I=20004Di=Pi>3Th>CPi>3Th>C
Pi=>00P000Q=a]K6e/KFCPH000Q=a]K6e/KFCPH000Q=a]K6e/KFCPH000M=a]K6e/I=00T000==CYD0
3ID00dd0000?00005@02CQ:E00=>00000`000dk6aP06aP03CP00008000=>a/H01/H00dh000020003
C/K600K600=>00000P000dk6aP06aP03CP00008000=>a/H01LH00dh00004009>4H<00dh000040003
C/K600K600=>00000P000dk6aP06aP03CP00008000=>a/H01/H01Dh0001>00S600=>00000P000dk6
aP06aP03CP0000@00ThAP`03CP0000@000=>a/H01/H00dh000020003C/K600G600=>00000P000dk6
aP06aP03CP00008000=>a/H01/H00dh0000300=>4ID00dh000040003C/K600K600=>00000`02CQ63
00=>000010000dk6aP06aP03CP00008000=>a/H01/H00dh000020003C/K600K600=>00000P000dk6
aP05aP03CP0000@00ThAU@03CP0000h0000D0003CIFE01>E011=0000CLKFa]K6e/KFa]I>0P0034g6
e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>0P002dg6e/KFa]K6e/I=00@0
01I>Th>CPi>3Th>CPi>3Th>CPi>3Th==100034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd2000<
C]K6e/KFa]K6e/I=0P002dkFa]K6e/KFa]I>008000a=a]K6e/KFa]K6eTh4000FCH>CPi>3Th>CPi>3
Th>CPi>3Th>CCP@000a=a]K6e/KFa]K6eTh2000;CLKFa]K6e/KFaTd00P0034kFa]K6e/KFa]K6C@80
00a>e/KFa]K6e/KFaTd30003CIFE01>E00==00000P0034kFa]K6e/KFa]K6C@<001I=Pi>3Th>CPi>3
Th>CPi>3Th>CPi=>100034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>
0P002dg6e/KFa]K6e/I=00@000=>UID04YD00dd0000=000050000djEU@0CU@05CP0004h02/H014h0
04h:aP04CP00CP[600A>001>2/H014h004h9aP05CP0004h05X<01Dh0001>00[600A>001>2/H014h0
04h:aP04CP00CPW600A>001>2/H01Dh0001>01J300E>0000CP0:aP04CP00CPW600A>001>2/H014h0
04h:aP05CP0004h05YD01Dh0001>00[600A>001>5X<01Dh0001>00[600A>001>2/H014h004h:aP04
CP00CPW600E>0000CP0FU@03CP0000`0000C0003CYFE01FE0?e>001=a]K6e/KFa]K6e/I=C]K6e/KF
a]K6e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFCP1>Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CPi>3C@1=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFaTd0CLKFa]K6e/KFa]K6C@1=
a]K6e/KFa]K6e/I=04g6e/KFa]K6e/KFaTd0CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Tdh0C]K6e/KF
a]K6e/KFCP1>e/KFa]K6e/KFa]I>04kFa]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFCP1>01RE06A=04g6
e/KFa]K6e/KFaTd0CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Tdh0C]K6e/KFa]K6e/KFaTe>e/KFa]K6
e/KFa]K6CDkFa]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFCP1>69D00dd0000;00004`000djEU@0EU@04
CP00CP_60Th<aP9>3<H2CP_600=>04h02lH00dh0CP0HP`03CP1>00c60Th;aP03CP1>00_600=>04h0
2lH00dh0CP0;aP03CP1>01R300=>04h02lH00dh0CP0;aP03CP1>00_600=>04h02lH00dh0CP0HU@03
CP1>00_600=>04h068<00dh0CP0<aP9>3<H2CP_600=>04h02lH00dh0CP0HU@03CP0000/0000B0003
CIFE01NE0?]=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6
e/KFaTg6e/KFa]K6e/KFa]K6CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCTg6e/KFa]K6e/KFa]I>
CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CDjCPi>3
Th>CPi>3Th>CPi>3Th>CPi>3Th>CPde>e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6
e/KFaTg6e/KFa]K6e/KFa]I>C@0JU@1RCTg6e/KFa]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>CPi>3Th>C
Pi>3Th==C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KF
aTdJU@03CP0000X0000B0003CYFE01NE0Th<aP9>3<H2CPc60Th<aP03C/K600_600=>Ph<068<2CPc6
0Th<aP9>3<H00dk6aP0;aP03C/K600[60ThJP`9>3<H00dk6aP0;aP03C/K600_600=>a/H02/H2CQZE
0Th<aP03CX>301R30Th<aP9>3<H2CPc600=>a/H02lH00djEU@0HU@03CP0000X0000A0003CYFE01VE
0?Y>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKF
a]K6e/KFa]K6e/I=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6eTi=a]K6e/KF
a]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCY>3Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKF
a]K6e/KFa]K6e/I=6YD0HTkFa]K6e/KFa]K6e/KFCY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3TdkF
a]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=6YD00dh0
000:00004@000djEU@0IU@03C/K600_600=>a/H02lH00dk6aP0:aP03C/K600_600=>a/H02lH00dj3
P`0IP`03C/K600[60Th<aP03C/K600_600=>a/H02lH00dk6aP0;aP03CX>301R300=>a/H02lH00dk6
aP0;aP03C/K600_600=>a/H02lH00djEU@0HU@03C/K600_600=>Ph<06H<00dk6aP0;aP03C/K600[6
00=>a/H02lH00dk6aP0;aP03CYFE01RE0Th;00004@000djEU@0IU@3jC]K6e/KFa]K6e/KFa]I>e/KF
a]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CH>CPi>3Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CPdg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KF
C]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdg6e/KF
a]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CAZE069>e/KF
a]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>e/KFa]K6e/KFa]K6eTkFa]K6e/KF
a]K6e/I=C]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CAZE00=>C@002P00014000=>UID06ID00dk6
aP0;aP03C/K600[60Th<aP03C/K600_600=>a/H02lH00dj3P`0HP`9>3<H2CPc600=>a/H02lH00dk6
aP0;aP03C/K600_600=>Ph<068<00dk6aP0;aP03C/K600_600=>a/H02lH00dk6aP0;aP03CYFE01RE
00=>a/H02lH00dj3P`0HP`9>3<H2CPc60Th<aP03C/K600_600=>UID069D00dh0000:00004@000djE
U@0IU@3jC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KF
aTg6e/KFa]K6e/KFa]K6CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCTg6e/KFa]K6e/KFa]I>CLKF
a]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTjCPi>3Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CPdg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KF
aTg6e/KFa]K6e/KFa]K6CAZE069>e/KFa]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>C
Pde>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CAZE
00=>00002P00018000=>UID05iD2CPc60Th<aP9>3<H2CPc60Th;aP03CP1>01V30Th<aP9>3<H2CPc6
0Th;aP9>3<H00dh0CP0HP`03CP1>00c60Th<aP03C/K600[60Th<aP9>6ID00dh0CP0<aP9>6H<2CPc6
0Th<aP9>3<H2CPc60ThHU@03CP0000/0000B0003CIFE01NE0?a=C]K6e/KFa]K6e/KFaTe>e/KFa]K6
e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]I>04jCPi>3Th>CPi>3
Th>CPi>3Th>CPi>3Th==04g6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6
e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6C@1=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP1>e/KFa]K6
e/KFa]K6CDkFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>04hHU@1TC@1=a]K6
e/KFa]K6e/KFCTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>04kFa]K6e/KFa]K6e/I=C]K6e/KFa]K6
e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=CQRE00==00002`0001<00ThFU@04CP00CP_6
00=>04h02/H014h004h:aP03CP1>00_600=>04h02lH00dh00002CQF300E>0000CP0:aP04CP00CP[6
00=>04h02lH00dh0CP0;aP03CP1>00_600A>001>5X<014h004h;aP03CP1>00_600=>04h02lH00dh0
CP0:aP05CP0004h05YD014h004h;aP03CP00009>5H<01Dh0001>00[600A>001>2/H00dh0CP0;aP03
CP1>00_600=>00000ThEU@03CP0000`0000E0003CYFE01:E00==00000P0034kFa]K6e/KFa]K6C@80
00]>e/KFa]K6e/KFCP02000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6
eTh4000ECH>CPi>3Th>CPi>3Th>CPi>3Th==00D000]=a]K6e/KFa]K6C@02000<C]K6e/KFa]K6e/I=
0P0034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=0`005Tf3Th>CPi>3
Th>CPi>3Th>CPi>3Tdh4000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6
eTh2000;CLKFa]K6e/KFaTd010000djEU@0BU@03C@00008000a>e/KFa]K6e/KFaTd4000ECY>3Th>C
Pi>3Th>CPi>3Th>CPi=>00D000]>e/KFa]K6e/KFCP02000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6
e/KFCP8000a=a]K6e/KFa]K6eTh40003CIFE016E00==00003@0001H000=>UID03iD2CPD000=>a/H0
1/H2CP<000=>a/H01/H00dh000020003C/K600K600E>0000CP09aP05CP0004h02LH00dh000040003
CX>300j30Th60003C/K600K600=>00000P000dk6aP06aP05CP0004h02LH01Dh0001>00W600E>0000
CP08aP9>1@000dj3P`0?P`9>1@000dk6aP07aP05CP0004h02LH01Dh0001>00S60Th30003C/K600K6
0Th50003CYFE00nE0Th50003C/K600O600=>000010000dj3P`0>P`9>1P000dk6aP06aP9>0`000dk6
aP06aP05CP0004h02LH01Dh0001>00W600=>000010000djEU@0>U@9>400001L000=>CID039D00de>
00070008CLKFa]K6eTh60008CLKFa]K6eTh60008CLKFa]K6eTh50009C]K6e/KFa]I>00D000U>e/KF
a]K6eTh0200044e>Th>CPi>3Th>CPi>3CDh90008C]K6e/KFaTd60008C]K6e/KFaTd50009CLKFa]K6
e/I=00D000U=a]K6e/KFaTd01@0024g6e/KFa]I>20004De>CH>CPi>3Th>CPi>3Tdi=00P000U>e/KF
a]K6eTh01@002DkFa]K6e/KFCP050008C]K6e/KFaTd60008C]K6e/KFaTd80003CTe>00bE00==CP00
1`002Dg6e/KFa]K6C@08000@CTf3Th>CPi>3Th>CPi=>C@T000Q=a]K6e/KFCPH000Q=a]K6e/KFCPD0
00U>e/KFa]K6eTh01@002DkFa]K6e/KFCP080003CDjE00^E00==CP004@0001T00dh7U@=>2`03CP03
aTi>00P00Th2aP9>2002CP;60Th700=>0/H2CPL00dh2aP9>2`03CPN30Th<009>0/H2CPP00Th2aP9>
1`03CP;60Th700=>0/H2CPL00dh00lI>CP0<009>28<2CP/00dh2aP9>1`03CP;60Th700=>00?6CTh0
2003CP03aTi>00`00Th7U@=>2`03CP;60Th;00=>1h<2CP`00dh00lI>CP08009>0/H2CPL00dh2aP9>
1`03CP;60Th;00=>1iD2CQ@0000L0007CDi=CTe>C@0A0003C@0000X000=>C@002`000di=000;0003
CTd000/000=>C@003`001di=CTe>CDh040000de>000;0003CDh000/000==CP002`000de>000;0003
C@0000h000Q>CDi=CTe>CA0000=>C@002`000di=000;0003CP0000/000=>00003P001de>CDi=CTd0
4@000de>000?0007CDi=CTe>C@0A0003C@0000X000=>C@002`000di=000;0003CTd000l000M>CDi=
CTe>01H0003o0</0003o0</0003o0</0003o0</00000\
\>"],
  ImageRangeCache->{{{0, 457}, {31, 0}} -> {-0.787665, -0.712262, 0.0723749, 
  0.0459524}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .05 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0322841 0.025 0.047619 [
[ 0 0 0 0 ]
[ 1 .05 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .05 L
0 .05 L
closepath
clip
newpath
p
p
.9 g
.001 w
.05609 .025 m
matrix currentmatrix
.01614 .02381 scale
3.47478 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
3.47478 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.10452 .025 m
matrix currentmatrix
.03228 .02381 scale
3.23751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03228 .02381 scale
3.23751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.15295 .025 m
matrix currentmatrix
.01614 .02381 scale
9.47525 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
9.47525 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.18523 .025 m
matrix currentmatrix
.01614 .02381 scale
11.475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
11.475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.21751 .025 m
matrix currentmatrix
.01614 .02381 scale
13.4747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
13.4747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.26594 .025 m
matrix currentmatrix
.03228 .02381 scale
8.23749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03228 .02381 scale
8.23749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.31437 .025 m
matrix currentmatrix
.01614 .02381 scale
19.4752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
19.4752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.34665 .025 m
matrix currentmatrix
.01614 .02381 scale
21.475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
21.475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.37893 .025 m
matrix currentmatrix
.01614 .02381 scale
23.4747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
23.4747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.41122 .025 m
matrix currentmatrix
.01614 .02381 scale
25.4751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
25.4751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.4435 .025 m
matrix currentmatrix
.01614 .02381 scale
27.4748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
27.4748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.49193 .025 m
matrix currentmatrix
.03228 .02381 scale
15.2375 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03228 .02381 scale
15.2375 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.54036 .025 m
matrix currentmatrix
.01614 .02381 scale
33.4753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
33.4753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.57264 .025 m
matrix currentmatrix
.01614 .02381 scale
35.4751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
35.4751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.60492 .025 m
matrix currentmatrix
.01614 .02381 scale
37.4748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
37.4748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.63721 .025 m
matrix currentmatrix
.01614 .02381 scale
39.4752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
39.4752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.66949 .025 m
matrix currentmatrix
.01614 .02381 scale
41.4749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
41.4749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.70178 .025 m
matrix currentmatrix
.01614 .02381 scale
43.4753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
43.4753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.4 g
.001 w
.73406 .025 m
matrix currentmatrix
.01614 .02381 scale
45.475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
45.475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.76634 .025 m
matrix currentmatrix
.01614 .02381 scale
47.4748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
47.4748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.79863 .025 m
matrix currentmatrix
.01614 .02381 scale
49.4751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
49.4751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.83091 .025 m
matrix currentmatrix
.01614 .02381 scale
51.4749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
51.4749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.8632 .025 m
matrix currentmatrix
.01614 .02381 scale
53.4752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
53.4752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.89548 .025 m
matrix currentmatrix
.01614 .02381 scale
55.475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
55.475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.94391 .025 m
matrix currentmatrix
.03228 .02381 scale
29.2376 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03228 .02381 scale
29.2376 1.05 1 0 365.73 arc
setmatrix
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{458, 32},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007:000080P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5H/1JX00=d81_l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000e5D0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0b`000?l0b`000?l0b`000?l0b`000?l0
b`0001T000A>CDi=3`001de>CDi=CTd04P0014i=CTd;0004CDi=CPX000A=CTe>40001de>CDi=CTd0
4P0014i=CTd:0004CTe>C@/000A=CTe>2`0014i=CTd;0004CDi=CPl000M>CDi=CTe>018000A=CTe>
2`0014i=CTd:0004CTe>C@/000A=CTe>2`0014i=CTd;0004CDi=CPX000A=CTe>2`0014i=CTd;0004
CDi=CP/000A>CDi=2P0014i=CTd;0004CDi=CQ0000M=CTe>CDi=01L0000F00=>1<H00dh0000:009>
1iD5CP/00Th4aP03CP0000D00dh4aP03CP0000D00Th4aP03CP0000X00dh7P`E>2P03CPC600=>0000
1@02CPC600=>00001P02CPC600=>00001P02CPC600=>00001@03CPC600=>00002P02CPN31Dh;009>
1<H00dh0000500=>1<H00dh00005009>1<H00dh00006009>1<H00dh00006009>1<H00dh0000500=>
1<H00dh00005009>18400dh00006009>1<H00dh00006009>1<H00dh0000500=>1<H00dh00005009>
1<H00dh00006009>1<H00dh0000:00=>1h<5CQ80000E0009C]K6e/KFa]I>00T000=>CDh03YD00de>
00070008CLKFa]K6eTh60009CLKFa]K6e/I=00H000U>e/KFa]K6eTh02@004Ti=Pi>3Th>CPi>3Th>C
Pi>3C@P000U>e/KFa]K6eTh01P002Dg6e/KFa]K6C@060008C]K6e/KFaTd70008CLKFa]K6eTh60009
CLKFa]K6e/I=00T001==CTf3Th>CPi>3Th>CPi>3Tdi=00P000Q>e/KFa]K6C@H000U>e/KFa]K6eTh0
1P002Dg6e/KFa]K6C@060008C]K6e/KFaTd70008CLKFa]K6eTh60009CLKFa]K6e/I=00H000=>PH40
1H400dh000040008CLKFa]K6eTh70008C]K6e/KFaTd60009C]K6e/KFa]I>00H000U=a]K6e/KFaTd0
1P0024kFa]K6e/I=2@004de>CH>CPi>3Th>CPi>3Th>CPdd04@0001@000=>a/H01lH00dh00004009>
4iD00dh000040003C/K600K600=>00000P000dk6aP07aP03CP00008000=>a/H01lH00dh0000300=>
4X<00dh000040003C/K600O600=>00000P000dk6aP07aP03CP00008000=>a/H01/H00dh000030003
C/K600K600=>00000P000dk6aP07aP03CP0000@00ThCP`03CP0000@000=>a/H01/H00dh000020003
C/K600O600=>00000P000dk6aP07aP03CP00008000=>a/H01/H00dh000030003C/K600K600=>0000
0P000dk6aP07aP03CP00008000=>PH401h400dh000020003C/K600K600=>00000`000dk6aP06aP03
CP00008000=>a/H01lH00dh000020003C/K600O600=>00000P000dk6aP06aP03CP0000@00ThCP`03
CP0000h0000C000=C]K6e/KFa]K6e/KFCP040003CIFE01BE00=>00000P0034g6e/KFa]K6e/KFCP80
00e=a]K6e/KFa]K6e/I=008000e>e/KFa]K6e/KFa]I>00<001Q>Th>CPi>3Th>CPi>3Th>CPi>3Th>C
Pdd4000=C]K6e/KFa]K6e/KFCP02000=CLKFa]K6e/KFa]K6C@02000<C]K6e/KFa]K6e/I=0`0034g6
e/KFa]K6e/KFCP8000e=a]K6e/KFa]K6e/I=00@001Q>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdd4000<
C]K6e/KFa]K6e/I=0P003DkFa]K6e/KFa]K6eTh00P003Dg6e/KFa]K6e/KFaTd00P0034kFa]K6e/KF
a]K6C@<000a=a]K6e/KFa]K6eTh2000=CLKFa]K6e/KFa]K6C@020003CX6100V100m>001=a]K6e/KF
a]K6eTh00`0034kFa]K6e/KFa]K6C@8000e>e/KFa]K6e/KFa]I>008000e=a]K6e/KFa]K6e/I=0080
00a>e/KFa]K6e/KFaTd4000HCY>3Th>CPi>3Th>CPi>3Th>CPi>3Th==3`0001<000=>a/H02LH01Dh0
001>01NE00=>00000P000dk6aP08aP04CP00CP_600A>001>2lH01Dh0001>01N300E>0000CP0;aP04
CP00CP_600A>001>2/H01Dh0001>00[600A>001>2lH01Dh0001>01N300=>00000P000dk6aP08aP04
CP00CP_600A>001>2lH014h004h:aP05CP0004h02/H014h004h;aP04CP00CP^100A>001>2/H01Dh0
001>00[600A>001>2lH014h004h;aP04CP00CP[600=>00000P000dj3P`0EP`03CP0000`0000B000A
CLKFa]K6e/KFa]K6e/I=04d06ID0;Td004kFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFa]I>CLKFa]K6
e/KFa]K6eTh2000KCH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==008006E>e/KFa]K6e/KFa]K6CDkF
a]K6e/KFa]K6e/I=04g6e/KFa]K6e/KFa]I>04kFa]K6e/KFa]K6e/I=04g6e/KFa]K6e/KFa]I>04jC
Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP02001ICLKFa]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFaTe>
e/KFa]K6e/KFa]K6C@1=a]K6e/KFa]K6e/KFCP1>e/KFa]K6e/KFa]K6C@1=a]K6e/KFa]K6e/KFCTd0
3840Bdh0C]K6e/KFa]K6e/KFaTd0CLKFa]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KF
a]K6C@1=a]K6e/KFa]K6e/KFCP02000KCH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==00d0000B0003
C/K600_600=>04h06ID014h004h<aP9>3LH2CPc600A>001>6H<014h004h<aP9>3<H00dh0CP0<aP03
CP1>00c600=>04h03<H00dh0CP0IP`04CP00CPc600=>04h03<H2CPc600=>04h03<H00dh0CP0<aP03
CP1>00c60Th<P@03CP1>00c600=>04h03<H00dh0CP0<aP9>3<H00dh0CP0<aP04CP00CQV300=>0000
2`000180011=a]K6e/KFa]K6e/KFaTe>6iD0odi=a]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6eTi=
a]K6e/KFa]K6e/KFaTe>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCTg6e/KFa]K6e/KFa]K6CDkF
a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFa]I>CH>C
Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPde>e/KFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFaTe>e/KF
a]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CDkFaP003Di=a]K6e/KFa]K6e/H0
3H40J4e>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6
e/KFCTg6e/KFa]K6e/KFa]K6CDjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>3000018000=>a/H0
2lH2CQ^E0Th=aP9>3LH2CPg60ThKP`9>3LH2CPg60Th=aP03C/K600_60Th=aP9>6h<2CPg60Th=aP9>
3LH2CPg600=>a/H02lH2CPg60Th=P@9>3LH00dk6aP0;aP9>3LH2CPg60Th=aP9>6h<00dh0000:0000
4P0044g6e/KFa]K6e/KFa]K6CDhLU@3oCLKFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>CLKFa]K6
e/KFa]K6e/I=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==a]K6e/KFa]K6e/KFaTe>e/KFa]K6
e/KFa]K6eTkFa]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCTf3Th>CPi>3
Th>CPi>3Th>CPi>3Th>CPi>3Th>CC]K6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/KFC]K6e/KFa]K6
e/KFa]I>e/KFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFa]I>e/KF000<CLKFa]K6e/KFa]K63H40J4g6
e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6
e/KFa]K6e/KFa]K6CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>3000018000=>a/H02lH2CQbE
00=>a/H03<H00dk6aP0;aP9>3LH00dj3P`0KP`03C/K600_60Th=aP03C/K600c600=>a/H03<H00dk6
aP0;aP9>78<00dk6aP0<aP03C/K600c600=>a/H02lH00dk6aP0<aP03C/K600c600=>a/H03<H00dj1
P@0;P@03C/K600c600=>a/H03<H00dk6aP0<aP03C/K600_600=>a/H03<H00dj3P`0JP`9>2`000180
011=a]K6e/KFa]K6e/KFaTe>79D0odg6e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCTg6e/KFa]K6
e/KFa]K6CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6e/I=C]K6e/KFa]K6
e/KFa]I>e/KFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTi=Pi>3Th>CPi>3
Th>CPi>3Th>CPi>3Th>CPi>3TdkFa]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6
e/KFC]K6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/KFC]K6eP0034g6e/KFa]K6e/KFaPf106U=a]K6
e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6
e/KFa]K6e/KFaTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCTd02`00018000=>a/H02lH2CQbE
00=>a/H03<H00dk6aP0;aP9>3LH00dj3P`0JP`9>3LH2CPg600=>a/H03<H00dk6aP0<aP03C/K600_6
0ThLP`03C/K600c600=>a/H02lH2CPg600=>a/H03<H00dk6aP0<aP03C/K600_60Th=P@03C/K600c6
00=>a/H03<H00dk6aP0;aP9>3LH00dk6aP0<aP03CX>301Z300=>00002P000180011=a]K6e/KFa]K6
e/KFaTe>79D0odg6e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]K6CH>CPi>3
Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>CLKFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFa]I>e/KFa]K6
e/KFa]K6e/I=a]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTi=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3
Th>CPi>3TdkFa]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6
e/KFa]K6CLKFa]K6e/KFa]K6e/KFC]K6eP0034g6e/KFa]K6e/KFaPf106Q=a]K6e/KFa]K6e/KFa]I>
e/KFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFaTf3
Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP`0000B0003C/K600_60ThKU@9>3LH2CPg60Th=aP9>
6h<2CPg60Th=aP9>3<H2CPg60Th=aP9>6h<2CPg60Th=aP9>3LH2CPc60Th=aP9>3LH2CPf10Th<aP9>
3LH2CPg60Th=aP9>3<H00dh0CP0JP`03CP0000/0000B000ACLKFa]K6e/KFa]K6e/I=04d06ID0odd0
CLKFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6e/I=CY>3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CPi>3C@1=a]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6
e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/KFCP1>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Tdh0C]K6
e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=a]K6
e/KFa]K6e/KFaTe>eP003Td0CLKFa]K6e/KFa]K63H40Ide>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6
e/KFCTg6e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>04jCPi>3Th>CPi>3
Th>CPi>3Th>CPi>3Th>CPdd03@0001<000=>a/H02LH01Dh0001>01NE00E>0000CP0;aP04CP00CP_6
00A>001>2lH00dh00002CQN300E>0000CP0;aP04CP00CP_600=>04h03<H00dh0CP0<aP03CP1>00_6
00E>0000CP0GP`05CP0004h03<H00dh0CP0;aP04CP00CP_600=>04h03<H00dh0CP0<aP03CP1>00_6
00A>001>2h400dh0CP0<aP03CP1>00c600=>04h02lH014h004h;aP03CP1>00c600=>00000ThGP`03
CP0000`0000D000<CLKFa]K6e/KFa]I>10000de>U@0DU@03CP00008000a=a]K6e/KFa]K6eTh3000<
C]K6e/KFa]K6e/I=0P003DkFa]K6e/KFa]K6eTh010005df3Th>CPi>3Th>CPi>3Th>CPi>3Th==00D0
00a=a]K6e/KFa]K6eTh2000=CLKFa]K6e/KFa]K6C@02000=C]K6e/KFa]K6e/KFCP02000=CLKFa]K6
e/KFa]K6C@02000<C]K6e/KFa]K6e/I=100064i=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3C@@000e>e/KF
a]K6e/KFa]I>008000a=a]K6e/KFa]K6eTh3000<C]K6e/KFa]K6e/I=0P003DkFa]K6e/KFa]K6eTh0
0P003Dg6e/KFa]K6e/KFaTd00P0034kFa]K6e/KFa]K6C@<000==PH40284044h004g6e/KFa]K6e/KF
aTd2000=C]K6e/KFa]K6e/KFCP02000<CLKFa]K6e/KFa]I>0`0034kFa]K6e/KFa]K6C@8000e>e/KF
a]K6e/KFa]I>00@001M=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3C@0?000050000dk6aP07aP03CP0000D0
00=>UID049D2CPD000=>a/H01lH2CP<000=>a/H01lH00dh000020003C/K600O600=>000010000dj3
P`0@P`9>1P000dk6aP07aP03CP00008000=>a/H01lH00dh000020003C/K600K60Th30003C/K600O6
0Th30003C/K600O600=>00001@000dj3P`0@P`9>1@000dk6aP07aP9>0`000dk6aP07aP03CP000080
00=>a/H01lH00dh000020003C/K600K60Th30003C/K600O60Th30003C/K600O600=>00000P000dj1
P@07P@03CP00008000=>a/H01/H2CP<000=>a/H01lH2CP<000=>a/H01lH00dh000020003C/K600O6
00=>00000P000dk6aP06aP9>1P000dj3P`0@P`9>400001D000U>e/KFa]K6eTh02@000di=U@0<U@03
CDi=00P000U>e/KFa]K6eTh01P002Dg6e/KFa]K6C@060009C]K6e/KFa]I>00P0019=CTf3Th>CPi>3
Th>CPi>3CDh90009C]K6e/KFa]I>00H000U=a]K6e/KFaTd01P0024kFa]K6e/I=1P002DkFa]K6e/KF
CP060009CLKFa]K6e/I=00T0019=CY>3Th>CPi>3Th>CPi=>CDh80009CLKFa]K6e/I=00H000U>e/KF
a]K6eTh01P002Dg6e/KFa]K6C@060008C]K6e/KFaTd60009C]K6e/KFa]I>00H000U=a]K6e/KFaTd0
1P000dj1P@05P@03CP0000@000Q=a]K6e/KFCPH000U=a]K6e/KFaTd01P002DkFa]K6e/KFCP060009
CLKFa]K6e/I=00H000Q>e/KFa]K6C@T0019=CTf3Th>CPi>3Th>CPi>3CDhB00005P03CP;60Th<00=>
29D2CP`00dh2aP9>2003CP;60Th800=>0/H2CP`00dh7P`=>3003CP;60Th800=>0/H2CPP00Th2aP9>
2003CP;60Th800=>0/H2CP`00dh8P`9>3003CP;60Th800=>0/H2CPP00dh2aP9>2002CP;60Th800=>
0/H2CPP00dh2aP9>2003CP:10Th8009>0/H2CPP00dh2aP9>2003CP;60Th800=>0/H2CPP00Th2aP9>
3@03CPN30dhD00006@000di=000@0008CDi=CTe>CDhA0003CTd000`000==CP0030000di=000@0007
CDi=CTe>C@0B0003CTd000`000==CP002`000de>000<0003CTd000`000==CP00400024i=CTe>CDi=
4@000de>000<0003CTd000`000==CP002`000de>000<0003CTd000`000==CP0030000di=000;0003
CTd000`000==CP0030000di=000<0003CDh000/000==CP004@001de>CDi=CTd05`000?l0b`000?l0
b`000?l0b`000?l0b`000001\
\>"],
  ImageRangeCache->{{{0, 457}, {31, 0}} -> {-0.737654, -0.712262, 0.0677797, 
  0.0459524}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .05 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0302343 0.025 0.047619 [
[ 0 0 0 0 ]
[ 1 .05 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .05 L
0 .05 L
closepath
clip
newpath
p
p
.9 g
.001 w
.05404 .025 m
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.08428 .025 m
matrix currentmatrix
.01512 .02381 scale
5.57512 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
5.57512 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.12963 .025 m
matrix currentmatrix
.03023 .02381 scale
4.28751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
4.28751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.17498 .025 m
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.22033 .025 m
matrix currentmatrix
.03023 .02381 scale
7.28741 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
7.28741 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.26568 .025 m
matrix currentmatrix
.01512 .02381 scale
17.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
17.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.29592 .025 m
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.32615 .025 m
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.35639 .025 m
matrix currentmatrix
.01512 .02381 scale
23.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
23.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.38662 .025 m
matrix currentmatrix
.01512 .02381 scale
25.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
25.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.43197 .025 m
matrix currentmatrix
.03023 .02381 scale
14.2874 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
14.2874 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.47732 .025 m
matrix currentmatrix
.01512 .02381 scale
31.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
31.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.50756 .025 m
matrix currentmatrix
.01512 .02381 scale
33.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
33.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.53779 .025 m
matrix currentmatrix
.01512 .02381 scale
35.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
35.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.56803 .025 m
matrix currentmatrix
.01512 .02381 scale
37.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
37.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.59826 .025 m
matrix currentmatrix
.01512 .02381 scale
39.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
39.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.6285 .025 m
matrix currentmatrix
.01512 .02381 scale
41.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
41.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.67385 .025 m
matrix currentmatrix
.03023 .02381 scale
22.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
22.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.7192 .025 m
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.76455 .025 m
matrix currentmatrix
.03023 .02381 scale
25.2875 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
25.2875 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.8099 .025 m
matrix currentmatrix
.01512 .02381 scale
53.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
53.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.84014 .025 m
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.87037 .025 m
matrix currentmatrix
.01512 .02381 scale
57.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
57.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.91572 .025 m
matrix currentmatrix
.03023 .02381 scale
30.2874 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
30.2874 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.96107 .025 m
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{458, 32},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007:000080P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5H/1JX00=d81_l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000e5D0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0b`000?l0b`000?l0b`000?l0b`000?l0
b`0001P000==CTd02`000de>C@0?0006CDi=CTe>4@0014i=CTd>0007CTe>CDi=CP0@0004CDi=CPX0
00A=CTe>2P0014e>CDh:0004CDi=CPX000==CTd03`001de>CDi=CTd0400014i=CTd:0004CTe>C@X0
00=>CDh02`000di=CP0:0004CDi=CPX000A=CTe>3`001Ti=CTe>CA4000==CTd03`001de>CDi=CTd0
400014i=CTd:0004CTe>C@X000=>CDh03`001di=CTe>CDh0400014e>CDh@00005P02CP?600=>0000
1@03CP?600=>00002@03CPJE1Dh:009>1<H00dh00009009>1h<5CPT00Th4aP03CP0000D00Th4aP03
CP0000D00Th4aP03CP0000D00Th4aP03CP0000D00Th3aP03CP0000T00dh7P`E>2@02CPC600=>0000
1@02CPC600=>00001@02CP?600=>00001P02CP?600=>00001@02CPC600=>00001@02CPC600=>0000
2@03CPJ31Dh:009>0lH00dh0000900=>1iD4CPX00Th4aP03CP0000D00Th4aP03CP0000D00Th3aP03
CP0000X00Th7P`E>2@02CPC600=>00003@0001D000M>e/KFa]I>00H000Q=a]K6e/KFCPT000=>CID0
3ID00dh000060008CLKFa]K6eTh8000BCDi=Pi>3Th>CPi>3Th>CPi=>1`0024kFa]K6e/I=1P0024kF
a]K6e/I=1P0024kFa]K6e/I=1P0024kFa]K6e/I=1P0024kFa]K6e/I=20004Ti=Pi>3Th>CPi>3Th>C
Pi>3C@L000Q=a]K6e/KFCPH000Q=a]K6e/KFCPH000Q=a]K6e/KFCPH000M=a]K6e/I=00H000Q>e/KF
a]K6C@H000Q>e/KFa]K6C@T0015=CY>3Th>CPi>3Th>CPi>3C@080008C]K6e/KFaTd80003CTfE00fE
00=>00001P0024g6e/KFa]I>1P0024g6e/KFa]I>1P0024g6e/KFa]I>20004Te>CH>CPi>3Th>CPi>3
Th>CCPL000Q>e/KFa]K6C@l0000D0003C/K600G600=>00000P000dk6aP06aP03CP0000@00ThAU@03
CP0000@000=>a/H01/H00dh00003009>4X<00dh000030003C/K600K600=>00000P000dk6aP06aP03
CP00008000=>a/H01/H00dh000020003C/K600K600=>00000P000dk6aP06aP03CP0000<00ThAP`03
CP0000@000=>a/H01/H00dh000020003C/K600K600=>00000P000dk6aP06aP03CP00008000=>a/H0
1LH00dh000020003C/K600K600=>00000P000dk6aP06aP03CP0000<00dhAP`03CP0000@000=>a/H0
1/H00dh00003009>4ID00dh000040003C/K600K600=>00000P000dk6aP06aP03CP00008000=>a/H0
1/H00dh00003009>4X<00dh000030003C/K600K600=>0000300001<000]>e/KFa]K6e/KFCP03000;
C]K6e/KFa]K6eTh010000dfEU@0BU@03CP00008000a=a]K6e/KFa]K6eTh3000GCY>3Th>CPi>3Th>C
Pi>3Th>CPi>3Tdh00`0034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=
0P0034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd3000FCH>CPi>3Th>CPi>3Th>CPi>3Th>CCP@0
00a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP8000]=a]K6e/KFa]K6
C@02000<C]K6e/KFa]K6e/I=0P0034kFa]K6e/KFa]K6C@<001M=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3
C@04000<C]K6e/KFa]K6e/I=0`000dfEU@0BU@03CP00008000a=a]K6e/KFa]K6eTh2000<CLKFa]K6
e/KFa]I>0P0034g6e/KFa]K6e/KFCP<001M>Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP03000<C]K6e/KF
a]K6e/I=3@0001<000=>a/H01lH01Dh0001>00W600E>0000CP0FU@05CP0004h02/H01Dh0001>01F3
00E>0000CP0:aP04CP00CP[600A>001>2/H014h004h:aP04CP00CP[600A>001>5X<01Dh0001>00[6
00A>001>2/H014h004h:aP04CP00CPW600A>001>2/H014h004h:aP05CP0004h05X<01Dh0001>00[6
00A>001>5YD01Dh0001>00[600A>001>2/H014h004h:aP04CP00CQJ300E>0000CP0:aP03CP0000/0
000B000MCLKFa]K6e/KFa]K6C@1=a]K6e/KFa]K6e/I=04d069D0:Th0C]K6e/KFa]K6e/KFaTd0CH>C
Pi>3Th>CPi>3Th>CPi>3Th>CPi>3C@800=i>e/KFa]K6e/KFa]I>04kFa]K6e/KFa]K6eTi=a]K6e/KF
a]K6e/KFCTg6e/KFa]K6e/KFaTd0CLKFa]K6e/KFa]K6C@1=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>C
CP1>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFCP1>e/KFa]K6e/KFa]I>04kF
a]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFCP1>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3C@1=a]K6e/KF
a]K6e/I=04dHU@16CP1>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFCP1>Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CPi>3C@8000e>e/KFa]K6e/KFa]I>00`0000B0003C/K600W600=>04h0
2lH00dh0CP0HU@03CP1>00c600=>04h05h<014h004h;aP03CP1>00_60Th<aP9>2lH00dh0CP0;aP03
CP1>01R300=>04h03<H2CPc60Th;aP03CP1>00_600=>04h02lH00dh0CP0;aP03CP1>01R300=>04h0
2lH00dh0CP0HU@03CP1>00c60Th<aP9>2lH00dh0CP0HP`04CP00CP_600=>00002P00018001a=a]K6
e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>6YD0ode>e/KFa]K6e/KFa]K6CDjCPi>3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CCTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6e/KFa]K6
e/KFa]I>CLKFa]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPde>e/KFa]K6e/KFa]K6
CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6
e/KFa]K6e/KFCTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Tdi=a]K6eP002De>e/KFa]K6eP0JU@1D
CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDjCPi>3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CCTg6e/KFa]K6e/KFa]I>3000018000=>a/H02/H00dk6aP0;aP03CYFE01RE0Th<aP9>
6H<2CPg600=>a/H02/H2CPc60Th<aP9>3<H00dj3P`0HP`9>3<H2CPc60Th<aP03C/K600_600=>a/H0
2lH00dk6aP0:aP9>6X<2CPc600=>UID069D2CPc60Th<aP9>3<H2CQV30Th<aP03CP0000X0000A000M
C]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTh06YD0ode>e/KFa]K6e/KFa]K6CH>CPi>3Th>CPi>3
Th>CPi>3Th>CPi>3Th>CPdg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFCTg6
e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>e/KFa]K6
e/KFa]K6eTkFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6
e/I=a]K6e/KFa]K6e/KFaTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3TdkFa]K6eP002De>e/KFa]K6
eP0KU@1DC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=Pi>3Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6e/I=2`00014000=>a/H02lH00dk6aP0;aP03CYFE01RE
0Th<aP03CX>301V300=>a/H02lH00dk6aP0;aP03C/K600[60Th<aP03C/K600_600=>Ph<06H<00dk6
aP0;aP03C/K600[600=>a/H02lH00dk6aP0;aP03C/K600_600=>a/H02lH00dj3P`0HP`03C/K600_6
00=>UID06ID00dk6aP0;aP03C/K600[600=>a/H02lH00dj3P`0IP`03C/K600_600=>00002@000140
01e>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCP0JU@3oCDkFa]K6e/KFa]K6e/I=CY>3Th>CPi>3
Th>CPi>3Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]I>
CLKFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3TdkFa]K6
e/KFa]K6e/KFC]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6
e/KFaTg6e/KFa]K6e/KFa]K6CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CC]K6e/KF0009CDkFa]K6
e/KF01^E05A>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTf3Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CPi>3Th==a]K6e/KFa]K6e/KFaTd;00004@000dk6aP0;aP03C/K600_600=>UID0
69D2CPc60ThJP`03C/K600_600=>a/H02lH00dk6aP0:aP9>3<H00dk6aP0;aP03CX>301R30Th<aP9>
3<H00dk6aP0;aP03C/K600_600=>a/H02lH00dk6aP0;aP03CX>301R300=>a/H02lH00djEU@0HU@9>
3<H2CPc60Th<aP03CX>301R30Th=aP03CP0000T0000A000MC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KF
a]K6eTh06YD0ode>e/KFa]K6e/KFa]K6CDjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdg6e/KFa]K6
e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6
eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPde>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=a]K6
e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTf3Th>CPi>3
Th>CPi>3Th>CPi>3Th>CPi>3TdkFa]K6eP002De>e/KFa]K6eP0JU@1ECDkFa]K6e/KFa]K6e/I=C]K6
e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCTg6e/KFa]K6
e/KFa]K6C@0;00004P000dk6aP0:aP9>2lH00dh0CP0HU@03CP1>00c60ThIP`9>3<H2CPc60Th<aP9>
3<H2CPc60ThIP`9>3<H2CPc60Th<aP9>3<H00dk6aP0:aP9>3<H2CQV300=>04h03<H2CQVE0Th<aP9>
3<H2CPc60ThIP`9>3<H00dh0000:00004P007Dg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6C@1=01RE
0?m>04kFa]K6e/KFa]K6e/I=CY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>CLKFa]K6e/KFa]K6eTi=
a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTf3Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CPi=>04kFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KF
a]K6CDkFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>04jCPi>3Th>CPi>3Th>C
Pi>3Th>CPi>3Th==04g6e/H000]>04kFa]K6e/KFaP0HU@1ECP1>e/KFa]K6e/KFa]K6CDkFa]K6e/KF
a]K6e/I=C]K6e/KFa]K6e/KFaTe>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3C@1=a]K6e/KFa]K6e/KF
CP0<00004P000dk6aP09aP03CP1>00_600=>00000ThEU@05CP0004h02/H00dh00002CQJ300A>001>
2lH00dh0CP0:aP04CP00CP[600A>001>2/H00dh0CP0;aP03CP00009>5H<01Dh0001>00[600A>001>
2/H00dh0CP0;aP03CP1>00_600=>04h02lH00dh0CP0:aP05CP0004h05X<014h004h;aP03CP00009>
5ID01Dh0001>00[600A>001>2/H00dh0CP0;aP03CP00009>5H<01Dh0001>00_600=>00002P0001<0
00a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=10000djEU@0AU@03CP00008000a=a]K6e/KFa]K6
eTh4000FCH>CPi>3Th>CPi>3Th>CPi>3Th>CCP@000a=a]K6e/KFa]K6eTh2000;CLKFa]K6e/KFaTd0
0`002dg6e/KFa]K6e/I=008000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=10005TjCPi>3Th>C
Pi>3Th>CPi>3Th>CPdd4000;C]K6e/KFa]K6eTh00P0034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6
eTh2000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP8000]=a]K6e/KFa]K6C@04000FCY>3Th>C
Pi>3Th>CPi>3Th>CPi>3C@@000a>e/KFa]K6e/KFaTd40003CYFE016E00=>00000`002dkFa]K6e/KF
a]I>008000a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>10005Tf3Th>CPi>3Th>CPi>3Th>CPi>3
Tdh4000<CLKFa]K6e/KFa]I>300001<000=>a/H01lH01Dh0001>00W600=>000010000djEU@0>U@9>
1P000dk6aP06aP03CP0000@000=>Ph<03h<2CPD000=>a/H01/H2CP<000=>a/H01/H2CP<000=>a/H0
1/H00dh000020003C/K600K600E>0000CP09aP03CP0000@000=>Ph<03h<2CPD000=>a/H01/H2CP<0
00=>a/H01/H01Dh0001>00W600E>0000CP09aP05CP0004h02<H2CP<000=>a/H01/H2CPD000=>Ph<0
3h<2CPD000=>a/H01lH00dh000040003CYFE00jE0Th60003C/K600K60Th30003C/K600K600E>0000
CP09aP03CP0000@000=>Ph<03h<2CPD000=>a/H01/H2CPd0000D0009CLKFa]K6e/I=00D000U=a]K6
e/KFaTd020000di=U@0;U@03CTd000P000Q=a]K6e/KFCPP0015=CY>3Th>CPi>3Th>CPi=>C@080008
C]K6e/KFaTd60008C]K6e/KFaTd60008C]K6e/KFaTd60008C]K6e/KFaTd50009CLKFa]K6e/I=00P0
015>CH>CPi>3Th>CPi>3Tdi=CP080008CLKFa]K6eTh60008CLKFa]K6eTh50009C]K6e/KFa]I>00D0
00U>e/KFa]K6eTh01@0024kFa]K6e/I=1P0024kFa]K6e/I=20004Di=CY>3Th>CPi>3Th>CPde>00P0
00U=a]K6e/KFaTd020000di=U@0;U@03CTd000P000Q=a]K6e/KFCPH000Q=a]K6e/KFCPD000U>e/KF
a]K6eTh020004De>Th>CPi>3Th>CPi>3CDi=00P000Q>e/KFa]K6C@l0000E00=>0/H2CPL00dh2aP9>
2`03CPNE0Th<009>0/H2CP/00dh7P`=>2`03CP03aTi>00P00dh00lI>CP08009>0/H2CPP00Th2aP9>
1`03CP;60Th;00=>1h<2CP`00dh00lI>CP08009>0/H2CPL00dh2aP9>1`03CP;60Th700=>00?6CTh0
2003CP03aTi>00`00Th7P`=>2`03CP;60Th;00=>1iD2CP`00dh00lI>CP08009>0/H2CPL00dh2aP9>
2`03CPN30Th<00=>00?6CTh0400001P000==CP002`000de>000?0007CDi=CTe>C@0@0003CTd000l0
00M>CDi=CTe>014000=>00002`000dh0000:0003CDh000/000==CP002`000de>000?0007CDi=CTe>
C@0A0003C@0000X000=>C@002`000di=000;0003CTd000/000=>00002`000dh0000>0007CDi=CTe>
C@0A0003CDh000l000M=CTe>CDi=014000==00002P000di=000;0003CTd000l000M>CDi=CTe>0140
00=>000040000?l0b`000?l0b`000?l0b`000?l0b`000001\
\>"],
  ImageRangeCache->{{{0, 457}, {31, 0}} -> {-0.787665, -0.712262, 0.0723749, 
  0.0459524}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .05 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0322841 0.025 0.047619 [
[ 0 0 0 0 ]
[ 1 .05 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .05 L
0 .05 L
closepath
clip
newpath
p
p
.9 g
.001 w
.05609 .025 m
matrix currentmatrix
.01614 .02381 scale
3.47478 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
3.47478 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.08838 .025 m
matrix currentmatrix
.01614 .02381 scale
5.47514 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
5.47514 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.12066 .025 m
matrix currentmatrix
.01614 .02381 scale
7.47489 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
7.47489 1.05 1 0 365.73 arc
setmatrix
s
P
p
.4 g
.001 w
.15295 .025 m
matrix currentmatrix
.01614 .02381 scale
9.47525 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
9.47525 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.18523 .025 m
matrix currentmatrix
.01614 .02381 scale
11.475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
11.475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.21751 .025 m
matrix currentmatrix
.01614 .02381 scale
13.4747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
13.4747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.2498 .025 m
matrix currentmatrix
.01614 .02381 scale
15.4751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
15.4751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.28208 .025 m
matrix currentmatrix
.01614 .02381 scale
17.4749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
17.4749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.31437 .025 m
matrix currentmatrix
.01614 .02381 scale
19.4752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
19.4752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.36279 .025 m
matrix currentmatrix
.03228 .02381 scale
11.2374 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03228 .02381 scale
11.2374 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.41122 .025 m
matrix currentmatrix
.01614 .02381 scale
25.4751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
25.4751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.4435 .025 m
matrix currentmatrix
.01614 .02381 scale
27.4748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
27.4748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.47579 .025 m
matrix currentmatrix
.01614 .02381 scale
29.4752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
29.4752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.50807 .025 m
matrix currentmatrix
.01614 .02381 scale
31.4749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
31.4749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.54036 .025 m
matrix currentmatrix
.01614 .02381 scale
33.4753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
33.4753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.57264 .025 m
matrix currentmatrix
.01614 .02381 scale
35.4751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
35.4751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.62107 .025 m
matrix currentmatrix
.03228 .02381 scale
19.2376 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03228 .02381 scale
19.2376 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.66949 .025 m
matrix currentmatrix
.01614 .02381 scale
41.4749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
41.4749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.70178 .025 m
matrix currentmatrix
.01614 .02381 scale
43.4753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
43.4753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.73406 .025 m
matrix currentmatrix
.01614 .02381 scale
45.475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
45.475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.78249 .025 m
matrix currentmatrix
.03228 .02381 scale
24.2376 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03228 .02381 scale
24.2376 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.83091 .025 m
matrix currentmatrix
.01614 .02381 scale
51.4749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
51.4749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.87934 .025 m
matrix currentmatrix
.03228 .02381 scale
27.2376 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03228 .02381 scale
27.2376 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.92776 .025 m
matrix currentmatrix
.01614 .02381 scale
57.4747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
57.4747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.96005 .025 m
matrix currentmatrix
.01614 .02381 scale
59.4751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
59.4751 1.05 1 0 365.73 arc
setmatrix
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{458, 32},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007:000080P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5H/1JX00=d81_l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000e5D0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0b`000?l0b`000?l0b`000?l0b`000?l0
b`0001T000A>CDi=2P0014i=CTd;0004CDi=CP/000A>CDi=2`0014e>CDh:0004CDi=CP/000A>CDi=
2`0014e>CDh;0004CTe>C@l000M=CTe>CDi=018000A>CDi=2`0014e>CDh:0004CDi=CP/000A>CDi=
2`0014e>CDh;0004CTe>C@l000M=CTe>CDi=018000A>CDi=2`0014e>CDh:0004CDi=CQ0000M=CTe>
CDi=018000A>CDi=3`001de>CDi=CTd04P0014i=CTd;0004CDi=CQ00000F00=>1<H00dh00005009>
1<H00dh00006009>1<H00dh00006009>18400dh0000500=>1<H00dh00005009>1<H00dh00006009>
1<H00dh00006009>1<H00dh0000500=>1<H00dh0000:009>1h<5CP/00Th4aP03CP0000D00dh4aP03
CP0000D00Th4aP03CP0000H00Th4aP03CP0000H00Th4aP03CP0000D00dh4aP03CP0000X00Th7P`E>
2`02CPC600=>00001@03CPC600=>00001@02CPC600=>00002P03CPNE1Dh:00=>1<H00dh0000:009>
1h<6CPX00Th4aP03CP0000D00dh4aP03CP0000d0000E0009C]K6e/KFa]I>00H000U=a]K6e/KFaTd0
1P0024kFa]K6e/I=1`000df1P@04P@03CP0000@000U=a]K6e/KFaTd01P002DkFa]K6e/KFCP060008
CLKFa]K6eTh70008C]K6e/KFaTd60009C]K6e/KFa]I>00T001=>CDjCPi>3Th>CPi>3Th>CPde>00P0
00Q=a]K6e/KFCPH000U=a]K6e/KFaTd01P002DkFa]K6e/KFCP060008CLKFa]K6eTh70008C]K6e/KF
aTd60009C]K6e/KFa]I>00T001=>CDjCPi>3Th>CPi>3Th>CPde>00P000Q=a]K6e/KFCPH000U=a]K6
e/KFaTd01P002DkFa]K6e/KFCP090003CTfE00jE00==00001P002DkFa]K6e/KFCP09000CCTe>Th>C
Pi>3Th>CPi>3Th>CCP080008CLKFa]K6eTh60009CLKFa]K6e/I=00l0000D0003C/K600O600=>0000
0P000dk6aP07aP03CP00008000=>a/H01/H00dh000030003CX6100J100=>00000P000dk6aP07aP03
CP00008000=>a/H01lH00dh000020003C/K600K600=>00000`000dk6aP06aP03CP00008000=>a/H0
1lH00dh00004009>4h<00dh000040003C/K600K600=>00000P000dk6aP07aP03CP00008000=>a/H0
1lH00dh000020003C/K600K600=>00000`000dk6aP06aP03CP00008000=>a/H01lH00dh00004009>
4h<00dh000040003C/K600K600=>00000P000dk6aP07aP03CP00008000=>a/H01lH00dh0000300=>
4YD00dh000040003C/K600O600=>00001002CQ>300=>000010000dk6aP06aP03CP00008000=>a/H0
1lH00dh0000<00004`003DkFa]K6e/KFa]K6eTh00P003Dg6e/KFa]K6e/KFaTd00P0034kFa]K6e/KF
a]K6C@<000==PH40284044h004g6e/KFa]K6e/KFaTd2000=C]K6e/KFa]K6e/KFCP02000<CLKFa]K6
e/KFa]I>0`0034kFa]K6e/KFa]K6C@8000e>e/KFa]K6e/KFa]I>00@001Q=Pi>3Th>CPi>3Th>CPi>3
Th>CPi>3Tdh4000<CLKFa]K6e/KFa]I>0P003Dg6e/KFa]K6e/KFaTd00P003DkFa]K6e/KFa]K6eTh0
0P0034g6e/KFa]K6e/KFCP<000a>e/KFa]K6e/KFaTd2000=C]K6e/KFa]K6e/KFCP04000HCH>CPi>3
Th>CPi>3Th>CPi>3Th>CPi=>100034g6e/KFa]K6e/KFCP8000e=a]K6e/KFa]K6e/I=008000e>e/KF
a]K6e/KFa]I>00<000=>UID059D00dd00002000=C]K6e/KFa]K6e/KFCP04000HCH>CPi>3Th>CPi>3
Th>CPi>3Th>CPi=>100034g6e/KFa]K6e/KFCP8000e=a]K6e/KFa]K6e/I=00d0000C0003C/K600W6
00A>001>2lH014h004h:aP05CP0004h02X4014h004h;aP04CP00CP_600A>001>2/H01Dh0001>00[6
00A>001>2lH01Dh0001>01N300=>00000P000dk6aP08aP04CP00CP_600A>001>2lH014h004h:aP05
CP0004h02/H014h004h;aP05CP0004h05h<00dh000020003C/K600S600A>001>2lH014h004h;aP05
CP0004h05iD01Dh0001>00_600E>0000CP0GP`03CP00008000=>a/H02<H014h004h;aP03CP0000/0
000B000^CLKFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTd0CLKFa]K6e/KFa]K6eTh0CPb106M=C]K6
e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFaTd0CLKFa]K6e/KFa]K6eTh0C]K6
e/KFa]K6e/KFaTd0CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==008007A>e/KFa]K6e/KFa]K6C@1=
a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>04kFa]K6e/KFa]K6e/I=04g6e/KFa]K6e/KFa]I>04kF
a]K6e/KFa]K6e/I=04f3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3C@8002]>e/KFa]K6e/KFa]K6C@1=
a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>008000==UID05iD0;Dd004kFa]K6e/KFa]K6e/I=04f3
Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3C@02000MC]K6e/KFa]K6e/KFaTd0CLKFa]K6e/KFa]K6eTh0
3000018000=>a/H02lH2CPc600=>04h03<H00dh0CP0<P@9>3LH2CPc600=>04h03<H00dh0CP0<aP03
CP1>00c600=>04h06H<014h004h<aP03CP1>00c60Th<aP03CP1>00c600=>04h03<H00dh0CP0<aP03
CP1>01V300A>001>3<H00dh0CP0<aP9>3<H014h004hIU@04CP00CPc600=>04h06H<014h004h<aP03
CP1>00c600=>00002P00018002e=a]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6
e/KFaTd03H40ode>e/KFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6eTkFa]K6
e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]K6CDjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>CLKFa]K6
e/KFa]K6e/I=C]K6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFa]I>e/KFa]K6
e/KFa]K6eTi=a]K6e/KFa]K6e/KFaTe>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCTg6e/KFa]K6
e/KFa]K6CDkFa]K6e/KFa]K6e/KFCTg6eP003De>e/KFa]K6e/KFa]H06iD0Bdi=a]K6e/KFa]K6e/KF
aTe>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCTg6e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/KF
CP0<00004P000dk6aP0;aP9>3LH00dk6aP0<aP03CX6100^10Th=aP9>3LH00dk6aP0<aP03C/K600_6
0Th=aP9>6h<2CPg60Th=aP9>3LH2CPg600=>a/H02lH2CPg60ThKP`9>3LH2CPg60Th=aP9>6iD2CPg6
0ThKP`9>3LH2CPg600=>00002P00018002e=a]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6eTkFa]K6
e/KFa]K6e/KFaTd03X40odkFa]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/KF
C]K6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=CY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==
a]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6eTkF
a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CLKF
a]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]K6CLKFaP002dkFa]K6e/KFa]K601fE04]=a]K6e/KFa]K6
e/KFa]I>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdg6e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6
e/KFaTd02`00018000=>a/H02lH2CPg600=>a/H03<H00dj1P@0<P@03C/K600_60Th=aP03C/K600c6
00=>a/H03<H00dk6aP0;aP9>78<00dk6aP0<aP03C/K600_60Th=aP03C/K600c600=>a/H03<H00dk6
aP0<aP03CX>301Z300=>a/H03<H00dk6aP0<aP03C/K600_600=>UID06iD00dk6aP0<aP03CX>301Z3
00=>a/H03<H00dk6aP0<aP03CP0000T0000B000]CLKFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFa]I>
e/KFa]K6e/KFa]K6e/I=00j10?m>e/KFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KF
a]K6eTkFa]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CDjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>C
Pi>3CLKFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KF
a]I>e/KFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>C
Pdg6e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFaTg6e/H000]>e/KFa]K6e/KFaP0MU@1;CLKFa]K6
e/KFa]K6e/KFCY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==a]K6e/KFa]K6e/KFa]I>e/KFa]K6
e/KFa]K6e/I=00/0000B0003C/K600_60Th=aP03C/K600c600=>PH4038400dk6aP0;aP9>3LH00dk6
aP0<aP03C/K600c600=>a/H02lH2CQb300=>a/H03<H00dk6aP0;aP9>3LH00dk6aP0<aP03C/K600c6
00=>a/H02lH2CQb300=>a/H03<H00dk6aP0;aP9>3LH00djEU@0KU@03C/K600_60ThLP`03C/K600c6
00=>a/H02lH00dh0000:00004P00;Dg6e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6
e/KFa]K6C@0>P@3oC]K6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFa]I>e/KF
a]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTe>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdg6e/KF
a]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/KFC]K6e/KF
a]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=CY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==a]K6e/KF
a]K6e/KFa]I>e/KFa]K6e/KFa]K6eTi=a]K6000;C]K6e/KFa]K6e/H07ID0BTg6e/KFa]K6e/KFa]K6
CDjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>
3000018000=>a/H02lH2CPg60Th<aP9>3H42CPg60Th=aP9>3<H2CPg60Th=aP9>6h<2CPg60Th=aP9>
3LH2CPc60Th=aP9>3LH2CQ^30Th=aP9>3LH2CPg60ThKU@9>3LH2CQ^300=>04h03<H2CPg600=>0000
2P00018002e=a]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTd03H40ode>
e/KFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/KFCTg6
e/KFa]K6e/KFa]K6C@1=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdd0CLKFa]K6e/KFa]K6e/I=C]K6
e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6eTi=a]K6
e/KFa]K6e/KFaTd0CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==04g6e/KFa]K6e/KFa]K6CDkFa]K6
e/KFa]K6e/KFCTg6eP003De>e/KFa]K6e/KFa]H06YD0;Dd0CLKFa]K6e/KFa]K6e/I=04f3Th>CPi>3
Th>CPi>3Th>CPi>3Th>CPi>3C@02000MC]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6eTh0300001<0
00=>a/H02LH014h004h;aP03CP1>00c600=>04h02h4014h004h;aP04CP00CP_600=>04h03<H00dh0
CP0;aP04CP00CP_600E>0000CP0GP`05CP0004h03<H00dh0CP0;aP04CP00CP_600=>04h03<H00dh0
CP0<aP03CP1>00_600E>0000CP0GP`05CP0004h03<H00dh0CP0;aP04CP00CP_600=>00000ThGU@05
CP0004h02lH01Dh0001>01N300E>0000CP0<aP03CP1>00_600=>00002`0001@000a=a]K6e/KFa]K6
eTh2000=CLKFa]K6e/KFa]K6C@02000=C]K6e/KFa]K6e/KFCP020003CH6100R1011>0000C]K6e/KF
a]K6e/I=0P003DkFa]K6e/KFa]K6eTh00P003Dg6e/KFa]K6e/KFaTd00P0034kFa]K6e/KFa]K6C@<0
00a=a]K6e/KFa]K6eTh4000HCDjCPi>3Th>CPi>3Th>CPi>3Th>CPi=>10003Dg6e/KFa]K6e/KFaTd0
0P0034kFa]K6e/KFa]K6C@<000a=a]K6e/KFa]K6eTh2000=CLKFa]K6e/KFa]K6C@02000=C]K6e/KF
a]K6e/KFCP02000<CLKFa]K6e/KFa]I>100064e>Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP@000e=a]K6
e/KFa]K6e/I=008000a>e/KFa]K6e/KFaTd3000<CLKFa]K6e/KFa]I>10000dfEU@0CU@03C@0000<0
00a=a]K6e/KFa]K6eTh4000HCDjCPi>3Th>CPi>3Th>CPi>3Th>CPi=>10003Dg6e/KFa]K6e/KFaTd0
0P0034kFa]K6e/KFa]K6C@d0000D0003C/K600O600=>00000P000dk6aP07aP03CP00008000=>a/H0
1/H2CP<000=>PH401h42CP<000=>a/H01lH00dh000020003C/K600O600=>00000P000dk6aP06aP9>
0`000dk6aP07aP9>0`000dk6aP07aP03CP0000D000=>Ph<048<2CPD000=>a/H01lH2CP<000=>a/H0
1lH00dh000020003C/K600O600=>00000P000dk6aP06aP9>0`000dk6aP07aP9>0`000dk6aP07aP03
CP0000D000=>Ph<048<2CPD000=>a/H01lH2CP<000=>a/H01lH00dh000020003C/K600O600=>0000
10000djEU@0@U@9>1P000dk6aP07aP03CP0000D000=>Ph<048<2CPD000=>a/H01lH2CP<000=>a/H0
1lH00dh0000<00005@002DkFa]K6e/KFCP060009CLKFa]K6e/I=00H000Q>e/KFa]K6C@H000=>PH40
1H400dh000040009CLKFa]K6e/I=00H000U>e/KFa]K6eTh01P0024g6e/KFa]I>1P002Dg6e/KFa]K6
C@060009C]K6e/KFa]I>00T0019>CH>CPi>3Th>CPi>3Th==CTd80009C]K6e/KFa]I>00H000U=a]K6
e/KFaTd01P002DkFa]K6e/KFCP060008CLKFa]K6eTh60009CLKFa]K6e/I=00H000U>e/KFa]K6eTh0
2@004Ti=Pi>3Th>CPi>3Th>CPde>C@P000U>e/KFa]K6eTh01P002Dg6e/KFa]K6C@060009C]K6e/KF
a]I>00P000==CTd03ID00de>00080009C]K6e/KFa]I>00T0019>CH>CPi>3Th>CPi>3Th==CTd80009
C]K6e/KFa]I>00H000U=a]K6e/KFaTd03`0001H00dh2aP9>2003CP;60Th8009>0/H2CPP00dh2P@9>
2003CP;60Th800=>0/H2CPP00Th2aP9>2003CP;60Th800=>0/H2CP`00dh8P`9>3003CP;60Th800=>
0/H2CPP00dh2aP9>2002CP;60Th800=>0/H2CPP00dh2aP9>3003CPR30Th<00=>0/H2CPP00dh2aP9>
2003CP;60Th<00=>1iD3CP`00dh2aP9>3003CPR30Th<00=>0/H2CPP00dh2aP9>400001T000=>C@00
30000de>000;0003CDh000`000=>C@0030000de>000<0003CTd000/000=>C@0030000de>000<0003
CTd0010000Q=CTe>CDi=CQ4000=>C@0030000de>000<0003CTd000/000=>C@0030000de>000<0003
CTd0010000Q=CTe>CDi=CQ4000=>C@0030000de>000<0003CTd0010000M=CTe>CDi=018000=>C@00
400024e>CDi=CTe>4@000di=000<0003CDh00140003o0</0003o0</0003o0</0003o0</00000\
\>"],
  ImageRangeCache->{{{0, 457}, {31, 0}} -> {-0.737654, -0.712262, 0.0677797, 
  0.0459524}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .05 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0322841 0.025 0.047619 [
[ 0 0 0 0 ]
[ 1 .05 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .05 L
0 .05 L
closepath
clip
newpath
p
p
.9 g
.001 w
.05609 .025 m
matrix currentmatrix
.01614 .02381 scale
3.47478 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
3.47478 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.08838 .025 m
matrix currentmatrix
.01614 .02381 scale
5.47514 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
5.47514 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.1368 .025 m
matrix currentmatrix
.03228 .02381 scale
4.23738 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03228 .02381 scale
4.23738 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.18523 .025 m
matrix currentmatrix
.01614 .02381 scale
11.475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
11.475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.23366 .025 m
matrix currentmatrix
.03228 .02381 scale
7.23762 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03228 .02381 scale
7.23762 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.28208 .025 m
matrix currentmatrix
.01614 .02381 scale
17.4749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
17.4749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.31437 .025 m
matrix currentmatrix
.01614 .02381 scale
19.4752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
19.4752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.34665 .025 m
matrix currentmatrix
.01614 .02381 scale
21.475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
21.475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.39508 .025 m
matrix currentmatrix
.03228 .02381 scale
12.2376 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03228 .02381 scale
12.2376 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.4435 .025 m
matrix currentmatrix
.01614 .02381 scale
27.4748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
27.4748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.47579 .025 m
matrix currentmatrix
.01614 .02381 scale
29.4752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
29.4752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.50807 .025 m
matrix currentmatrix
.01614 .02381 scale
31.4749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
31.4749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.54036 .025 m
matrix currentmatrix
.01614 .02381 scale
33.4753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
33.4753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.57264 .025 m
matrix currentmatrix
.01614 .02381 scale
35.4751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
35.4751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.60492 .025 m
matrix currentmatrix
.01614 .02381 scale
37.4748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
37.4748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.65335 .025 m
matrix currentmatrix
.03228 .02381 scale
20.2375 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03228 .02381 scale
20.2375 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.70178 .025 m
matrix currentmatrix
.01614 .02381 scale
43.4753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
43.4753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.73406 .025 m
matrix currentmatrix
.01614 .02381 scale
45.475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
45.475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.76634 .025 m
matrix currentmatrix
.01614 .02381 scale
47.4748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
47.4748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.79863 .025 m
matrix currentmatrix
.01614 .02381 scale
49.4751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
49.4751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.83091 .025 m
matrix currentmatrix
.01614 .02381 scale
51.4749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
51.4749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.4 g
.001 w
.8632 .025 m
matrix currentmatrix
.01614 .02381 scale
53.4752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
53.4752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.89548 .025 m
matrix currentmatrix
.01614 .02381 scale
55.475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
55.475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.92776 .025 m
matrix currentmatrix
.01614 .02381 scale
57.4747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
57.4747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.96005 .025 m
matrix currentmatrix
.01614 .02381 scale
59.4751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
59.4751 1.05 1 0 365.73 arc
setmatrix
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{458, 32},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007:000080P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5H/1JX00=d81_l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000e5D0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0b`000?l0b`000?l0b`000?l0b`000?l0
b`0001T000A>CDi=2P0014i=CTd@0007CTe>CDi=CP0B0004CDi=CPl000M>CDi=CTe>018000A=CTe>
2`0014i=CTd:0004CTe>CA0000M>CDi=CTe>018000A=CTe>2P0014e>CDh;0004CTe>C@/000A=CTe>
2`0014i=CTd:0004CTe>CA0000M>CDi=CTe>018000A=CTe>2P0014e>CDh;0004CTe>C@/000A=CTe>
2`0014i=CTd:0004CTe>C@/000A=CTe>2`0014i=CTd;0004CDi=CQ00000F00=>1<H00dh00005009>
1<H00dh0000:00=>1h<5CPX00dh4aP03CP0000X00Th7U@E>2`02CPC600=>00001@03CPC600=>0000
1@02CPC600=>00002P03CPN31Dh:00=>1<H00dh00005009>1<H00dh00006009>1<H00dh00006009>
1<H00dh0000500=>1<H00dh00005009>1<H00dh0000:00=>1h<5CPX00dh4aP03CP0000D00Th4aP03
CP0000H00Th4aP03CP0000H00Th4aP03CP0000D00dh4aP03CP0000D00Th4P@03CP0000H00Th4aP03
CP0000H00Th4aP03CP0000D00dh4aP03CP0000d0000E0009C]K6e/KFa]I>00H000U=a]K6e/KFaTd0
2@004Te>Th>CPi>3Th>CPi>3Th>CCPP000U=a]K6e/KFaTd02@000de>C@0>U@03CTd000L000Q>e/KF
a]K6C@H000U>e/KFa]K6eTh01P002Dg6e/KFa]K6C@09000BCDjCPi>3Th>CPi>3Th>CPi=>20002Dg6
e/KFa]K6C@060009C]K6e/KFa]I>00H000Q=a]K6e/KFCPL000Q>e/KFa]K6C@H000U>e/KFa]K6eTh0
1P002Dg6e/KFa]K6C@09000BCDjCPi>3Th>CPi>3Th>CPi=>20002Dg6e/KFa]K6C@060009C]K6e/KF
a]I>00H000Q=a]K6e/KFCPL000Q>e/KFa]K6C@H000U>e/KFa]K6eTh01P000df1P@05P@03C@0000@0
00Q>e/KFa]K6C@L000Q=a]K6e/KFCPH000U=a]K6e/KFaTd03`0001@000=>a/H01lH00dh000020003
C/K600O600=>00000`03CQ:300=>000010000dk6aP07aP03CP0000@00ThCU@03CP0000@000=>a/H0
1/H00dh000020003C/K600O600=>00000P000dk6aP07aP03CP0000<00dhBP`03CP0000@000=>a/H0
1lH00dh000020003C/K600O600=>00000P000dk6aP06aP03CP0000<000=>a/H01/H00dh000020003
C/K600O600=>00000P000dk6aP07aP03CP0000<00dhBP`03CP0000@000=>a/H01lH00dh000020003
C/K600O600=>00000P000dk6aP06aP03CP0000<000=>a/H01/H00dh000020003C/K600O600=>0000
0P000dj1P@07P@03CP00008000=>a/H01/H00dh000030003C/K600K600=>00000P000dk6aP07aP03
CP0000`0000C000=C]K6e/KFa]K6e/KFCP02000=CLKFa]K6e/KFa]K6C@03000HCH>CPi>3Th>CPi>3
Th>CPi>3Th>CPi=>10003Dg6e/KFa]K6e/KFaTd010000djEU@0DU@03C@00008000a>e/KFa]K6e/KF
aTd2000=C]K6e/KFa]K6e/KFCP02000=CLKFa]K6e/KFa]K6C@03000HCH>CPi>3Th>CPi>3Th>CPi>3
Th>CPi=>10003Dg6e/KFa]K6e/KFaTd00P003DkFa]K6e/KFa]K6eTh00P0034g6e/KFa]K6e/KFCP<0
00a>e/KFa]K6e/KFaTd2000=C]K6e/KFa]K6e/KFCP02000=CLKFa]K6e/KFa]K6C@03000HCH>CPi>3
Th>CPi>3Th>CPi>3Th>CPi=>10003Dg6e/KFa]K6e/KFaTd00P003DkFa]K6e/KFa]K6eTh00P0034g6
e/KFa]K6e/KFCP<000a>e/KFa]K6e/KFaTd2000=C]K6e/KFa]K6e/KFCP020003CH6100V100m=001>
e/KFa]K6e/KFaTd00`0034g6e/KFa]K6e/KFCP8000e=a]K6e/KFa]K6e/I=00d0000C0003C/K600W6
00A>001>2lH01Dh0001>01N300E>0000CP0;aP05CP0004h05iD00dh000020003C/K600S600A>001>
2lH014h004h;aP05CP0004h05h<01Dh0001>00_600A>001>2lH014h004h:aP05CP0004h02/H014h0
04h;aP04CP00CP_600E>0000CP0GP`05CP0004h02lH014h004h;aP04CP00CP[600E>0000CP0:aP04
CP00CP_600A>001>2h4014h004h:aP05CP0004h02/H014h004h;aP03CP0000/0000B000MCLKFa]K6
e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTd00P00;DjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP1>e/KF
a]K6e/KFa]K6eTh0CP0IU@0^CP00CLKFa]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KF
a]K6C@8001]>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Tdh00P00Edg6e/KFa]K6e/KFa]I>CLKFa]K6
e/KFa]K6eTh0C]K6e/KFa]K6e/KFaTd0CLKFa]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFaTe>e/KFa]K6
e/KFa]K6C@02000KCY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>008004Y=a]K6e/KFa]K6e/KFCTg6
e/KFa]K6e/KFa]I>04kFa]K6e/KFa]K6e/I=04g6e/KFa]K6e/KFa]I>04kFa]K6e/KFa]K6e/I=CPb1
02i=04g6e/KFa]K6e/KFa]I>04kFa]K6e/KFa]K6e/I=04g6e/KFa]K6e/KFa]I>3000018000=>a/H0
2lH2CPc600A>001>6H<00dh0CP0=aP03CP1>01VE00A>001>3<H00dh0CP0<aP9>3<H014h004hIP`04
CP00CPc60Th<aP03CP1>00c600=>04h03<H00dh0CP0<aP9>3<H014h004hIP`04CP00CPc60Th<aP03
CP1>00c600=>04h03<H00dh0CP0<aP9>38400dh0CP0<aP03CP1>00c600=>04h03<H00dh0000:0000
4P00Bdg6e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/KFCTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3
Th==C]K6e/KFa]K6e/KFa]I>C@0KU@3oCDkFa]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]K6CDkFa]K6
e/KFa]K6e/KFCTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==C]K6e/KFa]K6e/KFa]I>CLKFa]K6
e/KFa]K6e/I=C]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFaTe>e/KFa]K6
e/KFa]K6eTi=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CDkFa]K6e/KFa]K6e/KFCTg6e/KFa]K6
e/KFa]K6CDkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>CLKF000=CDkFa]K6e/KFa]K6eP0=P@0]
CTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFa]I>00`0000B0003C/K600_6
0Th=aP9>6h<2CPg60ThKU@9>3LH2CPg60Th=aP9>6h<2CPg60Th=aP9>3LH00dk6aP0;aP9>3LH2CPg6
0ThKP`9>3LH2CPg60Th=aP03C/K600_60Th=aP9>3H42CPg600=>a/H02lH2CPg600=>00002P000180
04]=a]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3
TdkFa]K6e/KFa]K6e/KFCTd079D0odkFa]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CDkFa]K6e/KF
a]K6e/KFCY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CC]K6e/KFa]K6e/KFa]I>CLKFa]K6e/KF
a]K6e/I=a]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KF
a]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3TdkFa]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KF
a]K6CLKFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]K6CLKFaP0034kFa]K6e/KFa]K6ePf102i>e/KF
a]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6e/I=2`00018000=>a/H02lH2CPg6
00=>Ph<06h<00dk6aP0;aP9>79D00dk6aP0<aP03C/K600_60Th=aP03CX>301^300=>a/H02lH2CPg6
00=>a/H03<H00dk6aP0<aP03C/K600c600=>a/H02lH00dj3P`0KP`03C/K600c600=>a/H02lH00dk6
aP0<aP03C/K600c600=>a/H03<H00dj1P@0;P@03C/K600c600=>a/H03<H00dk6aP0<aP03CP0000T0
000B001;CLKFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3
Th>CPi=>e/KFa]K6e/KFa]K6eTi=01bE0?m>e/KFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTe>e/KF
a]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3TdkFa]K6e/KFa]K6e/KFCTg6e/KF
a]K6e/KFa]K6CLKFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/KFC]K6e/KF
a]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>e/KFa]K6e/KFa]K6e/I=a]K6e/KF
a]K6e/KFaTg6e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFaTg6e/H000a>e/KFa]K6e/KFa]H=P@0^
C]K6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]K6C@/0000B0003C/K600_6
0Th=aP03CX>301Z30Th=aP9>79D00dk6aP0<aP03C/K600_60Th=aP03CX>301Z30Th=aP9>3LH00dk6
aP0<aP03C/K600c600=>a/H02lH2CPg600=>Ph<06h<00dk6aP0;aP9>3LH00dk6aP0<aP03C/K600c6
00=>a/H02lH2CPf100=>a/H03<H00dk6aP0<aP03C/K600_600=>00002P00018004]=a]K6e/KFa]K6
e/KFaTe>e/KFa]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CDkFa]K6e/KFa]K6
e/KFCTd079D0odkFa]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/KFCY>3Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==C]K6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6e/I=a]K6e/KF
a]K6e/KFa]I>e/KFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6eTjCPi>3Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CPi>3TdkFa]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KF
a]K6e/KFC]K6e/KFa]K6e/KFa]K6CLKFaP0034kFa]K6e/KFa]K6ePf102e>e/KFa]K6e/KFa]K6e/I=
a]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTh03000018000=>a/H02lH2CPg60ThKP`9>3LH2CQ^E
0Th=aP9>3LH2CPg60ThKP`9>3LH2CPg60Th<aP9>3LH2CPg60Th=aP9>6h<2CPg60Th=aP9>3<H2CPg6
0Th=aP9>3H42CPc600=>04h03<H2CPg600=>00002P00018004a=a]K6e/KFa]K6e/KFaTe>e/KFa]K6
e/KFa]K6eTi=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>04kFa]K6e/KFa]K6e/KFCP1>6ID0odh0
C]K6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFa]I>CH>CPi>3Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CCP1>e/KFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDkF
a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/KFCTf3Th>CPi>3Th>CPi>3Th>C
Pi>3Th>CPi>3Tdh0C]K6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KF
a]K6e/KFa]K6eTi=aP003Th0C]K6e/KFa]K6e/KF3H40;Di=a]K6e/KFa]K6e/KFCP1>e/KFa]K6e/KF
a]K6CDkFa]K6e/KFa]K6e/KFCP0<00004`000dk6aP09aP04CP00CP_600=>00000ThGP`05CP0004h0
2lH01Dh0001>01NE00E>0000CP0;aP04CP00CP_600A>001>2lH00dh00002CQN300E>0000CP0;aP04
CP00CP_600=>04h03<H00dh0CP0<aP03CP1>00_600A>001>2lH00dh00002CQN300E>0000CP0;aP04
CP00CP_600=>04h03<H00dh0CP0<aP03CP1>00_600A>001>2h400dh0CP0<aP03CP1>00c600=>04h0
2lH00dh0000;0000500034g6e/KFa]K6e/KFCP8000e=a]K6e/KFa]K6e/I=00@001M>Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CCP05000<C]K6e/KFa]K6e/I=10000di=U@0DU@03C@00008000a>e/KFa]K6e/KF
aTd3000<CLKFa]K6e/KFa]I>0P003Dg6e/KFa]K6e/KFaTd010005djCPi>3Th>CPi>3Th>CPi>3Th>C
Pi=>00D000a>e/KFa]K6e/KFaTd3000<CLKFa]K6e/KFa]I>0P003Dg6e/KFa]K6e/KFaTd00P003DkF
a]K6e/KFa]K6eTh00P0034g6e/KFa]K6e/KFCP<000a>e/KFa]K6e/KFaTd4000GCY>3Th>CPi>3Th>C
Pi>3Th>CPi>3Tdh01@0034kFa]K6e/KFa]K6C@<000a=a]K6e/KFa]K6eTh2000=CLKFa]K6e/KFa]K6
C@02000=C]K6e/KFa]K6e/KFCP02000<CLKFa]K6e/KFa]I>0`000dj1P@08P@0@C@00C]K6e/KFa]K6
e/KFCP8000e=a]K6e/KFa]K6e/I=008000a>e/KFa]K6e/KFaTd=000050000dk6aP07aP03CP000080
00=>a/H01lH00dh000040003CX>301230Th60003C/K600O600=>00001@000djEU@0@U@9>1@000dk6
aP07aP9>0`000dk6aP07aP03CP00008000=>a/H01lH00dh000040003CX>301230Th60003C/K600O6
00=>00000P000dk6aP07aP03CP00008000=>a/H01/H2CP<000=>a/H01lH2CP<000=>a/H01lH00dh0
00020003C/K600O600=>000010000dj3P`0@P`9>1P000dk6aP07aP03CP00008000=>a/H01lH00dh0
00020003C/K600K60Th30003C/K600O60Th30003C/K600O600=>00000P000dj1P@07P@03CP000080
00=>a/H01/H2CP<000=>a/H01lH2CP<000=>a/H01lH00dh0000<00005@002DkFa]K6e/KFCP060009
CLKFa]K6e/I=00P0019>CDjCPi>3Th>CPi>3Th>CCTd90009CLKFa]K6e/I=00T000==CYD039D00di=
CP080009CLKFa]K6e/I=00H000U>e/KFa]K6eTh01P002Dg6e/KFa]K6C@08000BCTe>Th>CPi>3Th>C
Pi>3Tdi=2@002Dg6e/KFa]K6C@060009C]K6e/KFa]I>00H000Q=a]K6e/KFCPH000U=a]K6e/KFaTd0
1P002DkFa]K6e/KFCP060009CLKFa]K6e/I=00P0019>CDjCPi>3Th>CPi>3Th>CCTd90009CLKFa]K6
e/I=00H000U>e/KFa]K6eTh01P0024g6e/KFa]I>1P002Dg6e/KFa]K6C@060009C]K6e/KFa]I>00H0
00==PH401H400dd000040008C]K6e/KFaTd60009C]K6e/KFa]I>00H000U=a]K6e/KFaTd03`0001H0
0dh2aP9>2003CP;60Th<00=>1h<3CP`00dh2aP9>3003CPRE0Th<00=>0/H2CPP00dh2aP9>2003CP;6
0Th<00=>1h<3CP`00dh2aP9>2003CP;60Th8009>0/H2CPP00dh2aP9>2003CP;60Th800=>0/H2CP`0
0dh7P`=>3003CP;60Th800=>0/H2CPP00Th2aP9>2003CP;60Th800=>0/H2CPP00dh2P@9>2002CP;6
0Th800=>0/H2CPP00dh2aP9>400001T000=>C@0030000de>000@0007CTe>CDi=CP0B0003CDh00100
00Q>CDi=CTe>CA4000==CP0030000di=000<0003CDh0010000M>CDi=CTe>018000==CP0030000di=
000;0003CTd000`000==CP0030000di=000<0003CDh0010000M>CDi=CTe>018000==CP0030000di=
000;0003CTd000`000==CP0030000di=000<0003CDh000/000==CP0030000di=000<0003CDh00140
003o0</0003o0</0003o0</0003o0</00000\
\>"],
  ImageRangeCache->{{{0, 457}, {31, 0}} -> {-0.737654, -0.712262, 0.0677797, 
  0.0459524}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .05 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0302343 0.025 0.047619 [
[ 0 0 0 0 ]
[ 1 .05 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .05 L
0 .05 L
closepath
clip
newpath
p
p
.9 g
.001 w
.05404 .025 m
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.0994 .025 m
matrix currentmatrix
.03023 .02381 scale
3.28766 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
3.28766 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.14475 .025 m
matrix currentmatrix
.01512 .02381 scale
9.57521 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
9.57521 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.17498 .025 m
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.20522 .025 m
matrix currentmatrix
.01512 .02381 scale
13.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
13.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.25057 .025 m
matrix currentmatrix
.03023 .02381 scale
8.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
8.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.29592 .025 m
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.34127 .025 m
matrix currentmatrix
.03023 .02381 scale
11.2875 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
11.2875 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.38662 .025 m
matrix currentmatrix
.01512 .02381 scale
25.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
25.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.41686 .025 m
matrix currentmatrix
.01512 .02381 scale
27.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
27.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.44709 .025 m
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.47732 .025 m
matrix currentmatrix
.01512 .02381 scale
31.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
31.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.50756 .025 m
matrix currentmatrix
.01512 .02381 scale
33.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
33.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.53779 .025 m
matrix currentmatrix
.01512 .02381 scale
35.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
35.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.58314 .025 m
matrix currentmatrix
.03023 .02381 scale
19.2874 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
19.2874 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.6285 .025 m
matrix currentmatrix
.01512 .02381 scale
41.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
41.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.65873 .025 m
matrix currentmatrix
.01512 .02381 scale
43.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
43.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.68896 .025 m
matrix currentmatrix
.01512 .02381 scale
45.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
45.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.7192 .025 m
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.74943 .025 m
matrix currentmatrix
.01512 .02381 scale
49.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
49.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.79478 .025 m
matrix currentmatrix
.03023 .02381 scale
26.2873 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
26.2873 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.84014 .025 m
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.88549 .025 m
matrix currentmatrix
.03023 .02381 scale
29.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
29.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.93084 .025 m
matrix currentmatrix
.01512 .02381 scale
61.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
61.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.96107 .025 m
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{458, 32},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007:000080P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5H/1JX00=d81_l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000e5D0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0b`000?l0b`000?l0b`000?l0b`000?l0
b`0001P000==CTd03`001de>CDi=CTd0400014i=CTd:0004CTe>C@X000=>CDh03`001di=CTe>CDh0
400014e>CDh?0006CTe>CDi=4@000de>C@0;0003CDi=00X000A>CDi=2P0014i=CTd:0004CTe>C@X0
00=>CDh03`001di=CTe>CDh0400014e>CDh:0004CDi=CPX000A=CTe>2P000de>C@0;0003CDi=00l0
00I=CTe>CDhA0004CTe>C@h000M>CDi=CTe>010000A=CTe>2P0014e>CDh@00005P02CP?600=>0000
2P02CPN31Dh9009>1<H00dh00005009>1<H00dh00005009>0lH00dh0000:009>1iD5CPT00Th4aP03
CP0000T00dh6P`E>2P02CP?600=>00001@03CP?600=>00001@02CPC600=>00001@02CPC600=>0000
1@02CPC600=>00001@02CP?600=>00002P02CPN31Dh9009>1<H00dh00005009>1<H00dh00005009>
1<H00dh00005009>0lH00dh0000500=>0lH00dh0000900=>1X<5CPX00Th4aP03CP0000T00Th7U@E>
2@02CPC600=>00001@02CPC600=>00003@0001D000M>e/KFa]I>00T0019>CDjCPi>3Th>CPi>3Th>C
Pdd70008CLKFa]K6eTh60008CLKFa]K6eTh60008CLKFa]K6eTh80003CDi=00jE00=>00001@0024kF
a]K6e/I=2@004De>Th>CPi>3Th>CPi>3Th==00P000Q>e/KFa]K6C@D000Q=a]K6e/KFCPH000Q=a]K6
e/KFCPH000Q=a]K6e/KFCPH000Q=a]K6e/KFCPH000Q=a]K6e/KFCPP0019=CTf3Th>CPi>3Th>CPi>3
Tdh70008C]K6e/KFaTd60008C]K6e/KFaTd60008C]K6e/KFaTd60008C]K6e/KFaTd50008CLKFa]K6
eTh9000ACTf3Th>CPi>3Th>CPi>3Tdh0200024g6e/KFa]I>20000de>C@0>U@03CP0000D000Q>e/KF
a]K6C@H000Q>e/KFa]K6C@l0000D0003C/K600G600=>00001002CQ:300=>00000`000dk6aP06aP03
CP00008000=>a/H01/H00dh000020003C/K600K600=>00000`02CQ:E00=>00000`000dk6aP06aP03
CP0000<00dhAP`03CP0000@000=>a/H01/H01Dh0001>00S600=>00000P000dk6aP06aP03CP000080
00=>a/H01/H00dh000020003C/K600K600=>00000P000dk6aP06aP03CP0000<00ThBP`03CP0000<0
00=>a/H01/H00dh000020003C/K600K600=>00000P000dk6aP06aP03CP00008000=>a/H01/H01Dh0
001>00S600=>00001002CQ6300=>000010000dk6aP06aP03CP0000<00ThBU@03CP0000<000=>a/H0
1/H00dh000020003C/K600K600=>0000300001<000]>e/KFa]K6e/KFCP04000GCH>CPi>3Th>CPi>3
Th>CPi>3Th>CPdd00`0034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>
0`000djEU@0CU@0@CP0004kFa]K6e/KFa]K6C@<001M=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3C@04000<
C]K6e/KFa]K6e/I=0P002dkFa]K6e/KFa]I>008000a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>
0P0034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6eTh3000GCY>3Th>CPi>3Th>CPi>3Th>CPi>3Tdh0
0`0034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=0P0034kFa]K6e/KF
a]K6C@8000]>e/KFa]K6e/KFCP04000FCH>CPi>3Th>CPi>3Th>CPi>3Th>CCP@000a=a]K6e/KFa]K6
eTh30003CYFE01>E011>0000C]K6e/KFa]K6e/I=0P0034kFa]K6e/KFa]K6C@d0000C0003C/K600O6
00E>0000CP0FP`05CP0004h02/H014h004h:aP04CP00CP[600E>0000CP0EU@05CP0004h02/H01Dh0
001>01J300E>0000CP0:aP04CP00CPW600A>001>2/H014h004h:aP04CP00CP[600A>001>2/H01Dh0
001>01F300E>0000CP0:aP04CP00CP[600A>001>2/H014h004h:aP04CP00CPW600E>0000CP0FP`05
CP0004h02/H01Dh0001>01FE00E>0000CP0:aP04CP00CP[600=>00002`000180059=a]K6e/KFa]K6
e/I=04f3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>04kFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>
e/KFa]K6e/KFa]I>0P000dfEU@0EU@1nC@00C]K6e/KFa]K6e/KFCP1>Th>CPi>3Th>CPi>3Th>CPi>3
Th>CPi>3C@1=a]K6e/KFa]K6e/I=04g6e/KFa]K6e/KFaTd0CLKFa]K6e/KFa]K6CDkFa]K6e/KFa]K6
e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]I>0P006Df3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdd0
0P00L4kFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFaTd0CLKFa]K6e/KFa]K6C@1=
a]K6e/KFa]K6e/I=04f3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>04kFa]K6e/KFa]K6e/I=04dGU@0N
C@00C]K6e/KFa]K6e/KFCP1>e/KFa]K6e/KFa]I>3000018000=>a/H02LH00dh0CP0HP`03CP1>00c6
0Th<aP9>2lH014h004hGU@04CP00CP_600=>04h068<00dh0CP0;aP03CP1>00_600=>04h02lH2CPc6
0Th<aP9>2lH014h004hGP`04CP00CP_60Th<aP9>2lH00dh0CP0;aP03CP1>00_600=>04h068<00dh0
CP0<aP03CP1>01NE00A>001>2lH00dh0CP0;aP03CP0000X0000B001DCLKFa]K6e/KFa]K6eTi=Pi>3
Th>CPi>3Th>CPi>3Th>CPi>3Th>CPde>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6
e/KFaTe>6ID0odi=a]K6e/KFa]K6e/KFCTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Tdi=a]K6e/KF
a]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KF
aTe>e/KFa]K6e/KFa]K6CDjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCTg6e/KFa]K6e/KFa]I>CLKF
a]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTjCPi>3Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CPde>e/KFaP002Ti=a]K6e/KFa]HIU@0MCTg6e/KFa]K6e/KFa]K6CLKF
a]K6e/KFa]K6eTh03000018000=>a/H02/H2CQV30Th<aP9>3<H2CPc60ThIU@9>3<H2CQZ30Th<aP03
C/K600_600=>a/H02/H2CPc60Th<aP9>3<H2CQV30Th<aP9>3<H2CPc60Th<aP03C/K600_600=>Ph<0
68<2CPc60ThIU@9>3LH00dk6aP0:aP03CP0000X0000A001DC]K6e/KFa]K6e/KFa]I>Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=
6iD0odg6e/KFa]K6e/KFa]K6CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CC]K6e/KFa]K6e/KFa]I>
e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CLKFa]K6
e/KFa]K6e/I=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6
e/KFCTg6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCY>3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CPi>3CDkFa]K6eP0024g6e/KFa]K66iD07Dg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6
e/I=00/0000A0003C/K600_600=>Ph<06H<00dk6aP0;aP03C/K600[600=>a/H02lH00djEU@0IU@03
C/K600_600=>Ph<068<00dk6aP0;aP03C/K600_600=>a/H02lH00dk6aP0;aP03C/K600[600=>a/H0
2lH00dj3P`0IP`03C/K600_600=>a/H02/H2CPc600=>a/H02lH00dk6aP0;aP03CX>301R30Th<aP03
CYFE01VE00=>a/H02lH00dk6aP0;aP03CP0000T0000A001DC]K6e/KFa]K6e/KFa]I>Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=
6iD0odg6e/KFa]K6e/KFa]K6CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CC]K6e/KFa]K6e/KFa]I>
e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CLKFa]K6
e/KFa]K6e/I=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6
e/KFCTg6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCY>3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CPi>3CDkFa]K6eP0024g6e/KFa]K66iD07Dg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6
e/I=00/0000A0003C/K600_600=>Ph<068<2CPc60Th<aP03C/K600_600=>UID06ID00dk6aP0;aP03
CX>301R300=>a/H02lH00dk6aP0;aP03C/K600_600=>a/H02/H2CPc600=>a/H02lH00dj3P`0IP`03
C/K600_600=>a/H02/H2CPc600=>a/H02lH00dk6aP0;aP03CX>301R30Th<aP03CYFE01VE00=>a/H0
2lH00dk6aP0;aP03CP0000T0000A001DC]K6e/KFa]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>CPi>3Th>C
Pi>3Th==C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=6iD0odg6e/KFa]K6
e/KFa]K6CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6
eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=Pi>3
Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFCTg6e/KFa]K6
e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3
CDkFa]K6eP0024g6e/KFa]K66iD07Dg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=00/0000B0003
C/K600[60ThIP`9>3<H2CPc60Th<aP9>6ID2CPc60ThIP`03CP1>00c60Th;aP9>3<H2CPc60Th<aP9>
3<H2CQV30Th<aP9>3<H2CPc60Th<aP9>2lH00dh0CP0HP`03CP1>00c60ThIU@9>3<H2CPc600=>0000
2P00018005A=a]K6e/KFa]K6e/KFCTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>04kFa]K6e/KFa]K6
e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDhHU@3oC@1=a]K6e/KFa]K6e/KFCP1>Th>CPi>3
Th>CPi>3Th>CPi>3Th>CPi>3C@1=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6
CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDjCPi>3Th>CPi>3Th>CPi>3
Th>CPi>3Th==04g6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6e/KFa]K6
e/KFa]I>CLKFa]K6e/KFa]K6C@1=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP1>e/KF000;C@1=a]K6
e/KFa]H06ID07Di=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>00`0000B0003C/K600W600=>0000
0ThEP`05CP0004h02/H014h004h:aP03CP1>00_600=>00000ThEU@05CP0004h02/H01Dh0001>01J3
00A>001>2lH00dh0CP0;aP03CP1>00_600=>04h02/H014h004h:aP03CP1>00_600=>00000ThEP`05
CP0004h02/H014h004h:aP04CP00CP[600=>04h02lH00dh0CP0;aP03CP00009>5H<01Dh0001>00[6
00=>00000ThFU@04CP00CP_600=>04h02lH00dh0000:00004`0034kFa]K6e/KFa]K6C@@001I>Th>C
Pi>3Th>CPi>3Th>CPi>3Th==10002dkFa]K6e/KFa]I>008000a=a]K6e/KFa]K6eTh2000<CLKFa]K6
e/KFa]I>10000dfEU@0BU@03CP00008000]=a]K6e/KFa]K6C@04000FCY>3Th>CPi>3Th>CPi>3Th>C
Pi>3C@@000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=0P0034kFa]K6e/KFa]K6C@8000]>e/KF
a]K6e/KFCP02000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP@001I=Pi>3Th>CPi>3Th>CPi>3
Th>CPi=>10002dg6e/KFa]K6e/I=00<000]=a]K6e/KFa]K6C@02000<C]K6e/KFa]K6e/I=0P0034kF
a]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd4000ECY>3Th>CPi>3Th>CPi>3Th>CPi=>00@000a=a]K6
e/KFa]K6eTh40003CIFE01:E00=>00000P0034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6eTh<0000
4`000dk6aP07aP03CP0000@000=>Ph<03h<2CPD000=>a/H01/H00dh000020003C/K600K600E>0000
CP09aP03CP0000@000=>UID03iD2CPD000=>a/H01/H2CPD000=>Ph<03h<2CPD000=>a/H01lH01Dh0
001>00W600E>0000CP08aP9>0`000dk6aP06aP9>0`000dk6aP06aP05CP0004h02LH00dh000040003
CX>300n30Th50003C/K600K60Th30003C/K600K600=>00000P000dk6aP06aP05CP0004h02LH01Dh0
001>00W600=>000010000dj3P`0>P`9>1P000dk6aP06aP03CP0000@000=>UID03iD2CPD000=>a/H0
1/H2CP<000=>a/H01/H2CPd0000D0009CLKFa]K6e/I=00P0015>CH>CPi>3Th>CPi>3Tdi=CP080008
CLKFa]K6eTh60008CLKFa]K6eTh50009C]K6e/KFa]I>00P000==CYD02iD00de>C@080008C]K6e/KF
aTd8000ACTe>Th>CPi>3Th>CPi>3CDh020002Dg6e/KFa]K6C@050009CLKFa]K6e/I=00D000Q=a]K6
e/KFCPH000Q=a]K6e/KFCPH000Q=a]K6e/KFCPD000U>e/KFa]K6eTh020004De>Th>CPi>3Th>CPi>3
CDi=00P000Q>e/KFa]K6C@H000Q>e/KFa]K6C@H000Q>e/KFa]K6C@D000U=a]K6e/KFaTd01@002Dg6
e/KFa]K6C@08000@CTf3Th>CPi>3Th>CPi=>C@T000Q=a]K6e/KFCPP000==CYD039D00di=00070008
C]K6e/KFaTd60008C]K6e/KFaTd?00005@03CP;60Th;00=>1h<2CP`00Th2aP9>2002CP;60Th700=>
0/H2CP/00dh7U@9>3003CP03aTi>00`00Th7P`=>2`03CP;60Th700=>0/H2CPL00dh00lI>CP0800=>
00?6CTh02002CP;60Th700=>0/H2CP/00dh7P`9>3003CP03aTi>00P00Th2aP9>2002CP;60Th700=>
0/H2CPL00dh2aP9>2`03CPN30Th<009>0/H2CP/00dh7U@=>2`03CP03aTi>00P00dh00lI>CP0@0000
60000de>000?0007CDi=CTe>C@0@0003CTd000/000=>C@002`000di=000?0007CTe>CDi=CP0A0003
CP0000h000M=CTe>CDi=014000==CP002`000de>000;0003C@0000/000==00002P000di=000;0003
CTd000l000M>CDi=CTe>014000=>00002P000de>000;0003CDh000/000==CP002`000de>000?0007
CDi=CTe>C@0@0003CTd000l000M>CDi=CTe>014000=>00002`000dh0000@0000o`3;0000o`3;0000
o`3;0000o`3;0000\
\>"],
  ImageRangeCache->{{{0, 457}, {31, 0}} -> {-0.787665, -0.712262, 0.0723749, 
  0.0459524}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .05 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0322841 0.025 0.047619 [
[ 0 0 0 0 ]
[ 1 .05 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .05 L
0 .05 L
closepath
clip
newpath
p
p
.1 g
.001 w
.07224 .025 m
matrix currentmatrix
.03228 .02381 scale
2.23763 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03228 .02381 scale
2.23763 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.12066 .025 m
matrix currentmatrix
.01614 .02381 scale
7.47489 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
7.47489 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.15295 .025 m
matrix currentmatrix
.01614 .02381 scale
9.47525 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
9.47525 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.18523 .025 m
matrix currentmatrix
.01614 .02381 scale
11.475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
11.475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.21751 .025 m
matrix currentmatrix
.01614 .02381 scale
13.4747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
13.4747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.2498 .025 m
matrix currentmatrix
.01614 .02381 scale
15.4751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
15.4751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.4 g
.001 w
.28208 .025 m
matrix currentmatrix
.01614 .02381 scale
17.4749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
17.4749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.31437 .025 m
matrix currentmatrix
.01614 .02381 scale
19.4752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
19.4752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.34665 .025 m
matrix currentmatrix
.01614 .02381 scale
21.475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
21.475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.37893 .025 m
matrix currentmatrix
.01614 .02381 scale
23.4747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
23.4747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.41122 .025 m
matrix currentmatrix
.01614 .02381 scale
25.4751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
25.4751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.4435 .025 m
matrix currentmatrix
.01614 .02381 scale
27.4748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
27.4748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.47579 .025 m
matrix currentmatrix
.01614 .02381 scale
29.4752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
29.4752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.52421 .025 m
matrix currentmatrix
.03228 .02381 scale
16.2374 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03228 .02381 scale
16.2374 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.57264 .025 m
matrix currentmatrix
.01614 .02381 scale
35.4751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
35.4751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.60492 .025 m
matrix currentmatrix
.01614 .02381 scale
37.4748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
37.4748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.63721 .025 m
matrix currentmatrix
.01614 .02381 scale
39.4752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
39.4752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.66949 .025 m
matrix currentmatrix
.01614 .02381 scale
41.4749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
41.4749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.70178 .025 m
matrix currentmatrix
.01614 .02381 scale
43.4753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
43.4753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.7502 .025 m
matrix currentmatrix
.03228 .02381 scale
23.2374 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03228 .02381 scale
23.2374 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.79863 .025 m
matrix currentmatrix
.01614 .02381 scale
49.4751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
49.4751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.83091 .025 m
matrix currentmatrix
.01614 .02381 scale
51.4749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
51.4749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.8632 .025 m
matrix currentmatrix
.01614 .02381 scale
53.4752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
53.4752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.91162 .025 m
matrix currentmatrix
.03228 .02381 scale
28.2374 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03228 .02381 scale
28.2374 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.96005 .025 m
matrix currentmatrix
.01614 .02381 scale
59.4751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01614 .02381 scale
59.4751 1.05 1 0 365.73 arc
setmatrix
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{458, 32},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007:000080P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5H/1JX00=d81_l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000e5D0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0b`000?l0b`000?l0b`000?l0b`000?l0
b`0001h000M=CTe>CDi=014000A=CTe>2`0014i=CTd;0004CDi=CPX000A=CTe>2`0014i=CTd;0004
CDi=CP/000A>CDi=2P0014i=CTd;0004CDi=CP/000A>CDi=2`0014e>CDh:0004CDi=CQ0000M=CTe>
CDi=018000A>CDi=2P0014i=CTd;0004CDi=CP/000A>CDi=2`0014e>CDh?0007CTe>CDi=CP0B0004
CDi=CP/000A>CDi=2P0014i=CTd@0007CTe>CDi=CP0B0004CDi=CQ00000K00=>1h<5CPX00Th4aP03
CP0000H00Th4aP03CP0000D00dh4aP03CP0000D00Th4aP03CP0000H00Th4aP03CP0000H00Th4P@03
CP0000D00dh4aP03CP0000D00Th4aP03CP0000H00Th4aP03CP0000H00Th4aP03CP0000D00dh4aP03
CP0000D00Th4aP03CP0000X00dh7P`E>2P03CPC600=>00001@02CPC600=>00001P02CPC600=>0000
1P02CPC600=>00001@03CPC600=>00002P02CPN31Dh;009>1<H00dh0000500=>1<H00dh00005009>
1<H00dh0000:00=>1iD5CPX00dh4aP03CP0000d0000H000CCDi=Pi>3Th>CPi>3Th>CPi>3C@080008
C]K6e/KFaTd70008CLKFa]K6eTh60009CLKFa]K6e/I=00H000U>e/KFa]K6eTh01P0024g6e/KFa]I>
1`000dj1P@04P@03C@0000@000U>e/KFa]K6eTh01P002Dg6e/KFa]K6C@060008C]K6e/KFaTd70008
CLKFa]K6eTh60009CLKFa]K6e/I=00H000U>e/KFa]K6eTh02@004Ti=Pi>3Th>CPi>3Th>CPi>3C@P0
00U>e/KFa]K6eTh01P002Dg6e/KFa]K6C@060008C]K6e/KFaTd70008CLKFa]K6eTh60009CLKFa]K6
e/I=00T001==CTf3Th>CPi>3Th>CPi>3Tdi=00P000Q>e/KFa]K6C@H000U>e/KFa]K6eTh01P002Dg6
e/KFa]K6C@090003CDjE00jE00=>00001P002Dg6e/KFa]K6C@0?00005P02CQ>300=>000010000dk6
aP06aP03CP0000<000=>a/H01/H00dh000020003C/K600O600=>00000P000dk6aP07aP03CP000080
00=>a/H01/H00dh000030003CX6100J100=>00000P000dk6aP07aP03CP00008000=>a/H01lH00dh0
00020003C/K600K600=>00000`000dk6aP06aP03CP00008000=>a/H01lH00dh000020003C/K600O6
00=>00000`03CQ:300=>000010000dk6aP07aP03CP00008000=>a/H01lH00dh000020003C/K600K6
00=>00000`000dk6aP06aP03CP00008000=>a/H01lH00dh00004009>4h<00dh000040003C/K600K6
00=>00000P000dk6aP07aP03CP00008000=>a/H01lH00dh0000300=>4YD00dh000040003C/K600O6
00=>0000300001D001Q>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdd4000<C]K6e/KFa]K6e/I=0`0034g6
e/KFa]K6e/KFCP8000e=a]K6e/KFa]K6e/I=008000e>e/KFa]K6e/KFa]I>008000a=a]K6e/KFa]K6
eTh30003CX6100R1011=001>e/KFa]K6e/KFa]I>0P003Dg6e/KFa]K6e/KFaTd00P0034kFa]K6e/KF
a]K6C@<000a=a]K6e/KFa]K6eTh2000=CLKFa]K6e/KFa]K6C@02000=C]K6e/KFa]K6e/KFCP03000H
CY>3Th>CPi>3Th>CPi>3Th>CPi>3Th==10003DkFa]K6e/KFa]K6eTh00P003Dg6e/KFa]K6e/KFaTd0
0P0034kFa]K6e/KFa]K6C@<000a=a]K6e/KFa]K6eTh2000=CLKFa]K6e/KFa]K6C@04000HCY>3Th>C
Pi>3Th>CPi>3Th>CPi>3Th==100034kFa]K6e/KFa]K6C@8000e>e/KFa]K6e/KFa]I>008000e=a]K6
e/KFa]K6e/I=00<000==UID059D00dh00002000=CLKFa]K6e/KFa]K6C@0=000050000dj3P`0EP`03
CP00008000=>a/H02<H01Dh0001>00[600A>001>2lH014h004h;aP04CP00CP[600E>0000CP0:P@04
CP00CP_600A>001>2lH014h004h:aP05CP0004h02/H014h004h;aP04CP00CP_600E>0000CP0GP`05
CP0004h02lH014h004h;aP04CP00CP[600E>0000CP0:aP04CP00CP_600E>0000CP0GP`03CP000080
00=>a/H02<H014h004h;aP04CP00CP_600E>0000CP0GU@05CP0004h02lH00dh0000;00004`006djC
Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP02001;CLKFa]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFaTe>
e/KFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCP1>e/KFa]K6e/KFa]K6C@1=00b105U>04kFa]K6e/KF
a]K6e/I=C]K6e/KFa]K6e/KFaTd0CLKFa]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFaTd0CLKFa]K6e/KF
a]K6eTi=a]K6e/KFa]K6e/KFCP02000KCH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==008006E>e/KF
a]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=04g6e/KFa]K6e/KFa]I>04kFa]K6e/KFa]K6e/I=04g6e/KF
a]K6e/KFa]I>04jCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP02000[CLKFa]K6e/KFa]K6eTh0C]K6
e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6C@020003CYFE01NE015>001=a]K6e/KFa]K6e/KFCP0<0000
4`000dj3P`0HP`03CP1>00c600=>04h03<H2CPg60Th<aP03CP1>00c600=>04h038400dh0CP0<aP9>
3<H00dh0CP0<aP03CP1>00c600=>04h03<H2CPc600A>001>6H<014h004h<aP9>3<H00dh0CP0<aP03
CP1>00c600=>04h03<H00dh0CP0IP`04CP00CPc600=>04h03<H2CPc600A>001>6ID014h004h<aP03
CP0000X0000B001XCH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>e/KFa]K6e/KFa]K6e/I=a]K6
e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6eTh=P@3o
CTg6e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=
C]K6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6e/I=CY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Tdi=
a]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CDkF
a]K6e/KFa]K6e/KFCTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==C]K6e/KFa]K6e/KFa]I>CLKF
a]K6e/KFa]K6e/I=C]K6000=CTg6e/KFa]K6e/KFaP0KU@0@CDkFa]K6e/KFa]K6e/KFCP`0000B0003
CX>301Z300=>a/H03<H00dk6aP0;aP9>3LH2CPg600=>a/H03<H00dj1P@0;P@9>3LH2CPg60Th=aP03
C/K600_60Th=aP9>3LH2CQ^30Th=aP9>3LH2CPg600=>a/H02lH2CPg60ThKP`9>3LH2CPg60Th=aP9>
6iD2CPg600=>00002P00018006Q=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3TdkFa]K6e/KFa]K6
e/KFaTg6e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6
e/KFCPj10?m=a]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFaTg6e/KFa]K6
e/KFa]K6eTkFa]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]K6CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3
Th>CPi>3CLKFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6e/I=a]K6e/KFa]K6
e/KFa]I>e/KFa]K6e/KFa]K6e/I=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3TdkFa]K6e/KFa]K6
e/KFaTg6e/KFa]K6e/KFa]K6eTkFa]H000]=a]K6e/KFa]K6eP0MU@0@C]K6e/KFa]K6e/KFa]K6C@/0
000B0003CX>301Z300=>a/H03<H00dk6aP0<aP03C/K600_60Th=aP03C/K600c600=>PH4038400dk6
aP0;aP9>3LH00dk6aP0<aP03C/K600c600=>a/H02lH2CPg600=>Ph<06h<00dk6aP0<aP03C/K600_6
00=>a/H03<H00dk6aP0<aP03C/K600c600=>Ph<06X<00dk6aP0<aP03C/K600c600=>a/H02lH00djE
U@0KU@03C/K600c600=>00002@00018006Q=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3TdkFa]K6
e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]K6CLKFa]K6
e/KFa]K6e/KFCPj10?m=a]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFaTg6
e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]K6CH>CPi>3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6e/I=a]K6
e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6e/I=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3TdkFa]K6
e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6eTkFa]H000]=a]K6e/KFa]K6eP0MU@0@C]K6e/KFa]K6e/KF
a]K6C@/0000B0003CX>301Z300=>a/H03<H00dk6aP0<aP03C/K600_60Th=aP03C/K600c600=>PH40
38400dk6aP0;aP9>3LH00dk6aP0<aP03C/K600c600=>a/H02lH2CPg600=>Ph<06X<2CPg60Th=aP03
C/K600c600=>a/H03<H00dk6aP0;aP9>78<00dk6aP0<aP03C/K600_60Th=aP03CYFE01^E00=>a/H0
2lH00dh0000:00004P00J4f3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CC]K6e/KFa]K6e/KFa]K6
CLKFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFa]I>
3X40odg6e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6
e/KFC]K6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6e/I=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3
Tdi=a]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6
eTkFa]K6e/KFa]K6e/KFCTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CC]K6e/KFa]K6e/KFa]K6
CLKFa]K6e/KFa]K6e/I=C]K6eP002dg6e/KFa]K6e/KF01fE00m>e/KFa]K6e/KFa]K6eTh0300001<0
00=>Ph<068<00dh0CP0<aP9>3LH2CPg60Th=aP9>3<H2CPf10Th=aP9>3LH2CPc60Th=aP9>3LH2CPg6
0ThKP`9>3LH2CPg60Th<aP9>3LH2CPg60ThKP`9>3LH2CPg60Th=aP9>6iD2CPg600=>00002P0001<0
06M>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==04g6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6e/I=
C]K6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>00f10?m>CLKFa]K6e/KF
a]K6e/I=C]K6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KF
a]K6eTi=a]K6e/KFa]K6e/KFaTe>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==04g6e/KFa]K6e/KF
a]K6CDkFa]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KF
a]I>04jCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP1>e/KFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KF
aTe>e/H000e>CLKFa]K6e/KFa]K601ZE015>04kFa]K6e/KFa]K6e/KFCP0<00005002CQN300A>001>
3<H00dh0CP0;aP04CP00CP_600A>001>2lH00dh0CP0<aP03CP1>00^100A>001>2lH014h004h;aP03
CP1>00c600=>04h03<H00dh0CP0;aP04CP00CP_600=>00000ThGP`05CP0004h02lH014h004h;aP03
CP1>00c600=>04h03<H00dh0CP0;aP05CP0004h05h<01Dh0001>00c600=>04h02lH014h004h;aP03
CP00009>5iD01Dh0001>00_600=>00002`0001H001M=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3C@04000=
C]K6e/KFa]K6e/KFCP02000<CLKFa]K6e/KFa]I>0`0034kFa]K6e/KFa]K6C@8000e>e/KFa]K6e/KF
a]I>008000e=a]K6e/KFa]K6e/I=008000=>PH40284044d0001=a]K6e/KFa]K6eTh2000=CLKFa]K6
e/KFa]K6C@02000=C]K6e/KFa]K6e/KFCP02000=CLKFa]K6e/KFa]K6C@02000<C]K6e/KFa]K6e/I=
0`0034g6e/KFa]K6e/KFCP@001M=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3C@05000<CLKFa]K6e/KFa]I>
0`0034kFa]K6e/KFa]K6C@8000e>e/KFa]K6e/KFa]I>008000e=a]K6e/KFa]K6e/I=008000a>e/KF
a]K6e/KFaTd4000HCTf3Th>CPi>3Th>CPi>3Th>CPi>3Th==10003DkFa]K6e/KFa]K6eTh00P0034g6
e/KFa]K6e/KFCP<000a>e/KFa]K6e/KFaTd40003CYFE01>E00=>00000`0034kFa]K6e/KFa]K6C@d0
000G0003CX>301230Th60003C/K600K60Th30003C/K600O60Th30003C/K600O600=>00000P000dk6
aP07aP03CP00008000=>a/H01/H2CP<000=>PH401h42CP<000=>a/H01lH00dh000020003C/K600O6
00=>00000P000dk6aP06aP9>0`000dk6aP07aP9>0`000dk6aP07aP03CP00008000=>a/H01lH00dh0
00040003CX>301230Th60003C/K600O600=>00000P000dk6aP07aP03CP00008000=>a/H01/H2CP<0
00=>a/H01lH2CP<000=>a/H01lH00dh000050003CX>301230Th50003C/K600O60Th30003C/K600O6
00=>00000P000dk6aP07aP03CP0000@000=>UID049D2CPH000=>a/H01lH00dh0000<000060004Te>
Th>CPi>3Th>CPi>3Th==CPT000Q>e/KFa]K6C@H000U>e/KFa]K6eTh01P002Dg6e/KFa]K6C@060009
C]K6e/KFa]I>00H000Q=a]K6e/KFCPH000==PH401H400dd000040009C]K6e/KFa]I>00H000U=a]K6
e/KFaTd01P0024kFa]K6e/I=1P002DkFa]K6e/KFCP060009CLKFa]K6e/I=00H000U>e/KFa]K6eTh0
20004Te>CH>CPi>3Th>CPi>3Th==CPT000U>e/KFa]K6eTh01P002Dg6e/KFa]K6C@060008C]K6e/KF
aTd60009C]K6e/KFa]I>00H000U=a]K6e/KFaTd02@004Te>Th>CPi>3Th>CPi>3Tdi=CPP000U=a]K6
e/KFaTd01P002DkFa]K6e/KFCP060009CLKFa]K6e/I=00P000=>CDh03ID00di=00080009CLKFa]K6
e/I=00l0000J00=>28<3CP`00Th2aP9>2003CP;60Th800=>0/H2CPP00dh2aP9>2002CP;60Th800=>
0X42CPP00dh2aP9>2003CP;60Th8009>0/H2CPP00dh2aP9>2003CP;60Th800=>0/H2CP`00dh7P`=>
3003CP;60Th800=>0/H2CPP00Th2aP9>2003CP;60Th800=>0/H2CP`00dh8P`9>3003CP;60Th800=>
0/H2CPP00dh2aP9>3003CPNE0dh<00=>0/H2CQ00000M0008CTe>CDi=CTdA0003CDh000`000=>C@00
30000de>000<0003CTd000/000=>C@0030000de>000<0003CTd000`000==CP002`000de>000<0003
CTd000`000==CP0030000di=000@0007CDi=CTe>C@0B0003CTd000`000==CP002`000de>000<0003
CTd000`000==CP00400024i=CTe>CDi=4@000de>000<0003CTd000`000==CP0040001di=CTe>CDh0
4P000de>000A0000o`3;0000o`3;0000o`3;0000o`3;0000\
\>"],
  ImageRangeCache->{{{0, 457}, {31, 0}} -> {-0.737654, -0.712262, 0.0677797, 
  0.0459524}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .05 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0302343 0.025 0.047619 [
[ 0 0 0 0 ]
[ 1 .05 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .05 L
0 .05 L
closepath
clip
newpath
p
p
.6 g
.001 w
.06916 .025 m
matrix currentmatrix
.03023 .02381 scale
2.28747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
2.28747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.11451 .025 m
matrix currentmatrix
.01512 .02381 scale
7.57484 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
7.57484 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.14475 .025 m
matrix currentmatrix
.01512 .02381 scale
9.57521 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
9.57521 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.17498 .025 m
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.20522 .025 m
matrix currentmatrix
.01512 .02381 scale
13.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
13.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.25057 .025 m
matrix currentmatrix
.03023 .02381 scale
8.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
8.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.29592 .025 m
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.34127 .025 m
matrix currentmatrix
.03023 .02381 scale
11.2875 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
11.2875 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.38662 .025 m
matrix currentmatrix
.01512 .02381 scale
25.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
25.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.41686 .025 m
matrix currentmatrix
.01512 .02381 scale
27.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
27.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.44709 .025 m
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.47732 .025 m
matrix currentmatrix
.01512 .02381 scale
31.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
31.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.52268 .025 m
matrix currentmatrix
.03023 .02381 scale
17.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
17.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.56803 .025 m
matrix currentmatrix
.01512 .02381 scale
37.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
37.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.59826 .025 m
matrix currentmatrix
.01512 .02381 scale
39.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
39.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.6285 .025 m
matrix currentmatrix
.01512 .02381 scale
41.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
41.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.65873 .025 m
matrix currentmatrix
.01512 .02381 scale
43.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
43.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.68896 .025 m
matrix currentmatrix
.01512 .02381 scale
45.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
45.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.73432 .025 m
matrix currentmatrix
.03023 .02381 scale
24.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
24.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.77967 .025 m
matrix currentmatrix
.01512 .02381 scale
51.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
51.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.8099 .025 m
matrix currentmatrix
.01512 .02381 scale
53.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
53.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.84014 .025 m
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.87037 .025 m
matrix currentmatrix
.01512 .02381 scale
57.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
57.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.9006 .025 m
matrix currentmatrix
.01512 .02381 scale
59.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
59.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.94596 .025 m
matrix currentmatrix
.03023 .02381 scale
31.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
31.2876 1.05 1 0 365.73 arc
setmatrix
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{458, 32},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007:000080P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5H/1JX00=d81_l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000e5D0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0b`000?l0b`000?l0b`000?l0b`000?l0
b`0001`000M=CTe>CDi=010000A>CDi=2P0014i=CTd:0004CTe>C@X000=>CDh03`001di=CTe>CDh0
400014e>CDh?0006CTe>CDi=4@000de>C@0;0003CDi=00X000A>CDi=2P0014i=CTd?0006CDi=CTe>
4@000di=CP0:0004CDi=CPX000A=CTe>2P0014e>CDh:0004CDi=CPh000M=CTe>CDi=010000A>CDi=
2P0014i=CTd:0004CTe>C@X000=>CDh02`000di=CP0?0006CTe>CDi=5`0001X00Th7U@E>2@02CPC6
00=>00001@02CPC600=>00001@02CPC600=>00001@02CP?600=>00002P02CPN31Dh9009>1<H00dh0
000900=>1YD5CPX00Th3aP03CP0000D00dh3aP03CP0000D00Th4aP03CP0000D00Th4aP03CP0000T0
0dh6P`E>2P02CP?600=>00001@02CPC600=>00001@02CPC600=>00001@02CPC600=>00001@02CPC6
00=>00002@02CPN31Dh9009>1<H00dh00005009>1<H00dh00005009>1<H00dh00005009>0lH00dh0
0006009>0lH00dh0000900=>1YD5CQ80000G0003CTe>00jE00==00001@0024g6e/KFa]I>1P0024g6
e/KFa]I>1P0024g6e/KFa]I>1P0024g6e/KFa]I>20004Te>CH>CPi>3Th>CPi>3Th>CCPL000Q>e/KF
a]K6C@T000==CYD03ID00dd000060008C]K6e/KFaTd50008CLKFa]K6eTh60008CLKFa]K6eTh60008
CLKFa]K6eTh8000BCDi=Pi>3Th>CPi>3Th>CPi=>20001dg6e/KFaTd01P0024kFa]K6e/I=1P0024kF
a]K6e/I=1P0024kFa]K6e/I=1P0024kFa]K6e/I=20004Ti=CY>3Th>CPi>3Th>CPi>3C@L000Q=a]K6
e/KFCPH000Q=a]K6e/KFCPH000Q=a]K6e/KFCPH000Q=a]K6e/KFCPH000M=a]K6e/I=00T000==CYD0
3ID00dd0000?00005@02CQ:E00=>00000`000dk6aP06aP03CP00008000=>a/H01/H00dh000020003
C/K600K600=>00000P000dk6aP06aP03CP0000<00ThBP`03CP0000<000=>a/H01/H00dh0000300=>
4ID00dh000040003C/K600K600E>0000CP08aP03CP00008000=>a/H01/H00dh000020003C/K600K6
00=>00000`02CQ:300=>000010000dk6aP05aP03CP00008000=>a/H01/H00dh000020003C/K600K6
00=>00000P000dk6aP06aP03CP00008000=>a/H01/H00dh00003009>4X<00dh000030003C/K600K6
00=>00000P000dk6aP06aP03CP00008000=>a/H01/H00dh000020003C/K600K600=>00000P000dk6
aP05aP03CP0000@00ThAU@03CP0000h0000D0003CIFE01>E011=0000CLKFa]K6e/KFa]I>0P0034g6
e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>0`005djCPi>3Th>CPi>3Th>C
Pi>3Th>CPi=>00<000a>e/KFa]K6e/KFaTd30003CIFE01>E00==00000P0034kFa]K6e/KFa]K6C@80
00]>e/KFa]K6e/KFCP02000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP<001M>Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CCP04000;CLKFa]K6e/KFaTd00P0034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KF
aTd2000<C]K6e/KFa]K6e/I=0P0034kFa]K6e/KFa]K6C@<001M=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3
C@03000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6eTh2000<CLKFa]K6
e/KFa]I>0P002dg6e/KFa]K6e/I=00@000=>UID04YD00dd0000=000050000djEU@0CU@05CP0004h0
2/H014h004h:aP04CP00CP[600A>001>2/H01Dh0001>01F300E>0000CP0:aP05CP0004h05YD01Dh0
001>00[600A>001>2LH014h004h:aP04CP00CP[600E>0000CP0EP`03CP00008000=>a/H01lH014h0
04h:aP04CP00CP[600A>001>2/H014h004h:aP05CP0004h05H<01Dh0001>00[600A>001>2/H014h0
04h:aP04CP00CP[600A>001>2LH01Dh0001>01JE00=>0000300001<000=>UID05ID0>Dh004g6e/KF
a]K6e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFCP02000ICH>CPi>3
Th>CPi>3Th>CPi>3Th>CPi>3C@02000?C]K6e/KFa]K6e/KFCP1>01RE05==04g6e/KFa]K6e/KFaTd0
CLKFa]K6e/KFa]K6C@1=a]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTd0CH>CPi>3Th>CPi>3Th>CPi>3
Th>CPi>3C@020014C]K6e/KFa]K6e/KFCP1>e/KFa]K6e/KFa]I>04kFa]K6e/KFa]K6eTi=a]K6e/KF
a]K6e/KFCTg6e/KFa]K6e/KFaTd2000ICY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP020016CLKFa]K6
e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]I>04kFa]K6e/KFa]K6
eTh0CQRE00==00002`0001<000=>UID05ID014h004h;aP9>3<H2CPc60Th;aP04CP00CQN300A>001>
2lH00dh0CP0HU@03CP1>00_600=>04h02lH00dh0CP0;aP9>3<H00dh0CP0HP`03CP1>00_600=>04h0
2lH00dh0CP0;aP9>3<H2CP_600A>001>5h<014h004h;aP9>3<H2CPc60Th;aP03CP1>00_600=>04h0
69D00dh0000;00004P000dfEU@0GU@1SCDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6
e/KFa]K6CDkFa]K6e/KFa]K6e/I=CY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>CLKFa]K6e/KFa]K6
eTi=01ZE0?Y>CLKFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KF
a]K6CDjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=
a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=Pi>3Th>CPi>3Th>CPi>3Th>C
Pi>3Th>CPde>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KF
a]K6CLKFa]K6e/KFa]K6e/I=6YD00dh0000:00004P000djEU@0GU@9>3<H2CPc60Th<aP9>3<H2CQV3
0Th<aP9>6YD2CPc600=>a/H02lH00dk6aP0:aP9>3<H2CQZ300=>a/H02lH00dk6aP0;aP03C/K600[6
0Th<aP9>3<H2CQV30Th<aP9>3<H2CPc60Th<aP03C/K600_600=>UID069D00dh0000:00004@000djE
U@0IU@1RC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KF
aTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==a]K6e/KFa]K6e/KFaTdJU@3jC]K6e/KFa]K6e/KF
a]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>C
Pi>3Th>CPi>3Th==a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KF
a]K6e/KFCTg6e/KFa]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CC]K6e/KFa]K6e/KF
a]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CAZE
00=>00002P00014000=>UID06ID00dk6aP0;aP03C/K600_600=>a/H02/H00dk6aP0;aP03CX>301V3
00=>a/H02lH00djEU@0HU@03C/K600_600=>a/H02lH00dk6aP0;aP03C/K600_600=>Ph<068<00dk6
aP0;aP03C/K600_600=>a/H02lH00dk6aP0:aP9>3<H00dj3P`0IP`03C/K600_600=>a/H02lH00dk6
aP0:aP03C/K600_600=>a/H02lH00djEU@0HU@9>2`00014000=>UID06ID0HTkFa]K6e/KFa]K6e/KF
C]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=Pi>3Th>CPi>3Th>CPi>3Th>C
Pi>3Th>CPi>3CLKFa]K6e/KFa]K6e/I=6YD0nTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KF
a]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CLKFa]K6e/KF
a]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KF
CY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3TdkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KF
a]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTdJU@03CTd000X0000A0003CYFE01VE
00=>a/H02lH00dk6aP0:aP9>3<H00dk6aP0;aP03CX>301V300=>a/H02lH00djEU@0HU@03C/K600_6
00=>a/H02lH00dk6aP0;aP03C/K600[60ThJP`03C/K600_600=>a/H02lH00dk6aP0;aP03C/K600[6
0Th<aP03CX>301V300=>a/H02lH00dk6aP0:aP9>3<H2CPc600=>a/H02lH00djEU@0HU@03CP0000X0
000A0003CYFE01VE069>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTg6e/KF
a]K6e/KFa]K6CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdg6e/KFa]K6e/KFa]K6CAZE0?Y>e/KF
a]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CDjCPi>3Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CPdg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KF
aTg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>e/KF
a]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CLKFa]K6e/KF
a]K6e/I=6YD00dh0000:00004P000djEU@0GU@9>3<H2CPc60Th<aP9>3<H2CQV30Th<aP9>6ID00dh0
CP0<aP9>2lH2CPc60Th<aP9>6H<00dh0CP0<aP03C/K600[60Th<aP9>3<H2CPc60ThIP`9>3<H2CPc6
0Th<aP9>3<H2CPc60ThHU@03CP0000/0000B0003CIFE01NE06A=C]K6e/KFa]K6e/KFaTe>e/KFa]K6
e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3
C@1=a]K6e/KFa]K6e/KFCP1>69D0o4d0CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/I=C]K6e/KFa]K6
e/KFaTe>e/KFa]K6e/KFa]K6C@1=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP1>e/KFa]K6e/KFa]K6
CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=Pi>3
Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP1>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6
e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=CQRE00==00002`0001<00ThFU@04CP00CP_6
00=>04h02/H014h004h:aP03CP1>00_600=>00000ThEP`05CP0004h02/H01Dh0001>01JE00A>001>
2lH00dh0CP0;aP03CP1>00_600=>04h02/H01Dh0001>01J300A>001>2lH00dh0CP0;aP03CP1>00[6
00A>001>2/H014h004h:aP03CP00009>5H<01Dh0001>00_600=>04h02/H014h004h:aP03CP1>00_6
00=>04h02lH00dh00002CQFE00=>0000300001D000=>UID04YD00dd00002000<C]K6e/KFa]K6e/I=
0P002dkFa]K6e/KFa]I>008000a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>10005Tf3Th>CPi>3
Th>CPi>3Th>CPi>3Tdh4000;CLKFa]K6e/KFaTd010000djEU@0BU@03C@00008000a>e/KFa]K6e/KF
aTd2000<C]K6e/KFa]K6e/I=0P0034kFa]K6e/KFa]K6C@8000]>e/KFa]K6e/KFCP04000FCH>CPi>3
Th>CPi>3Th>CPi>3Th>CCP@000a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>0P002dg6e/KFa]K6
e/I=00<000]=a]K6e/KFa]K6C@02000<C]K6e/KFa]K6e/I=10005TjCPi>3Th>CPi>3Th>CPi>3Th>C
Pdd4000<C]K6e/KFa]K6e/I=0P002dkFa]K6e/KFa]I>008000a=a]K6e/KFa]K6eTh2000<CLKFa]K6
e/KFa]I>0P0034g6e/KFa]K6e/KFCP@000==UID04ID00dd0000=00005P000djEU@0?U@9>1@000dk6
aP06aP9>0`000dk6aP06aP03CP00008000=>a/H01/H01Dh0001>00W600=>000010000dj3P`0?P`9>
1@000dk6aP06aP9>1@000djEU@0?U@9>1@000dk6aP07aP05CP0004h02LH01Dh0001>00S60Th30003
C/K600K60Th50003CX>300n30Th50003C/K600O600E>0000CP08aP9>0`000dk6aP06aP9>0`000dk6
aP06aP03CP00008000=>a/H01/H00dh000040003CX>300n30Th50003C/K600K60Th30003C/K600K6
0Th30003C/K600K600E>0000CP09aP05CP0004h02LH00dh000040003CYFE00jE0Th@00005`000di=
U@0<U@03CDh000L000Q=a]K6e/KFCPH000Q=a]K6e/KFCPH000Q=a]K6e/KFCPD000U>e/KFa]K6eTh0
20004De>Th>CPi>3Th>CPi>3CDi=00P000Q>e/KFa]K6C@P000=>CDh039D00de>00070009CLKFa]K6
e/I=00D000U=a]K6e/KFaTd01@0024g6e/KFa]I>1P0024g6e/KFa]I>20004De>CH>CPi>3Th>CPi>3
Tdi=00P000U>e/KFa]K6eTh01@0024kFa]K6e/I=1P0024kFa]K6e/I=1P0024kFa]K6e/I=1P0024kF
a]K6e/I=20004Di=Pi>3Th>CPi>3Th>CPde>00P000Q=a]K6e/KFCPH000Q=a]K6e/KFCPH000Q=a]K6
e/KFCPD000U>e/KFa]K6eTh01@002DkFa]K6e/KFCP080003CDjE00^E00==CP004@0001T00dh7U@=>
2`03CP03aTi>00P00Th2aP9>2002CP;60Th700=>0/H2CP/00dh7P`9>3003CP03aTi>00`00Th7U@=>
2`03CP;60Th700=>0/H2CPL00dh00lI>CP0800=>00?6CTh03002CPN30dh;00=>0/H2CPL00dh00lI>
CP0800=>00?6CTh02002CP;60Th8009>0/H2CP/00dh7P`=>2`03CP03aTi>00P00dh00lI>CP08009>
0/H2CPL00dh2aP9>1`03CP;60Th;00=>1iD2CQ@0000L0007CDi=CTe>C@0A0003C@0000X000=>C@00
2`000di=000;0003CTd000l000M>CDi=CTe>014000=>00003P001de>CDi=CTd04@000de>000;0003
CDh000/000==00002`000dd0000>0007CTe>CDi=CP0A0003CTd000/000=>00002`000dh0000:0003
CDh000/000==CP003`001de>CDi=CTd04@000dd0000;0003C@0000X000=>C@002`000di=000;0003
CTd000l000M>CDi=CTe>01H0003o0</0003o0</0003o0</0003o0</00000\
\>"],
  ImageRangeCache->{{{0, 457}, {31, 0}} -> {-0.787665, -0.712262, 0.0723749, 
  0.0459524}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .05 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0302343 0.025 0.047619 [
[ 0 0 0 0 ]
[ 1 .05 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .05 L
0 .05 L
closepath
clip
newpath
p
p
.9 g
.001 w
.05404 .025 m
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.0994 .025 m
matrix currentmatrix
.03023 .02381 scale
3.28766 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
3.28766 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.14475 .025 m
matrix currentmatrix
.01512 .02381 scale
9.57521 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
9.57521 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.17498 .025 m
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.22033 .025 m
matrix currentmatrix
.03023 .02381 scale
7.28741 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
7.28741 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.26568 .025 m
matrix currentmatrix
.01512 .02381 scale
17.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
17.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.29592 .025 m
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.32615 .025 m
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.3715 .025 m
matrix currentmatrix
.03023 .02381 scale
12.2874 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
12.2874 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.41686 .025 m
matrix currentmatrix
.01512 .02381 scale
27.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
27.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.44709 .025 m
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.49244 .025 m
matrix currentmatrix
.03023 .02381 scale
16.2875 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
16.2875 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.53779 .025 m
matrix currentmatrix
.01512 .02381 scale
35.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
35.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.56803 .025 m
matrix currentmatrix
.01512 .02381 scale
37.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
37.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.59826 .025 m
matrix currentmatrix
.01512 .02381 scale
39.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
39.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.6285 .025 m
matrix currentmatrix
.01512 .02381 scale
41.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
41.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.65873 .025 m
matrix currentmatrix
.01512 .02381 scale
43.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
43.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.70408 .025 m
matrix currentmatrix
.03023 .02381 scale
23.2875 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
23.2875 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.74943 .025 m
matrix currentmatrix
.01512 .02381 scale
49.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
49.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.77967 .025 m
matrix currentmatrix
.01512 .02381 scale
51.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
51.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.8099 .025 m
matrix currentmatrix
.01512 .02381 scale
53.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
53.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.84014 .025 m
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.87037 .025 m
matrix currentmatrix
.01512 .02381 scale
57.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
57.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.9006 .025 m
matrix currentmatrix
.01512 .02381 scale
59.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
59.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.94596 .025 m
matrix currentmatrix
.03023 .02381 scale
31.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
31.2876 1.05 1 0 365.73 arc
setmatrix
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{458, 32},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007:000080P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5H/1JX00=d81_l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000e5D0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0b`000?l0b`000?l0b`000?l0b`000?l0
b`0001P000==CTd03`001de>CDi=CTd0400014i=CTd:0004CTe>C@h000M>CDi=CTe>010000A=CTe>
2P0014e>CDh:0004CDi=CPl000I>CDi=CTdA0003CDi=00X000A>CDi=3`001Te>CDi=CQ4000=>CDh0
2`000di=CP0:0004CDi=CPX000A=CTe>2P0014e>CDh?0006CTe>CDi=4@000de>C@0:0004CTe>C@X0
00A>CDi=2P0014i=CTd:0003CTe>00/000=>CDh03`001Ti=CTe>CAL0000F009>0lH00dh0000:009>
1iD5CPT00Th4aP03CP0000D00Th4aP03CP0000T00Th7P`E>2@02CPC600=>00001@02CPC600=>0000
1@02CPC600=>00002@03CPJE1Dh900=>0lH00dh00005009>1<H00dh0000900=>1X<5CPX00Th3aP03
CP0000H00Th3aP03CP0000D00Th4aP03CP0000D00Th4aP03CP0000D00Th4aP03CP0000T00dh6P`E>
2@03CP?600=>00001@02CPC600=>00001@02CPC600=>00001@02CPC600=>00001@02CP?600=>0000
1P02CP?600=>00002@03CPJ31DhB00005@001dkFa]K6eTh02@000di=CP0>U@03C@0000D000Q=a]K6
e/KFCPH000Q=a]K6e/KFCPP0019=CTf3Th>CPi>3Th>CPi>3Tdh70008C]K6e/KFaTd60008C]K6e/KF
aTd60008C]K6e/KFaTd80003CTe>00jE00==00001@0024g6e/KFa]I>1P0024g6e/KFa]I>2@004Di=
Pi>3Th>CPi>3Th>CPi=>00P000Q=a]K6e/KFCPH000M=a]K6e/I=00H000Q>e/KFa]K6C@H000Q>e/KF
a]K6C@H000Q>e/KFa]K6C@P0019>CDjCPi>3Th>CPi>3Th>CPdd70008CLKFa]K6eTh60008CLKFa]K6
eTh60008CLKFa]K6eTh60008CLKFa]K6eTh60008CLKFa]K6eTh60007CLKFa]K6C@09000ACDjCPi>3
Th>CPi>3Th>CPdd04@0001@000=>a/H01LH00dh00004009>4YD00dh000030003C/K600K600=>0000
0P000dk6aP06aP03CP0000<00ThBP`03CP0000<000=>a/H01/H00dh000020003C/K600K600=>0000
0P000dk6aP06aP03CP0000<00ThBU@03CP0000<000=>a/H01/H00dh000020003C/K600K600=>0000
1002CQ6300=>000010000dk6aP06aP03CP00008000=>a/H01LH00dh000020003C/K600K600=>0000
0P000dk6aP06aP03CP00008000=>a/H01/H00dh00003009>4X<00dh000030003C/K600K600=>0000
0P000dk6aP06aP03CP00008000=>a/H01/H00dh000020003C/K600K600=>00000P000dk6aP06aP03
CP00008000=>a/H01LH00dh00004009>4H<00dh0000>00004`002dkFa]K6e/KFa]I>00@000==UID0
4iD044d0001=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>0`005djCPi>3Th>CPi>3Th>CPi>3Th>C
Pi=>00<000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=0P0034kFa]K6e/KFa]K6C@<000==UID0
4iD00dd00002000;C]K6e/KFa]K6eTh00P0034g6e/KFa]K6e/KFCP@001I=Pi>3Th>CPi>3Th>CPi>3
Th>CPi=>100034g6e/KFa]K6e/KFCP8000]=a]K6e/KFa]K6C@02000<C]K6e/KFa]K6e/I=0P0034kF
a]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd3000GCH>CPi>3Th>CPi>3Th>CPi>3Th>CPdd010002dkF
a]K6e/KFa]I>008000a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP80
00a=a]K6e/KFa]K6eTh2000;CLKFa]K6e/KFaTd010005TjCPi>3Th>CPi>3Th>CPi>3Th>CPdd?0000
4`000dk6aP07aP05CP0004h05YD01Dh0001>00[600A>001>2/H01Dh0001>01F300E>0000CP0:aP04
CP00CP[600A>001>2/H01Dh0001>01FE00=>00000P000dk6aP07aP04CP00CP[600E>0000CP0FP`05
CP0004h02/H014h004h9aP04CP00CP[600A>001>2/H014h004h:aP05CP0004h05H<00dh000020003
C/K600O600A>001>2/H014h004h:aP04CP00CP[600A>001>2/H014h004h9aP05CP0004h05X<00dh0
000<00004P003dg6e/KFa]K6e/KFaTd0C@0HU@0hCP1>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=
04f3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdd2000[C]K6e/KFa]K6e/KFCP1>e/KFa]K6e/KFa]I>CLKF
a]K6e/KFa]K6eTh0CP0GU@2ICP00CLKFa]K6e/KFa]K6C@1=a]K6e/KFa]K6e/I=04f3Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CPi=>04kFa]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFCP1>e/KFa]K6e/KFa]I>04kF
a]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCP1>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>008006e=a]K6
e/KFa]K6e/I=04g6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6
e/KFCP1>e/KFa]K6e/KFa]I>04jCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==00d0000B0003C/K600W6
00=>04h069D00dh0CP0<aP9>3<H00dh0CP0GP`04CP00CP_600=>04h02lH2CPc600=>04h05iD014h0
04h;aP03CP1>00_600=>04h068<00dh0CP0;aP03CP1>00_600=>04h02lH00dh0CP0;aP9>3<H00dh0
CP0GP`04CP00CP_600=>04h02lH2CPc60Th<aP9>2lH00dh0CP0;aP03CP1>01R300=>00002`000180
00m=a]K6e/KFa]K6e/KFCTd06ID0Hde>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=CY>3Th>CPi>3
Th>CPi>3Th>CPi>3Th>CPi=>CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>
C@0IU@3oCDkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFaTe>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3
Th==C]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFCTg6
e/KFa]K6e/KFa]I>CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==C]K6e/KFa]K6e/KFa]I>e/KFa]K6
e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6
e/I=Pi>3Th>CPi>3Th>CPi>3Th>C0009CDkFa]K6e/KF00`0000B0003C/K600[60ThIU@9>3<H2CPc6
0ThIP`9>3LH00dk6aP0:aP9>3<H2CQVE0Th=aP03C/K600[60ThJP`9>3<H00dk6aP0;aP03C/K600_6
00=>a/H02/H2CPc60ThIP`9>3LH00dk6aP0:aP9>3<H2CPc60Th<aP03C/K600_600=>Ph<068<00dh0
000:00004@003dkFa]K6e/KFa]K6e/KFCP0KU@1QC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CH>C
Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KF
a]K6e/KFCP0KU@3oC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>C
Pi>3Th>CPdg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KF
a]K6CLKFa]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>e/KFa]K6e/KFa]K6eTkF
a]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KF
a]K6e/KFaTf3Th>CPi>3Th>CPi>3Th>CPi>30008C]K6e/KFa]H<00004@000dk6aP0;aP03CYFE01VE
00=>a/H02lH00dk6aP0:aP03CX>301V300=>a/H02lH00dk6aP0;aP03C/K600[600=>UID06ID00dk6
aP0;aP03C/K600_600=>Ph<068<00dk6aP0;aP03C/K600_600=>a/H02lH00dk6aP0;aP03C/K600[6
00=>Ph<06H<00dk6aP0;aP03C/K600_600=>a/H02lH00dk6aP0:aP03C/K600_600=>a/H02lH00dj3
P`0HP`9>2`00014000m>e/KFa]K6e/KFa]K6eTh06iD0HTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KF
aTe>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKF
a]K6e/KFa]K6eTi=6YD0odkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>C
Pi>3Th>CPi>3Th==a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KF
a]K6e/KFaTg6e/KFa]K6e/KFa]I>CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CC]K6e/KFa]K6e/KF
a]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CLKF
a]K6e/KFa]K6e/I=Pi>3Th>CPi>3Th>CPi>3Th>CP`002DkFa]K6e/KFaP0;00004@000dk6aP0;aP03
CYFE01RE0Th<aP9>3<H2CQZ300=>a/H02lH00dk6aP0;aP03C/K600[60ThJU@03C/K600_600=>a/H0
2lH00dj3P`0HP`03C/K600_600=>a/H02lH00dk6aP0;aP03C/K600_600=>a/H02/H2CQZ300=>a/H0
2lH00dk6aP0;aP03C/K600[60Th<aP9>3<H00dk6aP0;aP03CX>301R300=>00002P00014000m>e/KF
a]K6e/KFa]K6eTh06YD0Hde>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=CY>3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CPi>3CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]I>C@0JU@3o
C]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdg6e/KF
a]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KF
a]K6eTi=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KF
C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTf3Th>C
Pi>3Th>CPi>3Th>CPi>30008C]K6e/KFa]H<00004P000dk6aP0:aP9>6ID2CPc60Th<aP9>6H<2CPc6
0Th<aP9>3<H2CQVE00=>04h02lH2CPc600=>04h068<00dh0CP0<aP9>3<H00dk6aP0:aP9>3<H2CPc6
0ThIP`03CP1>00_60Th<aP9>3<H2CPc60Th<aP9>3<H2CQR300=>00002`00018000m=a]K6e/KFa]K6
e/KFCTd069D0I4h0C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDjCPi>3Th>CPi>3Th>CPi>3Th>C
Pi>3Th>CCTg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTdIU@3oC@1=a]K6
e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTd0CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Tdh0C]K6e/KFa]K6
e/KFaTe>e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>
CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==04g6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6
e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=CY>3Th>CPi>3
Th>CPi>3Th>C0008C@1=a]K6e/H=00004P000dk6aP09aP03CP00009>5ID01Dh0001>00[600A>001>
2/H00dh00002CQJ300A>001>2lH00dh0CP0:aP04CP00CP[600=>00000ThFU@04CP00CP_600=>04h0
2lH014h004hFP`04CP00CP_600=>04h02lH00dh0CP0;aP03CP1>00[600A>001>2/H00dh00002CQJ3
00A>001>2lH00dh0CP0;aP03CP1>00[600A>001>2/H00dh0CP0;aP03CP1>00_600=>00000ThEP`03
CP0000`0000C000<C]K6e/KFa]K6e/I=10000djEU@0BU@03C@00008000]>e/KFa]K6e/KFCP02000<
CLKFa]K6e/KFa]I>10005Tf3Th>CPi>3Th>CPi>3Th>CPi>3Tdh4000<CLKFa]K6e/KFa]I>0P002dg6
e/KFa]K6e/I=00<000]=a]K6e/KFa]K6C@040003CYFE01:E00==00000P0034kFa]K6e/KFa]K6C@80
00a>e/KFa]K6e/KFaTd3000FCH>CPi>3Th>CPi>3Th>CPi>3Th>CCP@000a=a]K6e/KFa]K6eTh2000<
CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP8000]=a]K6e/KFa]K6C@03000;CLKFa]K6e/KFaTd0
10005TjCPi>3Th>CPi>3Th>CPi>3Th>CPdd4000<C]K6e/KFa]K6e/I=0P0034kFa]K6e/KFa]K6C@80
00]>e/KFa]K6e/KFCP02000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6
eTh4000ECH>CPi>3Th>CPi>3Th>CPi>3Th==00l0000C0003C/K600O600=>000010000djEU@0?U@9>
1@000dk6aP06aP03CP00008000=>a/H01/H00dh000040003CX>300n30Th50003C/K600K60Th30003
C/K600K60Th30003C/K600K600=>000010000djEU@0?U@9>1@000dk6aP07aP05CP0004h02<H2CPD0
00=>Ph<03h<2CPD000=>a/H01lH01Dh0001>00W600E>0000CP08aP9>0`000dk6aP06aP9>0`000dk6
aP06aP03CP0000@000=>Ph<03h<2CPD000=>a/H01lH01Dh0001>00S60Th30003C/K600K60Th30003
C/K600K600E>0000CP09aP05CP0004h02LH00dh000040003CX>300j30Th@000050002Dg6e/KFa]K6
C@080003CTfE00^E00=>CDh0200024g6e/KFa]I>1P0024g6e/KFa]I>20004De>Th>CPi>3Th>CPi>3
Tdi=00P000Q>e/KFa]K6C@H000Q>e/KFa]K6C@H000Q>e/KFa]K6C@P000=>CDh039D00de>00070009
CLKFa]K6e/I=00D000Q=a]K6e/KFCPP0015=CTf3Th>CPi>3Th>CPi=>C@080009C]K6e/KFa]I>00D0
00U>e/KFa]K6eTh01@0024kFa]K6e/I=1P0024kFa]K6e/I=1P0024kFa]K6e/I=20004Di=CY>3Th>C
Pi>3Th>CPde>00P000U=a]K6e/KFaTd01@0024g6e/KFa]I>1P0024g6e/KFa]I>1P0024g6e/KFa]I>
1@002DkFa]K6e/KFCP050009C]K6e/KFa]I>00P0011=CY>3Th>CPi>3Th>CPde>4P0001D00dh2aP9>
2`03CPNE0Th<009>0/H2CPP00Th2aP9>2`03CPN30dh;00=>00?6CTh02003CP03aTi>00P00Th2aP9>
3002CPNE0dh;00=>0/H2CPL00dh00lI>CP0<009>28<2CP/00dh2aP9>1`03CP;60Th700=>00?6CTh0
2003CP03aTi>00P00Th2aP9>3002CPN30dh;00=>0/H2CPL00dh00lI>CP0800=>00?6CTh02002CP;6
0Th700=>0/H2CPL00dh2aP9>2`03CPN30ThD000060000de>000?0007CDi=CTe>C@0@0003CTd000/0
00=>C@003`001di=CTe>CDh04@000dh0000;0003CP0000X000==CP003`001de>CDi=CTd04@000de>
000;0003C@0000h000Q>CDi=CTe>CA0000=>C@002`000di=000;0003CP0000/000=>00002P000de>
000?0007CDi=CTe>C@0A0003CDh000/000==00002`000dd0000:0003CTd000/000=>C@002`000di=
000?0007CTe>CDi=CP0F0000o`3;0000o`3;0000o`3;0000o`3;0000\
\>"],
  ImageRangeCache->{{{0, 457}, {31, 0}} -> {-0.787665, -0.712262, 0.0723749, 
  0.0459524}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .05 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0302343 0.025 0.047619 [
[ 0 0 0 0 ]
[ 1 .05 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .05 L
0 .05 L
closepath
clip
newpath
p
p
.9 g
.001 w
.05404 .025 m
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.08428 .025 m
matrix currentmatrix
.01512 .02381 scale
5.57512 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
5.57512 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.12963 .025 m
matrix currentmatrix
.03023 .02381 scale
4.28751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
4.28751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.1901 .025 m
matrix currentmatrix
.03023 .02381 scale
6.28756 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
6.28756 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.23545 .025 m
matrix currentmatrix
.01512 .02381 scale
15.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
15.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.26568 .025 m
matrix currentmatrix
.01512 .02381 scale
17.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
17.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.29592 .025 m
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.32615 .025 m
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.35639 .025 m
matrix currentmatrix
.01512 .02381 scale
23.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
23.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.40174 .025 m
matrix currentmatrix
.03023 .02381 scale
13.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
13.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.46221 .025 m
matrix currentmatrix
.03023 .02381 scale
15.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
15.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.50756 .025 m
matrix currentmatrix
.01512 .02381 scale
33.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
33.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.53779 .025 m
matrix currentmatrix
.01512 .02381 scale
35.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
35.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.56803 .025 m
matrix currentmatrix
.01512 .02381 scale
37.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
37.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.59826 .025 m
matrix currentmatrix
.01512 .02381 scale
39.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
39.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.6285 .025 m
matrix currentmatrix
.01512 .02381 scale
41.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
41.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.67385 .025 m
matrix currentmatrix
.03023 .02381 scale
22.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
22.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.7192 .025 m
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.74943 .025 m
matrix currentmatrix
.01512 .02381 scale
49.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
49.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.77967 .025 m
matrix currentmatrix
.01512 .02381 scale
51.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
51.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.8099 .025 m
matrix currentmatrix
.01512 .02381 scale
53.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
53.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.84014 .025 m
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.87037 .025 m
matrix currentmatrix
.01512 .02381 scale
57.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
57.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.91572 .025 m
matrix currentmatrix
.03023 .02381 scale
30.2874 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
30.2874 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.96107 .025 m
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{458, 32},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007:000080P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5H/1JX00=d81_l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000e5D0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0b`000?l0b`000?l0b`000?l0b`000?l0
b`0001P000==CTd02`000de>C@0?0006CDi=CTe>5P001Te>CDi=CQ4000=>CDh02P0014e>CDh:0004
CDi=CPX000A=CTe>2P0014e>CDh>0007CDi=CTe>C@0E0006CDi=CTe>4@0014i=CTd:0003CTe>00/0
00=>CDh02P0014e>CDh:0004CDi=CPl000I>CDi=CTdA0003CDi=00/000==CTd02P0014i=CTd:0004
CTe>C@X000A>CDi=2P000di=CP0?0007CTe>CDi=CP0@0004CDi=CQ00000F009>0lH00dh0000500=>
0lH00dh0000900=>1YD5CPh00dh6P`E>2P02CP?600=>00001@02CPC600=>00001@02CPC600=>0000
1@02CPC600=>00001@02CPC600=>00002@02CPNE1Dh=00=>1X<5CPX00Th4aP03CP0000D00Th3aP03
CP0000H00Th3aP03CP0000D00Th4aP03CP0000D00Th4aP03CP0000T00dh6P`E>2P02CP?600=>0000
1@03CP?600=>00001@02CPC600=>00001@02CPC600=>00001@02CPC600=>00001@02CP?600=>0000
2P02CPN31Dh9009>1<H00dh0000=00005@001dkFa]K6eTh01P0024g6e/KFa]I>2@000di=U@0=U@03
CP0000P0019=CTf3Th>CPi>3Th>CPi>3Tdh80007CLKFa]K6C@060008C]K6e/KFaTd60008C]K6e/KF
aTd60008C]K6e/KFaTd60008C]K6e/KFaTd80003CTe>00jE00==000020004Di=Pi>3Th>CPi>3Th>C
Pi=>00P000Q=a]K6e/KFCPH000Q=a]K6e/KFCPH000M=a]K6e/I=00H000Q>e/KFa]K6C@H000Q>e/KF
a]K6C@T0015=CY>3Th>CPi>3Th>CPi>3C@080008C]K6e/KFaTd50008CLKFa]K6eTh60008CLKFa]K6
eTh60008CLKFa]K6eTh60008CLKFa]K6eTh60008CLKFa]K6eTh8000BCDi=Pi>3Th>CPi>3Th>CPi=>
1`0024kFa]K6e/I=3`0001@000=>a/H01LH00dh000020003C/K600K600=>00001002CQ6E00=>0000
1@02CQ:300=>000010000dk6aP05aP03CP00008000=>a/H01/H00dh000020003C/K600K600=>0000
0P000dk6aP06aP03CP00008000=>a/H01/H00dh00003009>4YD00dh00005009>4H<00dh000040003
C/K600K600=>00000P000dk6aP06aP03CP00008000=>a/H01LH00dh000020003C/K600K600=>0000
0P000dk6aP06aP03CP0000<00dhAP`03CP0000@000=>a/H01/H01Dh0001>00S600=>00000P000dk6
aP06aP03CP00008000=>a/H01/H00dh000020003C/K600K600=>00000P000dk6aP06aP03CP0000<0
0ThBP`03CP0000<000=>a/H01/H00dh0000<00004`002dkFa]K6e/KFa]I>00<000]>e/KFa]K6e/KF
CP040003CIFE01:E00=>00000`005djCPi>3Th>CPi>3Th>CPi>3Th>CPi=>00@000]=a]K6e/KFa]K6
C@02000<C]K6e/KFa]K6e/I=0P0034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd2000<C]K6e/KF
a]K6e/I=0`000dfEU@0CU@03C@0000<001I=Pi>3Th>CPi>3Th>CPi>3Th>CPi=>100034g6e/KFa]K6
e/KFCP8000a=a]K6e/KFa]K6eTh2000;CLKFa]K6e/KFaTd00P0034kFa]K6e/KFa]K6C@8000a>e/KF
a]K6e/KFaTd3000GCH>CPi>3Th>CPi>3Th>CPi>3Th>CPdd0100034kFa]K6e/KFa]K6C@8000]>e/KF
a]K6e/KFCP02000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6eTh2000<
CLKFa]K6e/KFa]I>0`005djCPi>3Th>CPi>3Th>CPi>3Th>CPi=>00<000a>e/KFa]K6e/KFaTd=0000
4`000dk6aP07aP05CP0004h02LH01Dh0001>01JE00=>00000P000dj3P`0DP`05CP0004h02LH014h0
04h:aP04CP00CP[600A>001>2/H014h004h:aP05CP0004h05ID00dh000020003CX>301B300E>0000
CP0:aP04CP00CP[600A>001>2LH014h004h:aP04CP00CP[600E>0000CP0FP`05CP0004h02/H014h0
04h9aP04CP00CP[600A>001>2/H014h004h:aP04CP00CP[600A>001>5X<01Dh0001>00[600=>0000
2`00018001e=a]K6e/KFa]K6e/I=04g6e/KFa]K6e/KFaTd0C@0HU@1RCP00CH>CPi>3Th>CPi>3Th>C
Pi>3Th>CPi>3Tdh0C]K6e/KFa]K6e/KFCP1>e/KFa]K6e/KFa]I>04kFa]K6e/KFa]K6eTi=a]K6e/KF
a]K6e/KFCTg6e/KFa]K6e/KFaTd20003CYFE01FE0>a>001=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>C
CP1>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFCP1>e/KFa]K6e/KFa]I>04kF
a]K6e/KFa]K6eTh0CY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdd0CLKFa]K6e/KFa]K6C@1=a]K6e/KF
a]K6e/I=04g6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KF
CP1>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3C@8000e>e/KFa]K6e/KFa]I>00`0000B0003C/K600W6
00=>04h02lH00dh0CP0HU@04CP00CQR300=>04h02lH00dh0CP0;aP03CP1>00_60Th<aP9>2lH014h0
04hGU@04CP00CQR300=>04h03<H2CP_600=>04h02lH00dh0CP0;aP03CP1>00_600=>04h068<00dh0
CP0;aP03CP1>00_600=>04h02lH2CPc60Th<aP9>2lH00dh0CP0HP`04CP00CP_600=>00002P000180
01a=a]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>6YD0Hde>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3
Th==a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6
e/KFa]K6e/KFa]I>C@0IU@3jCDjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPde>e/KFa]K6e/KFa]K6
CDkFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6eTi=Pi>3
Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>CLKFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6
e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>Th>CPi>3Th>CPi>3
Th>CPi>3Th>CPi>3Tdi=a]K6e/KFa]K6e/KFCP`0000B0003C/K600[600=>a/H02lH00djEU@0HU@9>
6X<00dk6aP0;aP03C/K600_600=>a/H02/H2CPc60Th<aP9>6ID2CQZ30Th<aP9>3<H00dk6aP0;aP03
C/K600_600=>a/H02/H2CQZ30Th<aP03C/K600_600=>a/H02/H2CPc60Th<aP9>3<H2CQV30Th<aP03
CP0000X0000A000MC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTh06YD0HTe>Th>CPi>3Th>CPi>3
Th>CPi>3Th>CPi>3Th==a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6
e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>6iD0nTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPde>e/KF
a]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KF
a]K6e/I=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KF
C]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTf3Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==a]K6e/KFa]K6e/KFaTd;00004@000dk6aP0;aP03C/K600_6
00=>UID069D2CQZ300=>a/H02lH00dk6aP0;aP03C/K600_600=>a/H02/H2CPc600=>UID06ID00dj3
P`0HP`9>3<H00dk6aP0;aP03C/K600_600=>a/H02lH00dk6aP0;aP03CX>301R300=>a/H02lH00dk6
aP0;aP03C/K600_600=>a/H02lH00dk6aP0:aP03C/K600_600=>Ph<06H<00dk6aP0;aP03CP0000T0
000A000MC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTh06YD0HTe>Th>CPi>3Th>CPi>3Th>CPi>3
Th>CPi>3Th==a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6
e/KFCTg6e/KFa]K6e/KFa]I>6iD0nTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPde>e/KFa]K6e/KF
a]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=
Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KF
a]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTf3Th>CPi>3Th>C
Pi>3Th>CPi>3Th>CPi>3Th==a]K6e/KFa]K6e/KFaTd;00004@000dk6aP0;aP03C/K600_600=>UID0
69D2CQZ300=>a/H02lH00dk6aP0;aP03C/K600_600=>a/H02/H2CPc600=>UID06ID00dj3P`0HP`9>
3<H00dk6aP0;aP03C/K600_600=>a/H02lH00dk6aP0;aP03CX>301R300=>a/H02lH00dk6aP0;aP03
C/K600_600=>a/H02/H2CPc60Th<aP03CX>301R30Th=aP03CP0000T0000A000MC]K6e/KFa]K6e/KF
a]I>e/KFa]K6e/KFa]K6eTh06YD0HTe>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==a]K6e/KFa]K6
e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>
6iD0nTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPde>e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=
a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=Pi>3Th>CPi>3Th>CPi>3Th>C
Pi>3Th>CPi=>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KF
a]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Tdi=
a]K6e/KFa]K6e/KFaTd;00004P000dk6aP0:aP9>2lH00dh0CP0HU@03CP1>01V300=>04h02lH2CPc6
0Th<aP9>3<H2CPc60ThIU@03CP1>01R300=>04h03<H2CPc60Th<aP03C/K600[60Th<aP9>6H<00dh0
CP0<aP9>2lH2CPc60Th<aP9>3<H2CPc60ThIP`9>3<H00dh0000:00004P007Dg6e/KFa]K6e/KFa]I>
CLKFa]K6e/KFa]K6C@1=01RE06A>001=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP1>e/KFa]K6e/KF
a]I>CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=
69D0ndh004f3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>04kFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KF
aTe>e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCP1>Th>CPi>3Th>CPi>3Th>C
Pi>3Th>CPi>3C@1=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KF
a]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==
04g6e/KFa]K6e/KFa]I>00`0000B0003C/K600W600=>04h02lH00dh00002CQFE00=>00000P000dj3
P`0DP`04CP00CP_600=>04h02lH00dh0CP0:aP04CP00CP[600A>001>2/H00dh00002CQFE00=>0000
0P02CQF300E>0000CP0:aP03CP1>00_600=>04h02lH00dh0CP0;aP03CP1>00[600E>0000CP0FP`04
CP00CP_600=>04h02lH00dh0CP0;aP03CP1>00[600A>001>2/H00dh0CP0;aP03CP00009>5H<01Dh0
001>00_600=>00002P0001<000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=10000djEU@0AU@03
CP0000@001I=Pi>3Th>CPi>3Th>CPi>3Th>CPi=>100034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6
eTh2000;CLKFa]K6e/KFaTd00`002dg6e/KFa]K6e/I=008000a>e/KFa]K6e/KFaTd40003CYFE01:E
00==000010005DjCPi>3Th>CPi>3Th>CPi>3Th>CCP04000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6
e/KFCP8000a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>0P002dg6e/KFa]K6e/I=00@001I>Th>C
Pi>3Th>CPi>3Th>CPi>3Th==100034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd2000<C]K6e/KF
a]K6e/I=0P002dkFa]K6e/KFa]I>008000a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>10005Tf3
Th>CPi>3Th>CPi>3Th>CPi>3Tdh4000<CLKFa]K6e/KFa]I>300001<000=>a/H01lH01Dh0001>00W6
00=>000010000djEU@0>U@9>20000dj3P`0?P`9>1@000dk6aP07aP05CP0004h02<H2CP<000=>a/H0
1/H2CP<000=>a/H01/H00dh000020003C/K600K600=>000010000djEU@0?U@9>20000dj3P`0>P`9>
1P000dk6aP06aP05CP0004h02LH01Dh0001>00W600E>0000CP08aP9>0`000dk6aP06aP9>1@000dj3
P`0?P`9>1@000dk6aP07aP05CP0004h02LH01Dh0001>00S60Th30003C/K600K60Th30003C/K600K6
00E>0000CP09aP03CP0000@000=>Ph<03h<2CPD000=>a/H01/H2CPd0000D0009CLKFa]K6e/I=00D0
00U=a]K6e/KFaTd020000di=U@0;U@03CTd000X0015=CTf3Th>CPi>3Th>CPi=>C@080009C]K6e/KF
a]I>00D000Q>e/KFa]K6C@H000Q>e/KFa]K6C@H000Q>e/KFa]K6C@H000Q>e/KFa]K6C@P000=>CID0
39D00de>000:000@CTf3Th>CPi>3Th>CPi=>C@T000Q=a]K6e/KFCPD000U>e/KFa]K6eTh01@002DkF
a]K6e/KFCP050008C]K6e/KFaTd60008C]K6e/KFaTd8000ACTe>Th>CPi>3Th>CPi>3CDh020002Dg6
e/KFa]K6C@050009CLKFa]K6e/I=00D000Q=a]K6e/KFCPH000Q=a]K6e/KFCPH000Q=a]K6e/KFCPD0
00U>e/KFa]K6eTh020004De>Th>CPi>3Th>CPi>3CDi=00P000Q>e/KFa]K6C@l0000E00=>0/H2CPL0
0dh2aP9>2`03CPNE0Th@009>1h<3CP/00dh2aP9>1`03CP03aTi>00P00dh00lI>CP08009>0/H2CPP0
0Th2aP9>2`03CPNE0dh?00=>1h<2CP`00Th2aP9>1`03CP;60Th700=>0/H2CPL00dh00lI>CP0800=>
00?6CTh03002CPN30dh;00=>0/H2CPL00dh2aP9>1`03CP03aTi>00P00dh00lI>CP08009>0/H2CPL0
0dh2aP9>2`03CPN30Th<00=>00?6CTh0400001P000==CP002`000de>000?0007CDi=CTe>C@0D0007
CTe>CDi=CP0A0003CTd000/000=>00002`000dh0000:0003CDh000/000==CP003`001de>CDi=CTd0
5@001de>CDi=CTd040000di=000;0003CTd000/000=>C@002`000dh0000;0003CP0000h000M=CTe>
CDi=014000==CP002`000de>000;0003C@0000/000==00002P000di=000;0003CTd000l000M>CDi=
CTe>014000=>000040000?l0b`000?l0b`000?l0b`000?l0b`000001\
\>"],
  ImageRangeCache->{{{0, 457}, {31, 0}} -> {-0.787665, -0.712262, 0.0723749, 
  0.0459524}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .05 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0302343 0.025 0.047619 [
[ 0 0 0 0 ]
[ 1 .05 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .05 L
0 .05 L
closepath
clip
newpath
p
p
.9 g
.001 w
.05404 .025 m
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.08428 .025 m
matrix currentmatrix
.01512 .02381 scale
5.57512 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
5.57512 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.12963 .025 m
matrix currentmatrix
.03023 .02381 scale
4.28751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
4.28751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.1901 .025 m
matrix currentmatrix
.03023 .02381 scale
6.28756 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
6.28756 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.23545 .025 m
matrix currentmatrix
.01512 .02381 scale
15.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
15.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.26568 .025 m
matrix currentmatrix
.01512 .02381 scale
17.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
17.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.29592 .025 m
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.32615 .025 m
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.35639 .025 m
matrix currentmatrix
.01512 .02381 scale
23.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
23.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.40174 .025 m
matrix currentmatrix
.03023 .02381 scale
13.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
13.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.46221 .025 m
matrix currentmatrix
.03023 .02381 scale
15.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
15.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.50756 .025 m
matrix currentmatrix
.01512 .02381 scale
33.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
33.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.53779 .025 m
matrix currentmatrix
.01512 .02381 scale
35.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
35.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.56803 .025 m
matrix currentmatrix
.01512 .02381 scale
37.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
37.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.59826 .025 m
matrix currentmatrix
.01512 .02381 scale
39.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
39.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.64361 .025 m
matrix currentmatrix
.03023 .02381 scale
21.2874 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
21.2874 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.68896 .025 m
matrix currentmatrix
.01512 .02381 scale
45.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
45.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.7192 .025 m
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.74943 .025 m
matrix currentmatrix
.01512 .02381 scale
49.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
49.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.77967 .025 m
matrix currentmatrix
.01512 .02381 scale
51.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
51.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.8099 .025 m
matrix currentmatrix
.01512 .02381 scale
53.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
53.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.84014 .025 m
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
55.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.88549 .025 m
matrix currentmatrix
.03023 .02381 scale
29.2876 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
29.2876 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.93084 .025 m
matrix currentmatrix
.01512 .02381 scale
61.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
61.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.96107 .025 m
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{458, 32},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007:000080P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5H/1JX00=d81_l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000e5D0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0b`000?l0b`000?l0b`000?l0b`000?l0
b`0001P000==CTd02`000de>C@0?0006CDi=CTe>5P001Te>CDi=CQ4000=>CDh02P0014e>CDh:0004
CDi=CPX000A=CTe>2P0014e>CDh>0007CDi=CTe>C@0E0006CDi=CTe>4@0014i=CTd:0003CTe>00/0
00=>CDh02P0014e>CDh?0006CTe>CDi=4@0014e>CDh:0003CDi=00/000==CTd02P0014i=CTd:0004
CTe>C@X000A>CDi=3P001di=CTe>CDh0400014e>CDh:0004CDi=CQ00000F009>0lH00dh0000500=>
0lH00dh0000900=>1X<5CPh00dh6U@E>2P02CP?600=>00001@02CPC600=>00001@02CPC600=>0000
1@02CPC600=>00001@02CPC600=>00002@02CPN31Dh=00=>1YD5CPX00Th4aP03CP0000D00Th3aP03
CP0000H00Th3aP03CP0000D00Th4aP03CP0000T00dh6P`E>2P02CPC600=>00001@02CP?600=>0000
1@03CP?600=>00001@02CPC600=>00001@02CPC600=>00001@02CPC600=>00002@02CPN31Dh9009>
1<H00dh00005009>1<H00dh0000=00005@001dkFa]K6eTh01P0024g6e/KFa]I>2@004Di=Pi>3Th>C
Pi>3Th>CPi=>00X000==CTd03YD00dh000060007CLKFa]K6C@060008C]K6e/KFaTd60008C]K6e/KF
aTd60008C]K6e/KFaTd60008C]K6e/KFaTd8000BCTe>Th>CPi>3Th>CPi>3Th==2P000di=U@0=U@03
CP0000H000Q=a]K6e/KFCPH000Q=a]K6e/KFCPH000M=a]K6e/I=00H000Q>e/KFa]K6C@T0015=CY>3
Th>CPi>3Th>CPi>3C@080008C]K6e/KFaTd60008C]K6e/KFaTd50008CLKFa]K6eTh60008CLKFa]K6
eTh60008CLKFa]K6eTh60008CLKFa]K6eTh8000BCDi=Pi>3Th>CPi>3Th>CPi=>1`0024kFa]K6e/I=
1P0024kFa]K6e/I=3`0001@000=>a/H01LH00dh000020003C/K600K600=>00001002CQ6300=>0000
1@02CQ:E00=>000010000dk6aP05aP03CP00008000=>a/H01/H00dh000020003C/K600K600=>0000
0P000dk6aP06aP03CP00008000=>a/H01/H00dh00003009>4X<00dh00005009>4ID00dh000040003
C/K600K600=>00000P000dk6aP06aP03CP00008000=>a/H01LH00dh000020003C/K600K600=>0000
1002CQ6300=>000010000dk6aP06aP03CP00008000=>a/H01/H01Dh0001>00S600=>00000P000dk6
aP06aP03CP00008000=>a/H01/H00dh000020003C/K600K600=>00000`02CQ:300=>00000`000dk6
aP06aP03CP00008000=>a/H01/H00dh0000<00004`002dkFa]K6e/KFa]I>00<000]>e/KFa]K6e/KF
CP04000FCH>CPi>3Th>CPi>3Th>CPi>3Th>CCPD000=>UID04iD00dh00002000;CLKFa]K6e/KFaTd0
0P0034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=0P0034kFa]K6e/KF
a]K6C@<001M=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3C@050003CIFE01:E00=>00000P0034g6e/KFa]K6
e/KFCP8000a=a]K6e/KFa]K6eTh2000;CLKFa]K6e/KFaTd00P0034kFa]K6e/KFa]K6C@@001I>Th>C
Pi>3Th>CPi>3Th>CPi>3Th==100034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd2000;C]K6e/KF
a]K6eTh00P0034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>0`005djC
Pi>3Th>CPi>3Th>CPi>3Th>CPi=>00<000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=3@0001<0
00=>a/H01lH01Dh0001>00W600E>0000CP0FP`03CP00008000=>UID059D01Dh0001>00W600A>001>
2/H014h004h:aP04CP00CP[600A>001>2/H01Dh0001>01F300=>00000P000djEU@0DU@05CP0004h0
2/H014h004h:aP04CP00CPW600A>001>2/H01Dh0001>01J300E>0000CP0:aP04CP00CP[600A>001>
2LH014h004h:aP04CP00CP[600A>001>2/H01Dh0001>01F300E>0000CP0:aP04CP00CP[600=>0000
2`00018003I=a]K6e/KFa]K6e/I=04g6e/KFa]K6e/KFaTd0CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3
Tdh20003CIFE01JE04I>04kFa]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFCP1>e/KFa]K6e/KFa]I>CLKF
a]K6e/KFa]K6eTi=a]K6e/KFa]K6e/I=0P006DjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Tdh00P000dfE
U@0FU@32CP1>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFCP1>e/KFa]K6e/KF
a]I>04jCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==04g6e/KFa]K6e/KFaTd0CLKFa]K6e/KFa]K6C@1=
a]K6e/KFa]K6e/I=04g6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=04f3Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CPdd2000KC]K6e/KFa]K6e/KFCP1>e/KFa]K6e/KFa]I>00`0000B0003
C/K600W600=>04h02lH00dh0CP0HP`04CP00CQRE00=>04h02lH00dh0CP0;aP03CP1>00_60Th<aP9>
2lH014h004hGP`04CP00CQRE00=>04h03<H2CP_600=>04h02lH00dh0CP0;aP03CP1>01R300=>04h0
2lH00dh0CP0;aP03CP1>00_600=>04h02lH2CPc60Th<aP03CP1>01N300A>001>2lH00dh0CP0;aP03
CP0000X0000B000hCLKFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFCY>3Th>CPi>3Th>CPi>3Th>CPi>3
Th>CPi>3CDhJU@1RCLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]I>CLKFa]K6
e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CDhJU@3NCDkFa]K6
e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=Pi>3Th>CPi>3
Th>CPi>3Th>CPi>3Th>CPi=>CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>
e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>Th>CPi>3Th>CPi>3Th>CPi>3
Th>CPi>3Tdi=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]I>3000018000=>a/H02/H00dk6aP0;aP03
CX>301R30ThJU@03C/K600_600=>a/H02lH00dk6aP0:aP9>3<H2CPc60ThIP`9>6YD2CPc60Th<aP03
C/K600_600=>a/H02lH00dj3P`0HP`9>3<H2CPc600=>a/H02lH00dk6aP0:aP9>3<H2CPc60ThIP`9>
3LH00dk6aP0:aP03CP0000X0000A000iC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTjCPi>3Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CPde>01ZE069=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6
e/KFa]K6e/I=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3
Th>CCQZE0=m=C]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6
e/KFaTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Tdi=a]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>
e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6CH>CPi>3
Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=00/0000A0003
C/K600_600=>a/H02lH00dj3P`0HP`9>6YD00dk6aP0;aP03C/K600_600=>a/H02lH00dk6aP0:aP9>
3<H00dj3P`0IP`03CYFE01RE0Th<aP03C/K600_600=>a/H02lH00dk6aP0;aP03CX>301R30Th<aP03
C/K600_600=>a/H02lH00dk6aP0;aP03C/K600_600=>a/H02/H00dj3P`0IP`03C/K600_600=>a/H0
2lH00dh0000900004@00>DkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>C
Pi>3Th>CPi>3Th==CP0JU@1RCLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6
CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3TdhJU@3O
CDkFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=Pi>3
Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>CLKFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6
e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFaTf3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CPi>3Th==a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6C@0;00004@000dk6aP0;aP03
C/K600_600=>Ph<068<2CQZE00=>a/H02lH00dk6aP0;aP03C/K600_600=>a/H02/H2CPc600=>Ph<0
6H<00djEU@0HU@9>3<H00dk6aP0;aP03C/K600_600=>a/H02lH00dj3P`0HP`9>3<H00dk6aP0;aP03
C/K600_600=>a/H02lH00dk6aP0:aP9>3<H00dj3P`0IP`03C/K600_600=>a/H02lH00dh000090000
4@00>DkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==
CP0JU@1RCLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6
eTi=a]K6e/KFa]K6e/KFCY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3TdhJU@3OCDkFa]K6e/KFa]K6
e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=Pi>3Th>CPi>3Th>CPi>3
Th>CPi>3Th>CPi=>CLKFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6
e/KFa]K6eTkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3
Th==a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6C@0;00004P000dk6aP0:aP9>2lH00dh0CP0HP`03
CP1>01VE00=>04h02lH2CPc60Th<aP9>3<H2CPc60ThIP`03CP1>01RE00=>04h03<H2CPc60Th<aP03
C/K600[600=>04h068<00dh0CP0<aP9>3<H2CP_60Th<aP9>3<H2CPc60ThIP`9>3<H2CPc600=>0000
2P00018003I=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFaTd0CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3
Tdh20003CIFE01JE065>04kFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>CLKF
a]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>008000==UID0
5YD0gdh0C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KF
CP1>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3C@1=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>CLKF
a]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDjCPi>3Th>C
Pi>3Th>CPi>3Th>CPi>3Th>CCTg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTh03000018000=>a/H0
2LH00dh0CP0;aP03CP00009>5H<00dh000020003CYFE01BE00A>001>2lH00dh0CP0;aP03CP1>00[6
00A>001>2/H014h004h:aP03CP00009>5H<00dh00002009>5ID01Dh0001>00[600=>04h02lH00dh0
CP0;aP03CP1>00_600A>001>5X<01Dh0001>00[600=>04h02lH00dh0CP0;aP03CP1>00_600=>04h0
2/H014h004h:aP03CP00009>5X<014h004h;aP03CP1>00_600=>00002P0001<000a>e/KFa]K6e/KF
aTd2000<C]K6e/KFa]K6e/I=10005DjCPi>3Th>CPi>3Th>CPi>3Th>CCP060003CIFE01:E00=>0000
0P0034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6eTh2000;CLKFa]K6e/KFaTd00`002dg6e/KFa]K6
e/I=008000a>e/KFa]K6e/KFaTd4000FCY>3Th>CPi>3Th>CPi>3Th>CPi>3C@H000=>UID04ID00dh0
0002000<CLKFa]K6e/KFa]I>0P0034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6eTh2000<CLKFa]K6
e/KFa]I>0`005Ti=Pi>3Th>CPi>3Th>CPi>3Th>CPdd4000<C]K6e/KFa]K6e/I=0P0034kFa]K6e/KF
a]K6C@8000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=0P002dkFa]K6e/KFa]I>008000a=a]K6
e/KFa]K6eTh4000FCH>CPi>3Th>CPi>3Th>CPi>3Th>CCP@000a=a]K6e/KFa]K6eTh2000<CLKFa]K6
e/KFa]I>300001<000=>a/H01lH01Dh0001>00W600=>000010000dj3P`0>P`9>20000djEU@0?U@9>
1@000dk6aP07aP05CP0004h02<H2CP<000=>a/H01/H2CP<000=>a/H01/H00dh000020003C/K600K6
00=>000010000dj3P`0?P`9>20000djEU@0>U@9>1P000dk6aP06aP05CP0004h02LH01Dh0001>00W6
00E>0000CP08aP9>1P000dj3P`0>P`9>1P000dk6aP06aP05CP0004h02LH01Dh0001>00W600E>0000
CP08aP9>0`000dk6aP06aP9>0`000dk6aP06aP03CP0000@000=>Ph<03h<2CPD000=>a/H01/H2CP<0
00=>a/H01/H2CPd0000D0009CLKFa]K6e/I=00D000U=a]K6e/KFaTd0200044i=Pi>3Th>CPi>3Th>C
CTd;0003CDi=00bE00=>C@001`002DkFa]K6e/KFCP050008C]K6e/KFaTd60008C]K6e/KFaTd60008
C]K6e/KFaTd60008C]K6e/KFaTd8000ACTf3Th>CPi>3Th>CPi>3CDh02`000di=U@0;U@03CTd000P0
00Q=a]K6e/KFCPD000U>e/KFa]K6eTh01@002DkFa]K6e/KFCP050008C]K6e/KFaTd9000@CDjCPi>3
Th>CPi>3Th==CPT000Q>e/KFa]K6C@D000U=a]K6e/KFaTd01@002Dg6e/KFa]K6C@050008CLKFa]K6
eTh60008CLKFa]K6eTh60008CLKFa]K6eTh8000ACDjCPi>3Th>CPi>3Th>CCTd0200024kFa]K6e/I=
1P0024kFa]K6e/I=3`0001D00dh2aP9>1`03CP;60Th;00=>1h<2CQ000Th7U@=>2`03CP;60Th700=>
00?6CTh02003CP03aTi>00P00Th2aP9>2002CP;60Th;00=>1h<3CPl00dh7U@9>3002CP;60Th700=>
0/H2CPL00dh2aP9>1`03CP03aTi>00`00dh7P`9>3002CP;60Th700=>0/H2CPL00dh2aP9>1`03CP03
aTi>00P00dh00lI>CP08009>0/H2CP/00dh7P`=>2`03CP03aTi>00P00dh00lI>CP0@000060000de>
000;0003CDh000l000M=CTe>CDi=01@000M>CDi=CTe>014000=>C@002`000dh0000;0003CP0000X0
00==CP002`000de>000?0007CDi=CTe>C@0E0007CDi=CTe>C@0@0003CTd000/000=>C@002`000di=
000;0003CP0000l000M>CDi=CTe>010000==CP002`000de>000;0003CDh000/000==00002`000dd0
000:0003CTd000l000M>CDi=CTe>014000=>00002`000dh0000@0000o`3;0000o`3;0000o`3;0000
o`3;0000\
\>"],
  ImageRangeCache->{{{0, 457}, {31, 0}} -> {-0.787665, -0.712262, 0.0723749, 
  0.0459524}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .05 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0302343 0.025 0.047619 [
[ 0 0 0 0 ]
[ 1 .05 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .05 L
0 .05 L
closepath
clip
newpath
p
p
.9 g
.001 w
.05404 .025 m
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
3.57475 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.0994 .025 m
matrix currentmatrix
.03023 .02381 scale
3.28766 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
3.28766 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.14475 .025 m
matrix currentmatrix
.01512 .02381 scale
9.57521 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
9.57521 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.17498 .025 m
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
11.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.22033 .025 m
matrix currentmatrix
.03023 .02381 scale
7.28741 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
7.28741 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.26568 .025 m
matrix currentmatrix
.01512 .02381 scale
17.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
17.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.29592 .025 m
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
19.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.32615 .025 m
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
21.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.3715 .025 m
matrix currentmatrix
.03023 .02381 scale
12.2874 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
12.2874 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.41686 .025 m
matrix currentmatrix
.01512 .02381 scale
27.5753 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
27.5753 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.44709 .025 m
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
29.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.6 g
.001 w
.49244 .025 m
matrix currentmatrix
.03023 .02381 scale
16.2875 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
16.2875 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.53779 .025 m
matrix currentmatrix
.01512 .02381 scale
35.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
35.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.56803 .025 m
matrix currentmatrix
.01512 .02381 scale
37.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
37.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.61338 .025 m
matrix currentmatrix
.03023 .02381 scale
20.2875 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
20.2875 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.65873 .025 m
matrix currentmatrix
.01512 .02381 scale
43.575 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
43.575 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.68896 .025 m
matrix currentmatrix
.01512 .02381 scale
45.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
45.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.7192 .025 m
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
47.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.74943 .025 m
matrix currentmatrix
.01512 .02381 scale
49.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
49.5748 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.77967 .025 m
matrix currentmatrix
.01512 .02381 scale
51.5752 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
51.5752 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.8099 .025 m
matrix currentmatrix
.01512 .02381 scale
53.5749 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
53.5749 1.05 1 0 365.73 arc
setmatrix
s
P
p
.1 g
.001 w
.85525 .025 m
matrix currentmatrix
.03023 .02381 scale
28.2874 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.03023 .02381 scale
28.2874 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.9006 .025 m
matrix currentmatrix
.01512 .02381 scale
59.5747 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
59.5747 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.93084 .025 m
matrix currentmatrix
.01512 .02381 scale
61.5751 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
61.5751 1.05 1 0 365.73 arc
setmatrix
s
P
p
.9 g
.001 w
.96107 .025 m
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
F
1 0 0 r
.5 0 1 r
newpath
matrix currentmatrix
.01512 .02381 scale
63.5748 1.05 1 0 365.73 arc
setmatrix
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{458, 32},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007:000080P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5H/1JX00=d81_l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000e5D0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0b`000?l0b`000?l0b`000?l0b`000?l0
b`0001P000==CTd03`001de>CDi=CTd0400014i=CTd:0004CTe>C@h000M>CDi=CTe>010000A=CTe>
2P0014e>CDh:0004CDi=CPl000I>CDi=CTdA0003CDi=00X000A>CDi=3`001Te>CDi=CQ4000=>CDh0
2`000di=CP0?0007CTe>CDi=CP0@0004CDi=CPX000A=CTe>2P000de>C@0;0003CDi=00X000A>CDi=
2P0014i=CTd?0006CDi=CTe>4@000di=CP0:0004CDi=CPX000A=CTe>400001H00Th3aP03CP0000X0
0Th7P`E>2@02CPC600=>00001@02CPC600=>00002@02CPNE1Dh9009>1<H00dh00005009>1<H00dh0
0005009>1<H00dh0000900=>1X<5CPT00dh3aP03CP0000D00Th4aP03CP0000T00dh6U@E>2P02CP?6
00=>00001P02CP?600=>00002@03CPN314h:009>1<H00dh00005009>1<H00dh00005009>0lH00dh0
000500=>0lH00dh00005009>1<H00dh00005009>1<H00dh0000900=>1X<5CPX00Th3aP03CP0000D0
0Th4aP03CP0000D00Th4aP03CP0000d0000E0007C]K6e/KFCP09000BCTe>Th>CPi>3Th>CPi>3Th==
1`0024g6e/KFa]I>1P0024g6e/KFa]I>20000de>C@0>U@03CP0000D000Q>e/KFa]K6C@H000Q>e/KF
a]K6C@H000Q>e/KFa]K6C@P0019>CDjCPi>3Th>CPi>3Th>CPdd70008CLKFa]K6eTh60008CLKFa]K6
eTh90003CTfE00fE00=>00001P0024g6e/KFa]I>1P001dg6e/KFaTd02@004De>Th>CPi>3Th>CPi>3
Th==00P000Q>e/KFa]K6C@H000Q>e/KFa]K6C@H000Q>e/KFa]K6C@D000Q=a]K6e/KFCPH000Q=a]K6
e/KFCPH000Q=a]K6e/KFCPP0019=CTf3Th>CPi>3Th>CPi>3Tdh80007CLKFa]K6C@060008C]K6e/KF
aTd60008C]K6e/KFaTd?000050000dk6aP05aP03CP0000@00ThBP`03CP0000<000=>a/H01/H00dh0
00020003C/K600K600=>00000`02CQ:E00=>00000`000dk6aP06aP03CP00008000=>a/H01/H00dh0
00020003C/K600K600=>00000`02CQ:300=>00000`000dk6aP06aP03CP00008000=>a/H01/H00dh0
0004009>4ID00dh000040003C/K600K600=>00000P000dk6aP05aP03CP0000@00ThAP`03CP0000@0
00=>a/H01/H00dh000020003C/K600K600=>00000P000dk6aP06aP05CP0004h02<H00dh000020003
C/K600K600=>00000P000dk6aP06aP03CP0000<00ThBP`03CP0000@000=>a/H01LH00dh000020003
C/K600K600=>00000P000dk6aP06aP03CP0000`0000C000;C]K6e/KFa]K6eTh010005df3Th>CPi>3
Th>CPi>3Th>CPi>3Th==00<000a=a]K6e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>0`000djEU@0CU@0@
CP0004kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=0`005df3Th>CPi>3
Th>CPi>3Th>CPi>3Th==00@000]>e/KFa]K6e/KFCP02000<CLKFa]K6e/KFa]I>10000dfEU@0BU@03
CP00008000a=a]K6e/KFa]K6eTh2000;CLKFa]K6e/KFaTd010005TjCPi>3Th>CPi>3Th>CPi>3Th>C
Pdd4000<C]K6e/KFa]K6e/I=0P0034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd2000;C]K6e/KF
a]K6eTh00P0034g6e/KFa]K6e/KFCP8000a=a]K6e/KFa]K6eTh3000GCY>3Th>CPi>3Th>CPi>3Th>C
Pi>3Tdh010002dg6e/KFa]K6e/I=008000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=3@0001<0
00=>a/H01lH01Dh0001>01J300E>0000CP0:aP04CP00CP[600E>0000CP0EU@05CP0004h02/H014h0
04h:aP04CP00CP[600E>0000CP0EP`03CP00008000=>a/H01lH014h004h:aP05CP0004h05YD01Dh0
001>00[600A>001>2LH01Dh0001>01J300E>0000CP0:aP04CP00CP[600A>001>2/H014h004h9aP04
CP00CP[600A>001>2/H01Dh0001>01F300=>00000P000dk6aP07aP04CP00CP[600A>001>2/H00dh0
000;00004P00Adg6e/KFa]K6e/KFaTd0CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Tdh0C]K6e/KFa]K6
e/KFaTe>e/KFa]K6e/KFa]K6C@1=01NE04I=001>e/KFa]K6e/KFa]I>04kFa]K6e/KFa]K6eTi=a]K6
e/KFa]K6e/KFCP1>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>0P007Dg6e/KFa]K6e/KFaTd0CLKFa]K6
e/KFa]K6C@1=01RE0:I>04kFa]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFCP1>Th>CPi>3Th>CPi>3Th>C
Pi>3Th>CPi>3C@1=a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFaTd0CLKFa]K6e/KFa]K6C@1=a]K6e/KF
a]K6e/I=04g6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6C@1=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==
0P00:DkFa]K6e/KFa]K6eTh0C]K6e/KFa]K6e/KFCP1>e/KFa]K6e/KFa]I>00`0000B0003C/K600W6
00=>04h068<00dh0CP0<aP9>3<H00dh0CP0GU@04CP00CP_600=>04h02lH2CPc600=>04h05h<014h0
04h;aP03CP1>00_600=>04h069D00dh0CP0;aP03CP1>00_600=>04h068<00dh0CP0<aP9>2lH00dh0
CP0;aP03CP1>00_600=>04h02lH2CPc600=>04h05h<014h004h;aP03CP1>00_600=>04h02lH00dh0
000:00004P00ATg6e/KFa]K6e/KFa]I>CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==C]K6e/KFa]K6
e/KFaTe>e/KFa]K6e/KFa]K6CDhIU@1SCTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6eTi=a]K6e/KF
a]K6e/KFCTf3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CDkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KF
aTe>01ZE0=1=C]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3
Th>CCTg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>
e/KFa]K6e/KFa]K6CDkFa]K6e/KFa]K6e/I=CY>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>CLKFa]K6
e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]I>3000018000=>a/H02/H2CQV30Th<aP9>
3<H2CQVE0Th=aP03C/K600[60Th<aP9>6H<2CPg600=>a/H02/H2CQZE0Th<aP03C/K600_600=>Ph<0
68<2CPc60Th<aP9>3<H00dk6aP0;aP03C/K600[60Th<aP9>6H<2CPg600=>a/H02lH00dk6aP0:aP03
CP0000X0000A0016C]K6e/KFa]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CC]K6e/KF
a]K6e/KFa]I>e/KFa]K6e/KFa]K6CA^E069=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CLKFa]K6
e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6
e/KFCQZE0=5=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3
Th>CPdg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>
e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3CLKFa]K6
e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6e/KFa]K6e/KFa]K6C@0;00004@000dk6aP0;aP03CX>301V3
00=>a/H02lH00dk6aP0:aP03CYFE01VE00=>a/H02lH00dk6aP0;aP03C/K600[600=>Ph<06H<00dk6
aP0;aP03C/K600_600=>UID069D00dk6aP0;aP03C/K600_600=>Ph<06H<00dk6aP0:aP9>3<H00dk6
aP0;aP03C/K600_600=>a/H02lH00dk6aP0:aP03CX>301V300=>a/H02lH00dk6aP0;aP03C/K600_6
00=>00002@00014004M>e/KFa]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>e/KF
a]K6e/KFa]K6eTkFa]K6e/KFa]K6e/I=CP0JU@1RCLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTg6
e/KFa]K6e/KFa]I>CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CC]K6e/KFa]K6e/KFa]I>e/KFa]K6
e/KFa]K6eThJU@3ACLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTf3Th>CPi>3Th>CPi>3Th>CPi>3
Th>CPi>3Th==a]K6e/KFa]K6e/KFCTg6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6
e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTjCPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPdg6
e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFaTd02`00014000=>a/H02lH00dj3
P`0HP`9>3<H2CPc60ThJU@03C/K600_600=>a/H02lH00dk6aP0:aP9>6X<00dk6aP0;aP03C/K600_6
00=>UID069D00dk6aP0;aP03C/K600_600=>Ph<068<2CPc60Th<aP03C/K600_600=>a/H02lH00dk6
aP0;aP03C/K600[60ThJP`03C/K600_600=>a/H02lH00dk6aP0;aP03CP0000T0000A0017C]K6e/KF
a]K6e/KFa]I>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KF
a]K6CDh06YD0HTg6e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6e/I=a]K6e/KFa]K6e/KFCTf3Th>CPi>3
Th>CPi>3Th>CPi>3Th>CPi>3TdkFa]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>6YD0dDg6e/KFa]K6
e/KFa]K6CLKFa]K6e/KFa]K6e/I=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi=>CLKFa]K6e/KFa]K6
eTi=a]K6e/KFa]K6e/KFC]K6e/KFa]K6e/KFa]I>e/KFa]K6e/KFa]K6eTkFa]K6e/KFa]K6e/KFC]K6
e/KFa]K6e/KFaTe>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Th==a]K6e/KFa]K6e/KFaTg6e/KFa]K6
e/KFa]K6CLKFa]K6e/KFa]K6e/I=00/0000B0003C/K600[60ThIP`9>3<H2CPc60ThIU@9>3<H2CPc6
0Th<aP9>6H<00dh0CP0;aP9>3<H00dh0CP0HU@03CP1>00c60Th<aP9>6H<2CPc60Th<aP9>3<H2CP_6
0Th<aP9>3<H2CQV300=>04h03<H00dk6aP0:aP9>3<H00dh0000:00004P00ATg6e/KFa]K6e/KFa]I>
CH>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3Tdh0C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KFa]K6CDhIU@1T
CTg6e/KFa]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/KFCTf3Th>CPi>3Th>CPi>3Th>C
Pi>3Th>CPi>3C@1=a]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTd0CARE0=5>04kFa]K6e/KFa]K6e/I=
C]K6e/KFa]K6e/KFaTe>Th>CPi>3Th>CPi>3Th>CPi>3Th>CPi>3C@1=a]K6e/KFa]K6e/KFCTg6e/KF
a]K6e/KFa]I>CLKFa]K6e/KFa]K6eTi=a]K6e/KFa]K6e/I=C]K6e/KFa]K6e/KFaTe>e/KFa]K6e/KF
a]K6C@1=Pi>3Th>CPi>3Th>CPi>3Th>CPi>3Th>CCP1>e/KFa]K6e/KFa]K6CLKFa]K6e/KFa]K6eTi=
a]K6e/KFa]K6e/KFCP0<00004P000dk6aP09aP03CP00009>5H<01Dh0001>00[600A>001>2/H00dh0
0002CQJE00A>001>2lH00dh0CP0:aP04CP00CP[600=>00000ThFP`04CP00CP_600=>04h02lH014h0
04hFU@04CP00CP_600=>04h02lH00dh00002CQF300E>0000CP0:aP04CP00CP[600=>04h02lH00dh0
CP0;aP03CP1>00_600=>04h02/H01Dh0001>01J300A>001>2lH00dh0CP0;aP03CP1>00_600=>0000
2P0001<000a>e/KFa]K6e/KFaTd4000FCY>3Th>CPi>3Th>CPi>3Th>CPi>3C@@000]>e/KFa]K6e/KF
CP02000<CLKFa]K6e/KFa]I>10000dfEU@0BU@03CP00008000a=a]K6e/KFa]K6eTh2000;CLKFa]K6
e/KFaTd00`002dg6e/KFa]K6e/I=00@001I>Th>CPi>3Th>CPi>3Th>CPi>3Th==100034kFa]K6e/KF
a]K6C@8000a>e/KFa]K6e/KFaTd30003CIFE01:E00=>00000P0034g6e/KFa]K6e/KFCP8000a=a]K6
e/KFa]K6eTh4000ECH>CPi>3Th>CPi>3Th>CPi>3Th==00D000]=a]K6e/KFa]K6C@02000<C]K6e/KF
a]K6e/I=0P0034kFa]K6e/KFa]K6C@8000a>e/KFa]K6e/KFaTd2000<C]K6e/KFa]K6e/I=0P002dkF
a]K6e/KFa]I>00@001I=Pi>3Th>CPi>3Th>CPi>3Th>CPi=>100034g6e/KFa]K6e/KFCP8000a=a]K6
e/KFa]K6eTh2000<CLKFa]K6e/KFa]I>300001<000=>a/H01lH00dh000040003CX>300n30Th50003
C/K600K600=>00000P000dk6aP06aP03CP0000@000=>UID03iD2CPD000=>a/H01/H2CP<000=>a/H0
1/H2CP<000=>a/H01/H00dh000040003CX>300n30Th50003C/K600O600E>0000CP08aP9>1@000djE
U@0?U@9>1@000dk6aP07aP05CP0004h02LH00dh000040003CX>300j30Th60003C/K600K600=>0000
0P000dk6aP06aP05CP0004h02LH01Dh0001>00W600E>0000CP08aP9>0`000dk6aP06aP9>1@000dj3
P`0?P`9>1@000dk6aP07aP05CP0004h02<H2CP<000=>a/H01/H2CPd0000D0009CLKFa]K6e/I=00P0
015>CH>CPi>3Th>CPi>3Tdi=CP080008CLKFa]K6eTh60008CLKFa]K6eTh80003CDjE00bE00=>C@00
1`0024kFa]K6e/I=1P0024kFa]K6e/I=1P0024kFa]K6e/I=20004Di=CY>3Th>CPi>3Th>CPde>00P0
00U=a]K6e/KFaTd01@0024g6e/KFa]I>20000de>C@0<U@03CTd000L000U>e/KFa]K6eTh01@002DkF
a]K6e/KFCP08000@CDjCPi>3Th>CPi>3Th==CPT000Q>e/KFa]K6C@H000Q>e/KFa]K6C@D000U=a]K6
e/KFaTd01@002Dg6e/KFa]K6C@050008CLKFa]K6eTh60008CLKFa]K6eTh8000ACDi=Pi>3Th>CPi>3
Th>CCTd020002DkFa]K6e/KFCP050008C]K6e/KFaTd60008C]K6e/KFaTd?00005@03CP;60Th;00=>
1h<2CP`00Th2aP9>2002CP;60Th;00=>1iD3CP/00dh00lI>CP0800=>00?6CTh02002CP;60Th<009>
1h<3CP/00dh2aP9>1`03CP03aTi>00`00Th8U@9>2`03CP;60Th700=>0/H2CP/00dh7P`9>3002CP;6
0Th8009>0/H2CPL00dh2aP9>1`03CP;60Th700=>00?6CTh02003CP03aTi>00`00Th7P`=>2`03CP;6
0Th700=>00?6CTh02003CP03aTi>0100000H0003CDh000l000M=CTe>CDi=010000=>C@002`000di=
000?0007CTe>CDi=CP0A0003CP0000/000=>00002P000de>000?0007CDi=CTe>C@0A0003CDh000/0
00==00003P0024i=CTe>CDi=40000di=000;0003CTd000l000M>CDi=CTe>010000==CP002`000de>
000;0003CDh000/000==CP002`000dd0000;0003C@0000h000M>CDi=CTe>014000=>C@002`000dh0
000;0003CP000100003o0</0003o0</0003o0</0003o0</00000\
\>"],
  ImageRangeCache->{{{0, 457}, {31, 0}} -> {-0.787665, -0.712262, 0.0723749, 
  0.0459524}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Reference", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "C. Jacob, ",
  StyleBox["Illustrating Evolutionary Computation with Mathematica.",
    FontWeight->"Bold"],
  " Morgan Kaufmann Publishers, San Fancisco, 2001. Chapter 9.2.2.\n"
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 746}},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{750, 698},
WindowMargins->{{136, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> \
FrontEnd`FileName[{ParentDirectory[ParentDirectory[ParentDirectory[]]], \
"IEC-Setup"}, "EvolvicaStyle.nb", CharacterEncoding -> "MacintoshRoman"]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 133, 7, 205, "Title",
  Evaluatable->False],
Cell[1912, 62, 120, 3, 62, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2057, 69, 91, 2, 78, "Section",
  Evaluatable->False],
Cell[2151, 73, 270, 6, 89, "Input",
  InitializationCell->True],
Cell[2424, 81, 91, 2, 41, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[2552, 88, 109, 2, 62, "Section",
  Evaluatable->False],
Cell[2664, 92, 1029, 14, 386, "Input"],

Cell[CellGroupData[{
Cell[3718, 110, 107, 2, 41, "Input"],
Cell[3828, 114, 1454, 60, 251, "Output",
  Evaluatable->False]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[5331, 180, 86, 2, 62, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[5442, 186, 16696, 621, 102, 5852, 482, "GraphicsData", "PostScript", \
"Graphics",
  Evaluatable->False],
Cell[22141, 809, 16478, 618, 70, 5853, 482, "GraphicsData", "PostScript", \
"Graphics"],
Cell[38622, 1429, 16460, 618, 70, 5851, 482, "GraphicsData", "PostScript", \
"Graphics"],
Cell[55085, 2049, 16622, 620, 70, 5851, 482, "GraphicsData", "PostScript", \
"Graphics"],
Cell[71710, 2671, 16707, 621, 70, 5851, 482, "GraphicsData", "PostScript", \
"Graphics"],
Cell[88420, 3294, 16721, 621, 70, 5853, 482, "GraphicsData", "PostScript", \
"Graphics"],
Cell[105144, 3917, 16696, 621, 70, 5852, 482, "GraphicsData", "PostScript", \
"Graphics"],
Cell[121843, 4540, 16684, 621, 70, 5852, 482, "GraphicsData", "PostScript", \
"Graphics"],
Cell[138530, 5163, 16681, 621, 70, 5853, 482, "GraphicsData", "PostScript", \
"Graphics"],
Cell[155214, 5786, 16454, 618, 70, 5849, 482, "GraphicsData", "PostScript", \
"Graphics"],
Cell[171671, 6406, 16840, 623, 70, 5850, 482, "GraphicsData", "PostScript", \
"Graphics"],
Cell[188514, 7031, 16707, 621, 70, 5855, 482, "GraphicsData", "PostScript", \
"Graphics"],
Cell[205224, 7654, 16896, 623, 70, 5854, 482, "GraphicsData", "PostScript", \
"Graphics"],
Cell[222123, 8279, 16851, 623, 70, 5849, 482, "GraphicsData", "PostScript", \
"Graphics"],
Cell[238977, 8904, 16671, 621, 70, 5851, 482, "GraphicsData", "PostScript", \
"Graphics"],
Cell[255651, 9527, 16866, 623, 70, 5852, 482, "GraphicsData", "PostScript", \
"Graphics"],
Cell[272520, 10152, 16470, 618, 70, 5849, 482, "GraphicsData", "PostScript", \
"Graphics"],
Cell[288993, 10772, 16709, 621, 70, 5849, 482, "GraphicsData", "PostScript", \
"Graphics"],
Cell[305705, 11395, 16712, 621, 70, 5852, 482, "GraphicsData", "PostScript", \
"Graphics"],
Cell[322420, 12018, 16748, 622, 70, 5855, 482, "GraphicsData", "PostScript", \
"Graphics"],
Cell[339171, 12642, 16707, 621, 70, 5851, 482, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[355927, 13269, 76, 2, 62, "Section",
  Evaluatable->False],
Cell[356006, 13273, 208, 5, 62, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

