(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    101388,       1470]*)
(*NotebookOutlinePosition[    102472,       1502]*)
(*  CellTagsIndexPosition[    102428,       1498]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["L-Systems for Plantlike Structures", "Title"],

Cell["\<\
Christian Jacob, jacob@cpsc.ucalgary.ca \[Dash] April 1997 \
\[Copyright]\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Modeling Growth with L-Systems", "Section"],

Cell[TextData[{
  "Rewriting has proved to be a useful technique for defining complex objects \
by successively replacing parts of simple initial objects using a set of \
rewrite rules or productions. In the scope of this chapter we focus on a \
special type of character based rewrite systems, commonly termed L-systems \
(Lindenmayer systems), which are used in theoretical biology for describing \
and simulating natural growth processes (",
  ButtonBox["Lindenmayer 1968",
    ButtonData:>{
      FrontEnd`FileName[ {"..", "..", "..", "IEC-Setup", "References.nb"}], 
      "Lindenmayer 1968"},
    ButtonStyle->"Hyperlink"],
  "). All letters in a given word are replaced in parallel and \
simultaneously. This feature makes L-systems especially suitable for \
describing, e.g., fractal structures, cell divisions in multicellular \
organisms (",
  ButtonBox["Jacob 1994",
    ButtonData:>{
      FrontEnd`FileName[ {"..", "..", "..", "IEC-Setup", "References.nb"}], 
      "Jacob 1994"},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["1995a",
    ButtonData:>{
      FrontEnd`FileName[ {"..", "..", "..", "IEC-Setup", "References.nb"}], 
      "Jacob 1995a - Ma in E&R"},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["1995b",
    ButtonData:>{
      FrontEnd`FileName[ {"..", "..", "..", "IEC-Setup", "References.nb"}], 
      "Jacob 1995b - IMS-95"},
    ButtonStyle->"Hyperlink"],
  "), or flowering stages of herbaceous plants (",
  ButtonBox["Prusinkiewicz & Lindenmayer 1990",
    ButtonData:>{
      FrontEnd`FileName[ {"..", "..", "..", "IEC-Setup", "References.nb"}], 
      "Prusinkiewicz & Lindenmayer 1990"},
    ButtonStyle->"Hyperlink"],
  "), as we will demonstrate in the sequel."
}], "Text"],

Cell[TextData[{
  "A more detailed description of L-systems can be found in the introductory \
chapter about  ",
  ButtonBox["Growth Modeling",
    ButtonData:>{"ModelingGrowth.nb", None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Growth Modeling in 3-Dimensional Space", "Section"],

Cell[TextData[{
  "D0L-systems (D0 means ",
  StyleBox["deterministic",
    FontSlant->"Italic"],
  " with ",
  StyleBox["no",
    FontSlant->"Italic"],
  " context) are the simplest type of L-systems. Formally a D0L-system can be \
defined as a triple ",
  Cell[BoxData[
      \(TraditionalForm\`G = \((\[CapitalSigma], \[ScriptCapitalP], \[Alpha])\
\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalSigma] = {\[Sigma]\_1, \[Ellipsis], \
\[Sigma]\_n}\)]],
  " is an alphabet, \[Alpha], referred to as the axiom, is an element of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalSigma]\^*\)\)]],
  ", the set of all finite words over the alphabet \[CapitalSigma]. The \
structure preserving mapping ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalP] : \ \[CapitalSigma] \[Rule] \(\
\[CapitalSigma]\^*\)\)]],
  " is defined by a set of productions or rewrite rules ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma] \[Rule] \[ScriptCapitalP](\[Sigma])\)]],
  " for each ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma] \[Element] \[CapitalSigma]\)]],
  "."
}], "Text"],

Cell[" ", "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[{
      FormBox[
        RowBox[{
          "\n", \(G\_ArtFlower = \((\[CapitalSigma], \[ScriptCapitalP] = \
{p\_1, \[Ellipsis], p\_9}, \[Alpha])\)\)}], TraditionalForm], "\n", 
      FormBox[
        RowBox[{"\[CapitalSigma]", "=", 
          RowBox[{"{", 
            RowBox[{"f", ",", "pd", ",", "pu", ",", 
              StyleBox["sprout",
                FontSlant->"Italic"], ",", 
              StyleBox["stalk",
                FontSlant->"Italic"], ",", 
              StyleBox["leaf",
                FontSlant->"Italic"], ",", 
              StyleBox["Leaf",
                FontSlant->"Italic"], ",", 
              StyleBox["bloom",
                FontSlant->"Italic"]}], "}"}]}], TraditionalForm]}]],
  "\n\n\t\[Alpha]:\t",
  StyleBox["sprout(4)",
    FontSlant->"Italic"],
  "\n\n\n\n\t\[ScriptCapitalP]:\t",
  StyleBox["Sprout developing leaves and flowers:",
    FontWeight->"Bold"],
  "\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`p\_1\)]],
  ":\t",
  StyleBox["sprout(4)",
    FontSlant->"Italic"],
  " \t\[Rule]\tf ",
  StyleBox["stalk",
    FontSlant->"Italic"],
  "(2) [ pd(60) ",
  StyleBox["leaf",
    FontSlant->"Italic"],
  "(0) ]\n\t\t\t\t\t\tpu(20) [pu(25) ",
  StyleBox["sprout",
    FontSlant->"Italic"],
  "(0) ]\n\t\t\t\t\t\t[ pd(60) ",
  StyleBox["leaf",
    FontSlant->"Italic"],
  "(0) ] pd(20)\n\t\t\t\t\t\t[ pu(25) ",
  StyleBox["sprout",
    FontSlant->"Italic"],
  "(2) ]\n\t\t\t\t\t\tf ",
  StyleBox["stalk",
    FontSlant->"Italic"],
  "(1) ",
  StyleBox["bloom",
    FontSlant->"Italic"],
  "(0)\n\t\n\t\t",
  StyleBox["Riping sprout:",
    FontWeight->"Bold"],
  "\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`p\_2\)]],
  ":\t",
  StyleBox["sprout(t<4)",
    FontSlant->"Italic"],
  "\t\[Rule]\t",
  StyleBox["sprout(t+1)",
    FontSlant->"Italic"],
  "\n\t\n\t\t",
  StyleBox["Stalk elongation:",
    FontWeight->"Bold"],
  "\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`p\_3\)]],
  ":\t",
  StyleBox["stalk(t>0)",
    FontSlant->"Italic"],
  "\t\[Rule]\tf f ",
  StyleBox["stalk(t-1)",
    FontSlant->"Italic"],
  "\n\t\n\t\t",
  StyleBox["Changing leaf sizes:",
    FontWeight->"Bold"],
  "\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`p\_4\)]],
  ":\t",
  StyleBox["leaf(t)",
    FontSlant->"Italic"],
  "\t\t\[Rule]\t",
  StyleBox["leaf(i + 1.5)",
    FontSlant->"Italic"],
  "\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`p\_5\)]],
  ":\t",
  StyleBox["leaf(t>7)",
    FontSlant->"Italic"],
  "\t\[Rule]\t",
  StyleBox["Leaf(7)",
    FontSlant->"Italic"],
  "\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`p\_6\)]],
  ":\t",
  StyleBox["Leaf(t)",
    FontSlant->"Italic"],
  "\t\t\[Rule]\t",
  StyleBox["Leaf(i - 1.5)",
    FontSlant->"Italic"],
  "\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`p\_7\)]],
  ":\t",
  StyleBox["Leaf(t<2)",
    FontSlant->"Italic"],
  "\t\[Rule]\t",
  StyleBox["leaf(0)",
    FontSlant->"Italic"],
  "\n\t\n\t\t",
  StyleBox["Growing bloom:",
    FontWeight->"Bold"],
  "\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`p\_8\)]],
  ":\t",
  StyleBox["bloom(t)",
    FontSlant->"Italic"],
  "\t\[Rule]\t",
  StyleBox["bloom(t + 1)",
    FontSlant->"Italic"],
  "\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`p\_9\)]],
  ":\t",
  StyleBox["bloom(7)",
    FontSlant->"Italic"],
  "\t\[Rule]\t",
  StyleBox["bloom(1)\n\t\t",
    FontSlant->"Italic"]
}], "Text",
  CellMargins->{{Inherited, 18}, {Inherited, Inherited}},
  Background->GrayLevel[0.900008]],

Cell[TextData[{
  "Example of a parametrized contextfree L-system modeling flowering stages \
of an artificial plantlike structure (adapted from (",
  ButtonBox["Prusinkiewicz & Lindenmayer 1990",
    ButtonData:>{
      FrontEnd`FileName[ {"..", "..", "..", "IEC-Setup", "References.nb"}], 
      "Prusinkiewicz & Lindenmayer 1990"},
    ButtonStyle->"Hyperlink"],
  ", p. 83ff.)"
}], "NumberedFigure"],

Cell[TextData[{
  "Figure 1 shows a simple example L-system describing growth sequences of \
sprouts, leaves and blooms of an artificial flower, an animation sequence of \
which is depicted in Figure 2. The D0L-system encodes macros for generating \
graphical representations of the leaves, blooms and stalks. All the \
non-italic terms (f, pu, pd) represent commands to move (f: forward, b: back) \
and change the orientation (pu/pd: pitch up/down) of a virtual drawing tool, \
known as a ",
  StyleBox["turtle",
    FontSlant->"Italic"],
  ", in 3-dimensional space (rotate, yaw, pitch), thus translating a \
1-dimensional string into a 3D-object resembling a plant."
}], "Text"],

Cell[" ", "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400059000272000`400?l00000o`00003ooooooom:
ooooo`00oooooom:ooooo`00oooooom:ooooo`00oooooom:ooooo`00Q_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0;Wooooo0025ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0OOooool306IVISSooooo001]ooooo`0306IVI_oooooooooo01Gooooo00Co0000oooo
oooooooooooo0_l00003ooooo`03o`000?oooooooooo07cooooo0P1VIVHjooooo`00KOooool00`1V
IVKoooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000N_ooool4
06IVIQKooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`00K_ooool00`1V
IVKoooooooooo`0Dooooo`04o`000?ooooooooooooooo`?o00000_ooool00ol0003oooooooooo`1d
ooooo`@0IVIV00?ooooo06IVI_ooool05_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01Kooooo001^ooooo`80IVIV5Oooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0007Cooooo0P1VIVH6ooooo`0306IVI_oooooooooo01Cooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooooooool2o`0000?ooooo00?o0000ooooooooool05_ooool0073ooooo00<0
IVIVooooooooool04_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00073o
oooo101VIVH8ooooo`80IVIV5Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00006?ooool0077ooooo00<0IVIVooooooooool04Oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0006cooooo1@1VIVH=ooooo`0306IVI_oo
oooooooo01;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0001Sooooo001aooooo`80IVIV4oooool00ol0003oooooooooo`02o`0000;ooooo
00?o0000ooooooooool0JOooool306IVIQ;ooooo00<0IVIVooooooooool04Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00006?ooool005Ko
oooo0`1VIVHJooooo`0406IVI_ooooooooooooooo`<0IVIVO?ooool406IVIQCooooo00<0IVIVoooo
ooooool04Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00006?ooool005Sooooo00<0IVIVooooooooool06Oooool0101VIVKooooo06IVIP1V
IVIjooooo`@0IVIV6Oooool206IVIQ7ooooo00Co0000oooooooooooooooo0_l00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool05_ooool005Wooooo00<0IVIVooooooooool0
5Oooool506IVIW[ooooo0P1VIVH00oooool0IVIVooooo`0Kooooo`0306IVI_oooooooooo013ooooo
00Go0000ooooooooooooooooo`000003ooooo`;o00000_ooool00ol0003oooooooooo`0Gooooo`00
F_ooool206IVIQ7ooooo1@1VIVH4ooooo`0306IVI_oooooooooo07?ooooo101VIVH3ooooo`0306IV
I_oooooooooo01_ooooo00<0IVIVooooooooool00oooool306IVIRoooooo001Kooooo`0306IVI_oo
oooooooo00gooooo0P1VIVH9ooooo`0306IVI_oooooooooo06oooooo1@1VIVH7ooooo`80IVIV6ooo
ool206IVIP03ooooo`1VIVH0IVIV0080IVIV<Oooool005cooooo00<0IVIVooooooooool02?ooool4
06IVIPcooooo00<0IVIVooooooooool0K?ooool306IVIPcooooo00<0IVIVooooooooool06Oooool3
06IVISGooooo0011ooooo`80IVIV6_ooool206IVIP?ooooo1@1VIVHAooooo`80IVIVJOooool406IV
IPoooooo00<0IVIVooooooooool05Oooool406IVIP03ooooo`1VIVH0IVIV03Cooooo0013ooooo`03
06IVI_oooooooooo01Sooooo00<0IVIVooooo`1VIVH00P1VIVHFooooo`0306IVI_oooooooooo06?o
oooo101VIVHDooooo`80IVIV4Oooool406IVIPKooooo0P1VIVHcooooo`00@oooool206IVIQOooooo
101VIVHJooooo`0306IVI_oooooooooo063ooooo0P1VIVHIooooo`0306IVI_oooooooooo00gooooo
0P1VIVH<ooooo`0306IVI_oooooooooo033ooooo0015ooooo`0306IVI_oooooooooo017ooooo0`1V
IVH4ooooo`0306IVI_oooooooooo01Sooooo00<0IVIVooooooooool0Foooool606IVIQ[ooooo00<0
IVIVooooooooool02?ooool406IVIPkooooo00<0IVIVooooooooool0<?ooool004Gooooo0P1VIVH>
ooooo`D0IVIV1oooool00`1VIVKoooooooooo`0Hooooo`0306IVI_oooooooooo05Kooooo1@1VIVH5
ooooo`0306IVI_oooooooooo01Sooooo0P1VIVH3ooooo`D0IVIV4oooool00`1VIVKoooooooooo`0_
ooooo`00A_ooool206IVIPWooooo1@1VIVH<ooooo`0306IVI_oooooooooo01Sooooo00<0IVIVoooo
ooooool0Doooool206IVIP_ooooo00<0IVIVooooooooool06?ooool00`1VIVKoooooooooo`0206IV
IQSooooo00<0IVIVooooooooool0;_ooool002cooooo0P1VIVHJooooo`0306IVI_oooooooooo00Co
oooo0`1VIVHAooooo`0306IVI_oooooooooo01Sooooo00@0IVIVoooooooooooooooo0P1VIVI<oooo
o`@0IVIV3?ooool206IVIQOooooo1@1VIVHKooooo`0306IVI_oooooooooo02gooooo000]ooooo`80
IVIV6Oooool206IVIP03ooooo`1VIVH0IVIV00<0IVIV5?ooool00`1VIVKoooooooooo`0Gooooo`D0
IVIVB?ooool506IVIQ;ooooo00<0IVIVooooooooool04Oooool406IVIP?ooooo0P1VIVHJooooo`80
IVIV1Oooool206IVIROooooo000^ooooo`80IVIV5_ooool606IVIQWooooo00<0IVIVooooooooool0
4Oooool506IVIP;ooooo00<0IVIVooooooooool0Aoooool206IVIQOooooo00<0IVIVooooooooool0
3Oooool306IVIPSooooo00<0IVIVooooooooool06Oooool0101VIVKoooooooooooooool206IVIRWo
oooo000`ooooo`0306IVI_oooooooooo01;ooooo0P1VIVH4ooooo`0306IVI_oooooooooo01Sooooo
00<0IVIVooooooooool03_ooool306IVIPKooooo00<0IVIVooooooooool0@oooool406IVIQWooooo
0P1VIVH;ooooo`@0IVIV2oooool00`1VIVKoooooooooo`0Hooooo`@0IVIV:oooool0033ooooo0P1V
IVH>ooooo`D0IVIV1oooool00`1VIVKoooooooooo`0Hooooo`0306IVI_oooooooooo00Wooooo1@1V
IVH9ooooo`80IVIV?oooool406IVIP03ooooo`1VIVH0IVIV01cooooo00<0IVIVooooooooool01?oo
ool406IVIQ3ooooo00<0IVIVooooooooool04oooool406IVIP;ooooo0P1VIVH[ooooo`00<_ooool2
06IVIPSooooo1@1VIVH<ooooo`80IVIV6Oooool00`1VIVKoooooooooo`03ooooo`D0IVIV3oooool2
06IVIScooooo0P1VIVH7ooooo`0306IVI_oooooooooo01[ooooo00<0IVIVooooooooool00`1VIVHE
ooooo`0306IVI_oooooooooo00oooooo0`1VIVH7ooooo`0306IVI_oooooooooo02Wooooo000Hoooo
o`80IVIV6Oooool00`1VIVKoooooooooo`04ooooo`<0IVIV4Oooool00`1VIVKoooooooooo`0Hoooo
o`0306IVI_oooooooooo00<0IVIV5?ooool00`1VIVKoooooooooo`0fooooo`@0IVIV2_ooool00`1V
IVKoooooooooo`0Iooooo`@0IVIV5oooool206IVIPcooooo1@1VIVH9ooooo`80IVIV:_ooool001Wo
oooo0P1VIVHIooooo`H0IVIV5Oooool206IVIQOooooo101VIVHHooooo`80IVIV<_ooool506IVIPko
oooo00<0IVIVooooooooool05?ooool406IVIP;ooooo00<0IVIVooooooooool05oooool206IVIPOo
oooo101VIVH@ooooo`0306IVI_oooooooooo02Oooooo000Kooooo`80IVIV5?ooool606IVIQ[ooooo
00<0IVIVooooooooool04?ooool406IVIP04ooooo`000000000006IVIQWooooo0P1VIVH_ooooo`<0
IVIV4oooool00`1VIVKoooooooooo`0Aooooo`80IVIV1oooool00`1VIVKoooooooooo`0Hooooo`03
06IVI_oooooooooo00;ooooo0P1VIVHEooooo`0306IVI_oooooooooo02Kooooo000Looooo`0306IV
I_oooooooooo013ooooo0`1VIVH5ooooo`0306IVI_oooooooooo01Sooooo00<0IVIVooooooooool0
3?ooool306IVIPGooooo00@0EOl000000?ooool0IVIV6Oooool00`1VIVKoooooooooo`0Zooooo`@0
IVIV5_ooool206IVIPgooooo101VIVH9ooooo`80IVIV6Oooool506IVIQOooooo00<0IVIVoooooooo
ool09_ooool001gooooo0P1VIVH<ooooo`@0IVIV2?ooool306IVIQSooooo0P1VIVH9ooooo`D0IVIV
1oooool01@1Eo`000000ooooooooool0IVIV01Wooooo0P1VIVHWooooo`@0IVIV6_ooool206IVIPOo
oooo1@1VIVH?ooooo`0306IVI_oooooooooo01?ooooo1P1VIVHJooooo`80IVIV9_ooool001kooooo
0P1VIVH7ooooo`@0IVIV3_ooool206IVIQWooooo00@0IVIVoooooooooooooooo1@1VIVH=ooooo`05
05Go0?ooooooooooooooo`1VIVH06Oooool606IVIRKooooo00<0IVIVooooooooool06Oooool00`1V
IVKoooooooooo`03ooooo`80IVIV5?ooool00`1VIVKoooooooooo`0@ooooo`80IVIV1?ooool20000
000306IVI_oooooooooo01Sooooo00<0IVIVooooooooool00oooool206IVIQoooooo000Pooooo`04
06IVI_ooooooooooooooo`<0IVIV4oooool00`1VIVKoooooooooo`0Hooooo`@0IVIV4Oooool00`00
o`3oooooooooo`02ooooo`0306IVI_oooooooooo01Gooooo0`1VIVH[ooooo`0306IVI_oooooooooo
01Sooooo1P1VIVHFooooo`80IVIV3Oooool406IVIPKooooo00@0EOl00000001VIVH0IVIV6_ooool6
06IVIR3ooooo000Pooooo`D0IVIV5_ooool206IVIQGooooo1@1VIVHCooooo`0305Go0?oooooooooo
00?ooooo00<0IVIVooooooooool04?ooool406IVIP?ooooo00<0IVIVooooooooool0:Oooool206IV
IQKooooo1@1VIVHKooooo`0306IVI_oooooooooo00Gooooo1@1VIVH:ooooo`0305Go0?oooooooooo
0080IVIV5_ooool506IVIRCooooo000Mooooo`<0IVIV0_ooool206IVIQSooooo0P1VIVH@ooooo`@0
IVIV1Oooool206IVIQ3ooooo0P1Eo`06ooooo`0306IVI_oooooooooo00[ooooo1@1VIVH8ooooo`03
06IVI_oooooooooo02[ooooo00<0IVIVooooooooool04?ooool306IVIPGooooo00<0IVIVoooooooo
ool06Oooool00`1VIVKoooooooooo`02ooooo`<0IVIV3_ooool00`00o`3oooooooooo`02ooooo`03
06IVI_oooooooooo013ooooo0`1VIVH5ooooo`0306IVI_oooooooooo027ooooo000Tooooo`0306IV
I_oooooooooo01Oooooo00<0IVIVooooooooool02_ooool306IVIP[ooooo00<0IVIVooooooooool0
3_ooool205Go00Oooooo00<0IVIVooooooooool01oooool206IVIPkooooo00<0IVIVooooooooool0
:Oooool206IVIPkooooo101VIVH7ooooo`80IVIV6_ooool506IVIQ7ooooo00<0EOl0ooooooooool0
0_ooool206IVIPgooooo1@1VIVH7ooooo`80IVIV8_ooool002Cooooo0P1VIVHIooooo`0306IVI_oo
oooooooo00Gooooo1@1VIVH=ooooo`0306IVI_oooooooooo00gooooo0P1Eo`08ooooo`0406IVI_oo
ooooooooooooo`D0IVIV4?ooool206IVIR_ooooo0`1VIVH8ooooo`@0IVIV3Oooool206IVIQGooooo
101VIVH00oooool0IVIVooooo`0Booooo`0305Go0?oooooooooo00?ooooo0P1VIVH8ooooo`D0IVIV
3?ooool206IVIR7ooooo000Vooooo`80IVIV6?ooool706IVIQ?ooooo0P1VIVH=ooooo`80EOl02?oo
ool406IVIQOooooo00<0IVIVooooooooool0:_ooool00`1VIVKoooooooooo`04ooooo`80IVIV4_oo
ool00`1VIVKoooooooooo`0Aooooo`80IVIV1_ooool00`1VIVKoooooooooo`0@ooooo`0305Go0?oo
oooooooo00Gooooo00<0IVIVooooooooool00oooool206IVIQ?ooooo00<0IVIVooooooooool07_oo
ool002Oooooo0P1VIVHGooooo`<0IVIV6?ooool00`1VIVKoooooooooo`0;ooooo`800?l01Oooool3
06IVIP;ooooo00<0IVIVooooooooool05oooool00`1VIVKoooooooooo`0Zooooo`0306IVI_ooool0
IVIV00<0IVIV5Oooool00`1VIVKoooooooooo`0<ooooo`@0IVIV2?ooool206IVIQ7ooooo00<0EOl0
ooooooooool01Oooool606IVIQGooooo00<0IVIVooooooooool07_ooool002Sooooo0P1VIVHBoooo
o`D0IVIV00?ooooo06IVIP1VIVH06?ooool00`1VIVKoooooooooo`0:ooooo`80EOl01P1VIVH5oooo
o`0306IVI_oooooooooo01Kooooo0P1VIVHZooooo`@0IVIV6Oooool206IVIPSooooo101VIVH=oooo
o`80IVIV4?ooool00`1Eo`3oooooooooo`02ooooo`D0IVIV6_ooool00`1VIVKoooooooooo`0Moooo
o`00:_ooool206IVIP_ooooo1@1VIVH7ooooo`<0IVIV5oooool206IVIPSooooo0P1VIVH205Go0003
06IVI_oooooooooo00Wooooo00<0IVIVooooooooool05oooool00`1VIVKoooooooooo`0Zooooo`80
IVIV6Oooool206IVIPCooooo0`1VIVHCooooo`0306IVI_oooooooooo00gooooo00<00?l0oooooooo
ool00`1VIVH4ooooo`0306IVI_oooooooooo01Sooooo00<0IVIVooooooooool00oooool206IVIQOo
oooo000[ooooo`0306IVI_oooooooooo00Oooooo0`1VIVH=ooooo`0306IVI_oooooooooo01Oooooo
00<0IVIVooooooooool00_ooool306IVIP;ooooo0P1Eo`0=ooooo`0306IVI_oooooooooo01Oooooo
00<0IVIVooooooooool00`1VIVHWooooo`80IVIV6Oooool606IVIQGooooo0P1VIVH=ooooo`0406IV
IP1Eo`00IVIV06IVIPSooooo00<0IVIVooooooooool06?ooool506IVIQWooooo000/ooooo`80IVIV
0oooool406IVIQ7ooooo00<0IVIVooooooooool05_ooool606IVIP?ooooo0P1Eo`000`00o`3ooooo
ooooo`0<ooooo`0306IVI_oooooooooo01Gooooo1@1VIVH[ooooo`0306IVI_oooooooooo01?ooooo
1P1VIVHIooooo`80IVIV1oooool506IVIP80EOl02oooool00`1VIVKoooooooooo`0Cooooo`H0IVIV
7?ooool002gooooo101VIVHFooooo`80IVIV4_ooool506IVIP03ooooo`1VIVKooooo00Gooooo0P1E
o`0@ooooo`0306IVI_oooooooooo00oooooo1@1VIVH3ooooo`0306IVI_oooooooooo02_ooooo00<0
IVIVooooooooool04?ooool306IVIPGooooo00<0IVIVooooooooool06?ooool00`1VIVKooooooooo
o`02ooooo`<0IVIV1?ooool205Go00cooooo00<0IVIVooooooooool04?ooool206IVIPGooooo00<0
IVIVooooooooool06_ooool002[ooooo0`1VIVH2ooooo`0306IVI_oooooooooo01Kooooo0P1VIVH?
ooooo`<0IVIV1_ooool00`1VIVKoooooooooo`03ooooo`800?l04Oooool00`1VIVKoooooooooo`0;
ooooo`<0IVIV=_ooool306IVIPcooooo101VIVH8ooooo`80IVIV6Oooool506IVIPOooooo0P1Eo`0=
ooooo`0306IVI_oooooooooo00[ooooo1P1VIVH7ooooo`80IVIV6_ooool002Wooooo0P1VIVH5oooo
o`0306IVI_oooooooooo01Kooooo0P1VIVH9ooooo`D0IVIV2Oooool206IVIPCooooo0P1Eo`0Boooo
o`0306IVI_oooooooooo00Kooooo1@1VIVHjooooo`80IVIV1oooool406IVIPkooooo00<0IVIVoooo
ooooool04oooool606IVIPWooooo0P1Eo`0>ooooo`0306IVI_oooooooooo00Gooooo1@1VIVH=oooo
o`80IVIV6Oooool0037ooooo0P1VIVHHooooo`0406IVI_ooooooooooooooo`H0IVIV3oooool206IV
IP;ooooo00<0EOl0ooooooooool04_ooool00`1VIVKoooooooooo`0506IVIT3ooooo00<0IVIVoooo
ooooool00oooool206IVIQ?ooooo00<0IVIVooooooooool03oooool306IVIPKooooo00<0IVIVoooo
ooooool01_ooool00`00o`3oooooooooo`0>ooooo`0306IVI_oooooooooo00;ooooo0`1VIVHBoooo
o`0306IVI_oooooooooo01Oooooo000cooooo`0306IVI_oooooooooo01Kooooo00@0IVIVooooo`1V
IVH0IVIV5Oooool0101VIVKoooooooooo`1Eo`0Dooooo`<0IVIVA_ooool506IVIQKooooo0P1VIVH;
ooooo`D0IVIV2?ooool206IVIPOooooo00<0EOl0ooooooooool03oooool406IVIRoooooo000coooo
o`80IVIV5?ooool606IVIQOooooo0P1VIVH00`1Eo`3oooooooooo`0>ooooo`D0IVIV00?ooooo06IV
I_ooool0A?ooool206IVIP03ooooo`1VIVKooooo01Sooooo0P1VIVH6ooooo`D0IVIV3Oooool206IV
IP;ooooo1@00000<ooooo`D0IVIV00?ooooo06IVI_ooool0<?ooool003Gooooo0P1VIVH=ooooo`D0
IVIV1Oooool206IVIQOooooo00<0EOl000000?ooool02_ooool506IVIU3ooooo00<0IVIVoooooooo
ool05oooool00`1VIVKoooooooooo`02ooooo`80IVIV5?ooool01P1VIVKoooooooooooooool00000
05Go00<000002?ooool206IVIPOooooo00<0IVIVooooooooool0;_ooool003Kooooo00<0IVIVoooo
ooooool02Oooool206IVIP_ooooo00<0IVIVooooooooool04oooool4000000Sooooo0`1VIVIFoooo
o`80IVIV5oooool506IVIQKooooo0P1VIVH2ooooo`80EOl010000002ooooo`D0IVIV2_ooool00`1V
IVKoooooooooo`0]ooooo`00=oooool206IVIPCooooo1@1VIVH>ooooo`80IVIV5?ooool00`00o`00
EOl000000002000000;ooooo1@1VIVIIooooo`80IVIV4_ooool506IVIP03ooooo`1VIVH0IVIV01So
oooo0P1VIVH405Go0080000000@0IVIV0000001VIVH0IVIV3oooool00`1VIVKoooooooooo`0/oooo
o`00>Oooool506IVIQCooooo00<0IVIVooooooooool04?ooool01P00o`00EOl005Go001Eo`00IVIV
00000080IVIVH?ooool00`1VIVKoooooooooo`0=ooooo`<0IVIV1oooool00`1VIVKoooooooooo`0G
ooooo`@00?l000<0IVIVooooooooool0@Oooool003Kooooo0`1VIVH00oooool0IVIVooooo`0Goooo
o`0306IVI_oooooooooo00oooooo101Eo`02ooooo`0306IVI_oooooooooo05oooooo0P1VIVH:oooo
o`@0IVIV2oooool00`1VIVKoooooooooo`0Dooooo`0306IVIP00o`00EOl000@0EOl0@oooool003Go
oooo0P1VIVH4ooooo`80IVIV5oooool206IVIP[ooooo101VIVH605Go06Cooooo0`1VIVH3ooooo`D0
IVIV4?ooool00`1VIVKoooooooooo`0?ooooo`@0IVIV00L00?l005Go001Eo`00EOl006IVI_ooool0
EOl004?ooooo000looooo`80IVIV5oooool206IVIPCooooo1@1VIVH4ooooo`H0EOl0I_ooool00`1V
IVKooooo06IVIP0206IVIQGooooo00<0IVIVooooooooool03?ooool206IVIPCooooo0P1Eo`001Ooo
ool0EOl0ooooo`1VIVH0EOl004?ooooo000nooooo`0306IVI_oooooooooo01Gooooo00<0IVIVoooo
ooooool00`1VIVH7ooooo`@00?l000?ooooo003o0000o`00IOooool306IVIQWooooo00<0IVIVoooo
ooooool01_ooool506IVIPGooooo0P1Eo`001Oooool0EOl005Go0?ooool0IVIV0080EOl0@_ooool0
03oooooo00<0IVIVooooooooool04_ooool506IVIPWooooo1@1Eo`001?ooool0EOl005Go001Eo`1W
ooooo`80IVIV6?ooool206IVIP;ooooo101VIVH9ooooo`80EOl000@00?l0ooooo`1Eo`00EOl00_oo
ool205Go04;ooooo0010ooooo`80IVIV3Oooool606IVIP?ooooo00<0IVIVooooooooool01_ooool0
1000o`00EOl005Go0?ooool205Go00;ooooo0P1Eo`1Yooooo`0306IVI_oooooooooo01Oooooo0P1V
IVH<ooooo`<00?l00_ooool2003o00;ooooo0P00o`12ooooo`00@_ooool00`1VIVKoooooooooo`08
ooooo`<0IVIV4Oooool205Go00;ooooo00@0EOl0oooooooooooooooo0P1Eo`1Yooooo`80IVIV4ooo
ool706IVIPcooooo0P1Eo`03ooooo`0405Go0?ooool00000000000<0EOl0@Oooool004;ooooo0P1V
IVH4ooooo`D0IVIV4oooool205Go00;ooooo00<0000005Go0?ooool00oooool00`1Eo`3ooooooooo
o`1Yooooo`0306IVI_oooooooooo00cooooo1@1VIVH5ooooo`80IVIV2_ooool01P00o`00EOl00000
00000000ZUEE05Go0080000000<0ZUFZ0000000000000P1Eo`11ooooo`00A?ooool00`1VIVKooooo
06IVIP0206IVIQKooooo0`00o`001?ooool0000000000000o`04ooooo`03003o0?oooooooooo06[o
oooo00<0IVIVooooooooool02Oooool206IVIPcooooo00<0IVIVooooooooool01oooool205Go0004
0000001E05D0g=cL0:X000<0000000@0UIFE00000?ooool0EOl0@Oooool0047ooooo1@1VIVHIoooo
o`80EOl00_ooool010000000EJZZ000000000003ooooo`80EOl0K?ooool206IVIPCooooo1@1VIVH>
ooooo`80IVIV1oooool0101Eo`0000000000003/k>`800000003ooooo`1Eo`3ooooo043ooooo0010
ooooo`0306IVI_oooooooooo00?ooooo00<0IVIVooooooooool05Oooool00`00o`00000000000005
0000000405FZZP00003oooooooooo`80EOl0KOooool506IVIQ_ooooo0`0000030>c/k0030000003o
ZZX0000000@0000000?ooooo05Go001Eo`00@?ooool005kooooo0P1Eo`02ooooo`030000002ZojX0
00000080000000<0EEGo00000?ooool00P1Eo`1]ooooo`<0IVIV7Oooool00`000000g=cL0>c/k002
0>c/k0060=cLg0000000ojZZ0?nZZP000000ZUFZ0P0000000oooool00?l0003o0010ooooo`00GOoo
ool205Go0003003o0?ooool0000000L0000000?ooooo05Go001Eo`00L?ooool00`1VIVKooooooooo
o`0Iooooo`03003o00000000000000<0000000Cooooo0000003oZZX000000_ooool01P00003ooooo
ooooo`000000EOl0000003oooooo001Looooo`80EOl000D00?l0ooooo`00000000000?ooZP050000
00?ooooo00<0EOl0ooooooooool0Koooool00`1VIVKoooooooooo`0Hooooo`80EOl01Oooool20000
00Kooooo00@0000005Go001VIYT00000?_ooool005cooooo0P00o`000oooool000000?ooZP02oooo
o`<0000000<0VC?<00000?ooool00_ooool00`00o`3oooooooooo`1`ooooo`0306IVI_oooooooooo
01Oooooo00<0EOl0ooooooooool03?ooool305Go03oooooo001Looooo`0405Go0?ooool000000000
00;ooooo1P000002ooooo`80000000<0EOl0ooooooooool0L?ooool00`1VIVKoooooooooo`0Eoooo
o`80EOl03_ooool305Go03oooooo001Kooooo`80EOl01_ooool2000000Gooooo0P0000000`1Eo`00
0000ooooo`27ooooo`0305Go000000000?l000kooooo0`1Eo`03000003cooooo001Kooooo`0305Go
0?oooooooooo00gooooo0P1Eo`000`00003oooooooooo`26ooooo`03003o0000003ooooo00kooooo
0`00o`0010000000<fKo03=Vo`00000kooooo`00FOooool305Go00kooooo0`1Eo`02000008Gooooo
00<00?l005Go001Eo`004?ooool01P1Eo`3ooooo05Go0000000009W<03=Vo`800000>_ooool005Wo
oooo0P1Eo`0?ooooo`@0EOl000<00000ooooooooool0P_ooool405Go00oooooo0P1Eo`001_ooool0
EOl005Go0000VL`0<fKo002Ic0800000>Oooool005Sooooo00<00000003o000000003oooool5003o
08?ooooo1@1Eo`0>ooooo`<0EOl00_ooool00`1Eo`0009W<05EEZP03002Ic0D00000=?ooool005So
oooo0P0000000`1EEJX00000ooooo`0<ooooo`80EOl000?ooooo05Go000000000`000021ooooo`@0
EOl000<00?l0ooooooooool02oooool20000000405Go0?ooooooooooooooo`80EOl000<0<fKo002I
c00000000`0000000`2IVIT0EJ[o05FZo`02000003;ooooo001Fooooo`04003o001Eo`00EOl005Go
00kooooo00H00?l005Go001Eo`3ooooo05Go0000000305FZo`<00000OOooool505Go00cooooo1P00
000205iNGP03003o001Eo`000000008000000P00VL`2000000<0EJ[o00<00000ooooooooool0<?oo
ool005Kooooo101Eo`0>ooooo`80EOl00oooool00`1Eo`00EJZZ03=Vo`0405FZZP0300000?oooooo
oooo07Wooooo1P00o`0=ooooo`<0000000@0ZP1E069RHP1RHV80HV9R1P00000303=Vo`040000002I
<l`0VC?<000003;ooooo001Eooooo`@0EOl03_ooool205Go0005003o0?ooooooooooooooo`1Eo`00
101EZ_l0101EZZX0EJ[o00000000001iooooo`@0EOl000?ooooo05Go001Eo`003_ooool300000080
HV9R1P0000001000VL`000000000000cI_l200000080EJ[o00<00000ooooooooool0;oooool005Co
oooo1@1Eo`0;ooooo`<000000P1Eo`04ooooo`03003o001EZ_l0EJ[o0080EJ[o00<0EJZZ00000000
00000`00001eooooo`04003o001Eo`00EOl0ooooo`80EOl000<00?l005Go001Eo`003?ooool01000
o`00EOl005Go001Eo`0300000080HV9R0`00000205FZo`H0000000<0EJ[o00000?ooool0<?ooool0
05Cooooo1@00o`0:ooooo`030000002Z0000000000800?l00`2Z00000`1E003ooooo000000050000
00@0EJ[o0P00001cooooo`<0EOl000Cooooo05Go001Eo`3ooooo0P1Eo`0=ooooo`80EOl000@00000
05Go001Eo`0000000`1NGUh2000000030?nZZP000000EJ[o0080EJ[o00H0VIVI0000000000000000
05FZo`00000aooooo`00D_ooool00`00o`00EOl005Go000405Go00[ooooo0`0000000`1Eo`000000
000000020000000305EE00000000000000H00000101EZ_l00`1EZZX000000000001`ooooo`80EOl0
00<00?l0ooooo`1Eo`000P1Eo`000oooool0EOl005Go000<ooooo`@0EOl000@0000005Go00000000
00000P1RHV82000000030?nZZP000000EJ[o0080EJ[o00<0VIVI0000000000000`00000aooooo`00
DOooool00`00o`00EOl005Go000405Go00Cooooo2@0000001@2ZZ_l000000000001EE@00ZP0000@0
EED01@0000000`2ZEOl000000000000200000080EJZZ0P00001^ooooo`80EOl000D00?l000000000
0000EOl000000002ooooo`80EOl02_ooool200000080EOl000@00?l0000000000000EOl01@000000
103<VL`000000?nZZP00000205FZo`0509VIV@1EZ_l0EJ[o05FZo`000000<_ooool0057ooooo0P1E
o`000oooool0EOl0ooooo`0205Go00Oooooo0P00000306K<o`0405Go0000003oooooooooo`800000
0`1EE@0010000000c<c<0000000000020:YEo`040000002ZEOl0SHf=0:YEo`<0000000<0EJZZ0000
00000000Joooool305Go0003003o0?ooool0000000@0000000?ooooo05Go0000o`001Oooool30000
00;ooooo0`0000001@1Eo`000000000000000000EOl0008000000`3oZZX01`3<VL`0000005Go001E
o`00000005FZo`2IVIT00`1EZ_l00`00003oooooooooo`0`ooooo`00Coooool605Go0003ooooo`1E
o`3ooooo00Wooooo00@0000005Go001Eo`00EOl02@000000103oZZX000000000000000020:YEo`03
0000002ZEJX0ZUGo00<0ZUGo1000001Zooooo`800?l01?ooool3000000;ooooo00<00?l0oooooooo
ool01?ooool010000000ATI604I6AP3<<`02003o008005FZ00L0000009Tcc02ZEJX00000ooooo`00
o`00000000@0c9W<00H00000003o0000o`00000009Tcc03<VL`309Tcc00300000?oooooooooo033o
oooo001>ooooo`80EOl000D00?l005Go001Eo`000?l0ooooo`0205Go00[ooooo101Eo`0400000004
0:ZZo`0000000000000000<0ojZZ0`0000020:YEo`030:YEZP000000ZUGo00<0ZUGo00<0ZUFZ0000
00000000IOooool300000003ooooo`1Eo`00EOl000Gooooo0`000002ooooo`0305Go0?oooooooooo
00Gooooo00<0000006IV<`0000001@0000020:f][@<0000000H0EOl0000000000000ojZZ0<bIc000
000305Go00030000002IVIT0EJ[o0080EJ[o00<00000ooooooooool0<?ooool004kooooo0P00o`00
0oooool00?l0003o0002ooooo`800?l02Oooool5003o0080000000Kooooo00000000000000000:ZZ
o`0000030?nZZP030000003oZZX000000080EEGo00<0ZUFZ05EEo`0000000`1EEOl00`2ZEJX0EEGo
0000001Qooooo`H0000000@00?l005Go001Eo`00EOl02Oooool205Go00Sooooo00<0000006IV<`1V
IS<01@0000020:f][@D0000000<0ojZZ0<bIc00000000P3oZZX40000000305FZo`000000000003;o
oooo001<ooooo`80EOl000<00000ooooooooool00P1Eo`02ooooo`80EOl01oooool00`00o`00EOl0
05Go000205Go00<000000_ooool600000080ojZZ00H000000?nZZP3<c<`000000:YEo`2ZEJX20:YE
o`80000000@0ZUGo0:YEZP2ZEOl00000I?ooool200000080EOl00`000009ooooo`80EOl02?ooool2
00000080IVHc0`0000001000EED000000:f][@2ATI42000000050?nZZP000000ojZZ0;Fe]@000000
0P3oZZX00`00ZZX000000;Fe]@02000003Cooooo001;ooooo`80EOl000?ooooo0000M`0000000P1E
o`02ooooo`0309Tcc01Eo`00000000@000000_ooool01000o`00EOl005Go0000o`0205Go0004oooo
o`000000EOl0ooooo`80000000Cooooo000000000000c<c<0`3oZZX00`000000ojZZ0<c<c0020000
00030:YEZP2ZEOl0ZUGo0080ZUGo00@000000:YEZP2ZEOl00000Hoooool405Go00L000001_ooool2
05Go00Oooooo0P0000000`2ZojX0000000000006000000030:YEZP000000ojZZ00<0ojZZ00H0c9W<
0000003oZZX0ojZZ0000001Eo`03000003Cooooo0014ooooo`D0000000?ooooo05Go001Eo`000_oo
ool20000000405Go002MWId0WIfM06K<o`H0WIfM00<0I/co0000001Eo`001@1Eo`02ooooo`040000
001Eo`3ooooo000000;ooooo00<000000<c<c03ool`0103<c<`200000003ooooo`000000SHf=00<0
ZUGo1000001Rooooo`H0EOl000D00?l00000000000000000ooooo`03000000Gooooo0P1Eo`05oooo
o`8000000P2ZojX01?ooool000000000003oZZX2000000030:f][@000000000000800000103oZZX0
0`3<VL`00000000000020?nZZP<0EOl0=Oooool004?ooooo00<000000:X0003<<`000`3<<`0205Go
0080000000<0c3<00000000000000`0000000`1Vc?l0ZZ[o0:ZZo`040:ZZo`0306K<o`0000000000
0080000000<0EOl0003o0?ooool010000004ooooo`030000003oZZX0c<c<00<0ojZZ0P000002oooo
o`80000000<0ZUGo05EEo`2ZEOl01000001Pooooo`P00?l00_ooool2000000Wooooo0P00o`04oooo
o`040000002ZojX00?l00:[oZP;ooooo00H000000?nZZP3oZZX000000?nZZP0000020:YEZP030000
003<VL`0c9W<00D0c9W<0`000004003o03Cooooo0012ooooo`@0000000D0c3<00000001Eo`00EOl0
000000040<`c00L000000`2ZZ_l300000005003o0000000000000000002MWId0102UYJD2000000?o
oooo00@000000?nZZP3<c<`0ojZZ0P000006ooooo`030000002ZEOl0ZUGo0080ZUGo00<0ZUFZ0000
0?ooool0G?ooool2003o00H0EOl000<00?l005Go0?ooool00oooool00`00003oooooooooo`07oooo
o`80EOl01?ooool20000000505Go0000003oooooooooo`0000000P3oZZX01@000000ojZZ00000000
0000[Jf]00800000103oZZX00`3<VL`0000000000002ooooo`@0EOl000<00?l0ooooooooool0<Ooo
ool004;ooooo00<000000:ZZo`1EZ_l00`0000000`00o`00E@0005D0000305D000030000003oZZX0
000000<0000000<0ZZ[o0000000000000P2ZZ_l01@000000ZUD00:YE00000000E@1E00<000001@2M
WId01000003oooooooooo`0000020?nZZP030<c<c03oZZX0000000Oooooo00<0000005EEo`1EEOl0
0P1EEOl00`2ZEJX00?l0003o001Kooooo`@0EOl000D00?l005Go001Eo`00EOl0003o000205Go00ko
oooo00<0EOl0ooooooooool00oooool205Go00Cooooo00<000000?nZZP3oZZX0200000020?nZZP80
00001?ooool605Go03;ooooo0013ooooo`@0000000<0EOl00000000000001@0000020?nZZP@00000
00<0ZZ[o0000000000000`1Eo`000`000000ZUEE0000000600000080YJFU00@0WIfM00000?ooool0
00000P3oZZX2000000Wooooo0P0000020:YEo`040:YEZP000000EOl005Go00800?l0E_ooool305Go
00?ooooo0P1Eo`02ooooo`80EOl03oooool00`1Eo`3oooooooooo`02ooooo`80EOl01Oooool01000
0000c9VI0;Fe]@000003ooooo`0300000?oooooooooo00@000001Oooool205Go00030000001Eo`3o
oooo00<0EOl0<?ooool004?ooooo00@00?l005Go001Eo`0000000_ooool2000000030:[oZP000000
000000<0ojZZ00<000000?nZZP0000000`000000101Eo`0000000000001Vc?l2000000050:f][@00
000000000000002UYJD01@000002ooooo`<000003?ooool4000000D0EOl000<00?l0ooooooooool0
D?ooool405Go00800?l000Cooooo05Go001Eo`00EOl00_ooool205Go0003003o0?oooooooooo00[o
oooo0`0000000`1Eo`000000000000020000000305Go0000o`3ooooo00Cooooo1000000?ooooo`80
EOl000<0000005Go001Eo`000P00o`0205Go02oooooo0012ooooo`@0EOl00P0000000oooool00000
0?ooZP02ooooo`050000003Lg=`0g=cL0<c<c00000000P3Lg=`30000000405Go00000000000006K<
o`80000000D0ojZZ0000002][Jd0[Jf]000000020:FUY@8000005oooool00`1Eo`3oooooooooo`03
05Go053ooooo0P1Eo`02003o00;ooooo0`1Eo`000`00o`3oooooooooo`0205Go013ooooo0P1Eo`03
0000000305Go00000000000001Sooooo0P1Eo`001?ooool0EOl005Go001Eo`02ooooo`<0EOl0;Ooo
ool003oooooo1P1Eo`000`000000ZZ[o00000002000000;ooooo00<000000=cLg03oZZX00P3oZZX0
10000000ojZZ0=cLg000000205Go00H0000000@0[Jf]0000002][Jd0[Jf]0P0000020:FUY@800000
5_ooool205Go00;ooooo00@00?l005Go001Eo`00EOl0Boooool400000003003o0?oooooooooo0080
00000P00o`04ooooo`800?l04?ooool3003o0004ooooo`00o`000?l0000001Wooooo0P00o`02oooo
o`800?l00oooool2003o02gooooo000looooo`T0EOl010000003ooooo`030000003Lg=`0ojZZ00<0
ojZZ00@000000=cLg01Eo`00EOl00`0000001P2ZZ_l0I/co000000000000[Jf]000000<0[Jf]1@00
000Fooooo`04003o001Eo`00EOl005Go00;ooooo0P00o`1:ooooo`8000000`2Z000400000080EOl0
00H0TI6A00000?ooool0000005Go0000000Aooooo`<0EOl000@00?l005Go0000000000006Oooool2
05Go00;ooooo0P1Eo`03ooooo`<0EOl000<00?l0ooooooooool0:Oooool003_ooooo0`00o`02oooo
o`@00?l000Gooooo00000000003ooooo00000002ooooo`030000003oZZX0_Kfm00@0ojZZ00X00000
003o0000o`000000ooooo`000000VC?<0000002I<l`000000P2][Jd01`000000[Jf]0:f][@2][Jd0
0000ooooo`0000006_ooool2003o04gooooo00<00?l005Go001Eo`002@0000001@2ZEJX0EEFZ0000
00000000EOl0008000003oooool605Go000300000?oooooooooo01Sooooo0P1Eo`03ooooo`80EOl0
0`0000001Oooool0EOl005Go001Eo`00000002Wooooo000iooooo`@0EOl000Oooooo003o001Eo`00
EOl0ooooo`1Eo`00000000;ooooo00<00000ooooo`0000000_ooool00`000000ojZZ0=cLg0030?nZ
ZP04003o001Eo`00EOl005Go00?ooooo100000030:f][@040000002][Jd00000000001gooooo0P1E
o`19ooooo`8000000`1Eo`04ooooo`050000002Zoj[ooooo0000003oI/`00P000000101EEJX0EOl0
05Go003oI/`2000000kooooo201Eo`0Jooooo`80EOl01?ooool01`1Eo`00000003=Vo`0cI_l00000
ooooo`0000000P1Eo`0Yooooo`00=_ooool01000o`00EOl005Go001Eo`02ooooo`07003o001Eo`00
EOl005Go0?ooool00?l005Go0008ooooo`030000003oZZX0g=cL0080ojZZ00<00?l005Go00000000
0P1Eo`04ooooo`030000000007L0000000<0[Jf]0`00000Nooooo`<0EOl0AOooool600000004003o
0?ooooooooooooooo`80000000`0EJZZooooooooool000000;fm_@3oZZX0000005EEZP1Eo`000000
0;fm_@00000?ooooo`L0EOl000<00000ooooooooool07_ooool205Go0080EJZZ0`0000001?ooool0
EOl005Go001Eo`0Wooooo`00=Oooool305Go00Cooooo0P1Eo`03ooooo`80EOl01oooool00`000000
g=cL0=cLg0020=cLg0040000001Eo`00000000000080EOl01_ooool01@000000[Jf]0?nZZP2][Jd0
000002;ooooo0P1Eo`14ooooo`@0EOl00`0000001Oooool000000000002Ic9T0000000?ooooo00@0
00000;fm_@3oZZX000000P1Eo`000`000000_Kfm0000000?ooooo`L0EOl08Oooool00`000000EOl0
00000004000000;ooooo00@00?l005Go001Eo`00EOl09Oooool003;ooooo101Eo`001000o`3ooooo
ooooooooool305Go00?ooooo0`1Eo`07ooooo`040000003oZZX0ojZZ0=cLg080EOl000D00?l00000
00000000EOl000000006ooooo`040000002][Jd0[Jf]000002?ooooo00H00?l005Go000000000000
ooooo`3<VL`4000003_ooooo1000o`02000000040:ZZo`00003ooooo000000Gooooo00@000000?nZ
ZP2m_Kd0ojZZ0`00o`020000013ooooo1`00o`0Mooooo`<000000P2Z0002000000030:YEo`1EEJX0
0000008000000oooool2003o02Gooooo000`ooooo`0400000000o`000?l0003o00;ooooo00<00000
ooooooooool00`00o`04ooooo`800?l02Oooool2000000<00?l00oooool2003o000300000?oooooo
oooo00?ooooo0`00000Qooooo`D0000000<00?l00000001EZ_l00`1EZ_l00`2=SHd00000ooooo`0h
ooooo`03003o001Eo`00EOl000<0EOl000<00000ooooooooool00P000006ooooo`050000003oZZX0
_Kfm0?nZZP1Eo`000`00000@ooooo`03003o001Eo`000?l00080EOl000?ooooo05Go001Eo`007Ooo
ool4000000030:X0E@000000000000H000000oooool205Go00800?l08_ooool002kooooo0P00o`02
05Go00<0000000Cooooo0000000000000?l00P1Eo`0Aooooo`<0EOl00oooool305Go008000001Ooo
ool00`00003oooooooooo`0Tooooo`L0000000<0SHf=00000?ooool0=_ooool01@00o`00EOl005Go
001Eo`000?l00080EOl03?ooool00`000000ojZZ0;fm_@0205Go000305EEZP2ZEJX00000013ooooo
1@1Eo`000oooool0EOl005Go000Pooooo`D0000000@0EJ[o000000000000EEGo0P000003ooooo`<0
EOl000<00?l0ooooooooool07oooool002cooooo00<00?l005Go001Eo`000`000002ooooo`040000
0?ooool0000000000080EOl04?ooool00`00o`00EOl005Go0004ooooo`04003o001Eo`00EOl005Go
00@00000:Oooool70000000305FZo`000000000003Kooooo0`1Eo`02ooooo`80EOl03?ooool02@00
0000b<S80<S8b03oI/`0EOl00000001EEJX0ZUFZ0000000@ooooo`80EOl000Cooooo05Go001Eo`3o
oooo0P1Eo`0Pooooo`@0000000L0c9VI0000001EZ_l0000007inOP1EZ_l0000000Gooooo0`1Eo`0P
ooooo`00:oooool305Go00050000002Z0000ZP000:X0001E00000P2Z0006000000gooooo0P000000
0`1Eo`000000ooooo`04ooooo`@0EOl000@00000ooooooooool00000:?ooool3000000030?nZo`00
0000oj[o00<0000000<0OWin00000?ooool0<_ooool405Go0003003o0?ooool0EOl00080EOl03Ooo
ool00`000000ojZZ0?nZZP0205Go0004ooooo`0000000000000000kooooo0`000000101Eo`3ooooo
05Go001Eo`02ooooo`0305Go0?oooooooooo01kooooo0P0000001P3<VIT000000<bIV@2ZEOl00000
05FZo`<000001_ooool01@00o`00EOl005Go001Eo`00000001gooooo000Yooooo`<0EOl000@00?l0
ooooo`000000ZP00100000000`2Z0000000000000005000000cooooo1@000004ooooo`@0EOl000<0
0000ooooooooool0:?ooool200000003ooooo`000000oj[o00L00000<_ooool205Go00800?l00_oo
ool205Go0003003o0?oooooooooo00cooooo0`0000000`1Eo`000000ooooo`0>ooooo`L0000000?o
oooo0000001Eo`000_ooool00`1Eo`3oooooooooo`0Mooooo`<000000P3<VIT30000000305FZo`1E
EOl0000000Sooooo0P000000101Eo`00000000000000000Kooooo`009Oooool505Go0003003o0?oo
oooooooo00Cooooo100000000`3De=@0000000000004000000cooooo0P0000000`2YZJT000000000
0002ooooo`D0EOl000?ooooo05Go0?ooool0:oooool00`000000oj[o0?nZo`02000003Gooooo0P00
o`02000000Cooooo0P00o`0@ooooo`@000004Oooool600000004003o0000003oooooooooo`800?l0
00?ooooo0000000000007Oooool010000000^KVi0<bIc0000002ooooo`030000001EEOl0000000[o
oooo0`00000Looooo`009?ooool4003o00[ooooo0P0000000`3De=@00000000000040000000309Tc
c000003ooooo00[ooooo0P0000000`2YZJT00000ooooo`02ooooo`800?l000Cooooo003o0000o`3o
oooo0P00o`0[ooooo`<00000=Oooool00`000000EOl005Go000205Go000305FZo`000000000000;o
oooo00<0EOl0ooooooooool03_ooool5000001;ooooo2@00000205Go00030:YEo`1EZ_l0EJ[o00<0
00006_ooool00`000000c9VI00000004ooooo`8000002Oooool4000001cooooo000Qooooo`800?l0
0`1Eo`0;ooooo`D0000000<0oj[o0000000000001000000<ooooo`<000000oooool205Go0004oooo
o`1Eo`00EOl0ooooo`80EOl0H_ooool60000000305FZo`000000000001Gooooo00<00000ooooo`00
00004Oooool2000000040:FUY@000000000006IV<`D0000000<0EOl00:YEo`1EZ_l00`1EZ_l00`00
003oooooooooo`0Iooooo`0300000?oooooooooo02kooooo000Nooooo`03003o001Eo`00EOl000<0
EOl02oooool3000000040?ooZP3De=@000000?nZo`80000000Cooooo00000000000000004_ooool0
1000o`00EOl0ooooooooool205Go0003ooooo`1Eo`00EOl006?ooooo1@00000208f=S@0300000?oo
oooooooo02Oooooo0P000000103oZZX000000000002Z00030000000408f=S@000000EOl0000000D0
SHf=00<00000ooooooooool0BOooool001gooooo0`1Eo`0?ooooo`@000000_ooool2000000?ooooo
0P00000Booooo`80EOl00_ooool205Go00;ooooo00<0EOl0ooooooooool0H?ooool9000002Sooooo
1P000000101VIS<000000000003<VIT20000000405Go002ZEOl00000000000<0EJ[o00<0ZUGo0000
0?ooool0BOooool001_ooooo0P000000101Eo`00000000000000000>ooooo`0300000?oooooooooo
01cooooo0P1Eo`02ooooo`80EOl00_ooool205Go067ooooo1000000]ooooo`0300000?ooool0EOl0
00@0000000@0c9VI000000000000c9VI0`0000001`1EZ_l00000000000000000EJ[o0:YEo`000000
B_ooool001[ooooo1@0000000`1EZ_l00000ooooo`0[ooooo`80EOl00oooool205Go00;ooooo00<0
0?l005Go001Eo`00Toooool300000008ooooo`000000c9VI0<bIV@000000c9VI00000000VL`20000
0080EJ[o0P0000000`2ZEOl00000ooooo`19ooooo`007?ooool5000002_ooooo0`00o`03ooooo`80
0?l00oooool2003o097ooooo100000000oooool000000<bIc0020<bIV@050000003<VIT000000000
0000o`000P00000205FZo`<00000B_ooool001cooooo0P00000^ooooo`80EOl01?ooool00`000000
EOl0ooooo`02ooooo`80EOl0T_ooool00`1Eo`00000000000002000000040<bIc03<VIT0c9VI0000
0080c9VI0P1Eo`000`000000EJ[o05FZo`0205FZo`0300000?oooooooooo04Wooooo001;ooooo`03
0000001Eo`00000000Cooooo00@0000005Go0000003ooooo0P0000000`1Eo`000?l0ooooo`2@oooo
o`80EOl000<0_Kfm0000000000000`3oI/`00`000000]KFe0000000205Go008000000`2=SHd00`00
003oooooooooo`19ooooo`00C?ooool00`1Eo`000000ooooo`03ooooo`<000000`2MWId00`1Eo`00
0000ooooo`2@ooooo`80EOl00`0000000`3<VL`0c9VI0000000200000004ooooo`1Eo`00EOl005Go
0080000000<0EJ[o000000000000Boooool004_ooooo00<0EOl00000000000000P0000000`2ZEED0
IVHc000000040000000409fMW@1Eo`0000000000093ooooo0`1Eo`05000000;ooooo101Eo`000`00
003ooooo0000001=ooooo`00Boooool00`1Eo`0000000000000206IV<`060:YEE@00000000000?nZ
ZP000000WIfM0P00000205Go000303=Vo`00003ooooo08kooooo0`00o`000`00003oooooooooo`04
ooooo`@00?l000<00000ooooooooool0COooool004[ooooo0P00o`000`000000VC>I0:YEE@020:YE
E@80000000T0ojZZ000000000000VC?<0<bIc00000000?l009Tcc0000000S_ooool205Go0003oooo
o`1Eo`00EOl000Kooooo00<0EOl0ooooo`1Eo`000P1Eo`1?ooooo`00BOooool305Go00030000001V
IS<0IVHc0080000000<0IVHc0000003oZZX00P00000209fMW@040000001Eo`000000000008kooooo
0P1Eo`000oooool0EOl005Go0005ooooo`80EOl000?ooooo05Go001Eo`000P1Eo`000`00o`3ooooo
ooooo`1;ooooo`00BOooool205Go0003ooooo`00000000000080000000@0ZUEE06IV<`000000ojZZ
0`00000209fMW@80EOl0S_ooool305Go0003ooooo`1Eo`00EOl000Gooooo0P1Eo`02ooooo`0405Go
0?ooool0EOl005Go04gooooo0019ooooo`0305Go0?ooool000000080_Kfm00H0000006IV<`2ZEED0
00000?nZZP000002ooooo`030000002MWId0WIfM0080EOl000<00000ooooooooool0Roooool205Go
00?ooooo00<00?l0ooooooooool00oooool205Go00;ooooo00@0EOl0ooooo`00o`00EOl0COooool0
04Sooooo0P1Eo`0200000080Z_nZ0P0000000`2ZEED0000000000004ooooo`80000000<00?l005Go
001Eo`00SOooool00`1Eo`000?l0ooooo`07ooooo`80EOl000<00?l0ooooooooool00P1Eo`000ooo
ool00?l0ooooo`1<ooooo`00Aoooool205Go00040000003oojX0Z_nZ0:[oZP;ooooo0`000007oooo
o`030000001Eo`00EOl008gooooo00<00?l0ooooooooool01oooool2003o00?ooooo0P00o`1?oooo
o`00Aoooool00`00o`00000000000002000000oooooo00<00?l0ooooooooool0Q_ooool500000003
05Go0?oooooooooo00Oooooo0P1Eo`03ooooo`80EOl0Coooool004Kooooo0P1Eo`000`00003ooooo
ooooo`0>ooooo`@00000ROooool7000000Gooooo0`000003ooooo`80EOl0Coooool004Kooooo0P1E
o`0Aooooo`040000001EZZX0EOl0000008Wooooo00D000000>3Ph0000000000005EEo`02000000Go
oooo00@0EOl0000000000000ZP000_ooool205Go04oooooo0015ooooo`80EOl05?ooool00`1Eo`00
000000000027ooooo`030000003Ph>00h>3P00H000001?ooool00`1Eo`0000000000000400000004
05Go00000000ZUGoooooo`800000B_ooool004Cooooo00<0000005Go000000000P00000Booooo`04
05Go00000000a<C4000008Gooooo0`0000001?ooool000000000002I<l`2000000Gooooo00@0EOl0
003o0?oooooooooo100000001P2ZZ_l000000000002ZEOl0ZZ[o000004Wooooo0013ooooo`H00000
4_ooool205Go0003ooooo`00003ooooo08_ooooo0P000004ooooo`800?l00oooool01000003ooooo
00000034a<@400000080ZZ[o00<00000ooooooooool0A_ooool004Gooooo0`00000Cooooo`800?l0
S_ooool2000000Cooooo0P1Eo`003Oooool0000000000000003ooooo00000034a<@000000<C4a02Z
Z_l0ZUGo0000002ZZ_l00P000017ooooo`00AOooool00`00003oooooooooo`0Cooooo`80000000<0
EOl0ooooooooool0T?ooool01@00o`00EOl0ooooo`000000VLbI00;ooooo00<000000<C4a034a<@0
0P0000001P2ZZ_l0ZUGo0:ZZo`000000ZZ[o000004Oooooo001Kooooo`<0EOl000<00?l0oooooooo
ool0Soooool205Go000600000?ooooooooooooooo`000000_Kfm0`3<VL`2000000<0ZUGo00<00000
ooooooooool0A_ooool005_ooooo00@0EOl0ooooo`1Eo`00EOl0T?ooool305Go00Cooooo1P000002
ooooo`040000002ZZ_l00000000004Oooooo001Kooooo`0405Go0?ooool0EOl005Go093ooooo0P1E
o`07ooooo`8000001Oooool3000004Oooooo001Kooooo`0405Go0?oooooooooo05Go093ooooo00<0
0?l0ooooooooool0Eoooool005_ooooo00<00?l0ooooooooool00P00o`2>ooooo`03003o001Eo`3o
oooo05Sooooo001Kooooo`0305Go0?oooooooooo0080EOl0S_ooool00`000000EOl0ooooo`1Hoooo
o`00G_ooool205Go08cooooo1@00001Hooooo`00Goooool00`1Eo`3oooooooooo`2:ooooo`D00000
F?ooool005oooooo0P1Eo`2;ooooo`D00000F?ooool005oooooo0`1Eo`3Wooooo`00H?ooool00`00
o`000000ooooo`3Vooooo`00G?ooool7000000030:YEo`00000000000>?ooooo001Nooooo`@00000
00D0SHf=0000002=SHd0SHf=0000003Rooooo`00Goooool4000000050:YEo`000000000005EEo`00
0000hOooool005kooooo0P0000001@3oEJX000000?mEZP000000ZUGo00<00000hOooool005kooooo
0P0000001`3<VL`0000000000?ooool000000:YEo`000000h_ooool005oooooo0`000003ooooo`80
0000h_ooool00?ooooooB_ooool00?ooooooB_ooool00?ooooooB_ooool00?ooooooB_ooool00?oo
ooooB_ooool00?ooooooB_ooool00?ooooooB_ooool00?ooooooB_ooool00?ooooooB_ooool00?oo
ooooB_ooool00?ooooooB_ooool00?ooooooB_ooool00?ooooooB_ooool00?ooooooB_ooool00?oo
ooooB_ooool00?ooooooB_ooool00?ooooooB_ooool00?ooooooB_ooool00?ooooooB_ooool00?oo
ooooB_ooool00?ooooooB_ooool00?ooooooB_ooool00?ooooooB_ooool00?ooooooB_ooool00?oo
ooooB_ooool00?ooooooB_ooool00?ooooooB_ooool00?ooooooB_ooool00?ooooooB_ooool00?oo
ooooB_ooool00?ooooooB_ooool00?ooooooB_ooool008Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`2Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07?ooool0
08Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool06oooool006gooooo0P1VIVHFooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`2Aooooo`04o`000?ooooooooooooooo`;o00000oooool0
0ol0003oooooooooo`0Kooooo`00J?ooool606IVIQOooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo097ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000Mooooo`00I?ooool506IVIQcooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo097ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Moooo
o`00HOooool306IVIR7ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
09?ooooo00Co0000oooooooooooooooo0_l00003ooooo`03o`000?oooooooooo01_ooooo001Loooo
o`H0IVIV8oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000POooool4
06IVIPkooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Mooooo`00F?oo
ool506IVIRSooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0001looooo`D0IVIV
4_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001gooooo001Fooooo`80
IVIV;_ooool00ol0003oooooo`000003o`000003ooooool0003ooooo07[ooooo0P1VIVHHooooo`03
o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`0Looooo`00DOooool506IVIYoooooo
0P1VIVH=ooooo`D0IVIV@?ooool004cooooo1P1VIVH4ooooo`0306IVI_oooooooooo09kooooo0P1V
IVH6ooooo`H0IVIVA?ooool004[ooooo0`1VIVH:ooooo`0306IVI_oooooooooo09kooooo00<0IVIV
ooooooooool00_ooool306IVITWooooo0015ooooo`D0IVIV3_ooool206IVIYkooooo1@1VIVI<oooo
o`00@?ooool606IVIQ?ooooo0P1VIVJHooooo`H0IVIV00?ooooo06IVIP1VIVH0COooool003kooooo
0`1VIVHJooooo`0306IVI_oooooooooo09?ooooo0`1VIVH8ooooo`0306IVI_oooooooooo04[ooooo
000iooooo`D0IVIV7Oooool206IVIY3ooooo101VIVH;ooooo`80IVIVBoooool003Cooooo1P1VIVHS
ooooo`80IVIVN_ooool306IVIPcooooo1@1VIVHAooooo`0306IVI_oooooooooo04Sooooo000boooo
o`<0IVIV:Oooool00`1VIVKoooooooooo`1jooooo`0306IVI_oooooooooo00Sooooo0P1VIVHGoooo
o`0306IVI_oooooooooo04Oooooo000]ooooo`D0IVIV0_ooool00`1VIVKoooooooooo`0Xooooo`03
06IVI_oooooooooo01cooooo0P1VIVILooooo`0306IVI_oooooooooo00;ooooo1@1VIVHIooooo`80
IVIVB?ooool002Wooooo1@1VIVH7ooooo`80IVIV:Oooool206IVIQOooooo1@1VIVINooooo`D0IVIV
8?ooool206IVIQ_ooooo101VIVHWooooo`009oooool206IVIPkooooo00<0IVIVooooooooool0:?oo
ool00`1VIVKoooooooooo`0Aooooo`@0IVIVGoooool306IVIP?ooooo00<0IVIVooooooooool08?oo
ool00`1VIVKoooooooooo`0Fooooo`<0IVIV:oooool002;ooooo1@1VIVH@ooooo`<0IVIV:?ooool2
06IVIPgooooo1P1VIVINooooo`D0IVIV1_ooool206IVIR7ooooo0P1VIVHAooooo`H0IVIV;Oooool0
01gooooo1@1VIVHGooooo`80IVIV:Oooool206IVIPOooooo1@1VIVI=ooooo`80IVIV3oooool606IV
IP_ooooo0P1VIVHQooooo`80IVIV2oooool506IVIS?ooooo000Kooooo`80IVIV7Oooool206IVIRWo
oooo00<0IVIVooooooooool00_ooool306IVIU?ooooo00<0IVIVooooooooool02oooool306IVIQ;o
oooo00<0IVIVooooooooool07oooool00`1VIVKoooooooooo`07ooooo`80IVIV>?ooool001Kooooo
1@1VIVHQooooo`0306IVI_oooooooooo02Kooooo1P1VIVIFooooo`80IVIV1_ooool506IVIQGooooo
0P1VIVHQooooo`80IVIV0_ooool506IVIS[ooooo000Cooooo`<0IVIV9oooool206IVIR7ooooo1@1V
IVH01?ooool000000000001VIVIJooooo`L0IVIV6oooool206IVIQgooooo1P1VIVHoooooo`005Ooo
ool00`1VIVKoooooooooo`0Wooooo`0306IVI_oooooooooo01cooooo0P1VIVH6ooooo`0405Go0000
003ooooo06IVIUSooooo0`1VIVHQooooo`0306IVI_oooooooooo01Wooooo0`1VIVH4ooooo`0306IV
I_oooooooooo03gooooo000Eooooo`80IVIV:?ooool206IVIQSooooo1@1VIVH8ooooo`0505Go0000
003oooooooooo`1VIVH0Doooool406IVIP;ooooo0`1VIVHPooooo`80IVIV5?ooool506IVIPGooooo
0`0000000`1VIVKoooooooooo`0looooo`005oooool206IVIRSooooo0P1VIVHAooooo`D0IVIV3Ooo
ool205Go00?ooooo0P1VIVI<ooooo`D0IVIV2?ooool206IVIR7ooooo00<0IVIVooooooooool03?oo
ool506IVIP[ooooo0P1Eo`001000003ooooo06IVIP1VIVHlooooo`006Oooool00`1VIVKooooooooo
o`0Wooooo`0306IVI_oooooooooo00_ooooo0`1VIVHBooooo`800?l01Oooool00`1VIVKooooooooo
o`17ooooo`80IVIV3oooool00`1VIVKoooooooooo`0Oooooo`0306IVI_oooooooooo00Wooooo0`1V
IVH>ooooo`800?l01?ooool00`1VIVKoooooooooo`0iooooo`006Oooool306IVIROooooo0P1VIVH7
ooooo`H0IVIV5?ooool205Go00Gooooo0P1VIVI6ooooo`80IVIV4_ooool206IVIQoooooo0`1VIVH3
ooooo`H0IVIV4Oooool205Go00Cooooo0P1VIVHjooooo`006oooool206IVIRSooooo0P1VIVH00ooo
ool0IVIV06IVIP0306IVIQWooooo0P1Eo`06ooooo`80IVIVF_ooool206IVIR3ooooo1@1VIVHFoooo
o`80EOl01_ooool00`1VIVKoooooooooo`0Hooooo`D0IVIV6_ooool001gooooo00<0IVIVoooooooo
ool09Oooool306IVIQkooooo0P1Eo`08ooooo`0306IVI_oooooooooo05Wooooo00<0IVIVoooooooo
ool06_ooool306IVIP03ooooo`1VIVKooooo01Sooooo0P1Eo`07ooooo`0306IVI_oooooooooo01Go
oooo0`1VIVHNooooo`007_ooool206IVIR3ooooo1P1VIVH00oooool0IVIV06IVIP0Mooooo`80EOl0
2Oooool00`1VIVKoooooooooo`0Gooooo`D0IVIV??ooool206IVIQKooooo1P1VIVH4ooooo`80IVIV
5oooool205Go00Oooooo0`1VIVH?ooooo`H0IVIV8Oooool001oooooo0`1VIVHIooooo`D0IVIV2Ooo
ool206IVIQ[ooooo0`1Eo`0:ooooo`80IVIV4_ooool606IVIT;ooooo0P1VIVH?ooooo`H0IVIV2ooo
ool00`1VIVKoooooooooo`0Dooooo`80EOl02Oooool206IVIP[ooooo1@1VIVHVooooo`008Oooool0
0`1VIVKoooooooooo`0Eooooo`80IVIV4?ooool00`1VIVKoooooooooo`0Gooooo`800?l03?ooool2
06IVIPkooooo0`1VIVI:ooooo`0306IVI_oooooooooo00Wooooo0`1VIVHBooooo`0306IVI_oooooo
oooo01?ooooo0P00o`0:ooooo`0306IVI_oooooooooo00Gooooo0`1VIVH[ooooo`008_ooool206IV
IQ3ooooo1@1VIVHBooooo`80IVIV6?ooool205Go00gooooo0P1VIVH8ooooo`H0IVIVC?ooool206IV
IPKooooo1@1VIVHEooooo`80IVIV4oooool205Go00_ooooo201VIVH]ooooo`009?ooool206IVIPSo
oooo1P1VIVHIooooo`80IVIV5_ooool205Go00oooooo00<0IVIVooooooooool01@1VIVIDooooo`H0
IVIV6oooool206IVIQ;ooooo0P1Eo`08ooooo`H0IVIV<_ooool002Gooooo00<0IVIVooooooooool0
1?ooool306IVIQoooooo0P1VIVHEooooo`80EOl03oooool306IVIUOooooo101VIVHQooooo`0306IV
I_oooooooooo00oooooo00<0EOl0ooooooooool01Oooool206IVIPGooooo00<0IVIVooooooooool0
<?ooool002Kooooo1P1VIVHSooooo`80IVIV5?ooool205Go00[ooooo2@1VIVIAooooo`H0IVIV0ooo
ool206IVIR3ooooo00<0IVIVooooooooool03_ooool00`1Eo`3oooooooooo`0506IVIPSooooo0P1V
IVH`ooooo`00:?ooool206IVIROooooo0P1VIVHBooooo`0305Go0000o`3ooooo00?ooooo1P1VIVH8
ooooo`80IVIVBoooool506IVIP_ooooo0P1VIVHOooooo`80IVIV3?ooool206IVIP0305Go001VIVH0
IVIV00oooooo00<0IVIVooooooooool0;Oooool002[ooooo00<0IVIVooooooooool09Oooool00`1V
IVKoooooooooo`0@ooooo`04003o0?ooooooooooooooo`<0IVIV3_ooool00`1VIVKoooooooooo`18
ooooo`80IVIV4Oooool00`1VIVKoooooooooo`0Mooooo`80IVIV2?ooool306IVIP;ooooo00<00?l0
ooooooooool04?ooool00`1VIVKoooooooooo`0/ooooo`00:_ooool206IVIROooooo0P1VIVH?oooo
o`0306IVIP1Eo`00IVIV0080IVIV4_ooool206IVIU_ooooo0P1VIVHOooooo`80IVIV0_ooool606IV
IP?ooooo00<00?l005Go0?ooool04_ooool00`1VIVKoooooooooo`0[ooooo`00;?ooool206IVIROo
oooo00<0IVIVooooooooool01_ooool606IVIP03003o001Eo`3ooooo01Kooooo00<0IVIVoooooooo
ool0FOooool306IVIQcooooo1@1VIVH9ooooo`80EOl05?ooool00`1VIVKoooooooooo`0Zooooo`00
;_ooool00`1VIVKoooooooooo`0Uooooo`0306IVI_oooooooooo00;ooooo101VIVH5ooooo`80EOl0
6?ooool00`1VIVKoooooooooo`1Jooooo`0306IVI_oooooooooo01Sooooo0`1VIVH3ooooo`0306IV
I_oooooooooo00Oooooo0P1Eo`11ooooo`00;_ooool306IVIRGooooo1P1VIVH8ooooo`80EOl06Ooo
ool00`1VIVKoooooooooo`1Jooooo`80IVIV4oooool506IVIPOooooo0P1VIVH7ooooo`80EOl0@Ooo
ool0033ooooo0P1VIVHOooooo`H0IVIV00?ooooo06IVIP1VIVH02_ooool205Go07Sooooo0P1VIVH<
ooooo`D0IVIV3Oooool206IVIPGooooo0P1Eo`000`00o`3oooooooooo`0oooooo`00<_ooool00`1V
IVKoooooooooo`0Iooooo`@0IVIV2?ooool00`1VIVKoooooooooo`07ooooo`800?l0N_ooool00`1V
IVKoooooooooo`06ooooo`<0IVIV5?ooool00`1VIVKoooooooooo`02ooooo`800?l0@_ooool003?o
oooo0P1VIVHDooooo`H0IVIV3?ooool206IVIPOooooo0P1Eo`1jooooo`80IVIV0_ooool606IVIQOo
oooo00@0IVIVoooooooooooooooo0P1Eo`12ooooo`00=?ooool306IVIPgooooo1@1VIVHCooooo`80
IVIV1Oooool00`00o`00EOl0ooooo`1jooooo`D0IVIV7Oooool00`1VIVKoooooooooo`0205Go04;o
oooo000fooooo`0306IVI_oooooooooo00Sooooo0`1VIVHJooooo`0306IVI_oooooooooo00;ooooo
0P1Eo`1gooooo`@0IVIV0oooool00`1VIVKoooooooooo`0Oooooo`0305Go0?oooooooooo047ooooo
000gooooo`80IVIV0oooool506IVIQkooooo00<0IVIVooooooooool00`1Eo`1cooooo`D0IVIV1ooo
ool206IVIQkooooo00<0EOl0000000000000@_ooool003Wooooo0`1VIVHTooooo`0406IVI_ooool0
EOl005Go073ooooo101VIVH>ooooo`0306IVI_oooooooooo01_ooooo0P1Eo`000`00003ooooooooo
o`10ooooo`00>_ooool00`1VIVKoooooooooo`0Uooooo`800?l0Poooool00`1VIVKoooooooooo`0I
ooooo`@00?l0@_ooool003_ooooo0P1VIVHTooooo`040000001Eo`000000000008?ooooo0P1VIVHH
ooooo`H0EOl0@Oooool003gooooo0P1VIVHQooooo`80000000@0EOl0003o000000000000Poooool0
0`1VIVKoooooooooo`0Eooooo`05003o001Eo`3ooooo05Go0?ooool00P1Eo`11ooooo`00?oooool0
0`1VIVKoooooooooo`0Oooooo`@0EOl000<00000ooooooooool0VOooool405Go00;ooooo00<0EOl0
ooooooooool0?oooool003oooooo0P1VIVHOooooo`D0EOl0Voooool205Go0003ooooo`1Eo`00EOl0
00;ooooo0P1Eo`10ooooo`00@Oooool206IVIQ_ooooo101Eo`02003o000305Go0?oooooooooo09So
oooo0P1Eo`001000o`00EOl005Go0000o`02ooooo`<0EOl0?oooool005kooooo0P00o`001Oooool0
0?l0ooooooooool00?l009[ooooo00<00?l0ooooooooool00P00o`04ooooo`800?l0?oooool005co
oooo00H00?l005Go001Eo`3ooooo003o001Eo`02ooooo`80EOl0V?ooool205Go00;ooooo00<0EOl0
ooooooooool00oooool205Go03oooooo001Looooo`80EOl00_ooool205Go00;ooooo0P1Eo`2Goooo
o`03003o001Eo`3ooooo00;ooooo00<0EOl0ooooooooool01?ooool205Go03kooooo001Kooooo`80
EOl00oooool205Go00?ooooo0P1Eo`2Eooooo`<0EOl00oooool00`1Eo`3oooooooooo`04ooooo`80
EOl0?_ooool005_ooooo00@0EOl0003o0?oooooooooo0P1Eo`001000o`3oooooooooooooool305Go
09?ooooo0P1Eo`001000o`3oooooooooooooool205Go00Kooooo00<00?l005Go0?ooool0?Oooool0
05Wooooo0`1Eo`03ooooo`80EOl01Oooool205Go09?ooooo00<0EOl0003o0?ooool00oooool00`1E
o`000?l0ooooo`06ooooo`80EOl0?Oooool005Wooooo0P00o`04ooooo`03003o0?oooooooooo00Co
oooo0P00o`2Booooo`800?l01?ooool2000000Sooooo0P00o`0mooooo`00F?ooool00`00o`00EOl0
0000000300000003003o001Eo`3ooooo00Kooooo00<0EOl0ooooooooool0Soooool305Go00;ooooo
1P000006ooooo`<0EOl0??ooool005Oooooo00@00?l005Go001Eo`0000000`1EZZX3000000Kooooo
0P1Eo`2?ooooo`03003o001Eo`00EOl000;ooooo20000006ooooo`80EOl0??ooool005Kooooo0`1E
o`000oooool0000003=Vo`0503=Vo`8000001?ooool205Go08oooooo0P1Eo`03ooooo`80000000Co
oooo00000000000000002Oooool205Go03_ooooo001Fooooo`0505Go0000o`3oooooooooo`00EJX0
1@1EZZX00`0cI_l0EJZZ00000002000000;ooooo0P1Eo`2?ooooo`0305Go0000o`3ooooo00Gooooo
00<00000ooooooooool02Oooool205Go03_ooooo001Eooooo`80EOl01?ooool505FZZP0403=Vo`1E
ZZX0EJZZ05FZZP8000000_ooool205Go08cooooo0`1Eo`0Dooooo`80EOl0>_ooool005Cooooo0P00
o`05ooooo`03001EZP1EZZX0EJZZ0080EJZZ00<005FZ05FZZP1EZZX00`1EZZX00`00003ooooo003o
0002003o08_ooooo0P00o`0Dooooo`0300000000o`000?l003[ooooo001>ooooo`<000000_ooool0
0`00o`00EOl005Go0006ooooo`@0EJZZ00<0<fKo05FZZP0000001P00000205Go08[ooooo0P1Eo`0C
ooooo`H00000>Oooool004Wooooo1@00000204i>CP030<`c<`1>CTh0CTi>00@0CTi>00@0c3<c04i>
CP1>CTh0CTi>1`00000405FZZP0303=Vo`1EZZX000000080EOl000<00000ooooooooool0Qoooool2
05Go01Cooooo1P00000hooooo`00BOooool00`000000ZP000<`c<`040<`c<`030:X0003<<c<0c3<c
00@0c3<c00<0ZP000000000000000P3<<c<6000000P0<fKo00@0EOl00000000000000000Q_ooool2
05Go01Oooooo0P0000000`1Eo`000000ooooo`0gooooo`00B?ooool00`000000CTi>0<`c<`0504i>
CP030<`c<`1>CTh0CTi>0080CTi>1000000204i>CPX0000000<0EJZZ03=Vo`1EZZX0101EZZX30000
08Cooooo0`1Eo`0Iooooo`80EOl00P00000fooooo`00BOooool00`000000c3<c04i>CP0404i>CP03
0<`c<`1>CTh00000008000000P1>CTh0103<<c<0CTi>04i>CP1>CTh400000080ZUGo0P0000000`2=
SHd0000000000002000000@0EJZZ00@0<fKo05FZZP0000000000Poooool00`1Eo`000?l0ooooo`0I
ooooo`030000001Eo`00ZZ[o00800000=Oooool004[ooooo0P00000404i>CP8000001@1>CTh02@3<
<c<0CTi>04i>CP1>CTh000000:6QX@000000XJ6Q0000000209Tcc0030000001nOWh0VC?<00<0VC?<
0P00000205FZZP03001EZP1EZZX0EJZZ00800000POooool2003o01_ooooo0`00o`02000003Gooooo
001<ooooo`@0000000<0c3<c04i>CP1>CTh0101>CTh00`3<<c<0CTi>04i>CP02000000040:6QX@00
00000000000000<0ZUGo0P0000040:YEo`0308f=S@000000000000H00000P?ooool205Go01cooooo
0P1Eo`03000003Cooooo001>ooooo`80000000<0c3<c04i>CP1>CTh0101>CTh01@3<<c<0CTi>0000
001>CTh000000080XJ6Q00L000000:6QX@00000000000:YEo`2=SHd0ZUGo008000000P2ZEOl0102=
SHd0ZUGo05Go0000o`0200000080EJ[o00<00000ooooooooool0N_ooool30000000305Go00000000
000001cooooo0P1Eo`001000003oooooooooo`00000cooooo`00C_ooool00`1Eo`0000000:X00006
0<`c<`040:X0003<<c<0c3<c00000080VLbI00@0c9W<0000002Ic9T0VLbI1`0000000`2ZEOl0SHf=
0:YEo`0305Go0080EJ[o0P00001mooooo`030000001Eo`00EOl0008000007?ooool305Go03Kooooo
001<ooooo`0305Go00000000000000L0000000D0CTi>0<`c<`000000000009W<V@030:6QX@030000
002QXJ40VLbI0080000000<0<oo<0000000000001P0000000`1Eo`00000000000003000007gooooo
0`1Eo`02000001cooooo101Eo`0eooooo`00BOooool6000000Kooooo1@0000002P2Ic9T0XJ6Q0:6Q
X@2QXJ4000000:6QX@2Ic9T0XJ6Q0000002=SHd30:YEo`0300000000VL`0<oo<008000000P1Eo`04
000007cooooo101Eo`001?ooool0000000000000000Jooooo`D0EOl0=?ooool004Wooooo0`000000
0`1Eo`3oooooooooo`09ooooo`030000002QXJ40VLbI00<0XJ6Q00@000000:6QX@2Ic9T0XJ6Q0P00
00050:YEo`0608f=S@00000000000<c<c01Eo`0000000P2ZZ_l3000007Sooooo1@1Eo`001@00o`3o
ooooooooooooool0000001[ooooo0P1Eo`001?ooool0EOl005Go001Eo`0cooooo`00@?ooool60000
00;ooooo0`0000000`2ZZ_l00000ooooo`0:ooooo`030000002QXJ40c9VI00@0XJ6Q00<000000<bI
V@2QXJ400P2QXJ400`000000VC?<09Tcc00209Tcc00407inOP000000c<c<0<c<c0800?l000H00000
0:ZZo`2ZZ_l0c9W<0:ZZo`00001fooooo`H00?l07oooool2003o0004ooooo`00o`000?l0003o03?o
oooo0013ooooo`0303?oc0000000EJ[o00@0000000<0I/co0000000000002_ooool2000000030:6Q
X@2Ic9T0XJ6Q00<0XJ6Q00<0000009W<V@2QXJ400P2QXJ400`000000ZUGo0:YEo`020:YEo`0408f=
S@000000e=CD0<c<c080EOl000<0SHf=0000000000001@00001cooooo`L0EOl07oooool205Go00;o
oooo00@0EOl000000000000000001Oooool5000002Oooooo0015ooooo`80000000@0<oo<003o001E
o`00EOl010000007ooooo`8000000P2QXJ400`2Ic9T0XJ6Q0:6QX@020:6QX@030000002Ic9T0XJ6Q
0080XJ6Q0P0000030:YEo`@000000`1Eo`02000000;ooooo1000001aooooo`80EOl000?ooooo003o
001Eo`000`1Eo`0Jooooo`D000000P1Eo`03ooooo`0305Go0000EOl005Go00<0000000<0ZUGo09fM
W@2ZEOl0102MWId00`00003oooooooooo`0Tooooo`00B?ooool305Go00030000001EZ_l0EJ[o0080
00001_ooool00`000000c9W<09W<V@0409W<V@030<bIc02Ic9T0000000<0VLbI00<0c9W<09W<V@00
00000`2ZEOl010000000e=CD0000002ZEOl305Go000300000?oooooooooo00Cooooo00<0_Kfm0000
0?ooool0K_ooool205Go00;ooooo0P1Eo`000oooool0EOl0ooooo`0Iooooo`030000002Z0000ZP00
00<0ZP000P1Eo`020:X00004ooooo`0000000000000000<005FZ00<0000009fMW@2ATI40102MWId0
0`00003oooooooooo`0Tooooo`00A_ooool405Go0005003o0000000000000000002][Jd00`000004
ooooo`050000002QXJ40XJ6Q0:6QX@2Ic9T0102QXJ400`000000VLbI0:6QX@030:6QX@8000000P2Z
EOl200000080ZUGo0`1Eo`02000000Oooooo00<00000ooooooooool0Joooool205Go0004003o0?oo
ool0EOl005Go00;ooooo00<0EOl0ooooooooool06?ooool2000000<0ZP000P0000000`1Eo`000000
0000000:000000D0WIfM00<00000ooooooooool08oooool004Gooooo1@1Eo`00103@d=000000oooo
ooooool5000000?ooooo00D000000:6QX@2QXJ40XJ6Q09W<V@040:6QX@030000002Ic9T0XJ6Q00@0
XJ6Q00<0VLbI0000002ZEOl00P000000102ZEOl0EOl005Go002ZEOl205Go000300000?oooooooooo
077ooooo0`1Eo`02ooooo`80EOl000@00?l0ooooooooool0EOl07Oooool40000000405Go002Z0000
ZP000:X000@000000P2MWId5000000<0WIfM00<0ZUGo00000?ooool08oooool004Gooooo1@00o`00
0`3@d=000000ooooo`04ooooo`8000000_ooool00`000000XJ6Q0:6QX@020:6QX@030<bIV@2QXJ40
XJ6Q00<0XJ6Q00<000000:6QX@2QXJ400`2QXJ40103<VIT0000009Tcc01nOWh209Tcc0800?l000@0
VC?<07inOP00o`000?l0L_ooool3003o00?ooooo0P00o`03ooooo`03003o0?oooooooooo01_ooooo
00<00000002Ic000VL`01P0000001@3oZZX000000000002ZEOl0UIFE0080ZUGo0P0000000`00EOl0
0000000000020:YEo`0300000?oooooooooo02;ooooo0013ooooo`H0EOl00`000007ooooo`030000
0?ooool0000000@0XJ6Q00<0VLbI0:6QX@2QXJ400`2QXJ400`000000XJ6Q0:6QX@030:6QX@0309W<
V@2QXJ40000000H0000000<0SHf=05Go001Eo`00LOooool00`00o`00EOl005Go0003ooooo`03003o
001Eo`3ooooo00;ooooo0P1Eo`0Nooooo`040000001Eo`00EOl005Go0080000000H0ojYE0000003o
ZZX000000?nZZP00000309fMW@030:YEo`000000000000@000009Oooool004;ooooo0P1Eo`001?oo
ool0EOl005Go0?ooool205Go00_ooooo00<000000:6QX@2QXJ400P2QXJ400`2Ic9T0XJ6Q0:6QX@03
0:6QX@030000002QXJ40XJ6Q00<0XJ6Q00L0VLbI00000000000000000:YEo`000000EOl000<00000
0`1Eo`1^ooooo`04003o001Eo`00EOl005Go00Cooooo0P1Eo`03ooooo`80EOl07Oooool01000o`00
EOl005Go001Eo`04000000<0ojZZ00<000000?nZZP0000000P2MWId0102ZEOl0WIfM09fMW@2MWId3
000002Gooooo0011ooooo`80EOl000?ooooo05Go001Eo`000_ooool00`1Eo`3oooooooooo`0:oooo
o`030000002Ic9T0c9W<00D0VLbI00L0c9W<09W<V@2Ic9T0VLbI0000002Ic9T0c9W<00<0VLbI00<0
0000ooooooooool00P0000001@1Eo`00ZUGo0:YEo`2m_Kd0000000<0EOl0K?ooool305Go00Gooooo
0P1Eo`03ooooo`<0EOl07?ooool305Go0003ooooo`1Eo`3ooooo00<000000`3oZZX01P000000ojZZ
0<c<c0000000WIfM096AT@@0WIfM00<00000ooooooooool09?ooool003oooooo0`1Eo`001@00o`00
EOl005Go0000o`3ooooo0080EOl03?ooool00`000000XJ6Q0:6QX@020:6QX@0309W<V@2QXJ40XJ6Q
00<0XJ6Q1`000004ooooo`030000001Eo`00ZUGo00<000000`1Eo`1[ooooo`80EOl000<00?l0oooo
ooooool00oooool305Go00?ooooo0P1Eo`0Mooooo`8000000_ooool00`1Eo`000000000000030000
0080ojZZ00<000000?nZZP3oZZX00P0000000`2ZEOl0WIfM09fMW@0209fMW@8000009Oooool003go
oooo0`1Eo`001P00o`3oooooooooo`1Eo`000?l0ooooo`<0EOl03?ooool2000000<0XJ6Q00@0VLbI
0:6QX@2QXJ40XJ6Q0P00000;ooooo`0305Go0000o`00000000?ooooo00@00?l005Go001Eo`00EOl0
JOooool205Go0006003o0?ooooooooooooooo`00003ooooo0P1Eo`000`00o`3oooooooooo`02oooo
o`80EOl06oooool305Go000500000?ooool0EOl005Go002ZoeD0100000020?nZZPL00000102MWId0
0`00003oooooooooo`0Sooooo`00?Oooool3003o00;ooooo0P00o`02ooooo`800?l03_ooool20000
0080XJ6Q00D0c9VI0:6QX@2QXJ40XJ6Q0000000<ooooo`03003o0?oooooooooo00Gooooo0P00o`05
ooooo`<00000Goooool3003o00Kooooo00<00000003o0000o`001Oooool2003o01[ooooo0`00o`03
ooooo`04003o00000000Z_mE000000@0ojZZ00<0_Kfm0000000000001?ooool01@000000ZUGo09FE
U@2ZEOl0000002Kooooo000looooo`80EOl00oooool00`00o`00EOl005Go0002ooooo`80EOl04?oo
ool3000000030:6QX@000000000000cooooo0P1Eo`07ooooo`0305Go0000003ooooo0080SHf=00D0
VC?<0:YEo`2ZEOl0UIFE0:YEo`03000005_ooooo00<00?l005Go001Eo`000`000002ooooo`05069R
HP000000EOl005Go001EEJX01Oooool205Go01Sooooo00@00?l005Go001Eo`00EOl01?ooool0101E
o`000000ooooo`0000030?nZZP8000001_ooool00`1Eo`00000000000002000002Kooooo000joooo
o`03003o001Eo`00EOl000?ooooo0`1Eo`03ooooo`80EOl04oooool00`00003oooooooooo`0<oooo
o`80EOl00_ooool50000000405Go00000000UIFE000000@0ZUGo00D0UIFE0:YEo`2ZEOl0ZUGo0000
001Iooooo`03003o001Eo`00EOl000<0000000@0VC>I069RHP1RHV80HV9R1@00000305FZZP<00000
6Oooool205Go00Gooooo00@0000005Go0?oooooooooo1@000008ooooo`80EOl000<00?l0oooooooo
ool09Oooool003[ooooo0P1Eo`03ooooo`80EOl01Oooool00`1Eo`3oooooooooo`0Qooooo`80EOl0
00Kooooo000000000000E@0006IV<`00000206IV<`80000000<0ZUGo0000002ZEOl00P2ZEOl00`2E
UID0ZUGo0:YEo`020:YEo`0300000?oooooooooo05Gooooo0`1Eo`000oooool0000003lo?`040<`c
<`030000003<<c<0c3<c00<000000`1EZZX00`2ZEJX0EJZZ0000000Oooooo`80000000<0EOl0oooo
ooooool03_ooool205Go02Oooooo000hooooo`<0EOl01?ooool205Go00Gooooo00<0EOl0oooooooo
ool08Oooool01`1Eo`000000000000000000IVHc0:X0E@0000000`1VIS<3000000050:YEo`000000
00000:YEo`2EUID0102ZEOl00`00003oooooooooo`1Cooooo`<0EOl000@00?l0ooooooooool00000
0P1RHV800`2I<iT0000000000003069RHPD00000101EZZX2000001gooooo00@0000005Go00000000
00004?ooool205Go02Kooooo000eooooo`@0000000@00?l0oooooooooooooooo0`1Eo`06ooooo`03
05Go0?oooooooooo01oooooo00H0000005Go001Eo`00000009VIV@2QXJ49000000<0ZUGo0`000003
0:YEo`800000Doooool205Go0003003o0?oooooooooo00;ooooo1@000003069RHP030000003<c<`0
ojZZ00@00000101EZZX00`00003oooooooooo`0Gooooo`D0000000<0E@1E0000000000000P00000>
ooooo`80EOl09_ooool003Kooooo0P00o`02000000?ooooo0P00o`07ooooo`03003o0?oooooooooo
01kooooo00@0000006IV<`00o`000?l00P0000000`2IVIT00000ooooo`02ooooo`040000003<VIT0
00000<bIV@80000000L0VC?<08f=S@2=SHd0SHf=0000002=SHd0VC?<0080SHf=00<00000oooooooo
ool0C_ooool2000000<00?l01Oooool30000000309TcV@1RHV80HV9R0080HV9R00<000000<c<c03<
c<`01000000305FZZP0305EEZP00003ooooo01Sooooo00<0000005D0E@0000000P1E05D400000003
05EEZP00003ooooo00gooooo0P00o`0Uooooo`00=?ooool00`00o`00EOl005Go0003000000;ooooo
0P1Eo`07ooooo`80EOl07oooool9000000;ooooo00L000000<bIc03<VIT0c9VI0000003<VIT00000
00<0ZUGo00<0UIFE0:YEo`0000001000001;ooooo`H0000000@0EOl000000000000000001?ooool2
00000080d=3@0P000002069RHP80000000<0c<c<0?nZZP0000001@00000305FZZP0300000?oooooo
oooo01Kooooo1@000000103<VIT000000000001EEJX2000000kooooo0`1Eo`0Tooooo`00<oooool3
05Go0007ooooo`000000000000000?ooool00?l005Go0005ooooo`D000007Oooool;000000;ooooo
00H000000<bIc03<VIT0c9VI0000003<VIT200000080ZUGo00@0UIFE0:YEo`2ZEOl0ZUGo0P00001;
ooooo`040000001Vc?l0I/co003o00@0EOl000<000000:ZZo`000000100000060=3@d0<0000000<0
ojZZ0<c<c03oZZX01`00000205FZZP0300000?oooooooooo01Kooooo0P0000000`2ZojX000000000
00060000013ooooo00<0EOl0003o0?ooool08_ooool0037ooooo0`1Eo`05ooooo`8000000P1Eo`03
ooooo`@0EJ[o00<0VIVI05FZo`0000007Oooool200000003ooooo`000000000000Sooooo00D00000
0?mVc03oI/`0ofK<000000020?mVc080000000<0ZUGo09FEU@2ZEOl00`2ZEOl00`00003ooooooooo
o`1<ooooo`<0EOl000<000000<S8b038b<P00`0000000`2ZZ_l000000?ooc0040?ooZP030?ooc03o
ojX0000000<0ojZZ00<0a<C40?nZZP0000000P000000101EZZX0ZUFZ05FZZP00000205FZZP030000
0?oooooooooo01Kooooo0P000007ooooo`8000004?ooool205Go02?ooooo000`ooooo`80EOl00P00
o`060000000505Go00000000000005FZo`2IVIT01@1EZ_l0102IVIT0EJ[o00000000000Xooooo`03
0000003<VIT0c9W<00<0c9VI00H000000<bIV@00000000000:YEo`2EUID40:YEo`0300000?oooooo
oooo04[ooooo101Eo`000oooool0000000000007000000D0d=3@0P0000030?nZZP030<c<c0000000
000000;ooooo00@0000005FZZP1EZZX0EJZZ0`00000Qooooo`8000004Oooool305Go027ooooo000Z
ooooo`D000000P1Eo`08000000030:[oZP000000000000@00000101EZ_l01@2IVIT0EJ[o05FZo`1E
Z_l0000002Oooooo00<000000<bIV@3<VL`00`3<VIT00`000000c9VI0<bIc0020000000309FEU@2Z
EOl0ZUGo0080ZUGo00<00000ooooooooool0Aoooool505Go0004003o0?ooooooooooooooo`@00000
1`3@d=0200000003ooooo`000000000000@000000oooool2000000<0EJZZ00<00000ooooooooool0
=?ooool00`000000EOl000000002000001kooooo000[ooooo`030000001E003ooooo00800?l00P00
0004ooooo`040000002Zoj[oooooooooo`<0000000@0VC?<0<bIc000000000000`2I<l`01@3<VL`0
VC?<09Tcc02I<l`0000002Oooooo00<000000<bIV@3<VL`00`3<VIT00`000000c9VI0<bIc0020<bI
V@060000002=SHd0SHf=09Tcc02=SHd00000Aoooool6003o00Oooooo00<000000=3@d03@d=001`3@
d=0<ooooo`050000001EZZX0EJZZ05EEZP000000=Oooool010000000ZP1E003o0000o`03000001go
oooo000/ooooo`03003o001Eo`00EOl000Gooooo0`0000000`2Zoj[ooooo000000040000000309VI
V@1EZ_l000000080000000<0EJ[o09VIV@1EZ_l00P1EZ_l2000002Gooooo0P0000000`3<VIT0c9W<
0<bIV@020<bIV@030000003<VIT000000080000000Cooooo000000000000ZUGo0P000015ooooo`03
003o001Eo`00EOl000@0EOl01oooool2000000H0d=3@0P00000>ooooo`050000001EZZX0EJZZ05FZ
ZP000000<oooool9000001cooooo000Zooooo`04003o001Eo`00EOl005Go00?ooooo0`0000000`2Z
ojX00000ooooo`02ooooo`030000003oZZX0VLaV00<000000`1EZ_l4000000<0EJ[o00<00000oooo
ooooool08oooool010000000c9VI0<bIV@3<VL`20<bIV@<000001_ooool00`00003oooooooooo`13
ooooo`800?l00P1Eo`000`00o`00EOl005Go0009ooooo`L0000000<0oonZooooooooool01?ooool9
00000003ooooo`000000000000<00000=_ooool200000003ooooo`000000000001gooooo000Yoooo
o`<0EOl01Oooool00`000000Z_nZ00000005ooooo`040000003oZZX0VLaV00000080ojZZ00<00000
05FZo`1EZ_l00P1EZ_l01@2IVIT000000000001EZ_l0000002Oooooo00D000000?mVc03oI/`0ofK<
0000001>ooooo`L0EOl02_ooool01000003oooooooooooooool2000000Oooooo00<0000006K<o`00
0000200000000`1Eo`00000000000002000005Sooooo000Xooooo`80EOl000@00?l0oooooooooooo
oooo100000000`2a/K7oooooooooo`04ooooo`030000003oZZX0VLaV00@00000101EZ_l00`2IVIT0
EJ[o00000002000002Sooooo1000001=ooooo`80EOl000D00?l005Go001Eo`00EOl0003o000Moooo
o`<0000000@0I/co000000000000EOl02000001Dooooo`009Oooool405Go00Cooooo0P0000020:[o
ZPOooooo00@000000?nZZP3oZZX0VLaV0P000002ooooo`050000001EZ_l0EJ[o05FZo`2IVIT00`1E
Z_l3000007Sooooo0`1Eo`000`00o`3oooooooooo`0Rooooo`<0EOl000Cooooo000000000000ZJVY
1P00001Aooooo`009Oooool3003o00Cooooo00<000000:[oZP0000002Oooool01@000000`<300<30
`030`<00000000?ooooo00D0000009Tcc02I<l`0VC?<0<bIc00309Tcc00300000?oooooooooo07Ko
oooo1000o`0Uooooo`@00?l01oooool2000000030:VYZ@00003ooooo04oooooo000Sooooo`03003o
001Eo`00EOl000Cooooo1000000:ooooo`030000003oZZX0ojZZ008000001?ooool20000000305FZ
o`2IVIT0EJ[o0080EJ[o00<00000ooooooooool0MOooool405Go02Kooooo101Eo`09ooooo`030000
0?oooooooooo04oooooo000Rooooo`<0EOl00oooool4000000_ooooo00@000000?nZZP3oZZX00000
1oooool20000000509VIV@1EZ_l0EJ[o05FZo`000000M?ooool00`00o`00EOl005Go0002000002So
oooo101Eo`000`00o`3oooooooooo`1Hooooo`008Oooool205Go00Cooooo0P00000>ooooo`030000
003oZZX0000000Wooooo0P0000000`1EZ_l000000000001eooooo`80EOl000<0I/co0:YEZP000000
:?ooool00`1Eo`00000005Go000205Go05[ooooo000Oooooo`<0EOl000<00?l0ooooooooool00_oo
ool00`00003oooooooooo`0=ooooo`<000002Oooool00`1Eo`3ooooo0000001booooo`<0000000@0
CTi>05Go001Eo`0000000P2UYJD2000002Oooooo00<0EOl00000001Eo`000`1Eo`1Iooooo`006ooo
ool80000023ooooo00<0EOl0ooooooooool0LOooool200000003069RHP00000000000080000000<0
YJFU0000000000000P2UYJD00`00003oooooooooo`0Sooooo`80EOl000?ooooo05Go0?ooool00P1E
o`1Iooooo`006oooool20000000303lo?`0000000000008000008Oooool00`00o`3oooooooooo`1b
ooooo`8000000P1RHV82000000<0YJFU0P00000Vooooo`800?l000?ooooo003o0?ooool00P00o`1I
ooooo`006oooool50000000309VIV@00003ooooo01oooooo0P1Eo`1dooooo`80000000<0HV9R0000
000000000P0000030:FUY@0300000?oooooooooo02Cooooo0P1Eo`001Oooool0EOl0ooooooooool0
EOl005Wooooo000Nooooo`@000008?ooool205Go07Kooooo0P0000000`2][Jd00000000000020000
00030:FUY@00003ooooo02Gooooo00@0EOl0ooooooooool0EOl00_ooool205Go05Sooooo0012oooo
o`80EOl0Moooool01@000000ojZZ0:f][@00003ooooo008000009_ooool205Go00;ooooo00<0EOl0
ooooooooool00P1Eo`1Hooooo`00>oooool9000007Oooooo00@000000:f][@0000000000:Oooool2
05Go00;ooooo00<0EOl0ooooooooool00P1Eo`1Hooooo`00>_ooool010000000I/co03?oc00col`2
00000003002ZZP1Vc?l0EOl000L00000LOooool3000002kooooo00<0EOl0ooooooooool00P1Eo`1H
ooooo`00@_ooool2003o0003ooooo`000000000000D00000X?ooool00`00o`3oooooooooo`02003o
05Sooooo0012ooooo`80EOl00oooool500000:3ooooo00D0EOl0oooooooooooooooo05Go0002oooo
o`D00000DOooool004;ooooo0P1Eo`000`00o`3oooooooooo`2Kooooo`D000001Oooool00`1Eo`00
0?l0ooooo`040000000305FZo`1VIYT0EJ[o0080EJ[o00<00000ooooooooool0C_ooool004;ooooo
0`1Eo`2Mooooo`030000000A0000000000T000000P1VIYT00`000000EOl00000000406IVV@030<bI
c01VIYT0000004oooooo0012ooooo`@0EOl0Xoooool00`0000004@00000000020000000408f=S@00
0000000005Go0080000000<0IVJI05FZo`1EZ_l00P1EZ_l00`00003oooooooooo`1=ooooo`00@_oo
ool0101Eo`3ooooo05Go001Eo`2Tooooo`L0000000<0EOl00000000000000P00000305FZo`030000
0?oooooooooo04gooooo0012ooooo`04003o0?ooool00?l0003o0:Cooooo0P0000001@3oZZX00000
0<c<c03oZZX0000000800?l000<0EJ[o08f=S@1EZ_l00P0000000`1EZ_l00000ooooo`1>ooooo`00
@_ooool01@1Eo`3ooooo0000001Eo`0000000:?ooooo0P0000020?nZZP030000003oZZX000000080
EOl000<0EJ[o06IVV@1EZ_l00P1EZ_l00`00003oooooooooo`1>ooooo`00@_ooool01@1Eo`3ooooo
ooooo`1Eo`0000000:;ooooo0P0000030?nZZP<0000000@0EOl0000000000000IVJI0`1EZ_l20000
04oooooo0012ooooo`0305Go0?oooooooooo0080EOl0X_ooool00`000000g=cL0<c<c0020=cLg080
00000_ooool00`1Eo`00000006IVV@0206IVV@030<bIc0000000000004oooooo0012ooooo`0305Go
0?oooooooooo0080EOl0X_ooool01@000000ojZZ0?nZZP3oZZX0000000Cooooo00<0EOl0ooooo`00
00001000001@ooooo`00@_ooool0101Eo`3oooooooooooooool205Go0:3ooooo1@000005ooooo`80
EOl0EOooool004;ooooo00@00?l0oooooooooooooooo0P00o`2Zooooo`800?l0EOooool004;ooooo
00@0EOl0oooooooooooooooo0P1Eo`000`00o`3oooooooooo`2Wooooo`80EOl0EOooool004;ooooo
00<0EOl0ooooooooool00_ooool205Go0:Wooooo0P1Eo`1Eooooo`00@_ooool00`1Eo`3ooooooooo
o`2^ooooo`0305Go0?oooooooooo05?ooooo0012ooooo`0305Go0?oooooooooo0:kooooo0P1Eo`1D
ooooo`00@_ooool00`1Eo`3oooooooooo`2^ooooo`<0EOl0Doooool004;ooooo00<00?l0oooooooo
ool0[oooool2003o05?ooooo0012ooooo`0305Go0?oooooooooo0:oooooo0P1Eo`1Cooooo`00@_oo
ool00`1Eo`3oooooooooo`2_ooooo`80EOl0Doooool004;ooooo00<0EOl0ooooooooool0[_ooool2
0000000305Go000000000000057ooooo0011ooooo`040000001Eo`000000ooooo`<00000Zoooool6
0000053ooooo000jooooo`/000000`1VIYT00`00003oooooooooo`2Xooooo`H00000D?ooool003Wo
oooo00<0000004i>CP0000000P000000103<<c<0000004i>CP1>CTh2000000050<bIc0000000VC?<
09Tcc0000000ooooool1ooooo`00??ooool30000000604i>CP00000000000?nZZP000000TI6A1000
003oooooo`7ooooo000looooo`D0000000D0c<c<0?nZZP000000000006IVV@0300000?oooooo0Ooo
ool0043ooooo00<000000?mVc02m_Kd00P00000306IVV@0300000?oooooooooo0?kooooo000ooooo
o`80000000<0c<c<0?nZZP0000000P00000206IVV@0300000?oooooooooo0?kooooo000oooooo`04
0000003oZZX00000000000;ooooo0P0000000`1VIYT00000ooooo`3oooooo`00?oooool2000000Ko
oooo0P00003oooooo`7ooooo003ooooood[ooooo003ooooood[ooooo003ooooood[ooooo003ooooo
od[ooooo003ooooood[ooooo003ooooood[ooooo003ooooood[ooooo003ooooood[ooooo003ooooo
od[ooooo003ooooood[ooooo003ooooood[ooooo003ooooood[ooooo003ooooood[ooooo003ooooo
od[ooooo003ooooood[ooooo003ooooood[ooooo003ooooood[ooooo003ooooood[ooooo003ooooo
od[ooooo003ooooood[ooooo003ooooood[ooooo003ooooood[ooooo003ooooood[ooooo003ooooo
od[ooooo003ooooood[ooooo003ooooood[ooooo003ooooood[ooooo003ooooood[ooooo0027oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01cooooo0026ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0T?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01_ooooo0026ooooo`04o`00
0?ooooooooooooooo`;o00000oooool00ol0003oooooooooo`2@ooooo`04o`000?oooooooooooooo
o`;o00000oooool00ol0003oooooooooo`0Kooooo`00Q_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0007cooooo0P1VIVHDooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00007Oooool007gooooo1@1VIVH4ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo0000O_ooool00`1VIVKoooooooooo`0Aooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00007Oooool007[ooooo0`1VIVH9ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo0000Ooooool00`1VIVKoooooooooo`0206IVIPkooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool0000Mooooo`00MOooool606IVIP_ooooo00?o0000
ooooooooool00ol00003ooooo`03o`000?oooooooooo07_ooooo1@1VIVH@ooooo`03o`000?oooooo
oooo00?o00000oooool00ol0003oooooooooo`0Kooooo`00Ioooool206IVIPOooooo1@1VIVHAoooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0M_ooool606IVIP?ooooo00<0IVIV
ooooooooool03_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo01_ooooo001X
ooooo`0306IVI_oooooooooo00;ooooo101VIVHFooooo`03o`000?oooooo000000?o000000?ooooo
o`000?ooool0Ioooool206IVIPgooooo0`1VIVH9ooooo`80IVIV3oooool00ol0003oooooooooo`02
o`0000;ooooo00?o0000ooooooooool07?ooool006Sooooo1P1VIVJ:ooooo`80IVIV1oooool506IV
IPgooooo0P1VIVHdooooo`00Hoooool606IVIP03ooooo`1VIVH0IVIV01Oooooo1P1VIVI`ooooo`80
IVIV00?ooooo06IVIP1VIVH0101VIVHBooooo`80IVIV<oooool0067ooooo0P1VIVH9ooooo`0306IV
I_oooooooooo01;ooooo0`1VIVIfooooo`<0IVIV6Oooool00`1VIVKoooooooooo`0`ooooo`00Fooo
ool606IVIPcooooo00<0IVIVooooooooool03?ooool506IVIWCooooo1@1VIVH2ooooo`0306IVI_oo
oooooooo01Oooooo0P1VIVHaooooo`00COooool206IVIPOooooo1P1VIVHBooooo`80IVIV1_ooool6
06IVIVOooooo0`1VIVH;ooooo`D0IVIV1oooool206IVIQSooooo0`1VIVH_ooooo`00C_ooool00`1V
IVKoooooooooo`03ooooo`80IVIV6_ooool00`1VIVKoooooooooo`0406IVIVkooooo00<0IVIVoooo
ooooool01_ooool306IVIPgooooo00<0IVIVooooooooool06?ooool00`1VIVKoooooooooo`0]oooo
o`00C_ooool606IVIQ[ooooo1P1VIVHHooooo`<0IVIVEoooool206IVIP03ooooo`1VIVH0IVIV00@0
IVIV4?ooool206IVIQSooooo1@1VIVH[ooooo`00BOooool606IVIP;ooooo00<0IVIVooooooooool0
5?ooool606IVIP;ooooo0P00000206IVIQ?ooooo1P1VIVIGooooo`H0IVIV5oooool00`1VIVKooooo
ooooo`0@ooooo`H0IVIV00?ooooo06IVIP1VIVH0;?ooool004Kooooo101VIVH8ooooo`0306IVI_oo
oooooooo017ooooo0`1VIVH7ooooo`04003o0000003ooooo06IVIQ3ooooo0`1VIVIKooooo`80IVIV
1Oooool00`1VIVKoooooooooo`0Fooooo`0306IVI_oooooooooo00cooooo0`1VIVH8ooooo`0306IV
I_oooooooooo02[ooooo0012ooooo`D0IVIV3?ooool206IVIPcooooo1@1VIVH:ooooo`0405Go0000
003oooooooooo`80IVIV2Oooool506IVITcooooo0P1VIVH;ooooo`D0IVIV1oooool306IVIQKooooo
0`1VIVH7ooooo`H0IVIV2oooool00`1VIVKoooooooooo`0Yooooo`00=?ooool206IVIPKooooo1P1V
IVHBooooo`80IVIV1Oooool606IVIPoooooo00<0EOl0ooooooooool00oooool00`1VIVKooooooooo
o`0606IVIU;ooooo0`1VIVH4ooooo`D0IVIV3_ooool206IVIQOooooo0P1VIVH00oooool0IVIV06IV
IP0306IVIQ;ooooo0P1VIVHYooooo`00=_ooool0101VIVKoooooooooooooool306IVIQWooooo00<0
IVIVooooo`1VIVH00`1VIVHDooooo`0305Go0?oooooooooo00?ooooo101VIVIIooooo`0306IVI_oo
oooooooo0080IVIV5?ooool00`1VIVKoooooooooo`0Eooooo`@0IVIV6?ooool00`1VIVKooooooooo
o`0Vooooo`00=?ooool606IVIQWooooo1P1VIVHGooooo`0305Go001VIVH0IVIV00L0IVIV5_ooool5
06IVIScooooo1@1VIVHGooooo`80IVIV4?ooool606IVIP03ooooo`1VIVH0IVIV01Sooooo0P1VIVHW
ooooo`00;oooool606IVIP?ooooo0P1VIVHDooooo`D0IVIV1Oooool206IVIQ7ooooo1@1VIVH00`1E
o`3oooooooooo`06ooooo`80IVIV4?ooool506IVIRcooooo0P1VIVH>ooooo`D0IVIV1?ooool206IV
IQSooooo00<0IVIVooooooooool02?ooool606IVIPGooooo0P0000000oooool0IVIVooooo`0Hoooo
o`0306IVI_oooooooooo02Cooooo000]ooooo`80IVIV2oooool00`1VIVKoooooooooo`0>ooooo`<0
IVIV3?ooool00`1VIVKoooooooooo`0;ooooo`@0IVIV1?ooool00`00o`3oooooooooo`07ooooo`03
06IVI_oooooooooo00_ooooo0`1VIVHcooooo`0306IVI_oooooooooo00Wooooo0P1VIVH;ooooo`03
06IVI_oooooooooo01Kooooo0P1VIVH6ooooo`80IVIV2oooool01@00o`000000ooooooooool0IVIV
01Wooooo00<0IVIVooooooooool00P1VIVHQooooo`009oooool606IVIPgooooo0`1VIVH8ooooo`H0
IVIV4?ooool00`1VIVKoooooooooo`05ooooo`H0IVIV1oooool00`1Eo`3oooooooooo`08ooooo`80
IVIV1Oooool606IVISKooooo0P1VIVH5ooooo`D0IVIV3Oooool306IVIQOooooo1`1VIVH=ooooo`03
05Go0?oooooooooo00;ooooo0P1VIVHDooooo`H0IVIV8oooool001_ooooo0P1VIVH5ooooo`H0IVIV
5?ooool206IVIP;ooooo1P1VIVHFooooo`L0IVIV3Oooool00`1Eo`3oooooooooo`09ooooo`L0IVIV
?Oooool506IVIQCooooo0P1VIVHCooooo`H0IVIV4Oooool00`1Eo`3oooooooooo`03ooooo`80IVIV
3_ooool606IVIPCooooo0P1VIVHRooooo`007Oooool606IVIQ[ooooo0`1VIVHKooooo`@0IVIV4Ooo
ool00`1Eo`3oooooooooo`07ooooo`<0IVIV00?ooooo06IVI_ooool0?_ooool206IVIP03ooooo`1V
IVH0IVIV01Oooooo0P1VIVH?ooooo`<0IVIV1Oooool206IVIQ3ooooo00<0EOl0ooooooooool01Ooo
ool00`1VIVKoooooooooo`09ooooo`80IVIV2oooool00`1VIVKoooooooooo`0Pooooo`006oooool5
06IVIQSooooo1P1VIVH00oooool0IVIV06IVIP0Dooooo`H0IVIV0oooool206IVIQ3ooooo00@0EOl0
oooooooooooooooo1P1VIVH5ooooo`0306IVI_oooooooooo03Oooooo1@1VIVH4ooooo`<0IVIV5ooo
ool00`1VIVKoooooooooo`07ooooo`H0IVIV2Oooool00`1VIVKoooooooooo`0=ooooo`0305Go0?oo
oooooooo00Gooooo0P1VIVH4ooooo`H0IVIV3_ooool206IVIR3ooooo000Fooooo`D0IVIV1Oooool2
06IVIQ7ooooo1@1VIVH8ooooo`<0IVIV3Oooool606IVIP[ooooo0P1VIVH<ooooo`80IVIV00@0EOl0
06IVIP1VIVH0IVIV@Oooool406IVIP_ooooo0P1VIVHGooooo`80IVIV00?ooooo06IVIP1VIVH0101V
IVH@ooooo`80IVIV3Oooool00`1Eo`3oooooooooo`06ooooo`H0IVIV5?ooool206IVIQoooooo000R
ooooo`0306IVI_oooooooooo00_ooooo0`1VIVH?ooooo`0306IVI_oooooooooo00Sooooo0`1VIVHB
ooooo`0306IVI_oooooooooo00Kooooo101VIVH00oooool00?l0ooooo`1Cooooo`80IVIV5oooool3
06IVIQOooooo00<0IVIVooooooooool02_ooool00`00o`3oooooooooo`03ooooo`@0IVIV00?ooooo
06IVI_ooool05oooool00`1VIVKoooooooooo`0Mooooo`008_ooool306IVIPGooooo1P1VIVHCoooo
o`80IVIV0oooool506IVIQGooooo0`1VIVH00oooool0IVIV06IVIP0406IVIPCooooo00<0EOl0oooo
ooooool0E?ooool00`1VIVKoooooooooo`0?ooooo`D0IVIV00?ooooo06IVIP1VIVH05oooool206IV
IP_ooooo00<0EOl0ooooo`1VIVH0101VIVH5ooooo`80IVIV5oooool206IVIQgooooo000Tooooo`L0
IVIV5oooool606IVIQSooooo1P1VIVH:ooooo`0305Go0?oooooooooo05Gooooo0P1VIVH:ooooo`H0
IVIV1oooool206IVIQKooooo0`1VIVH5ooooo`@0IVIV00<0EOl006IVI_ooool02oooool00`1VIVKo
ooooooooo`0Fooooo`0306IVI_oooooooooo0080IVIV6?ooool002;ooooo0`1VIVH00oooool0IVIV
ooooo`0Gooooo`@0IVIV0oooool00`1VIVKoooooooooo`0Eooooo`80IVIV1Oooool00`1VIVKooooo
ooooo`07ooooo`80EOl0FOooool00`1VIVKoooooooooo`04ooooo`<0IVIV3_ooool206IVIQOooooo
00@0IVIVoooooooooooooooo0`1VIVH3ooooo`0305Go0?oooooooooo00cooooo00<0IVIVoooooooo
ool05Oooool306IVIQ[ooooo000Nooooo`D0IVIV1?ooool206IVIQ7ooooo1P1VIVH7ooooo`80IVIV
3oooool606IVIQ7ooooo0P1Eo`1Iooooo`P0IVIV4Oooool206IVIQCooooo1P1VIVH6ooooo`0305Go
0?oooooooooo00cooooo0`1VIVH@ooooo`D0IVIV0_ooool00`1VIVKoooooooooo`0Hooooo`00:?oo
ool306IVIPWooooo1P1VIVH?ooooo`80IVIV1oooool606IVIQOooooo0P1Eo`1Fooooo`L0IVIV5ooo
ool206IVIPgooooo1P1VIVH3ooooo`80IVIV1_ooool00`1Eo`3oooooooooo`0>ooooo`80IVIV2_oo
ool506IVIPSooooo00<0IVIVooooooooool05oooool002[ooooo0P1VIVH6ooooo`<0IVIV5_ooool0
101VIVKoooooooooooooool406IVIQcooooo0P00o`1Cooooo`@0IVIV1_ooool00`1VIVKooooooooo
o`0Eooooo`0306IVI_oooooooooo00Wooooo0P1VIVH;ooooo`0306IVI_oooooooooo00;ooooo0P00
o`0Aooooo`0306IVI_oooooooooo00Gooooo0`1VIVH>ooooo`0306IVI_oooooooooo01Kooooo000[
ooooo`L0IVIV6?ooool606IVIQoooooo0P1Eo`1@ooooo`@0IVIV2Oooool306IVIQKooooo0P1VIVH3
ooooo`H0IVIV3Oooool306IVIP;ooooo0P1Eo`0Booooo`L0IVIV4_ooool00`1VIVKoooooooooo`0E
ooooo`009oooool506IVIP03ooooo`1VIVH0IVIV01Kooooo1@1VIVH3ooooo`80IVIV8?ooool205Go
05oooooo0P1VIVHFooooo`D0IVIV5?ooool206IVIP03ooooo`1Eo`00EOl000kooooo1`1VIVH^oooo
o`009Oooool206IVIPSooooo00<0IVIVooooooooool04?ooool306IVIR[ooooo0P1Eo`1Qooooo`03
06IVI_oooooooooo013ooooo0`1VIVH2ooooo`80IVIV5_ooool0101VIVKooooo05Go001Eo`0;oooo
o`@0IVIV1_ooool00`1VIVKoooooooooo`0[ooooo`00<?ooool206IVIP[ooooo1P1VIVH]ooooo`80
EOl0H_ooool206IVIP_ooooo1@1VIVH6ooooo`80IVIV5_ooool00`1VIVH0EOl005Go0006ooooo`H0
IVIV2_ooool00`1VIVKoooooooooo`0Zooooo`00<Oooool306IVIP;ooooo1`1VIVHbooooo`80EOl0
Hoooool206IVIPCooooo1P1VIVH<ooooo`<0IVIV5Oooool205Go0003ooooo`1VIVH0IVIV00<0IVIV
4Oooool00`1VIVKoooooooooo`0Yooooo`00<oooool406IVISOooooo0`00o`1Uooooo`0306IVI_oo
ool0IVIV0080IVIV4oooool00`1VIVKoooooooooo`0Cooooo`04003o001VIVH0IVIV06IVIT7ooooo
000^ooooo`P0IVIV>?ooool205Go06?ooooo1P1VIVHFooooo`80IVIV3_ooool506IVIP0305Go0?oo
oooooooo0080IVIV@?ooool002gooooo00<0IVIVooooooooool01_ooool00`1VIVKoooooooooo`0e
ooooo`80EOl0GOooool606IVIPKooooo00<0IVIVooooooooool05Oooool00`1VIVKoooooooooo`06
ooooo`D0IVIV1Oooool0101Eo`3oooooooooooooool206IVISoooooo001^ooooo`80EOl0G?ooool2
06IVIPcooooo00<0IVIVooooooooool05Oooool00`1VIVKoooooooooo`02ooooo`<0IVIV2_ooool0
0`1Eo`3oooooooooo`03ooooo`0306IVI_oooooooooo03cooooo001^ooooo`0305Go0?oooooooooo
06[ooooo0P1VIVHEooooo`D0IVIV3?ooool205Go04Cooooo001]ooooo`80EOl0KOooool206IVIPko
oooo1P1VIVH2ooooo`80IVIV3Oooool205Go04Cooooo001]ooooo`800?l0Koooool00`1VIVKooooo
ooooo`09ooooo`<0IVIV2Oooool00`1VIVKoooooooooo`09ooooo`<00?l0A?ooool006gooooo0P1E
o`1`ooooo`80IVIV1?ooool506IVIPcooooo0P1VIVH:ooooo`80EOl0AOooool006gooooo0P1Eo`1`
ooooo`H0IVIV7Oooool205Go04Gooooo001]ooooo`80EOl0K_ooool306IVIP;ooooo00<0IVIVoooo
ooooool07Oooool205Go04Gooooo001]ooooo`0305Go0?oooooooooo06Oooooo1P1VIVH6ooooo`80
IVIV7Oooool205Go04Gooooo001]ooooo`0305Go0?oooooooooo06Kooooo0P1VIVH=ooooo`0306IV
I_oooooooooo01[ooooo00<0EOl0ooooooooool0A?ooool006cooooo0P00o`2Cooooo`800?l0A_oo
ool006cooooo0P1Eo`2Cooooo`80EOl0A_ooool006?ooooo0`000005ooooo`03003o001Eo`00EOl0
09?ooooo00<0EOl000000?ooool0AOooool006?ooooo00<0000006K<o`1Vc?l00P000003ooooo`80
EOl0U?ooool2000004Kooooo001Nooooo`D0000000?ooooo0000002ZZ_l00P2ZZ_l300000080EOl0
S_ooool9000004Gooooo001Mooooo`8000000`1EZ_l8000000030:ZZo`1Eo`000?l0093ooooo0P00
000205Go00@00000A?ooool0067ooooo0P0000000`1Eool0EJ[o05FZo`0305FZo`0405Goo`000000
0?l0000009;ooooo0`00o`00102ZZ_l0c9W<000000000013ooooo`00Hoooool2000000<0EJ[o0P00
00000`00o`00EOl000000002000008oooooo101Eo`05000004;ooooo001Yooooo`05003o001Eo`00
EOl005Go002ZZ_l01000002;ooooo`07003o001Eo`00EOl005Go00000000EOl0ooooo`0200000003
0:ZZo`00003ooooo043ooooo001Xooooo`D0EOl000D0000005FZo`2m_Kd0000005FZo`02000008So
oooo101Eo`000`000000EOl005Go0004ooooo`0300000?oooooooooo03oooooo001Xooooo`0505Go
0000o`00EOl00000001Eo`000P0000030:ZZo`0305FZo`000000000008Kooooo0P1Eo`000`00o`3o
oooo05Go0002ooooo`80EOl0AOooool006Oooooo0P1Eo`001Oooool0EOl0ooooo`00o`00EOl000@0
000000<0EJ[o0:ZZo`2ZZ_l00`000023ooooo`80EOl000?ooooo05Go001Eo`000_ooool205Go04Go
oooo001Wooooo`04003o0?ooool00?l0003o00;ooooo00<00?l00000000000000P2ZZ_l300000080
ZZ[o00<00000ooooooooool0P?ooool2003o00;ooooo0P00o`02ooooo`800?l0AOooool006Gooooo
00@00?l005Go001Eo`3ooooo0P1Eo`02ooooo`80EOl000Cooooo000000000000ZZ[o1`00001ooooo
o`03003o001Eo`00EOl000;ooooo0P1Eo`02ooooo`<0EOl0A?ooool006Cooooo00D00?l005Go001E
o`3ooooo003o000205Go00;ooooo0P1Eo`02ooooo`<000001?ooool2000007kooooo00<00?l005Go
001Eo`000oooool00`1Eo`3oooooooooo`02ooooo`80EOl0A?ooool006Cooooo0P1Eo`02ooooo`80
EOl01?ooool00`1Eo`3oooooooooo`02ooooo`0300000?oooooooooo08;ooooo0P1Eo`03ooooo`80
EOl01?ooool205Go04Cooooo001Sooooo`80EOl00oooool205Go00Cooooo0P1Eo`27ooooo`80EOl0
1?ooool205Go00Gooooo00<0EOl0ooooooooool0@_ooool006;ooooo0P1Eo`001@00o`3ooooooooo
ooooool0EOl000Gooooo00<00?l005Go001Eo`00QOooool205Go0004003o0?ooooooooooooooo`80
EOl000<00?l0ooooooooool00oooool205Go04?ooooo001Qooooo`800?l01?ooool2003o00Kooooo
0P00o`24ooooo`03003o000000000000008000000_ooool2003o00Kooooo0P00o`13ooooo`00H?oo
ool00`00o`00EOl005Go0004ooooo`80EOl01oooool00`1Eo`000?l0ooooo`21ooooo`03003o001E
o`0000000080EJZZ10000008ooooo`0305Go0?oooooooooo00Cooooo2`00000booooo`00Goooool0
0`00o`00EOl005Go0005ooooo`80EOl01oooool205Go087ooooo0`1Eo`001@000000EJZZ05FZZP1E
ZZX005Go0080EJZZ0`000005ooooo`80EOl00_ooool00`2ZEOl000000000000:0:VYZ@0300000?oo
oooooooo033ooooo001Oooooo`80EOl01Oooool205Go00Sooooo0P1Eo`21ooooo`80EOl00_ooool3
03=Vo`03001Eo`0cI_l0<fKo00<0<fKo0P000003ooooo`80EOl000<0ZZZZ0:VYZ@2YZJT00P2YZJT0
0`2ZZZX0ZJVY0:VYZ@030:VYZ@030:ZZZP2YZJT0ZJVY0080ZJVY00<00000ooooooooool0;oooool0
05kooooo0P1Eo`06ooooo`80EOl02Oooool205Go07oooooo0P1Eo`04ooooo`80EJZZ00<005Go05FZ
ZP1EZZX00`1EZZX01P00EOl00000000000000000ZJVY003o0080EOl03`2YZJT00`00003ooooooooo
o`0_ooooo`00G_ooool00`1Eo`000?l0ooooo`04ooooo`80EOl000<00?l0ooooooooool01oooool3
05Go07kooooo00<0EOl0003o0?ooool00oooool205FZZP03001Eo`1EZZX0EJZZ00<0EJZZ00@005Go
05FZZP1EZZX0EJZZ0P00000205Go0100ZJVY0P00000_ooooo`00GOooool2003o00Kooooo0P00o`0;
ooooo`800?l0OOooool2003o00Kooooo00<0EJZZ001EZP1EZZX0101EZZX00`00EJX0EJZZ05FZZP02
05FZZP0500000000o`000?l00:VYZ@2ZEOl01@2YZJT00`2ZEOl0ZJVY0:VYZ@030:VYZ@050:YEo`2Y
ZJT0ZJVY0:VYZ@000000;oooool005cooooo0`1Eo`06ooooo`80EOl02oooool205Go07cooooo00<0
0?l005Go001Eo`001_ooool>0000000305Go00000000ZJVY00l0ZJVY00<00000ooooooooool0;Ooo
ool005_ooooo00<00?l005Go0?ooool01oooool00`1Eo`3oooooooooo`0;ooooo`0305Go0?oooooo
oooo07Wooooo00<00?l005Go001Eo`00102Z000:00000003001Eo`1EZZX0EJZZ00<0EJZZ00<005Go
05Go000000000`00000=0:VYZ@800000;_ooool005_ooooo0P1Eo`07ooooo`80EOl03Oooool205Go
07?ooooo0P000002ooooo`T0E@000P0000001P1E00000000000000000000c9VI00000080ZJVY0`00
000403=Vo`03001Eo`0cI_l0<fKo0080<fKo0P0000050:VYZ@030:ZZZP2YZJT0ZJVY00<0ZJVY00<0
ZZZZ0:VYZ@000000;_ooool005[ooooo0P1Eo`08ooooo`80EOl03Oooool205Go06gooooo1P00000:
0:X000<00000102Z00000`000000ojZZ00000002000000<0ZJVY100000000`1EZZX005Go05FZZP04
05FZZP04001Eo`0000000000000000T0ZJVY00<00000ooooooooool0;Oooool005Wooooo0P1Eo`00
0`00o`3oooooooooo`06ooooo`0305Go0000o`3ooooo00cooooo00<00?l005Go0?ooool0J_ooool2
000000d0ZP000`0000060:X00080000000D0ojZZ0000003oZZX0ojZZ000000060:VYZ@@000000`1E
ZZX01@00EOl0EJZZ05FZZP1EZZX0000000P0ZJVY00<00000ooooooooool0;Oooool005Sooooo0P1E
o`09ooooo`80EOl03oooool205Go06Wooooo0P00000;0:X000<000002@2Z000010000000ojZZ0?nZ
ZP0000030?nZZP030000002YZJT0ZJVY00H0ZJVY00D0EOl00000000000000000001Eo`0405FZZP03
0000002YZJT0ZJVY00@0ZJVY00<00000ooooooooool0;_ooool005Sooooo0P00o`09ooooo`800?l0
3_ooool2000000800?l0J?ooool00`000000ZP000:X000080:X0008000002`2Z000200000080ojZZ
00<000000?nZZP3oZZX00P3oZZX010000000ZJVY0:VYZ@2ZEOl40:VYZ@800?l00P2YZJT2000000@0
EJZZ0P000000102YZJT0ZUGo0:VYZ@00000aooooo`00Eoooool00`00o`00EOl0ooooo`06ooooo`<0
00000P1Eo`0;ooooo`D0000000@0EOl00000000000000000Ioooool00`000000E@00000000030000
00040:X0000000000000000000`0ZP0000<00000ooooo`0000000P3oZZX00`000000ojZZ0?nZZP03
0?nZZP030000002YZJT0ZJVY00@0ZJVY0P1Eo`040:VYZ@@0000000<005Go0000000000000`00000a
ooooo`00E_ooool305Go00Oooooo0P00EJX205Go000300000?oooooooooo00cooooo00@00000oooo
o`000000EOl01000001[ooooo`<000002`2Z000500000080ojZZ00<000000?nZZP3oZZX0103oZZX0
0`000000ZJVY0:VYZ@030:VYZ@80EOl000<00?l00:VYZ@2YZJT0102YZJT400000080ZJVY00<00000
ooooooooool0;oooool005Kooooo0P1Eo`09ooooo`@005FZ00<00000ooooooooool03_ooool00`1E
o`0000000<bIc003000006gooooo00<0000005D0001E00001`1E00000`000000ooo<0?nZZP020000
0080c9VI00<0_Kfm0<bIV@0000000`3<VIT0102m_Kd0c9VI0000000000020:VYZ@030:ZZZP2YZJT0
ZJVY0080EOl000<0ZJVY0:ZZZP2YZJT0102YZJT00`2ZZZX0ZJVY0:VYZ@020:VYZ@0300000?oooooo
oooo02oooooo001Eooooo`0405Go000000000000000000Sooooo1@00EJX2000000Cooooo0`1VIYT8
0000000305Go00000000000000<00000K?ooool:000000030?nZZP3<VIT0000000800000103oZZX0
0`000000ojZZ0?nZZP020?nZZP80000000?ooooo0000002YZJT00`2YZJT205Go00`0ZJVY00<00000
ooooooooool0;oooool005;ooooo100000000`2ZEED0c3<c0:YEE@040:YEE@030<`c<`2ZEED00000
00T000000`1EZ_l00`1VIYT0EJ[o05FZo`0305FZo`0306IVV@1EZ_l0EJ[o0080EJ[o00<0EOl00000
00000000K_ooool205Go00?ooooo0P0000050?nZZP0300000?ooool0000000D0ojZZ00<000000?nZ
ZP3oZZX00`000003ooooo`060000002YZJT0ZJVY0:VYZ@00o`00EOl0302YZJT00`00003ooooooooo
o`0_ooooo`00D_ooool00`000000CTi>04i>CP0204i>CP030<`c<`1>CTh0CTi>00<0CTi>0P000002
04i>CPD0000000@0003o001EZP00EJX000000P1EZ_l00`1EEJX0EJ[o05FZo`0305FZo`0305EEZP1E
Z_l0EJ[o0080EJ[o0P00o`000`00003oooooooooo`1/ooooo`800?l00_ooool01@000000c9VI0<bI
V@3<VIT0oonZ0080c9VI00@00000ooooooooool000001@3oZZX010000000ojZZ0?nZZP000006oooo
o`050000002YZJT0ZJVY0:YEo`00o`00102YZJT00`2ZEOl0ZJVY0:VYZ@030:VYZ@030:YEo`2YZJT0
0000037ooooo001Booooo`8000000`2ZEED00`3<<c<0ZUEE00000003000000040<`c<`2ZEED0ZUEE
0:YEE@80000000<0ojZZ0000000000000P000002001EZP030000001EZ_l0IVJI00D0EJ[o00<0IVJI
05FZo`1EZ_l00P1EZ_l205Go00800000K?ooool205Go00;ooooo0P0000000`3<VIT0ojZZ0?nZZP03
0?nZZP0400000?oooooooooo000000D0ojZZ0`000003ooooo`P0000000<0EOl00:VYZ@2YZJT02P2Y
ZJT00`00003oooooooooo`0_ooooo`00D_ooool305Go00D000000`2ZEED0103<<c<0ZUEE0:YEE@2Z
EED200000080ojZZ00<0000006IVV@0000000P0000000`00EJX000000000000505FZo`0306IVV@1E
Z_l0EJ[o00<0EJ[o0P1Eo`02000006[ooooo0`1Eo`02ooooo`050000003oZZX0c9VI0?nZZP000000
0P3oZZX01000003oooooooooo`0000060?nZZP0300000?oooooooooo00;ooooo0P0000000`00VL`0
EJ[o000000040000000305Go00000000000000800000202YZJT00`00003oooooooooo`0_ooooo`00
D_ooool0101Eo`3oooooooooooooool2000000D0ZUEE00L0ZP000:YEE@2ZEED000000<bIV@000000
]KFe0080c9VI00H0000006IVV@1VIYT0c9W<00000000EJX3000000030<bIc01VIYT0IVJI00<0IVJI
00<0c9W<06IVV@1VIYT00P1Eo`000`1VIYT00000ooooo`1Uooooo`80000000?ooooo05Go001Eo`00
0oooool010000000ojZZ0?nZZP3ool`30?nZZP0500000?ooooooooooooooo`000000103<VIT00`2m
_Kd0c9VI0000000=ooooo`0605Go00000000^KVi0:YEZP2=SHd000000P2YZJT01@2ZZZX0ZJVY0:VY
Z@2YZJT0000003;ooooo001Aooooo`0305Go000000000000008000000P2ZojX2000000<0ZUEE00@0
c3<c0:YEE@00000000000P3oZZX01@000000ojZZ0?nZZP3<VIT0000000<0EJ[o1`0000000`1VIYT0
EJ[o05FZo`0305FZo`0506IVV@1Eo`00EOl005FZo`000000G_ooool5000000;ooooo0P00000205Go
0004003o0?oooooooooo000000<0ojZZ00@0c9VI0?nZZP00000000001?ooool00`000000ojZZ0?nZ
ZP030?nZZP0300000?oooooooooo00_ooooo0P1Eo`04000000050:ZZo`00000000000000002YZJT0
0`00000booooo`00Coooool4000000D0Z_nZ20000000103<VIT0ojZZ0?nZZP0000020?nZZP030<bI
V@3oZZX0000000<0EJ[o00<0IVJI0000001EZ_l00P1EZ_l4000000<0EJ[o00D0IVJI05Go001Eo`00
EJ[o0000001Oooooo`03002Ic0000000EJ[o00@0000000<0EJ[o05Go001Eo`000_ooool200000003
0?nZZP0000000000008000001_ooool010000000ojZZ0?nZZP3oZZX2000000kooooo0`1Eo`02oooo
o`H00000=Oooool004kooooo0P0000030:[oZP050:[oo`2ZojX0Z_nZ0:[oZP0000001_ooool00`00
0000ojZZ0<bIc0020?nZZP040000003oZZX0ojZZ0<bIc080ojZZ00@0000005FZo`1EZ_l0EEFZ1@1E
Z_l00`1EEJX0EJ[o05FZo`020000000605FZo`1EEJX0EJ[o003o001EZ_l00000H?ooool01@000000
0:[o002Zo`000000EJ[o0080000000@0EJ[o00000?oooooooooo0`0000000oooool00000ooooo`07
ooooo`030000003oZZX0ojZZ008000003oooool3003o00Gooooo00@0ZZ[o00000?ooool00000=?oo
ool004_ooooo0`0000070:[oZP8000001oooool00`000000ojZZ0<bIV@030?nZZP030000003oZZX0
c9VI00<0ojZZ00<0000005FZo`1VIYT01@1EZ_l0101VIYT0EJ[o05FZo`1EZ_l400000080EOl0H_oo
ool8000000;ooooo00<00000ooooooooool02_ooool4000000oooooo00@0000005Go000000000000
1oooool00`00003oooooooooo`0cooooo`00B?ooool3000000L0Z_nZ0`000009ooooo`030000003o
ZZX0c9VI00<0ojZZ00<000000?nZZP3<VIT0103oZZX00`000000IVJI05FZo`0405FZo`0306IVV@1E
Z_l0EJ[o00<0EJ[o00<0IVJI05FZo`0000000P1Eo`1Tooooo`04003o001Eo`00EOl00:ZZo`800000
8Oooool205Go00030000001Eo`00EOl003cooooo0017ooooo`040000002ZojX0Z_nZ0=cLg0D0Z_nZ
00<0g=cL00000?ooool02_ooool00`000000c9VI0<bIV@030<bIV@030;Fe]@000000c9VI00<0c9VI
00<0]KFe0<bIV@3<VIT00P0000000`1VIYT0c9W<06IVV@0406IVV@030<bIc01VIYT0IVJI0080IVJI
00<0000005Go001Eo`00Hoooool405Go00040:ZZo`000000ZZ[o0000023ooooo0P1Eo`000oooool0
EOl005Go000looooo`00A_ooool00`000000Z_nZ00000007000000cooooo0P0000020?nZZP070<bI
V@3oZZX0ojZZ0?nZZP000000ojZZ0<bIV@050?nZZP030<bIV@000000000000<0EJ[o00<0IVJI05FZ
o`1EZ_l00`1EZ_l0101VIYT0EJ[o00000?ooool205Go067ooooo101Eo`001P000000ZZ[o0:ZZo`00
0000a<C4000001oooooo00@0EOl0ooooooooool00?l00P1Eo`0kooooo`00A_ooool00`00003ooooo
ooooo`03ooooo`80EOl000<00?l0ooooooooool02oooool01@000000ojZZ0?nZZP3oZZX0c9VI00<0
ojZZ00<000000?nZZP3<VIT01@3oZZX00`3<VIT0ojZZ0?nZZP020000000305FZo`1VIYT0EJ[o00@0
EJ[o00D0IVJI05FZo`00003ooooo003o000205Go05kooooo1P1Eo`001@2ZZ_l00000000000000000
a<C4008000007Oooool205Go00?ooooo0P1Eo`0kooooo`00C?ooool00`00o`3oooooooooo`0=oooo
o`050000003oZZX0ojZZ0?nZZP3<VL`00`3oZZX00`000000ojZZ0<bIc0050?nZZP070<bIc03oZZX0
ojZZ0?nZZP000000EJ[o05EEZP0505FZo`0305EEZP1EZ_l0000000;ooooo0P00o`1Nooooo`H00?l0
00<0ZZ[o0<c<c00000000`3<VOl00`00003oooooooooo`0Qooooo`03003o0?oooooooooo03Wooooo
001;ooooo`80EOl03_ooool00`000000ojZZ0?nZZP020?nZZP030<bIV@3oZZX0ojZZ0080ojZZ00<0
00000<bIV@3oZZX0103oZZX00`3<VIT0ojZZ0?nZZP030?nZZP8000000`1EZ_l3000000?ooooo0`1E
o`1Looooo`80EOl000Gooooo05Go001Eo`00EOl0000000020:ZZo`H000008_ooool00`1Eo`000?l0
ooooo`0iooooo`00B_ooool00`00o`00EOl0ooooo`0>ooooo`030000003oZZX0ojZZ0080ojZZ00<0
c9VI0?nZZP3oZZX00P3oZZX00`000000c9VI0?nZZP040?nZZP030<bIV@3oZZX0ojZZ00<0ojZZ00<0
c9VI0000000000000`000006ooooo`80EOl0F_ooool01@000000EOl00000000000000?l000<0EOl0
0P0000000`2ZZ_l00000ooooo`02ooooo`<000008Oooool205Go03[ooooo001:ooooo`80EOl03_oo
ool010000000c9VI0<bIV@2e]KD50<bIV@030;Fe]@3<VIT0000000<0c9VI00<0]KFe0<bIV@3<VIT0
0`3<VIT01@2e]KD0c9VI0<bIV@3<VIT0000000_ooooo00<0EOl0ooooooooool0F?ooool205Go0080
0000101Eo`001?ooool000000:ZZo`000005ooooo`0300000?oooooooooo023ooooo00<0EOl0oooo
ooooool0>?ooool004Wooooo0P1Eo`000`00o`3oooooooooo`0<ooooo`030000003oZZX0ojZZ00<0
ojZZ00<0c9VI0?nZZP3oZZX00P3oZZX00`000000c9VI0?nZZP040?nZZP030<bIV@3oZZX0ojZZ00<0
ojZZ00<0c9VI00000?ooool02_ooool205Go05Oooooo0`1Eo`02ooooo`80EOl000?ooooo05Go001E
o`000_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo023ooooo0P1Eo`0iooooo`00
BOooool00`1Eo`000?l0ooooo`0=ooooo`030000003<VIT0ojZZ00@0ojZZ00<0c9VI0?nZZP3oZZX0
0P3oZZX00`000000c9VI0?nZZP040?nZZP030<bIV@3oZZX0ojZZ00<0ojZZ0P00000;ooooo`03003o
001Eo`00EOl000800000D_ooool305Go0003003o0?oooooooooo0080EOl00_ooool00`1Eo`3ooooo
ooooo`0[ooooo`<0EOl0>?ooool0043ooooo10000004ooooo`800?l03oooool00`000000c9W<0?nZ
ZP040?nZZP030<bIc03oZZX0ojZZ0080ojZZ00<000000<bIc03oZZX0103oZZX00`3<VL`0ojZZ0?nZ
ZP030?nZZP0300000?oooooooooo00_ooooo0P00o`0205EEo`0300000?ooool0000000<00000Booo
ool3003o00?ooooo0P00o`02ooooo`800?l0;_ooool2003o03Sooooo000looooo`/0000000<00?l0
05Go001Eo`003oooool00`000000c9VI0?nZZP040?nZZP030<bIV@3oZZX0ojZZ00<0ojZZ00<00000
0?nZZP3oZZX00`3oZZX0103<VIT0ojZZ0?nZZP3oZZX2000000[ooooo1000000305Go00@000000P2Z
Z_l2000004Wooooo0`1Eo`03ooooo`03003o001Eo`00EOl000;ooooo0P1Eo`0^ooooo`0305Go0000
0000000003Oooooo000oooooo`P0000000<0EOl00000000000000P00000<ooooo`80000000<0c9VI
0?nZZP3oZZX00`3oZZX00`3<VIT0ojZZ0?nZZP030?nZZP030000003oZZX0ojZZ00<0ojZZ00<0c9VI
0?nZZP3oZZX00P00000;ooooo`@0000000<0ZUEE0:X0000000001@0000020:ZZo`800000Aoooool2
05Go00Gooooo0P1Eo`03ooooo`80EOl09oooool4000000Cooooo0P00EJX2000000Cooooo0`00000^
ooooo`00A_ooool205Go00030000003<VOl0_Kfm008000002oooool00`000000c9VI0<bIV@020<bI
V@030;Fe]@3<VIT0c9VI00<0c9VI00@0]KFe0<bIV@3<VIT000000P3<VIT00`2e]KD0c9VI0<bIV@02
0<bIV@0300000?oooooooooo00kooooo1P000000102ZZZX0<`2I0000000000020:ZZZP0300000?oo
oooooooo04Gooooo00<0EOl0ooooooooool00oooool205Go00Cooooo00<0EOl0ooooooooool09ooo
ool010000000ZUD00:YE002Z00030:YE0080000000<0002Z001EZP0000000`1EZZX00`3<VL`0EJZZ
00000002000002cooooo0015ooooo`<0EOl00P0000000`3<VL`0000000000002000000Wooooo00<0
00000?nZZP3<VIT01@3oZZX00`3<VIT0ojZZ0?nZZP030?nZZP030<bIV@000000000000H000004Ooo
ool2000000040:VYZ@000000VC?<00000080ZZ[o0`00001>ooooo`80EOl01?ooool00`1Eo`3ooooo
ooooo`0Yooooo`@0000000<0ZUD00000000000000`0000000`1EEJX0000005FZo`0305FZo`0305FZ
ZP1EZ_l0000002_ooooo0015ooooo`<0EOl01@0000020:ZZo`<000001_ooool00`000000ojZZ0<bI
V@050?nZZP030<bIV@3oZZX0ojZZ0080ojZZ1000000Fooooo`D0000000?ooooo09Tcc00000000`2Z
Z_l00`00003oooooooooo`1:ooooo`<0EOl01?ooool205Go02gooooo1@0000000`3De=@0EJ[o0000
000400000080EJ[o00@0EJZZ05FZo`1EZ_l00000:_ooool004Cooooo1000o`02ooooo`80000000H0
ZZ[o00000000000000000<bIc0000006ooooo`030000003oZZX0c9W<00D0ojZZ00<0c9W<0?nZZP3o
ZZX00P3oZZX00`00003oooooooooo`0Nooooo`050000002ZZ_l0ZZ[o0:ZZo`000000C?ooool2003o
00Gooooo0P00o`0/ooooo`80000000P0oonZooooo`00000000000=CDe03oZZX0EJ[o05EEZP@00000
00<0EJ[o05EEZP1EZ_l00P1EZ_l00`00003oooooooooo`0Wooooo`00@oooool00`00o`00EOl005Go
000205Go00?ooooo10000002ooooo`8000001Oooool00`000000ojZZ0<bIV@050?nZZP030<bIV@3o
ZZX0ojZZ008000008_ooool3000004cooooo00<00?l005Go0?ooool01Oooool205Go02[ooooo0P00
00020:[oZP050=3@d000000000000?nZZP0000000`3oZZX00`1EZ_l0000000000007000002Wooooo
0013ooooo`80EOl000?ooooo05Go0?ooool01_ooool00`00003oooooooooo`07ooooo`@00000103o
ZZX00`3<VIT000000000001booooo`03003o001Eo`00EOl000Gooooo00<00?l005Go001Eo`00:Ooo
ool200000080Z_nZ00<0d=3@0000000000000P3oZZX40000000305FZZP1EZ_l0EJ[o00<0000000<0
EJ[o00000?ooool0:_ooool004;ooooo0P1Eo`02ooooo`0305Go0?oooooooooo01?ooooo0`000002
0<bIV@0300000?oooooooooo077ooooo0P1Eo`06ooooo`80EOl0:Oooool010000000d=3@0:[oZP00
0002ooooo`040000003oojX0c<c<0<c<c08000000oooool0101EZZX0c9W<05FZZP1EZZX3000002_o
oooo0012ooooo`80EOl00_ooool00`1Eo`3oooooooooo`0Fooooo`800000Loooool205Go0003003o
0?oooooooooo00Cooooo0P1Eo`0Xooooo`80000000<0d=3@00000?ooool00_ooool010000000ojZZ
0?nZZP000006ooooo`<0EJ[o00@0EJZZ0000000000000000:_ooool0047ooooo0P1Eo`02ooooo`80
EOl0O_ooool3000000_ooooo0P1Eo`08ooooo`@000009Oooool3000000Gooooo0`000008ooooo`D0
0000:oooool0043ooooo0`00o`02ooooo`800?l0OOooool010000000c3<00<`c003<<`02000000Wo
oooo00<00?l0ooooooooool01?ooool300000004002Ic03<VL`009W<000006Sooooo000oooooo`03
003o001Eo`00EOl000?ooooo00<0EOl0000000000000O?ooool00`000000EED005EE000205EE0003
0<`c<`1EE@00c3<00080c3<00oooool00`00o`00EOl005Go0002ooooo`8009W<00<0c9W<002Ic000
VL`00`00VL`00`1EZZX009W<002Ic002000006Kooooo000oooooo`80EOl01?ooool3000007cooooo
0`00000205EE00030<`c<`000000000000D000000P1Eo`02000000<009W<00<0EJZZ002Ic000VL`0
0`00VL`01@1EZZX009W<002Ic000VL`0000006Kooooo000oooooo`0305Go0?oooooooooo00?ooooo
00<0EOl000000?ooool0Ooooool3000000<0EED01000000205EE0080000000<0c9W<000000000000
0`1EZZX00`3<VL`0EJZZ05FZZP0305FZZP030<bIc01EZZX0000006Gooooo000nooooo`80EOl01Ooo
ool205Go083ooooo0P0000000`3<<c<00000000000020000000305EE003<<c<0000000H0000000<0
09W<0000000000000`0000000`00VL`0EJZZ002Ic003002Ic00300000?oooooooooo06?ooooo000m
ooooo`80EOl000<00?l0ooooooooool00oooool205Go083ooooo1@00000205EE00<0000000D0ojZZ
00000000000000000:YE00020000000405FZZP00VL`009W<002Ic0D0000000<009W<000000000000
IOooool003gooooo0P00o`06ooooo`800?l0O_ooool2000000@0f=SH100000001?ooool000000?nZ
ZP0000020?nZZP80000000<0ZUD00000000000001000VL`00`3<VL`009W<002Ic002000006Kooooo
000looooo`80EOl01oooool00`1Eo`3oooooooooo`1jooooo`<00000102ZojX00`3Hf=P000000000
0004ooooo`040000003oZZX0000000000080ojZZ1@000003002Ic00505FZZP00VL`009W<002Ic000
0000I_ooool003_ooooo00<00?l005Go001Eo`001oooool00`1Eo`3oooooooooo`1iooooo`@00000
00<0Z_nZ0000000000000P000005ooooo`8000000P3oZZX01P000000ojZZ0?nZZP3oZZX00000oooo
o`D0000000D0EJZZ002Ic000VL`009W<0000001Vooooo`00>oooool205Go00Sooooo00<0EOl0oooo
ooooool0N?ooool2000000;ooooo0P000009ooooo`080000003oZZX0ojZZ0?nZZP000000ojZZ0;fm
_@000004ooooo`<000000`1EZZX00`3<VL`00000ooooo`1Uooooo`00>_ooool205Go0003003o0?oo
oooooooo00Kooooo00<0EOl0ooooooooool0Q_ooool2000000<0ojZZ0`000006ooooo`<0000000@0
09W<0000000000000000I_ooool003Wooooo0P1Eo`0:ooooo`0305Go0?oooooooooo08Kooooo00<0
00000?nZZP3oZZX00P3oZZX2000000Kooooo0P1Eo`02ooooo`0300000?oooooooooo06Oooooo000h
ooooo`800?l02oooool00`00o`3oooooooooo`26ooooo`030000003oZZX0ojZZ0080ojZZ00<00000
ooooooooool01Oooool2003o06cooooo000gooooo`03003o001Eo`00EOl009?ooooo0P0000030?nZ
ZP8000001oooool205Go06cooooo000gooooo`80EOl0U?ooool00`000000ojZZ0?nZZP02000000Wo
oooo0P1Eo`1/ooooo`00=_ooool205Go09Kooooo0`00000:ooooo`80EOl0K?ooool003Kooooo00<0
EOl0003o0?ooool0X_ooool205Go06cooooo000eooooo`80EOl0Y?ooool205Go06cooooo000doooo
o`<00?l0Y?ooool2003o06cooooo000dooooo`80EOl0Y?ooool305Go06cooooo000cooooo`03003o
001Eo`3ooooo0:Cooooo0P1Eo`1]ooooo`00<oooool205Go0:Gooooo0P1Eo`1]ooooo`00<Oooool0
0`000000EOl005Go002Vooooo`80EOl0KOooool002gooooo0P000000100A0000000005Go0000o`03
05EEo`@00000X?ooool205Go06gooooo000Tooooo`D0000000<0E@000140000A00001P000000101E
ZZX0000005FZZP2=SHd305FZZP0300000?oooooooooo09kooooo0P00o`1]ooooo`008_ooool20000
0003014000000000000000P0000000<0Z_oo0000000000000`0000000`1EEOl0EJZZ05FZZP0205FZ
ZP0300000?oooooooooo09gooooo0P1Eo`1]ooooo`00:?ooool4000000060=cLg00000000000oooo
o`000000ojZZ1@00000305FZZP0300000?oooooooooo09gooooo00<0EOl0ooooooooool0K?ooool0
02Oooooo0P0000001@3ool`0g=cL0=cLg03Lg=`0000000;ooooo00<000000<bIV@2m_Kd00P000002
05EEo`040000002ZEJX0EEGo000009oooooo00<0EOl0ooooooooool0K?ooool002Cooooo10000000
0`3Lg=`0Z_oo0=cLg002000000;ooooo0P0000020?nZZPH000000P1EZZX00`00003oooooooooo`2L
ooooo`0305Go0?oooooooooo06cooooo000Rooooo`800000103Lg=`00`000000Z_oo00000003oooo
o`8000000`3oZZX00`000000ojZZ0000000305FZZP<00000W_ooool00`1Eo`3oooooooooo`1/oooo
o`008_ooool4000000030?ooc000003ooooo00Gooooo00<000000<bIc03oZZX00P3oZZX010000000
ojZZ0<bIc000000305FZZP0300000?oooooooooo09gooooo00<00?l0ooooooooool0K?ooool0027o
oooo0P000002ooooo`8000001oooool00`000000c9VI0?nZZP020?nZZP040000003oZZX0c9VI0000
00<0EJZZ00<00000ooooooooool0W?ooool00`1Eo`000000ooooo`1]ooooo`00;Oooool200000004
0<bIV@3oZZX0ojZZ0?nZZPD000000P1EZZX00`00003oooooooooo`2Jooooo`0300000?ooool0EOl0
00H00000JOooool002gooooo00<000000<bIV@3<VIT00P3<VIT2000000?ooooo00@000000:YEZP1E
EOl00000Voooool00`000000c3<c000000020000000308f=S@000000000000800000JOooool002ko
oooo10000006ooooo`<00000Voooool20000000306IV<`000000000000H00000J?ooool00=Oooooo
1`0000000`2ZEOl00000ooooo`1Xooooo`00fOooool00`00003oooooooooo`02ooooo`<00000J?oo
ool00=oooooo00<00000ooooooooool0Ioooool00?ooooooB_ooool00?ooooooB_ooool00?oooooo
B_ooool00?ooooooB_ooool00?ooooooB_ooool00?ooooooB_ooool00?ooooooB_ooool00?oooooo
B_ooool00?ooooooB_ooool00001\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{329, 540},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Visualizing growth stages of an artificial plant modeled by the D0L-system \
of Figure 1. The numbers in brackets mark the number of production iterations \
starting from the axiom \[Alpha] = ",
  StyleBox["sprout(4)",
    FontSlant->"Italic"],
  "."
}], "NumberedFigure"],

Cell["\<\
Further examples of turtle interpretations of L-system strings will \
be presented in the following chapters.\
\>", "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
ScreenStyleEnvironment->"Working",
WindowToolbars->"RulerBar",
WindowSize->{970, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PageHeaders->{{Inherited, Inherited, Inherited}, {Cell[ 
        TextData[ {"L-Systems for Plantlike Structures"}]], Inherited, 
      Inherited}},
PrintingOptions->{"FirstPageHeader"->False},
Magnification->1,
StyleDefinitions -> \
FrontEnd`FileName[{ParentDirectory[ParentDirectory[ParentDirectory[]]], \
"IEC-Setup"}, "EvolvicaStyle.nb", CharacterEncoding -> "WindowsANSI"]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 51, 0, 96, "Title"],
Cell[1781, 54, 104, 3, 62, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1910, 61, 49, 0, 78, "Section"],
Cell[1962, 63, 1724, 40, 116, "Text"],
Cell[3689, 105, 237, 7, 26, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3963, 117, 57, 0, 62, "Section"],
Cell[4023, 119, 1111, 31, 62, "Text"],
Cell[5137, 152, 17, 0, 26, "Text"],
Cell[5157, 154, 3503, 140, 590, "Text"],
Cell[8663, 296, 403, 9, 64, "NumberedFigure"],
Cell[9069, 307, 681, 12, 98, "Text"],
Cell[9753, 321, 17, 0, 26, "Text"],
Cell[9773, 323, 91157, 1129, 610, 91043, 1125, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[100933, 1454, 291, 7, 64, "NumberedFigure"],
Cell[101227, 1463, 133, 3, 26, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

